/*!
 * Vue.js v2.6.12
 * (c) 2014-2020 Evan You
 * Released under the MIT License.
 */
/*  */

var emptyObject = Object.freeze({});

// These helpers produce better VM code in JS engines due to their
// explicitness and function inlining.
function isUndef (v) {
  return v === undefined || v === null
}

function isDef (v) {
  return v !== undefined && v !== null
}

function isTrue (v) {
  return v === true
}

function isFalse (v) {
  return v === false
}

/**
 * Check if value is primitive.
 */
function isPrimitive (value) {
  return (
    typeof value === 'string' ||
    typeof value === 'number' ||
    // $flow-disable-line
    typeof value === 'symbol' ||
    typeof value === 'boolean'
  )
}

/**
 * Quick object check - this is primarily used to tell
 * Objects from primitive values when we know the value
 * is a JSON-compliant type.
 */
function isObject (obj) {
  return obj !== null && typeof obj === 'object'
}

/**
 * Get the raw type string of a value, e.g., [object Object].
 */
var _toString = Object.prototype.toString;

function toRawType (value) {
  return _toString.call(value).slice(8, -1)
}

/**
 * Strict object type check. Only returns true
 * for plain JavaScript objects.
 */
function isPlainObject (obj) {
  return _toString.call(obj) === '[object Object]'
}

function isRegExp (v) {
  return _toString.call(v) === '[object RegExp]'
}

/**
 * Check if val is a valid array index.
 */
function isValidArrayIndex (val) {
  var n = parseFloat(String(val));
  return n >= 0 && Math.floor(n) === n && isFinite(val)
}

function isPromise (val) {
  return (
    isDef(val) &&
    typeof val.then === 'function' &&
    typeof val.catch === 'function'
  )
}

/**
 * Convert a value to a string that is actually rendered.
 */
function toString (val) {
  return val == null
    ? ''
    : Array.isArray(val) || (isPlainObject(val) && val.toString === _toString)
      ? JSON.stringify(val, null, 2)
      : String(val)
}

/**
 * Convert an input value to a number for persistence.
 * If the conversion fails, return original string.
 */
function toNumber (val) {
  var n = parseFloat(val);
  return isNaN(n) ? val : n
}

/**
 * Make a map and return a function for checking if a key
 * is in that map.
 */
function makeMap (
  str,
  expectsLowerCase
) {
  var map = Object.create(null);
  var list = str.split(',');
  for (var i = 0; i < list.length; i++) {
    map[list[i]] = true;
  }
  return expectsLowerCase
    ? function (val) { return map[val.toLowerCase()]; }
    : function (val) { return map[val]; }
}

/**
 * Check if a tag is a built-in tag.
 */
var isBuiltInTag = makeMap('slot,component', true);

/**
 * Check if an attribute is a reserved attribute.
 */
var isReservedAttribute = makeMap('key,ref,slot,slot-scope,is');

/**
 * Remove an item from an array.
 */
function remove (arr, item) {
  if (arr.length) {
    var index = arr.indexOf(item);
    if (index > -1) {
      return arr.splice(index, 1)
    }
  }
}

/**
 * Check whether an object has the property.
 */
var hasOwnProperty = Object.prototype.hasOwnProperty;
function hasOwn (obj, key) {
  return hasOwnProperty.call(obj, key)
}

/**
 * Create a cached version of a pure function.
 */
function cached (fn) {
  var cache = Object.create(null);
  return (function cachedFn (str) {
    var hit = cache[str];
    return hit || (cache[str] = fn(str))
  })
}

/**
 * Camelize a hyphen-delimited string.
 */
var camelizeRE = /-(\w)/g;
var camelize = cached(function (str) {
  return str.replace(camelizeRE, function (_, c) { return c ? c.toUpperCase() : ''; })
});

/**
 * Capitalize a string.
 */
var capitalize = cached(function (str) {
  return str.charAt(0).toUpperCase() + str.slice(1)
});

/**
 * Hyphenate a camelCase string.
 */
var hyphenateRE = /\B([A-Z])/g;
var hyphenate = cached(function (str) {
  return str.replace(hyphenateRE, '-$1').toLowerCase()
});

/**
 * Simple bind polyfill for environments that do not support it,
 * e.g., PhantomJS 1.x. Technically, we don't need this anymore
 * since native bind is now performant enough in most browsers.
 * But removing it would mean breaking code that was able to run in
 * PhantomJS 1.x, so this must be kept for backward compatibility.
 */

/* istanbul ignore next */
function polyfillBind (fn, ctx) {
  function boundFn (a) {
    var l = arguments.length;
    return l
      ? l > 1
        ? fn.apply(ctx, arguments)
        : fn.call(ctx, a)
      : fn.call(ctx)
  }

  boundFn._length = fn.length;
  return boundFn
}

function nativeBind (fn, ctx) {
  return fn.bind(ctx)
}

var bind = Function.prototype.bind
  ? nativeBind
  : polyfillBind;

/**
 * Convert an Array-like object to a real Array.
 */
function toArray (list, start) {
  start = start || 0;
  var i = list.length - start;
  var ret = new Array(i);
  while (i--) {
    ret[i] = list[i + start];
  }
  return ret
}

/**
 * Mix properties into target object.
 */
function extend (to, _from) {
  for (var key in _from) {
    to[key] = _from[key];
  }
  return to
}

/**
 * Merge an Array of Objects into a single Object.
 */
function toObject (arr) {
  var res = {};
  for (var i = 0; i < arr.length; i++) {
    if (arr[i]) {
      extend(res, arr[i]);
    }
  }
  return res
}

/* eslint-disable no-unused-vars */

/**
 * Perform no operation.
 * Stubbing args to make Flow happy without leaving useless transpiled code
 * with ...rest (https://flow.org/blog/2017/05/07/Strict-Function-Call-Arity/).
 */
function noop (a, b, c) {}

/**
 * Always return false.
 */
var no = function (a, b, c) { return false; };

/* eslint-enable no-unused-vars */

/**
 * Return the same value.
 */
var identity = function (_) { return _; };

/**
 * Generate a string containing static keys from compiler modules.
 */
function genStaticKeys (modules) {
  return modules.reduce(function (keys, m) {
    return keys.concat(m.staticKeys || [])
  }, []).join(',')
}

/**
 * Check if two values are loosely equal - that is,
 * if they are plain objects, do they have the same shape?
 */
function looseEqual (a, b) {
  if (a === b) { return true }
  var isObjectA = isObject(a);
  var isObjectB = isObject(b);
  if (isObjectA && isObjectB) {
    try {
      var isArrayA = Array.isArray(a);
      var isArrayB = Array.isArray(b);
      if (isArrayA && isArrayB) {
        return a.length === b.length && a.every(function (e, i) {
          return looseEqual(e, b[i])
        })
      } else if (a instanceof Date && b instanceof Date) {
        return a.getTime() === b.getTime()
      } else if (!isArrayA && !isArrayB) {
        var keysA = Object.keys(a);
        var keysB = Object.keys(b);
        return keysA.length === keysB.length && keysA.every(function (key) {
          return looseEqual(a[key], b[key])
        })
      } else {
        /* istanbul ignore next */
        return false
      }
    } catch (e) {
      /* istanbul ignore next */
      return false
    }
  } else if (!isObjectA && !isObjectB) {
    return String(a) === String(b)
  } else {
    return false
  }
}

/**
 * Return the first index at which a loosely equal value can be
 * found in the array (if value is a plain object, the array must
 * contain an object of the same shape), or -1 if it is not present.
 */
function looseIndexOf (arr, val) {
  for (var i = 0; i < arr.length; i++) {
    if (looseEqual(arr[i], val)) { return i }
  }
  return -1
}

/**
 * Ensure a function is called only once.
 */
function once (fn) {
  var called = false;
  return function () {
    if (!called) {
      called = true;
      fn.apply(this, arguments);
    }
  }
}

var SSR_ATTR = 'data-server-rendered';

var ASSET_TYPES = [
  'component',
  'directive',
  'filter'
];

var LIFECYCLE_HOOKS = [
  'beforeCreate',
  'created',
  'beforeMount',
  'mounted',
  'beforeUpdate',
  'updated',
  'beforeDestroy',
  'destroyed',
  'activated',
  'deactivated',
  'errorCaptured',
  'serverPrefetch'
];

/*  */



var config = ({
  /**
   * Option merge strategies (used in core/util/options)
   */
  // $flow-disable-line
  optionMergeStrategies: Object.create(null),

  /**
   * Whether to suppress warnings.
   */
  silent: false,

  /**
   * Show production mode tip message on boot?
   */
  productionTip: "development" !== 'production',

  /**
   * Whether to enable devtools
   */
  devtools: "development" !== 'production',

  /**
   * Whether to record perf
   */
  performance: false,

  /**
   * Error handler for watcher errors
   */
  errorHandler: null,

  /**
   * Warn handler for watcher warns
   */
  warnHandler: null,

  /**
   * Ignore certain custom elements
   */
  ignoredElements: [],

  /**
   * Custom user key aliases for v-on
   */
  // $flow-disable-line
  keyCodes: Object.create(null),

  /**
   * Check if a tag is reserved so that it cannot be registered as a
   * component. This is platform-dependent and may be overwritten.
   */
  isReservedTag: no,

  /**
   * Check if an attribute is reserved so that it cannot be used as a component
   * prop. This is platform-dependent and may be overwritten.
   */
  isReservedAttr: no,

  /**
   * Check if a tag is an unknown element.
   * Platform-dependent.
   */
  isUnknownElement: no,

  /**
   * Get the namespace of an element
   */
  getTagNamespace: noop,

  /**
   * Parse the real tag name for the specific platform.
   */
  parsePlatformTagName: identity,

  /**
   * Check if an attribute must be bound using property, e.g. value
   * Platform-dependent.
   */
  mustUseProp: no,

  /**
   * Perform updates asynchronously. Intended to be used by Vue Test Utils
   * This will significantly reduce performance if set to false.
   */
  async: true,

  /**
   * Exposed for legacy reasons
   */
  _lifecycleHooks: LIFECYCLE_HOOKS
});

/*  */

/**
 * unicode letters used for parsing html tags, component names and property paths.
 * using https://www.w3.org/TR/html53/semantics-scripting.html#potentialcustomelementname
 * skipping \u10000-\uEFFFF due to it freezing up PhantomJS
 */
var unicodeRegExp = /a-zA-Z\u00B7\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u037D\u037F-\u1FFF\u200C-\u200D\u203F-\u2040\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD/;

/**
 * Check if a string starts with $ or _
 */
function isReserved (str) {
  var c = (str + '').charCodeAt(0);
  return c === 0x24 || c === 0x5F
}

/**
 * Define a property.
 */
function def (obj, key, val, enumerable) {
  Object.defineProperty(obj, key, {
    value: val,
    enumerable: !!enumerable,
    writable: true,
    configurable: true
  });
}

/**
 * Parse simple path.
 */
var bailRE = new RegExp(("[^" + (unicodeRegExp.source) + ".$_\\d]"));
function parsePath (path) {
  if (bailRE.test(path)) {
    return
  }
  var segments = path.split('.');
  return function (obj) {
    for (var i = 0; i < segments.length; i++) {
      if (!obj) { return }
      obj = obj[segments[i]];
    }
    return obj
  }
}

/*  */

// can we use __proto__?
var hasProto = '__proto__' in {};

// Browser environment sniffing
var inBrowser = typeof window !== 'undefined';
var inWeex = typeof WXEnvironment !== 'undefined' && !!WXEnvironment.platform;
var weexPlatform = inWeex && WXEnvironment.platform.toLowerCase();
var UA = inBrowser && window.navigator.userAgent.toLowerCase();
var isIE = UA && /msie|trident/.test(UA);
var isIE9 = UA && UA.indexOf('msie 9.0') > 0;
var isEdge = UA && UA.indexOf('edge/') > 0;
var isAndroid = (UA && UA.indexOf('android') > 0) || (weexPlatform === 'android');
var isIOS = (UA && /iphone|ipad|ipod|ios/.test(UA)) || (weexPlatform === 'ios');
var isChrome = UA && /chrome\/\d+/.test(UA) && !isEdge;
var isPhantomJS = UA && /phantomjs/.test(UA);
var isFF = UA && UA.match(/firefox\/(\d+)/);

// Firefox has a "watch" function on Object.prototype...
var nativeWatch = ({}).watch;

var supportsPassive = false;
if (inBrowser) {
  try {
    var opts = {};
    Object.defineProperty(opts, 'passive', ({
      get: function get () {
        /* istanbul ignore next */
        supportsPassive = true;
      }
    })); // https://github.com/facebook/flow/issues/285
    window.addEventListener('test-passive', null, opts);
  } catch (e) {}
}

// this needs to be lazy-evaled because vue may be required before
// vue-server-renderer can set VUE_ENV
var _isServer;
var isServerRendering = function () {
  if (_isServer === undefined) {
    /* istanbul ignore if */
    if (!inBrowser && !inWeex && typeof global !== 'undefined') {
      // detect presence of vue-server-renderer and avoid
      // Webpack shimming the process
      _isServer = global['process'] && global['process'].env.VUE_ENV === 'server';
    } else {
      _isServer = false;
    }
  }
  return _isServer
};

// detect devtools
var devtools = inBrowser && window.__VUE_DEVTOOLS_GLOBAL_HOOK__;

/* istanbul ignore next */
function isNative (Ctor) {
  return typeof Ctor === 'function' && /native code/.test(Ctor.toString())
}

var hasSymbol =
  typeof Symbol !== 'undefined' && isNative(Symbol) &&
  typeof Reflect !== 'undefined' && isNative(Reflect.ownKeys);

var _Set;
/* istanbul ignore if */ // $flow-disable-line
if (typeof Set !== 'undefined' && isNative(Set)) {
  // use native Set when available.
  _Set = Set;
} else {
  // a non-standard Set polyfill that only works with primitive keys.
  _Set = /*@__PURE__*/(function () {
    function Set () {
      this.set = Object.create(null);
    }
    Set.prototype.has = function has (key) {
      return this.set[key] === true
    };
    Set.prototype.add = function add (key) {
      this.set[key] = true;
    };
    Set.prototype.clear = function clear () {
      this.set = Object.create(null);
    };

    return Set;
  }());
}

/*  */

var warn = noop;
var tip = noop;
var generateComponentTrace = (noop); // work around flow check
var formatComponentName = (noop);

{
  var hasConsole = typeof console !== 'undefined';
  var classifyRE = /(?:^|[-_])(\w)/g;
  var classify = function (str) { return str
    .replace(classifyRE, function (c) { return c.toUpperCase(); })
    .replace(/[-_]/g, ''); };

  warn = function (msg, vm) {
    var trace = vm ? generateComponentTrace(vm) : '';

    if (config.warnHandler) {
      config.warnHandler.call(null, msg, vm, trace);
    } else if (hasConsole && (!config.silent)) {
      console.error(("[Vue warn]: " + msg + trace));
    }
  };

  tip = function (msg, vm) {
    if (hasConsole && (!config.silent)) {
      console.warn("[Vue tip]: " + msg + (
        vm ? generateComponentTrace(vm) : ''
      ));
    }
  };

  formatComponentName = function (vm, includeFile) {
    if (vm.$root === vm) {
      return '<Root>'
    }
    var options = typeof vm === 'function' && vm.cid != null
      ? vm.options
      : vm._isVue
        ? vm.$options || vm.constructor.options
        : vm;
    var name = options.name || options._componentTag;
    var file = options.__file;
    if (!name && file) {
      var match = file.match(/([^/\\]+)\.vue$/);
      name = match && match[1];
    }

    return (
      (name ? ("<" + (classify(name)) + ">") : "<Anonymous>") +
      (file && includeFile !== false ? (" at " + file) : '')
    )
  };

  var repeat = function (str, n) {
    var res = '';
    while (n) {
      if (n % 2 === 1) { res += str; }
      if (n > 1) { str += str; }
      n >>= 1;
    }
    return res
  };

  generateComponentTrace = function (vm) {
    if (vm._isVue && vm.$parent) {
      var tree = [];
      var currentRecursiveSequence = 0;
      while (vm) {
        if (tree.length > 0) {
          var last = tree[tree.length - 1];
          if (last.constructor === vm.constructor) {
            currentRecursiveSequence++;
            vm = vm.$parent;
            continue
          } else if (currentRecursiveSequence > 0) {
            tree[tree.length - 1] = [last, currentRecursiveSequence];
            currentRecursiveSequence = 0;
          }
        }
        tree.push(vm);
        vm = vm.$parent;
      }
      return '\n\nfound in\n\n' + tree
        .map(function (vm, i) { return ("" + (i === 0 ? '---> ' : repeat(' ', 5 + i * 2)) + (Array.isArray(vm)
            ? ((formatComponentName(vm[0])) + "... (" + (vm[1]) + " recursive calls)")
            : formatComponentName(vm))); })
        .join('\n')
    } else {
      return ("\n\n(found in " + (formatComponentName(vm)) + ")")
    }
  };
}

/*  */

var uid = 0;

/**
 * A dep is an observable that can have multiple
 * directives subscribing to it.
 */
var Dep = function Dep () {
  this.id = uid++;
  this.subs = [];
};

Dep.prototype.addSub = function addSub (sub) {
  this.subs.push(sub);
};

Dep.prototype.removeSub = function removeSub (sub) {
  remove(this.subs, sub);
};

Dep.prototype.depend = function depend () {
  if (Dep.target) {
    Dep.target.addDep(this);
  }
};

Dep.prototype.notify = function notify () {
  // stabilize the subscriber list first
  var subs = this.subs.slice();
  if ( !config.async) {
    // subs aren't sorted in scheduler if not running async
    // we need to sort them now to make sure they fire in correct
    // order
    subs.sort(function (a, b) { return a.id - b.id; });
  }
  for (var i = 0, l = subs.length; i < l; i++) {
    subs[i].update();
  }
};

// The current target watcher being evaluated.
// This is globally unique because only one watcher
// can be evaluated at a time.
Dep.target = null;
var targetStack = [];

function pushTarget (target) {
  targetStack.push(target);
  Dep.target = target;
}

function popTarget () {
  targetStack.pop();
  Dep.target = targetStack[targetStack.length - 1];
}

/*  */

var VNode = function VNode (
  tag,
  data,
  children,
  text,
  elm,
  context,
  componentOptions,
  asyncFactory
) {
  this.tag = tag;
  this.data = data;
  this.children = children;
  this.text = text;
  this.elm = elm;
  this.ns = undefined;
  this.context = context;
  this.fnContext = undefined;
  this.fnOptions = undefined;
  this.fnScopeId = undefined;
  this.key = data && data.key;
  this.componentOptions = componentOptions;
  this.componentInstance = undefined;
  this.parent = undefined;
  this.raw = false;
  this.isStatic = false;
  this.isRootInsert = true;
  this.isComment = false;
  this.isCloned = false;
  this.isOnce = false;
  this.asyncFactory = asyncFactory;
  this.asyncMeta = undefined;
  this.isAsyncPlaceholder = false;
};

var prototypeAccessors = { child: { configurable: true } };

// DEPRECATED: alias for componentInstance for backwards compat.
/* istanbul ignore next */
prototypeAccessors.child.get = function () {
  return this.componentInstance
};

Object.defineProperties( VNode.prototype, prototypeAccessors );

var createEmptyVNode = function (text) {
  if ( text === void 0 ) text = '';

  var node = new VNode();
  node.text = text;
  node.isComment = true;
  return node
};

function createTextVNode (val) {
  return new VNode(undefined, undefined, undefined, String(val))
}

// optimized shallow clone
// used for static nodes and slot nodes because they may be reused across
// multiple renders, cloning them avoids errors when DOM manipulations rely
// on their elm reference.
function cloneVNode (vnode) {
  var cloned = new VNode(
    vnode.tag,
    vnode.data,
    // #7975
    // clone children array to avoid mutating original in case of cloning
    // a child.
    vnode.children && vnode.children.slice(),
    vnode.text,
    vnode.elm,
    vnode.context,
    vnode.componentOptions,
    vnode.asyncFactory
  );
  cloned.ns = vnode.ns;
  cloned.isStatic = vnode.isStatic;
  cloned.key = vnode.key;
  cloned.isComment = vnode.isComment;
  cloned.fnContext = vnode.fnContext;
  cloned.fnOptions = vnode.fnOptions;
  cloned.fnScopeId = vnode.fnScopeId;
  cloned.asyncMeta = vnode.asyncMeta;
  cloned.isCloned = true;
  return cloned
}

/*
 * not type checking this file because flow doesn't play well with
 * dynamically accessing methods on Array prototype
 */

var arrayProto = Array.prototype;
var arrayMethods = Object.create(arrayProto);

var methodsToPatch = [
  'push',
  'pop',
  'shift',
  'unshift',
  'splice',
  'sort',
  'reverse'
];

/**
 * Intercept mutating methods and emit events
 */
methodsToPatch.forEach(function (method) {
  // cache original method
  var original = arrayProto[method];
  def(arrayMethods, method, function mutator () {
    var args = [], len = arguments.length;
    while ( len-- ) args[ len ] = arguments[ len ];

    var result = original.apply(this, args);
    var ob = this.__ob__;
    var inserted;
    switch (method) {
      case 'push':
      case 'unshift':
        inserted = args;
        break
      case 'splice':
        inserted = args.slice(2);
        break
    }
    if (inserted) { ob.observeArray(inserted); }
    // notify change
    ob.dep.notify();
    return result
  });
});

/*  */

var arrayKeys = Object.getOwnPropertyNames(arrayMethods);

/**
 * In some cases we may want to disable observation inside a component's
 * update computation.
 */
var shouldObserve = true;

function toggleObserving (value) {
  shouldObserve = value;
}

/**
 * Observer class that is attached to each observed
 * object. Once attached, the observer converts the target
 * object's property keys into getter/setters that
 * collect dependencies and dispatch updates.
 */
var Observer = function Observer (value) {
  this.value = value;
  this.dep = new Dep();
  this.vmCount = 0;
  def(value, '__ob__', this);
  if (Array.isArray(value)) {
    if (hasProto) {
      protoAugment(value, arrayMethods);
    } else {
      copyAugment(value, arrayMethods, arrayKeys);
    }
    this.observeArray(value);
  } else {
    this.walk(value);
  }
};

/**
 * Walk through all properties and convert them into
 * getter/setters. This method should only be called when
 * value type is Object.
 */
Observer.prototype.walk = function walk (obj) {
  var keys = Object.keys(obj);
  for (var i = 0; i < keys.length; i++) {
    defineReactive$$1(obj, keys[i]);
  }
};

/**
 * Observe a list of Array items.
 */
Observer.prototype.observeArray = function observeArray (items) {
  for (var i = 0, l = items.length; i < l; i++) {
    observe(items[i]);
  }
};

// helpers

/**
 * Augment a target Object or Array by intercepting
 * the prototype chain using __proto__
 */
function protoAugment (target, src) {
  /* eslint-disable no-proto */
  target.__proto__ = src;
  /* eslint-enable no-proto */
}

/**
 * Augment a target Object or Array by defining
 * hidden properties.
 */
/* istanbul ignore next */
function copyAugment (target, src, keys) {
  for (var i = 0, l = keys.length; i < l; i++) {
    var key = keys[i];
    def(target, key, src[key]);
  }
}

/**
 * Attempt to create an observer instance for a value,
 * returns the new observer if successfully observed,
 * or the existing observer if the value already has one.
 */
function observe (value, asRootData) {
  if (!isObject(value) || value instanceof VNode) {
    return
  }
  var ob;
  if (hasOwn(value, '__ob__') && value.__ob__ instanceof Observer) {
    ob = value.__ob__;
  } else if (
    shouldObserve &&
    !isServerRendering() &&
    (Array.isArray(value) || isPlainObject(value)) &&
    Object.isExtensible(value) &&
    !value._isVue
  ) {
    ob = new Observer(value);
  }
  if (asRootData && ob) {
    ob.vmCount++;
  }
  return ob
}

/**
 * Define a reactive property on an Object.
 */
function defineReactive$$1 (
  obj,
  key,
  val,
  customSetter,
  shallow
) {
  var dep = new Dep();

  var property = Object.getOwnPropertyDescriptor(obj, key);
  if (property && property.configurable === false) {
    return
  }

  // cater for pre-defined getter/setters
  var getter = property && property.get;
  var setter = property && property.set;
  if ((!getter || setter) && arguments.length === 2) {
    val = obj[key];
  }

  var childOb = !shallow && observe(val);
  Object.defineProperty(obj, key, {
    enumerable: true,
    configurable: true,
    get: function reactiveGetter () {
      var value = getter ? getter.call(obj) : val;
      if (Dep.target) {
        dep.depend();
        if (childOb) {
          childOb.dep.depend();
          if (Array.isArray(value)) {
            dependArray(value);
          }
        }
      }
      return value
    },
    set: function reactiveSetter (newVal) {
      var value = getter ? getter.call(obj) : val;
      /* eslint-disable no-self-compare */
      if (newVal === value || (newVal !== newVal && value !== value)) {
        return
      }
      /* eslint-enable no-self-compare */
      if ( customSetter) {
        customSetter();
      }
      // #7981: for accessor properties without setter
      if (getter && !setter) { return }
      if (setter) {
        setter.call(obj, newVal);
      } else {
        val = newVal;
      }
      childOb = !shallow && observe(newVal);
      dep.notify();
    }
  });
}

/**
 * Set a property on an object. Adds the new property and
 * triggers change notification if the property doesn't
 * already exist.
 */
function set (target, key, val) {
  if (
    (isUndef(target) || isPrimitive(target))
  ) {
    warn(("Cannot set reactive property on undefined, null, or primitive value: " + ((target))));
  }
  if (Array.isArray(target) && isValidArrayIndex(key)) {
    target.length = Math.max(target.length, key);
    target.splice(key, 1, val);
    return val
  }
  if (key in target && !(key in Object.prototype)) {
    target[key] = val;
    return val
  }
  var ob = (target).__ob__;
  if (target._isVue || (ob && ob.vmCount)) {
     warn(
      'Avoid adding reactive properties to a Vue instance or its root $data ' +
      'at runtime - declare it upfront in the data option.'
    );
    return val
  }
  if (!ob) {
    target[key] = val;
    return val
  }
  defineReactive$$1(ob.value, key, val);
  ob.dep.notify();
  return val
}

/**
 * Delete a property and trigger change if necessary.
 */
function del (target, key) {
  if (
    (isUndef(target) || isPrimitive(target))
  ) {
    warn(("Cannot delete reactive property on undefined, null, or primitive value: " + ((target))));
  }
  if (Array.isArray(target) && isValidArrayIndex(key)) {
    target.splice(key, 1);
    return
  }
  var ob = (target).__ob__;
  if (target._isVue || (ob && ob.vmCount)) {
     warn(
      'Avoid deleting properties on a Vue instance or its root $data ' +
      '- just set it to null.'
    );
    return
  }
  if (!hasOwn(target, key)) {
    return
  }
  delete target[key];
  if (!ob) {
    return
  }
  ob.dep.notify();
}

/**
 * Collect dependencies on array elements when the array is touched, since
 * we cannot intercept array element access like property getters.
 */
function dependArray (value) {
  for (var e = (void 0), i = 0, l = value.length; i < l; i++) {
    e = value[i];
    e && e.__ob__ && e.__ob__.dep.depend();
    if (Array.isArray(e)) {
      dependArray(e);
    }
  }
}

/*  */

/**
 * Option overwriting strategies are functions that handle
 * how to merge a parent option value and a child option
 * value into the final value.
 */
var strats = config.optionMergeStrategies;

/**
 * Options with restrictions
 */
{
  strats.el = strats.propsData = function (parent, child, vm, key) {
    if (!vm) {
      warn(
        "option \"" + key + "\" can only be used during instance " +
        'creation with the `new` keyword.'
      );
    }
    return defaultStrat(parent, child)
  };
}

/**
 * Helper that recursively merges two data objects together.
 */
function mergeData (to, from) {
  if (!from) { return to }
  var key, toVal, fromVal;

  var keys = hasSymbol
    ? Reflect.ownKeys(from)
    : Object.keys(from);

  for (var i = 0; i < keys.length; i++) {
    key = keys[i];
    // in case the object is already observed...
    if (key === '__ob__') { continue }
    toVal = to[key];
    fromVal = from[key];
    if (!hasOwn(to, key)) {
      set(to, key, fromVal);
    } else if (
      toVal !== fromVal &&
      isPlainObject(toVal) &&
      isPlainObject(fromVal)
    ) {
      mergeData(toVal, fromVal);
    }
  }
  return to
}

/**
 * Data
 */
function mergeDataOrFn (
  parentVal,
  childVal,
  vm
) {
  if (!vm) {
    // in a Vue.extend merge, both should be functions
    if (!childVal) {
      return parentVal
    }
    if (!parentVal) {
      return childVal
    }
    // when parentVal & childVal are both present,
    // we need to return a function that returns the
    // merged result of both functions... no need to
    // check if parentVal is a function here because
    // it has to be a function to pass previous merges.
    return function mergedDataFn () {
      return mergeData(
        typeof childVal === 'function' ? childVal.call(this, this) : childVal,
        typeof parentVal === 'function' ? parentVal.call(this, this) : parentVal
      )
    }
  } else {
    return function mergedInstanceDataFn () {
      // instance merge
      var instanceData = typeof childVal === 'function'
        ? childVal.call(vm, vm)
        : childVal;
      var defaultData = typeof parentVal === 'function'
        ? parentVal.call(vm, vm)
        : parentVal;
      if (instanceData) {
        return mergeData(instanceData, defaultData)
      } else {
        return defaultData
      }
    }
  }
}

strats.data = function (
  parentVal,
  childVal,
  vm
) {
  if (!vm) {
    if (childVal && typeof childVal !== 'function') {
       warn(
        'The "data" option should be a function ' +
        'that returns a per-instance value in component ' +
        'definitions.',
        vm
      );

      return parentVal
    }
    return mergeDataOrFn(parentVal, childVal)
  }

  return mergeDataOrFn(parentVal, childVal, vm)
};

/**
 * Hooks and props are merged as arrays.
 */
function mergeHook (
  parentVal,
  childVal
) {
  var res = childVal
    ? parentVal
      ? parentVal.concat(childVal)
      : Array.isArray(childVal)
        ? childVal
        : [childVal]
    : parentVal;
  return res
    ? dedupeHooks(res)
    : res
}

function dedupeHooks (hooks) {
  var res = [];
  for (var i = 0; i < hooks.length; i++) {
    if (res.indexOf(hooks[i]) === -1) {
      res.push(hooks[i]);
    }
  }
  return res
}

LIFECYCLE_HOOKS.forEach(function (hook) {
  strats[hook] = mergeHook;
});

/**
 * Assets
 *
 * When a vm is present (instance creation), we need to do
 * a three-way merge between constructor options, instance
 * options and parent options.
 */
function mergeAssets (
  parentVal,
  childVal,
  vm,
  key
) {
  var res = Object.create(parentVal || null);
  if (childVal) {
     assertObjectType(key, childVal, vm);
    return extend(res, childVal)
  } else {
    return res
  }
}

ASSET_TYPES.forEach(function (type) {
  strats[type + 's'] = mergeAssets;
});

/**
 * Watchers.
 *
 * Watchers hashes should not overwrite one
 * another, so we merge them as arrays.
 */
strats.watch = function (
  parentVal,
  childVal,
  vm,
  key
) {
  // work around Firefox's Object.prototype.watch...
  if (parentVal === nativeWatch) { parentVal = undefined; }
  if (childVal === nativeWatch) { childVal = undefined; }
  /* istanbul ignore if */
  if (!childVal) { return Object.create(parentVal || null) }
  {
    assertObjectType(key, childVal, vm);
  }
  if (!parentVal) { return childVal }
  var ret = {};
  extend(ret, parentVal);
  for (var key$1 in childVal) {
    var parent = ret[key$1];
    var child = childVal[key$1];
    if (parent && !Array.isArray(parent)) {
      parent = [parent];
    }
    ret[key$1] = parent
      ? parent.concat(child)
      : Array.isArray(child) ? child : [child];
  }
  return ret
};

/**
 * Other object hashes.
 */
strats.props =
strats.methods =
strats.inject =
strats.computed = function (
  parentVal,
  childVal,
  vm,
  key
) {
  if (childVal && "development" !== 'production') {
    assertObjectType(key, childVal, vm);
  }
  if (!parentVal) { return childVal }
  var ret = Object.create(null);
  extend(ret, parentVal);
  if (childVal) { extend(ret, childVal); }
  return ret
};
strats.provide = mergeDataOrFn;

/**
 * Default strategy.
 */
var defaultStrat = function (parentVal, childVal) {
  return childVal === undefined
    ? parentVal
    : childVal
};

/**
 * Validate component names
 */
function checkComponents (options) {
  for (var key in options.components) {
    validateComponentName(key);
  }
}

function validateComponentName (name) {
  if (!new RegExp(("^[a-zA-Z][\\-\\.0-9_" + (unicodeRegExp.source) + "]*$")).test(name)) {
    warn(
      'Invalid component name: "' + name + '". Component names ' +
      'should conform to valid custom element name in html5 specification.'
    );
  }
  if (isBuiltInTag(name) || config.isReservedTag(name)) {
    warn(
      'Do not use built-in or reserved HTML elements as component ' +
      'id: ' + name
    );
  }
}

/**
 * Ensure all props option syntax are normalized into the
 * Object-based format.
 */
function normalizeProps (options, vm) {
  var props = options.props;
  if (!props) { return }
  var res = {};
  var i, val, name;
  if (Array.isArray(props)) {
    i = props.length;
    while (i--) {
      val = props[i];
      if (typeof val === 'string') {
        name = camelize(val);
        res[name] = { type: null };
      } else {
        warn('props must be strings when using array syntax.');
      }
    }
  } else if (isPlainObject(props)) {
    for (var key in props) {
      val = props[key];
      name = camelize(key);
      res[name] = isPlainObject(val)
        ? val
        : { type: val };
    }
  } else {
    warn(
      "Invalid value for option \"props\": expected an Array or an Object, " +
      "but got " + (toRawType(props)) + ".",
      vm
    );
  }
  options.props = res;
}

/**
 * Normalize all injections into Object-based format
 */
function normalizeInject (options, vm) {
  var inject = options.inject;
  if (!inject) { return }
  var normalized = options.inject = {};
  if (Array.isArray(inject)) {
    for (var i = 0; i < inject.length; i++) {
      normalized[inject[i]] = { from: inject[i] };
    }
  } else if (isPlainObject(inject)) {
    for (var key in inject) {
      var val = inject[key];
      normalized[key] = isPlainObject(val)
        ? extend({ from: key }, val)
        : { from: val };
    }
  } else {
    warn(
      "Invalid value for option \"inject\": expected an Array or an Object, " +
      "but got " + (toRawType(inject)) + ".",
      vm
    );
  }
}

/**
 * Normalize raw function directives into object format.
 */
function normalizeDirectives (options) {
  var dirs = options.directives;
  if (dirs) {
    for (var key in dirs) {
      var def$$1 = dirs[key];
      if (typeof def$$1 === 'function') {
        dirs[key] = { bind: def$$1, update: def$$1 };
      }
    }
  }
}

function assertObjectType (name, value, vm) {
  if (!isPlainObject(value)) {
    warn(
      "Invalid value for option \"" + name + "\": expected an Object, " +
      "but got " + (toRawType(value)) + ".",
      vm
    );
  }
}

/**
 * Merge two option objects into a new one.
 * Core utility used in both instantiation and inheritance.
 */
function mergeOptions (
  parent,
  child,
  vm
) {
  {
    checkComponents(child);
  }

  if (typeof child === 'function') {
    child = child.options;
  }

  normalizeProps(child, vm);
  normalizeInject(child, vm);
  normalizeDirectives(child);

  // Apply extends and mixins on the child options,
  // but only if it is a raw options object that isn't
  // the result of another mergeOptions call.
  // Only merged options has the _base property.
  if (!child._base) {
    if (child.extends) {
      parent = mergeOptions(parent, child.extends, vm);
    }
    if (child.mixins) {
      for (var i = 0, l = child.mixins.length; i < l; i++) {
        parent = mergeOptions(parent, child.mixins[i], vm);
      }
    }
  }

  var options = {};
  var key;
  for (key in parent) {
    mergeField(key);
  }
  for (key in child) {
    if (!hasOwn(parent, key)) {
      mergeField(key);
    }
  }
  function mergeField (key) {
    var strat = strats[key] || defaultStrat;
    options[key] = strat(parent[key], child[key], vm, key);
  }
  return options
}

/**
 * Resolve an asset.
 * This function is used because child instances need access
 * to assets defined in its ancestor chain.
 */
function resolveAsset (
  options,
  type,
  id,
  warnMissing
) {
  /* istanbul ignore if */
  if (typeof id !== 'string') {
    return
  }
  var assets = options[type];
  // check local registration variations first
  if (hasOwn(assets, id)) { return assets[id] }
  var camelizedId = camelize(id);
  if (hasOwn(assets, camelizedId)) { return assets[camelizedId] }
  var PascalCaseId = capitalize(camelizedId);
  if (hasOwn(assets, PascalCaseId)) { return assets[PascalCaseId] }
  // fallback to prototype chain
  var res = assets[id] || assets[camelizedId] || assets[PascalCaseId];
  if ( warnMissing && !res) {
    warn(
      'Failed to resolve ' + type.slice(0, -1) + ': ' + id,
      options
    );
  }
  return res
}

/*  */



function validateProp (
  key,
  propOptions,
  propsData,
  vm
) {
  var prop = propOptions[key];
  var absent = !hasOwn(propsData, key);
  var value = propsData[key];
  // boolean casting
  var booleanIndex = getTypeIndex(Boolean, prop.type);
  if (booleanIndex > -1) {
    if (absent && !hasOwn(prop, 'default')) {
      value = false;
    } else if (value === '' || value === hyphenate(key)) {
      // only cast empty string / same name to boolean if
      // boolean has higher priority
      var stringIndex = getTypeIndex(String, prop.type);
      if (stringIndex < 0 || booleanIndex < stringIndex) {
        value = true;
      }
    }
  }
  // check default value
  if (value === undefined) {
    value = getPropDefaultValue(vm, prop, key);
    // since the default value is a fresh copy,
    // make sure to observe it.
    var prevShouldObserve = shouldObserve;
    toggleObserving(true);
    observe(value);
    toggleObserving(prevShouldObserve);
  }
  {
    assertProp(prop, key, value, vm, absent);
  }
  return value
}

/**
 * Get the default value of a prop.
 */
function getPropDefaultValue (vm, prop, key) {
  // no default, return undefined
  if (!hasOwn(prop, 'default')) {
    return undefined
  }
  var def = prop.default;
  // warn against non-factory defaults for Object & Array
  if ( isObject(def)) {
    warn(
      'Invalid default value for prop "' + key + '": ' +
      'Props with type Object/Array must use a factory function ' +
      'to return the default value.',
      vm
    );
  }
  // the raw prop value was also undefined from previous render,
  // return previous default value to avoid unnecessary watcher trigger
  if (vm && vm.$options.propsData &&
    vm.$options.propsData[key] === undefined &&
    vm._props[key] !== undefined
  ) {
    return vm._props[key]
  }
  // call factory function for non-Function types
  // a value is Function if its prototype is function even across different execution context
  return typeof def === 'function' && getType(prop.type) !== 'Function'
    ? def.call(vm)
    : def
}

/**
 * Assert whether a prop is valid.
 */
function assertProp (
  prop,
  name,
  value,
  vm,
  absent
) {
  if (prop.required && absent) {
    warn(
      'Missing required prop: "' + name + '"',
      vm
    );
    return
  }
  if (value == null && !prop.required) {
    return
  }
  var type = prop.type;
  var valid = !type || type === true;
  var expectedTypes = [];
  if (type) {
    if (!Array.isArray(type)) {
      type = [type];
    }
    for (var i = 0; i < type.length && !valid; i++) {
      var assertedType = assertType(value, type[i]);
      expectedTypes.push(assertedType.expectedType || '');
      valid = assertedType.valid;
    }
  }

  if (!valid) {
    warn(
      getInvalidTypeMessage(name, value, expectedTypes),
      vm
    );
    return
  }
  var validator = prop.validator;
  if (validator) {
    if (!validator(value)) {
      warn(
        'Invalid prop: custom validator check failed for prop "' + name + '".',
        vm
      );
    }
  }
}

var simpleCheckRE = /^(String|Number|Boolean|Function|Symbol)$/;

function assertType (value, type) {
  var valid;
  var expectedType = getType(type);
  if (simpleCheckRE.test(expectedType)) {
    var t = typeof value;
    valid = t === expectedType.toLowerCase();
    // for primitive wrapper objects
    if (!valid && t === 'object') {
      valid = value instanceof type;
    }
  } else if (expectedType === 'Object') {
    valid = isPlainObject(value);
  } else if (expectedType === 'Array') {
    valid = Array.isArray(value);
  } else {
    valid = value instanceof type;
  }
  return {
    valid: valid,
    expectedType: expectedType
  }
}

/**
 * Use function string name to check built-in types,
 * because a simple equality check will fail when running
 * across different vms / iframes.
 */
function getType (fn) {
  var match = fn && fn.toString().match(/^\s*function (\w+)/);
  return match ? match[1] : ''
}

function isSameType (a, b) {
  return getType(a) === getType(b)
}

function getTypeIndex (type, expectedTypes) {
  if (!Array.isArray(expectedTypes)) {
    return isSameType(expectedTypes, type) ? 0 : -1
  }
  for (var i = 0, len = expectedTypes.length; i < len; i++) {
    if (isSameType(expectedTypes[i], type)) {
      return i
    }
  }
  return -1
}

function getInvalidTypeMessage (name, value, expectedTypes) {
  var message = "Invalid prop: type check failed for prop \"" + name + "\"." +
    " Expected " + (expectedTypes.map(capitalize).join(', '));
  var expectedType = expectedTypes[0];
  var receivedType = toRawType(value);
  var expectedValue = styleValue(value, expectedType);
  var receivedValue = styleValue(value, receivedType);
  // check if we need to specify expected value
  if (expectedTypes.length === 1 &&
      isExplicable(expectedType) &&
      !isBoolean(expectedType, receivedType)) {
    message += " with value " + expectedValue;
  }
  message += ", got " + receivedType + " ";
  // check if we need to specify received value
  if (isExplicable(receivedType)) {
    message += "with value " + receivedValue + ".";
  }
  return message
}

function styleValue (value, type) {
  if (type === 'String') {
    return ("\"" + value + "\"")
  } else if (type === 'Number') {
    return ("" + (Number(value)))
  } else {
    return ("" + value)
  }
}

function isExplicable (value) {
  var explicitTypes = ['string', 'number', 'boolean'];
  return explicitTypes.some(function (elem) { return value.toLowerCase() === elem; })
}

function isBoolean () {
  var args = [], len = arguments.length;
  while ( len-- ) args[ len ] = arguments[ len ];

  return args.some(function (elem) { return elem.toLowerCase() === 'boolean'; })
}

/*  */

function handleError (err, vm, info) {
  // Deactivate deps tracking while processing error handler to avoid possible infinite rendering.
  // See: https://github.com/vuejs/vuex/issues/1505
  pushTarget();
  try {
    if (vm) {
      var cur = vm;
      while ((cur = cur.$parent)) {
        var hooks = cur.$options.errorCaptured;
        if (hooks) {
          for (var i = 0; i < hooks.length; i++) {
            try {
              var capture = hooks[i].call(cur, err, vm, info) === false;
              if (capture) { return }
            } catch (e) {
              globalHandleError(e, cur, 'errorCaptured hook');
            }
          }
        }
      }
    }
    globalHandleError(err, vm, info);
  } finally {
    popTarget();
  }
}

function invokeWithErrorHandling (
  handler,
  context,
  args,
  vm,
  info
) {
  var res;
  try {
    res = args ? handler.apply(context, args) : handler.call(context);
    if (res && !res._isVue && isPromise(res) && !res._handled) {
      res.catch(function (e) { return handleError(e, vm, info + " (Promise/async)"); });
      // issue #9511
      // avoid catch triggering multiple times when nested calls
      res._handled = true;
    }
  } catch (e) {
    handleError(e, vm, info);
  }
  return res
}

function globalHandleError (err, vm, info) {
  if (config.errorHandler) {
    try {
      return config.errorHandler.call(null, err, vm, info)
    } catch (e) {
      // if the user intentionally throws the original error in the handler,
      // do not log it twice
      if (e !== err) {
        logError(e, null, 'config.errorHandler');
      }
    }
  }
  logError(err, vm, info);
}

function logError (err, vm, info) {
  {
    warn(("Error in " + info + ": \"" + (err.toString()) + "\""), vm);
  }
  /* istanbul ignore else */
  if ((inBrowser || inWeex) && typeof console !== 'undefined') {
    console.error(err);
  } else {
    throw err
  }
}

/*  */

var isUsingMicroTask = false;

var callbacks = [];
var pending = false;

function flushCallbacks () {
  pending = false;
  var copies = callbacks.slice(0);
  callbacks.length = 0;
  for (var i = 0; i < copies.length; i++) {
    copies[i]();
  }
}

// Here we have async deferring wrappers using microtasks.
// In 2.5 we used (macro) tasks (in combination with microtasks).
// However, it has subtle problems when state is changed right before repaint
// (e.g. #6813, out-in transitions).
// Also, using (macro) tasks in event handler would cause some weird behaviors
// that cannot be circumvented (e.g. #7109, #7153, #7546, #7834, #8109).
// So we now use microtasks everywhere, again.
// A major drawback of this tradeoff is that there are some scenarios
// where microtasks have too high a priority and fire in between supposedly
// sequential events (e.g. #4521, #6690, which have workarounds)
// or even between bubbling of the same event (#6566).
var timerFunc;

// The nextTick behavior leverages the microtask queue, which can be accessed
// via either native Promise.then or MutationObserver.
// MutationObserver has wider support, however it is seriously bugged in
// UIWebView in iOS >= 9.3.3 when triggered in touch event handlers. It
// completely stops working after triggering a few times... so, if native
// Promise is available, we will use it:
/* istanbul ignore next, $flow-disable-line */
if (typeof Promise !== 'undefined' && isNative(Promise)) {
  var p = Promise.resolve();
  timerFunc = function () {
    p.then(flushCallbacks);
    // In problematic UIWebViews, Promise.then doesn't completely break, but
    // it can get stuck in a weird state where callbacks are pushed into the
    // microtask queue but the queue isn't being flushed, until the browser
    // needs to do some other work, e.g. handle a timer. Therefore we can
    // "force" the microtask queue to be flushed by adding an empty timer.
    if (isIOS) { setTimeout(noop); }
  };
  isUsingMicroTask = true;
} else if (!isIE && typeof MutationObserver !== 'undefined' && (
  isNative(MutationObserver) ||
  // PhantomJS and iOS 7.x
  MutationObserver.toString() === '[object MutationObserverConstructor]'
)) {
  // Use MutationObserver where native Promise is not available,
  // e.g. PhantomJS, iOS7, Android 4.4
  // (#6466 MutationObserver is unreliable in IE11)
  var counter = 1;
  var observer = new MutationObserver(flushCallbacks);
  var textNode = document.createTextNode(String(counter));
  observer.observe(textNode, {
    characterData: true
  });
  timerFunc = function () {
    counter = (counter + 1) % 2;
    textNode.data = String(counter);
  };
  isUsingMicroTask = true;
} else if (typeof setImmediate !== 'undefined' && isNative(setImmediate)) {
  // Fallback to setImmediate.
  // Technically it leverages the (macro) task queue,
  // but it is still a better choice than setTimeout.
  timerFunc = function () {
    setImmediate(flushCallbacks);
  };
} else {
  // Fallback to setTimeout.
  timerFunc = function () {
    setTimeout(flushCallbacks, 0);
  };
}

function nextTick (cb, ctx) {
  var _resolve;
  callbacks.push(function () {
    if (cb) {
      try {
        cb.call(ctx);
      } catch (e) {
        handleError(e, ctx, 'nextTick');
      }
    } else if (_resolve) {
      _resolve(ctx);
    }
  });
  if (!pending) {
    pending = true;
    timerFunc();
  }
  // $flow-disable-line
  if (!cb && typeof Promise !== 'undefined') {
    return new Promise(function (resolve) {
      _resolve = resolve;
    })
  }
}

/*  */

var mark;
var measure;

{
  var perf = inBrowser && window.performance;
  /* istanbul ignore if */
  if (
    perf &&
    perf.mark &&
    perf.measure &&
    perf.clearMarks &&
    perf.clearMeasures
  ) {
    mark = function (tag) { return perf.mark(tag); };
    measure = function (name, startTag, endTag) {
      perf.measure(name, startTag, endTag);
      perf.clearMarks(startTag);
      perf.clearMarks(endTag);
      // perf.clearMeasures(name)
    };
  }
}

/* not type checking this file because flow doesn't play well with Proxy */

var initProxy;

{
  var allowedGlobals = makeMap(
    'Infinity,undefined,NaN,isFinite,isNaN,' +
    'parseFloat,parseInt,decodeURI,decodeURIComponent,encodeURI,encodeURIComponent,' +
    'Math,Number,Date,Array,Object,Boolean,String,RegExp,Map,Set,JSON,Intl,' +
    'require' // for Webpack/Browserify
  );

  var warnNonPresent = function (target, key) {
    warn(
      "Property or method \"" + key + "\" is not defined on the instance but " +
      'referenced during render. Make sure that this property is reactive, ' +
      'either in the data option, or for class-based components, by ' +
      'initializing the property. ' +
      'See: https://vuejs.org/v2/guide/reactivity.html#Declaring-Reactive-Properties.',
      target
    );
  };

  var warnReservedPrefix = function (target, key) {
    warn(
      "Property \"" + key + "\" must be accessed with \"$data." + key + "\" because " +
      'properties starting with "$" or "_" are not proxied in the Vue instance to ' +
      'prevent conflicts with Vue internals. ' +
      'See: https://vuejs.org/v2/api/#data',
      target
    );
  };

  var hasProxy =
    typeof Proxy !== 'undefined' && isNative(Proxy);

  if (hasProxy) {
    var isBuiltInModifier = makeMap('stop,prevent,self,ctrl,shift,alt,meta,exact');
    config.keyCodes = new Proxy(config.keyCodes, {
      set: function set (target, key, value) {
        if (isBuiltInModifier(key)) {
          warn(("Avoid overwriting built-in modifier in config.keyCodes: ." + key));
          return false
        } else {
          target[key] = value;
          return true
        }
      }
    });
  }

  var hasHandler = {
    has: function has (target, key) {
      var has = key in target;
      var isAllowed = allowedGlobals(key) ||
        (typeof key === 'string' && key.charAt(0) === '_' && !(key in target.$data));
      if (!has && !isAllowed) {
        if (key in target.$data) { warnReservedPrefix(target, key); }
        else { warnNonPresent(target, key); }
      }
      return has || !isAllowed
    }
  };

  var getHandler = {
    get: function get (target, key) {
      if (typeof key === 'string' && !(key in target)) {
        if (key in target.$data) { warnReservedPrefix(target, key); }
        else { warnNonPresent(target, key); }
      }
      return target[key]
    }
  };

  initProxy = function initProxy (vm) {
    if (hasProxy) {
      // determine which proxy handler to use
      var options = vm.$options;
      var handlers = options.render && options.render._withStripped
        ? getHandler
        : hasHandler;
      vm._renderProxy = new Proxy(vm, handlers);
    } else {
      vm._renderProxy = vm;
    }
  };
}

/*  */

var seenObjects = new _Set();

/**
 * Recursively traverse an object to evoke all converted
 * getters, so that every nested property inside the object
 * is collected as a "deep" dependency.
 */
function traverse (val) {
  _traverse(val, seenObjects);
  seenObjects.clear();
}

function _traverse (val, seen) {
  var i, keys;
  var isA = Array.isArray(val);
  if ((!isA && !isObject(val)) || Object.isFrozen(val) || val instanceof VNode) {
    return
  }
  if (val.__ob__) {
    var depId = val.__ob__.dep.id;
    if (seen.has(depId)) {
      return
    }
    seen.add(depId);
  }
  if (isA) {
    i = val.length;
    while (i--) { _traverse(val[i], seen); }
  } else {
    keys = Object.keys(val);
    i = keys.length;
    while (i--) { _traverse(val[keys[i]], seen); }
  }
}

/*  */

var normalizeEvent = cached(function (name) {
  var passive = name.charAt(0) === '&';
  name = passive ? name.slice(1) : name;
  var once$$1 = name.charAt(0) === '~'; // Prefixed last, checked first
  name = once$$1 ? name.slice(1) : name;
  var capture = name.charAt(0) === '!';
  name = capture ? name.slice(1) : name;
  return {
    name: name,
    once: once$$1,
    capture: capture,
    passive: passive
  }
});

function createFnInvoker (fns, vm) {
  function invoker () {
    var arguments$1 = arguments;

    var fns = invoker.fns;
    if (Array.isArray(fns)) {
      var cloned = fns.slice();
      for (var i = 0; i < cloned.length; i++) {
        invokeWithErrorHandling(cloned[i], null, arguments$1, vm, "v-on handler");
      }
    } else {
      // return handler return value for single handlers
      return invokeWithErrorHandling(fns, null, arguments, vm, "v-on handler")
    }
  }
  invoker.fns = fns;
  return invoker
}

function updateListeners (
  on,
  oldOn,
  add,
  remove$$1,
  createOnceHandler,
  vm
) {
  var name, def$$1, cur, old, event;
  for (name in on) {
    def$$1 = cur = on[name];
    old = oldOn[name];
    event = normalizeEvent(name);
    if (isUndef(cur)) {
       warn(
        "Invalid handler for event \"" + (event.name) + "\": got " + String(cur),
        vm
      );
    } else if (isUndef(old)) {
      if (isUndef(cur.fns)) {
        cur = on[name] = createFnInvoker(cur, vm);
      }
      if (isTrue(event.once)) {
        cur = on[name] = createOnceHandler(event.name, cur, event.capture);
      }
      add(event.name, cur, event.capture, event.passive, event.params);
    } else if (cur !== old) {
      old.fns = cur;
      on[name] = old;
    }
  }
  for (name in oldOn) {
    if (isUndef(on[name])) {
      event = normalizeEvent(name);
      remove$$1(event.name, oldOn[name], event.capture);
    }
  }
}

/*  */

function mergeVNodeHook (def, hookKey, hook) {
  if (def instanceof VNode) {
    def = def.data.hook || (def.data.hook = {});
  }
  var invoker;
  var oldHook = def[hookKey];

  function wrappedHook () {
    hook.apply(this, arguments);
    // important: remove merged hook to ensure it's called only once
    // and prevent memory leak
    remove(invoker.fns, wrappedHook);
  }

  if (isUndef(oldHook)) {
    // no existing hook
    invoker = createFnInvoker([wrappedHook]);
  } else {
    /* istanbul ignore if */
    if (isDef(oldHook.fns) && isTrue(oldHook.merged)) {
      // already a merged invoker
      invoker = oldHook;
      invoker.fns.push(wrappedHook);
    } else {
      // existing plain hook
      invoker = createFnInvoker([oldHook, wrappedHook]);
    }
  }

  invoker.merged = true;
  def[hookKey] = invoker;
}

/*  */

function extractPropsFromVNodeData (
  data,
  Ctor,
  tag
) {
  // we are only extracting raw values here.
  // validation and default values are handled in the child
  // component itself.
  var propOptions = Ctor.options.props;
  if (isUndef(propOptions)) {
    return
  }
  var res = {};
  var attrs = data.attrs;
  var props = data.props;
  if (isDef(attrs) || isDef(props)) {
    for (var key in propOptions) {
      var altKey = hyphenate(key);
      {
        var keyInLowerCase = key.toLowerCase();
        if (
          key !== keyInLowerCase &&
          attrs && hasOwn(attrs, keyInLowerCase)
        ) {
          tip(
            "Prop \"" + keyInLowerCase + "\" is passed to component " +
            (formatComponentName(tag || Ctor)) + ", but the declared prop name is" +
            " \"" + key + "\". " +
            "Note that HTML attributes are case-insensitive and camelCased " +
            "props need to use their kebab-case equivalents when using in-DOM " +
            "templates. You should probably use \"" + altKey + "\" instead of \"" + key + "\"."
          );
        }
      }
      checkProp(res, props, key, altKey, true) ||
      checkProp(res, attrs, key, altKey, false);
    }
  }
  return res
}

function checkProp (
  res,
  hash,
  key,
  altKey,
  preserve
) {
  if (isDef(hash)) {
    if (hasOwn(hash, key)) {
      res[key] = hash[key];
      if (!preserve) {
        delete hash[key];
      }
      return true
    } else if (hasOwn(hash, altKey)) {
      res[key] = hash[altKey];
      if (!preserve) {
        delete hash[altKey];
      }
      return true
    }
  }
  return false
}

/*  */

// The template compiler attempts to minimize the need for normalization by
// statically analyzing the template at compile time.
//
// For plain HTML markup, normalization can be completely skipped because the
// generated render function is guaranteed to return Array<VNode>. There are
// two cases where extra normalization is needed:

// 1. When the children contains components - because a functional component
// may return an Array instead of a single root. In this case, just a simple
// normalization is needed - if any child is an Array, we flatten the whole
// thing with Array.prototype.concat. It is guaranteed to be only 1-level deep
// because functional components already normalize their own children.
function simpleNormalizeChildren (children) {
  for (var i = 0; i < children.length; i++) {
    if (Array.isArray(children[i])) {
      return Array.prototype.concat.apply([], children)
    }
  }
  return children
}

// 2. When the children contains constructs that always generated nested Arrays,
// e.g. <template>, <slot>, v-for, or when the children is provided by user
// with hand-written render functions / JSX. In such cases a full normalization
// is needed to cater to all possible types of children values.
function normalizeChildren (children) {
  return isPrimitive(children)
    ? [createTextVNode(children)]
    : Array.isArray(children)
      ? normalizeArrayChildren(children)
      : undefined
}

function isTextNode (node) {
  return isDef(node) && isDef(node.text) && isFalse(node.isComment)
}

function normalizeArrayChildren (children, nestedIndex) {
  var res = [];
  var i, c, lastIndex, last;
  for (i = 0; i < children.length; i++) {
    c = children[i];
    if (isUndef(c) || typeof c === 'boolean') { continue }
    lastIndex = res.length - 1;
    last = res[lastIndex];
    //  nested
    if (Array.isArray(c)) {
      if (c.length > 0) {
        c = normalizeArrayChildren(c, ((nestedIndex || '') + "_" + i));
        // merge adjacent text nodes
        if (isTextNode(c[0]) && isTextNode(last)) {
          res[lastIndex] = createTextVNode(last.text + (c[0]).text);
          c.shift();
        }
        res.push.apply(res, c);
      }
    } else if (isPrimitive(c)) {
      if (isTextNode(last)) {
        // merge adjacent text nodes
        // this is necessary for SSR hydration because text nodes are
        // essentially merged when rendered to HTML strings
        res[lastIndex] = createTextVNode(last.text + c);
      } else if (c !== '') {
        // convert primitive to vnode
        res.push(createTextVNode(c));
      }
    } else {
      if (isTextNode(c) && isTextNode(last)) {
        // merge adjacent text nodes
        res[lastIndex] = createTextVNode(last.text + c.text);
      } else {
        // default key for nested array children (likely generated by v-for)
        if (isTrue(children._isVList) &&
          isDef(c.tag) &&
          isUndef(c.key) &&
          isDef(nestedIndex)) {
          c.key = "__vlist" + nestedIndex + "_" + i + "__";
        }
        res.push(c);
      }
    }
  }
  return res
}

/*  */

function initProvide (vm) {
  var provide = vm.$options.provide;
  if (provide) {
    vm._provided = typeof provide === 'function'
      ? provide.call(vm)
      : provide;
  }
}

function initInjections (vm) {
  var result = resolveInject(vm.$options.inject, vm);
  if (result) {
    toggleObserving(false);
    Object.keys(result).forEach(function (key) {
      /* istanbul ignore else */
      {
        defineReactive$$1(vm, key, result[key], function () {
          warn(
            "Avoid mutating an injected value directly since the changes will be " +
            "overwritten whenever the provided component re-renders. " +
            "injection being mutated: \"" + key + "\"",
            vm
          );
        });
      }
    });
    toggleObserving(true);
  }
}

function resolveInject (inject, vm) {
  if (inject) {
    // inject is :any because flow is not smart enough to figure out cached
    var result = Object.create(null);
    var keys = hasSymbol
      ? Reflect.ownKeys(inject)
      : Object.keys(inject);

    for (var i = 0; i < keys.length; i++) {
      var key = keys[i];
      // #6574 in case the inject object is observed...
      if (key === '__ob__') { continue }
      var provideKey = inject[key].from;
      var source = vm;
      while (source) {
        if (source._provided && hasOwn(source._provided, provideKey)) {
          result[key] = source._provided[provideKey];
          break
        }
        source = source.$parent;
      }
      if (!source) {
        if ('default' in inject[key]) {
          var provideDefault = inject[key].default;
          result[key] = typeof provideDefault === 'function'
            ? provideDefault.call(vm)
            : provideDefault;
        } else {
          warn(("Injection \"" + key + "\" not found"), vm);
        }
      }
    }
    return result
  }
}

/*  */



/**
 * Runtime helper for resolving raw children VNodes into a slot object.
 */
function resolveSlots (
  children,
  context
) {
  if (!children || !children.length) {
    return {}
  }
  var slots = {};
  for (var i = 0, l = children.length; i < l; i++) {
    var child = children[i];
    var data = child.data;
    // remove slot attribute if the node is resolved as a Vue slot node
    if (data && data.attrs && data.attrs.slot) {
      delete data.attrs.slot;
    }
    // named slots should only be respected if the vnode was rendered in the
    // same context.
    if ((child.context === context || child.fnContext === context) &&
      data && data.slot != null
    ) {
      var name = data.slot;
      var slot = (slots[name] || (slots[name] = []));
      if (child.tag === 'template') {
        slot.push.apply(slot, child.children || []);
      } else {
        slot.push(child);
      }
    } else {
      (slots.default || (slots.default = [])).push(child);
    }
  }
  // ignore slots that contains only whitespace
  for (var name$1 in slots) {
    if (slots[name$1].every(isWhitespace)) {
      delete slots[name$1];
    }
  }
  return slots
}

function isWhitespace (node) {
  return (node.isComment && !node.asyncFactory) || node.text === ' '
}

/*  */

function normalizeScopedSlots (
  slots,
  normalSlots,
  prevSlots
) {
  var res;
  var hasNormalSlots = Object.keys(normalSlots).length > 0;
  var isStable = slots ? !!slots.$stable : !hasNormalSlots;
  var key = slots && slots.$key;
  if (!slots) {
    res = {};
  } else if (slots._normalized) {
    // fast path 1: child component re-render only, parent did not change
    return slots._normalized
  } else if (
    isStable &&
    prevSlots &&
    prevSlots !== emptyObject &&
    key === prevSlots.$key &&
    !hasNormalSlots &&
    !prevSlots.$hasNormal
  ) {
    // fast path 2: stable scoped slots w/ no normal slots to proxy,
    // only need to normalize once
    return prevSlots
  } else {
    res = {};
    for (var key$1 in slots) {
      if (slots[key$1] && key$1[0] !== '$') {
        res[key$1] = normalizeScopedSlot(normalSlots, key$1, slots[key$1]);
      }
    }
  }
  // expose normal slots on scopedSlots
  for (var key$2 in normalSlots) {
    if (!(key$2 in res)) {
      res[key$2] = proxyNormalSlot(normalSlots, key$2);
    }
  }
  // avoriaz seems to mock a non-extensible $scopedSlots object
  // and when that is passed down this would cause an error
  if (slots && Object.isExtensible(slots)) {
    (slots)._normalized = res;
  }
  def(res, '$stable', isStable);
  def(res, '$key', key);
  def(res, '$hasNormal', hasNormalSlots);
  return res
}

function normalizeScopedSlot(normalSlots, key, fn) {
  var normalized = function () {
    var res = arguments.length ? fn.apply(null, arguments) : fn({});
    res = res && typeof res === 'object' && !Array.isArray(res)
      ? [res] // single vnode
      : normalizeChildren(res);
    return res && (
      res.length === 0 ||
      (res.length === 1 && res[0].isComment) // #9658
    ) ? undefined
      : res
  };
  // this is a slot using the new v-slot syntax without scope. although it is
  // compiled as a scoped slot, render fn users would expect it to be present
  // on this.$slots because the usage is semantically a normal slot.
  if (fn.proxy) {
    Object.defineProperty(normalSlots, key, {
      get: normalized,
      enumerable: true,
      configurable: true
    });
  }
  return normalized
}

function proxyNormalSlot(slots, key) {
  return function () { return slots[key]; }
}

/*  */

/**
 * Runtime helper for rendering v-for lists.
 */
function renderList (
  val,
  render
) {
  var ret, i, l, keys, key;
  if (Array.isArray(val) || typeof val === 'string') {
    ret = new Array(val.length);
    for (i = 0, l = val.length; i < l; i++) {
      ret[i] = render(val[i], i);
    }
  } else if (typeof val === 'number') {
    ret = new Array(val);
    for (i = 0; i < val; i++) {
      ret[i] = render(i + 1, i);
    }
  } else if (isObject(val)) {
    if (hasSymbol && val[Symbol.iterator]) {
      ret = [];
      var iterator = val[Symbol.iterator]();
      var result = iterator.next();
      while (!result.done) {
        ret.push(render(result.value, ret.length));
        result = iterator.next();
      }
    } else {
      keys = Object.keys(val);
      ret = new Array(keys.length);
      for (i = 0, l = keys.length; i < l; i++) {
        key = keys[i];
        ret[i] = render(val[key], key, i);
      }
    }
  }
  if (!isDef(ret)) {
    ret = [];
  }
  (ret)._isVList = true;
  return ret
}

/*  */

/**
 * Runtime helper for rendering <slot>
 */
function renderSlot (
  name,
  fallback,
  props,
  bindObject
) {
  var scopedSlotFn = this.$scopedSlots[name];
  var nodes;
  if (scopedSlotFn) { // scoped slot
    props = props || {};
    if (bindObject) {
      if ( !isObject(bindObject)) {
        warn(
          'slot v-bind without argument expects an Object',
          this
        );
      }
      props = extend(extend({}, bindObject), props);
    }
    nodes = scopedSlotFn(props) || fallback;
  } else {
    nodes = this.$slots[name] || fallback;
  }

  var target = props && props.slot;
  if (target) {
    return this.$createElement('template', { slot: target }, nodes)
  } else {
    return nodes
  }
}

/*  */

/**
 * Runtime helper for resolving filters
 */
function resolveFilter (id) {
  return resolveAsset(this.$options, 'filters', id, true) || identity
}

/*  */

function isKeyNotMatch (expect, actual) {
  if (Array.isArray(expect)) {
    return expect.indexOf(actual) === -1
  } else {
    return expect !== actual
  }
}

/**
 * Runtime helper for checking keyCodes from config.
 * exposed as Vue.prototype._k
 * passing in eventKeyName as last argument separately for backwards compat
 */
function checkKeyCodes (
  eventKeyCode,
  key,
  builtInKeyCode,
  eventKeyName,
  builtInKeyName
) {
  var mappedKeyCode = config.keyCodes[key] || builtInKeyCode;
  if (builtInKeyName && eventKeyName && !config.keyCodes[key]) {
    return isKeyNotMatch(builtInKeyName, eventKeyName)
  } else if (mappedKeyCode) {
    return isKeyNotMatch(mappedKeyCode, eventKeyCode)
  } else if (eventKeyName) {
    return hyphenate(eventKeyName) !== key
  }
}

/*  */

/**
 * Runtime helper for merging v-bind="object" into a VNode's data.
 */
function bindObjectProps (
  data,
  tag,
  value,
  asProp,
  isSync
) {
  if (value) {
    if (!isObject(value)) {
       warn(
        'v-bind without argument expects an Object or Array value',
        this
      );
    } else {
      if (Array.isArray(value)) {
        value = toObject(value);
      }
      var hash;
      var loop = function ( key ) {
        if (
          key === 'class' ||
          key === 'style' ||
          isReservedAttribute(key)
        ) {
          hash = data;
        } else {
          var type = data.attrs && data.attrs.type;
          hash = asProp || config.mustUseProp(tag, type, key)
            ? data.domProps || (data.domProps = {})
            : data.attrs || (data.attrs = {});
        }
        var camelizedKey = camelize(key);
        var hyphenatedKey = hyphenate(key);
        if (!(camelizedKey in hash) && !(hyphenatedKey in hash)) {
          hash[key] = value[key];

          if (isSync) {
            var on = data.on || (data.on = {});
            on[("update:" + key)] = function ($event) {
              value[key] = $event;
            };
          }
        }
      };

      for (var key in value) loop( key );
    }
  }
  return data
}

/*  */

/**
 * Runtime helper for rendering static trees.
 */
function renderStatic (
  index,
  isInFor
) {
  var cached = this._staticTrees || (this._staticTrees = []);
  var tree = cached[index];
  // if has already-rendered static tree and not inside v-for,
  // we can reuse the same tree.
  if (tree && !isInFor) {
    return tree
  }
  // otherwise, render a fresh tree.
  tree = cached[index] = this.$options.staticRenderFns[index].call(
    this._renderProxy,
    null,
    this // for render fns generated for functional component templates
  );
  markStatic(tree, ("__static__" + index), false);
  return tree
}

/**
 * Runtime helper for v-once.
 * Effectively it means marking the node as static with a unique key.
 */
function markOnce (
  tree,
  index,
  key
) {
  markStatic(tree, ("__once__" + index + (key ? ("_" + key) : "")), true);
  return tree
}

function markStatic (
  tree,
  key,
  isOnce
) {
  if (Array.isArray(tree)) {
    for (var i = 0; i < tree.length; i++) {
      if (tree[i] && typeof tree[i] !== 'string') {
        markStaticNode(tree[i], (key + "_" + i), isOnce);
      }
    }
  } else {
    markStaticNode(tree, key, isOnce);
  }
}

function markStaticNode (node, key, isOnce) {
  node.isStatic = true;
  node.key = key;
  node.isOnce = isOnce;
}

/*  */

function bindObjectListeners (data, value) {
  if (value) {
    if (!isPlainObject(value)) {
       warn(
        'v-on without argument expects an Object value',
        this
      );
    } else {
      var on = data.on = data.on ? extend({}, data.on) : {};
      for (var key in value) {
        var existing = on[key];
        var ours = value[key];
        on[key] = existing ? [].concat(existing, ours) : ours;
      }
    }
  }
  return data
}

/*  */

function resolveScopedSlots (
  fns, // see flow/vnode
  res,
  // the following are added in 2.6
  hasDynamicKeys,
  contentHashKey
) {
  res = res || { $stable: !hasDynamicKeys };
  for (var i = 0; i < fns.length; i++) {
    var slot = fns[i];
    if (Array.isArray(slot)) {
      resolveScopedSlots(slot, res, hasDynamicKeys);
    } else if (slot) {
      // marker for reverse proxying v-slot without scope on this.$slots
      if (slot.proxy) {
        slot.fn.proxy = true;
      }
      res[slot.key] = slot.fn;
    }
  }
  if (contentHashKey) {
    (res).$key = contentHashKey;
  }
  return res
}

/*  */

function bindDynamicKeys (baseObj, values) {
  for (var i = 0; i < values.length; i += 2) {
    var key = values[i];
    if (typeof key === 'string' && key) {
      baseObj[values[i]] = values[i + 1];
    } else if ( key !== '' && key !== null) {
      // null is a special value for explicitly removing a binding
      warn(
        ("Invalid value for dynamic directive argument (expected string or null): " + key),
        this
      );
    }
  }
  return baseObj
}

// helper to dynamically append modifier runtime markers to event names.
// ensure only append when value is already string, otherwise it will be cast
// to string and cause the type check to miss.
function prependModifier (value, symbol) {
  return typeof value === 'string' ? symbol + value : value
}

/*  */

function installRenderHelpers (target) {
  target._o = markOnce;
  target._n = toNumber;
  target._s = toString;
  target._l = renderList;
  target._t = renderSlot;
  target._q = looseEqual;
  target._i = looseIndexOf;
  target._m = renderStatic;
  target._f = resolveFilter;
  target._k = checkKeyCodes;
  target._b = bindObjectProps;
  target._v = createTextVNode;
  target._e = createEmptyVNode;
  target._u = resolveScopedSlots;
  target._g = bindObjectListeners;
  target._d = bindDynamicKeys;
  target._p = prependModifier;
}

/*  */

function FunctionalRenderContext (
  data,
  props,
  children,
  parent,
  Ctor
) {
  var this$1 = this;

  var options = Ctor.options;
  // ensure the createElement function in functional components
  // gets a unique context - this is necessary for correct named slot check
  var contextVm;
  if (hasOwn(parent, '_uid')) {
    contextVm = Object.create(parent);
    // $flow-disable-line
    contextVm._original = parent;
  } else {
    // the context vm passed in is a functional context as well.
    // in this case we want to make sure we are able to get a hold to the
    // real context instance.
    contextVm = parent;
    // $flow-disable-line
    parent = parent._original;
  }
  var isCompiled = isTrue(options._compiled);
  var needNormalization = !isCompiled;

  this.data = data;
  this.props = props;
  this.children = children;
  this.parent = parent;
  this.listeners = data.on || emptyObject;
  this.injections = resolveInject(options.inject, parent);
  this.slots = function () {
    if (!this$1.$slots) {
      normalizeScopedSlots(
        data.scopedSlots,
        this$1.$slots = resolveSlots(children, parent)
      );
    }
    return this$1.$slots
  };

  Object.defineProperty(this, 'scopedSlots', ({
    enumerable: true,
    get: function get () {
      return normalizeScopedSlots(data.scopedSlots, this.slots())
    }
  }));

  // support for compiled functional template
  if (isCompiled) {
    // exposing $options for renderStatic()
    this.$options = options;
    // pre-resolve slots for renderSlot()
    this.$slots = this.slots();
    this.$scopedSlots = normalizeScopedSlots(data.scopedSlots, this.$slots);
  }

  if (options._scopeId) {
    this._c = function (a, b, c, d) {
      var vnode = createElement(contextVm, a, b, c, d, needNormalization);
      if (vnode && !Array.isArray(vnode)) {
        vnode.fnScopeId = options._scopeId;
        vnode.fnContext = parent;
      }
      return vnode
    };
  } else {
    this._c = function (a, b, c, d) { return createElement(contextVm, a, b, c, d, needNormalization); };
  }
}

installRenderHelpers(FunctionalRenderContext.prototype);

function createFunctionalComponent (
  Ctor,
  propsData,
  data,
  contextVm,
  children
) {
  var options = Ctor.options;
  var props = {};
  var propOptions = options.props;
  if (isDef(propOptions)) {
    for (var key in propOptions) {
      props[key] = validateProp(key, propOptions, propsData || emptyObject);
    }
  } else {
    if (isDef(data.attrs)) { mergeProps(props, data.attrs); }
    if (isDef(data.props)) { mergeProps(props, data.props); }
  }

  var renderContext = new FunctionalRenderContext(
    data,
    props,
    children,
    contextVm,
    Ctor
  );

  var vnode = options.render.call(null, renderContext._c, renderContext);

  if (vnode instanceof VNode) {
    return cloneAndMarkFunctionalResult(vnode, data, renderContext.parent, options, renderContext)
  } else if (Array.isArray(vnode)) {
    var vnodes = normalizeChildren(vnode) || [];
    var res = new Array(vnodes.length);
    for (var i = 0; i < vnodes.length; i++) {
      res[i] = cloneAndMarkFunctionalResult(vnodes[i], data, renderContext.parent, options, renderContext);
    }
    return res
  }
}

function cloneAndMarkFunctionalResult (vnode, data, contextVm, options, renderContext) {
  // #7817 clone node before setting fnContext, otherwise if the node is reused
  // (e.g. it was from a cached normal slot) the fnContext causes named slots
  // that should not be matched to match.
  var clone = cloneVNode(vnode);
  clone.fnContext = contextVm;
  clone.fnOptions = options;
  {
    (clone.devtoolsMeta = clone.devtoolsMeta || {}).renderContext = renderContext;
  }
  if (data.slot) {
    (clone.data || (clone.data = {})).slot = data.slot;
  }
  return clone
}

function mergeProps (to, from) {
  for (var key in from) {
    to[camelize(key)] = from[key];
  }
}

/*  */

/*  */

/*  */

/*  */

// inline hooks to be invoked on component VNodes during patch
var componentVNodeHooks = {
  init: function init (vnode, hydrating) {
    if (
      vnode.componentInstance &&
      !vnode.componentInstance._isDestroyed &&
      vnode.data.keepAlive
    ) {
      // kept-alive components, treat as a patch
      var mountedNode = vnode; // work around flow
      componentVNodeHooks.prepatch(mountedNode, mountedNode);
    } else {
      var child = vnode.componentInstance = createComponentInstanceForVnode(
        vnode,
        activeInstance
      );
      child.$mount(hydrating ? vnode.elm : undefined, hydrating);
    }
  },

  prepatch: function prepatch (oldVnode, vnode) {
    var options = vnode.componentOptions;
    var child = vnode.componentInstance = oldVnode.componentInstance;
    updateChildComponent(
      child,
      options.propsData, // updated props
      options.listeners, // updated listeners
      vnode, // new parent vnode
      options.children // new children
    );
  },

  insert: function insert (vnode) {
    var context = vnode.context;
    var componentInstance = vnode.componentInstance;
    if (!componentInstance._isMounted) {
      componentInstance._isMounted = true;
      callHook(componentInstance, 'mounted');
    }
    if (vnode.data.keepAlive) {
      if (context._isMounted) {
        // vue-router#1212
        // During updates, a kept-alive component's child components may
        // change, so directly walking the tree here may call activated hooks
        // on incorrect children. Instead we push them into a queue which will
        // be processed after the whole patch process ended.
        queueActivatedComponent(componentInstance);
      } else {
        activateChildComponent(componentInstance, true /* direct */);
      }
    }
  },

  destroy: function destroy (vnode) {
    var componentInstance = vnode.componentInstance;
    if (!componentInstance._isDestroyed) {
      if (!vnode.data.keepAlive) {
        componentInstance.$destroy();
      } else {
        deactivateChildComponent(componentInstance, true /* direct */);
      }
    }
  }
};

var hooksToMerge = Object.keys(componentVNodeHooks);

function createComponent (
  Ctor,
  data,
  context,
  children,
  tag
) {
  if (isUndef(Ctor)) {
    return
  }

  var baseCtor = context.$options._base;

  // plain options object: turn it into a constructor
  if (isObject(Ctor)) {
    Ctor = baseCtor.extend(Ctor);
  }

  // if at this stage it's not a constructor or an async component factory,
  // reject.
  if (typeof Ctor !== 'function') {
    {
      warn(("Invalid Component definition: " + (String(Ctor))), context);
    }
    return
  }

  // async component
  var asyncFactory;
  if (isUndef(Ctor.cid)) {
    asyncFactory = Ctor;
    Ctor = resolveAsyncComponent(asyncFactory, baseCtor);
    if (Ctor === undefined) {
      // return a placeholder node for async component, which is rendered
      // as a comment node but preserves all the raw information for the node.
      // the information will be used for async server-rendering and hydration.
      return createAsyncPlaceholder(
        asyncFactory,
        data,
        context,
        children,
        tag
      )
    }
  }

  data = data || {};

  // resolve constructor options in case global mixins are applied after
  // component constructor creation
  resolveConstructorOptions(Ctor);

  // transform component v-model data into props & events
  if (isDef(data.model)) {
    transformModel(Ctor.options, data);
  }

  // extract props
  var propsData = extractPropsFromVNodeData(data, Ctor, tag);

  // functional component
  if (isTrue(Ctor.options.functional)) {
    return createFunctionalComponent(Ctor, propsData, data, context, children)
  }

  // extract listeners, since these needs to be treated as
  // child component listeners instead of DOM listeners
  var listeners = data.on;
  // replace with listeners with .native modifier
  // so it gets processed during parent component patch.
  data.on = data.nativeOn;

  if (isTrue(Ctor.options.abstract)) {
    // abstract components do not keep anything
    // other than props & listeners & slot

    // work around flow
    var slot = data.slot;
    data = {};
    if (slot) {
      data.slot = slot;
    }
  }

  // install component management hooks onto the placeholder node
  installComponentHooks(data);

  // return a placeholder vnode
  var name = Ctor.options.name || tag;
  var vnode = new VNode(
    ("vue-component-" + (Ctor.cid) + (name ? ("-" + name) : '')),
    data, undefined, undefined, undefined, context,
    { Ctor: Ctor, propsData: propsData, listeners: listeners, tag: tag, children: children },
    asyncFactory
  );

  return vnode
}

function createComponentInstanceForVnode (
  vnode, // we know it's MountedComponentVNode but flow doesn't
  parent // activeInstance in lifecycle state
) {
  var options = {
    _isComponent: true,
    _parentVnode: vnode,
    parent: parent
  };
  // check inline-template render functions
  var inlineTemplate = vnode.data.inlineTemplate;
  if (isDef(inlineTemplate)) {
    options.render = inlineTemplate.render;
    options.staticRenderFns = inlineTemplate.staticRenderFns;
  }
  return new vnode.componentOptions.Ctor(options)
}

function installComponentHooks (data) {
  var hooks = data.hook || (data.hook = {});
  for (var i = 0; i < hooksToMerge.length; i++) {
    var key = hooksToMerge[i];
    var existing = hooks[key];
    var toMerge = componentVNodeHooks[key];
    if (existing !== toMerge && !(existing && existing._merged)) {
      hooks[key] = existing ? mergeHook$1(toMerge, existing) : toMerge;
    }
  }
}

function mergeHook$1 (f1, f2) {
  var merged = function (a, b) {
    // flow complains about extra args which is why we use any
    f1(a, b);
    f2(a, b);
  };
  merged._merged = true;
  return merged
}

// transform component v-model info (value and callback) into
// prop and event handler respectively.
function transformModel (options, data) {
  var prop = (options.model && options.model.prop) || 'value';
  var event = (options.model && options.model.event) || 'input'
  ;(data.attrs || (data.attrs = {}))[prop] = data.model.value;
  var on = data.on || (data.on = {});
  var existing = on[event];
  var callback = data.model.callback;
  if (isDef(existing)) {
    if (
      Array.isArray(existing)
        ? existing.indexOf(callback) === -1
        : existing !== callback
    ) {
      on[event] = [callback].concat(existing);
    }
  } else {
    on[event] = callback;
  }
}

/*  */

var SIMPLE_NORMALIZE = 1;
var ALWAYS_NORMALIZE = 2;

// wrapper function for providing a more flexible interface
// without getting yelled at by flow
function createElement (
  context,
  tag,
  data,
  children,
  normalizationType,
  alwaysNormalize
) {
  if (Array.isArray(data) || isPrimitive(data)) {
    normalizationType = children;
    children = data;
    data = undefined;
  }
  if (isTrue(alwaysNormalize)) {
    normalizationType = ALWAYS_NORMALIZE;
  }
  return _createElement(context, tag, data, children, normalizationType)
}

function _createElement (
  context,
  tag,
  data,
  children,
  normalizationType
) {
  if (isDef(data) && isDef((data).__ob__)) {
     warn(
      "Avoid using observed data object as vnode data: " + (JSON.stringify(data)) + "\n" +
      'Always create fresh vnode data objects in each render!',
      context
    );
    return createEmptyVNode()
  }
  // object syntax in v-bind
  if (isDef(data) && isDef(data.is)) {
    tag = data.is;
  }
  if (!tag) {
    // in case of component :is set to falsy value
    return createEmptyVNode()
  }
  // warn against non-primitive key
  if (
    isDef(data) && isDef(data.key) && !isPrimitive(data.key)
  ) {
    {
      warn(
        'Avoid using non-primitive value as key, ' +
        'use string/number value instead.',
        context
      );
    }
  }
  // support single function children as default scoped slot
  if (Array.isArray(children) &&
    typeof children[0] === 'function'
  ) {
    data = data || {};
    data.scopedSlots = { default: children[0] };
    children.length = 0;
  }
  if (normalizationType === ALWAYS_NORMALIZE) {
    children = normalizeChildren(children);
  } else if (normalizationType === SIMPLE_NORMALIZE) {
    children = simpleNormalizeChildren(children);
  }
  var vnode, ns;
  if (typeof tag === 'string') {
    var Ctor;
    ns = (context.$vnode && context.$vnode.ns) || config.getTagNamespace(tag);
    if (config.isReservedTag(tag)) {
      // platform built-in elements
      if ( isDef(data) && isDef(data.nativeOn)) {
        warn(
          ("The .native modifier for v-on is only valid on components but it was used on <" + tag + ">."),
          context
        );
      }
      vnode = new VNode(
        config.parsePlatformTagName(tag), data, children,
        undefined, undefined, context
      );
    } else if ((!data || !data.pre) && isDef(Ctor = resolveAsset(context.$options, 'components', tag))) {
      // component
      vnode = createComponent(Ctor, data, context, children, tag);
    } else {
      // unknown or unlisted namespaced elements
      // check at runtime because it may get assigned a namespace when its
      // parent normalizes children
      vnode = new VNode(
        tag, data, children,
        undefined, undefined, context
      );
    }
  } else {
    // direct component options / constructor
    vnode = createComponent(tag, data, context, children);
  }
  if (Array.isArray(vnode)) {
    return vnode
  } else if (isDef(vnode)) {
    if (isDef(ns)) { applyNS(vnode, ns); }
    if (isDef(data)) { registerDeepBindings(data); }
    return vnode
  } else {
    return createEmptyVNode()
  }
}

function applyNS (vnode, ns, force) {
  vnode.ns = ns;
  if (vnode.tag === 'foreignObject') {
    // use default namespace inside foreignObject
    ns = undefined;
    force = true;
  }
  if (isDef(vnode.children)) {
    for (var i = 0, l = vnode.children.length; i < l; i++) {
      var child = vnode.children[i];
      if (isDef(child.tag) && (
        isUndef(child.ns) || (isTrue(force) && child.tag !== 'svg'))) {
        applyNS(child, ns, force);
      }
    }
  }
}

// ref #5318
// necessary to ensure parent re-render when deep bindings like :style and
// :class are used on slot nodes
function registerDeepBindings (data) {
  if (isObject(data.style)) {
    traverse(data.style);
  }
  if (isObject(data.class)) {
    traverse(data.class);
  }
}

/*  */

function initRender (vm) {
  vm._vnode = null; // the root of the child tree
  vm._staticTrees = null; // v-once cached trees
  var options = vm.$options;
  var parentVnode = vm.$vnode = options._parentVnode; // the placeholder node in parent tree
  var renderContext = parentVnode && parentVnode.context;
  vm.$slots = resolveSlots(options._renderChildren, renderContext);
  vm.$scopedSlots = emptyObject;
  // bind the createElement fn to this instance
  // so that we get proper render context inside it.
  // args order: tag, data, children, normalizationType, alwaysNormalize
  // internal version is used by render functions compiled from templates
  vm._c = function (a, b, c, d) { return createElement(vm, a, b, c, d, false); };
  // normalization is always applied for the public version, used in
  // user-written render functions.
  vm.$createElement = function (a, b, c, d) { return createElement(vm, a, b, c, d, true); };

  // $attrs & $listeners are exposed for easier HOC creation.
  // they need to be reactive so that HOCs using them are always updated
  var parentData = parentVnode && parentVnode.data;

  /* istanbul ignore else */
  {
    defineReactive$$1(vm, '$attrs', parentData && parentData.attrs || emptyObject, function () {
      !isUpdatingChildComponent && warn("$attrs is readonly.", vm);
    }, true);
    defineReactive$$1(vm, '$listeners', options._parentListeners || emptyObject, function () {
      !isUpdatingChildComponent && warn("$listeners is readonly.", vm);
    }, true);
  }
}

var currentRenderingInstance = null;

function renderMixin (Vue) {
  // install runtime convenience helpers
  installRenderHelpers(Vue.prototype);

  Vue.prototype.$nextTick = function (fn) {
    return nextTick(fn, this)
  };

  Vue.prototype._render = function () {
    var vm = this;
    var ref = vm.$options;
    var render = ref.render;
    var _parentVnode = ref._parentVnode;

    if (_parentVnode) {
      vm.$scopedSlots = normalizeScopedSlots(
        _parentVnode.data.scopedSlots,
        vm.$slots,
        vm.$scopedSlots
      );
    }

    // set parent vnode. this allows render functions to have access
    // to the data on the placeholder node.
    vm.$vnode = _parentVnode;
    // render self
    var vnode;
    try {
      // There's no need to maintain a stack because all render fns are called
      // separately from one another. Nested component's render fns are called
      // when parent component is patched.
      currentRenderingInstance = vm;
      vnode = render.call(vm._renderProxy, vm.$createElement);
    } catch (e) {
      handleError(e, vm, "render");
      // return error render result,
      // or previous vnode to prevent render error causing blank component
      /* istanbul ignore else */
      if ( vm.$options.renderError) {
        try {
          vnode = vm.$options.renderError.call(vm._renderProxy, vm.$createElement, e);
        } catch (e) {
          handleError(e, vm, "renderError");
          vnode = vm._vnode;
        }
      } else {
        vnode = vm._vnode;
      }
    } finally {
      currentRenderingInstance = null;
    }
    // if the returned array contains only a single node, allow it
    if (Array.isArray(vnode) && vnode.length === 1) {
      vnode = vnode[0];
    }
    // return empty vnode in case the render function errored out
    if (!(vnode instanceof VNode)) {
      if ( Array.isArray(vnode)) {
        warn(
          'Multiple root nodes returned from render function. Render function ' +
          'should return a single root node.',
          vm
        );
      }
      vnode = createEmptyVNode();
    }
    // set parent
    vnode.parent = _parentVnode;
    return vnode
  };
}

/*  */

function ensureCtor (comp, base) {
  if (
    comp.__esModule ||
    (hasSymbol && comp[Symbol.toStringTag] === 'Module')
  ) {
    comp = comp.default;
  }
  return isObject(comp)
    ? base.extend(comp)
    : comp
}

function createAsyncPlaceholder (
  factory,
  data,
  context,
  children,
  tag
) {
  var node = createEmptyVNode();
  node.asyncFactory = factory;
  node.asyncMeta = { data: data, context: context, children: children, tag: tag };
  return node
}

function resolveAsyncComponent (
  factory,
  baseCtor
) {
  if (isTrue(factory.error) && isDef(factory.errorComp)) {
    return factory.errorComp
  }

  if (isDef(factory.resolved)) {
    return factory.resolved
  }

  var owner = currentRenderingInstance;
  if (owner && isDef(factory.owners) && factory.owners.indexOf(owner) === -1) {
    // already pending
    factory.owners.push(owner);
  }

  if (isTrue(factory.loading) && isDef(factory.loadingComp)) {
    return factory.loadingComp
  }

  if (owner && !isDef(factory.owners)) {
    var owners = factory.owners = [owner];
    var sync = true;
    var timerLoading = null;
    var timerTimeout = null

    ;(owner).$on('hook:destroyed', function () { return remove(owners, owner); });

    var forceRender = function (renderCompleted) {
      for (var i = 0, l = owners.length; i < l; i++) {
        (owners[i]).$forceUpdate();
      }

      if (renderCompleted) {
        owners.length = 0;
        if (timerLoading !== null) {
          clearTimeout(timerLoading);
          timerLoading = null;
        }
        if (timerTimeout !== null) {
          clearTimeout(timerTimeout);
          timerTimeout = null;
        }
      }
    };

    var resolve = once(function (res) {
      // cache resolved
      factory.resolved = ensureCtor(res, baseCtor);
      // invoke callbacks only if this is not a synchronous resolve
      // (async resolves are shimmed as synchronous during SSR)
      if (!sync) {
        forceRender(true);
      } else {
        owners.length = 0;
      }
    });

    var reject = once(function (reason) {
       warn(
        "Failed to resolve async component: " + (String(factory)) +
        (reason ? ("\nReason: " + reason) : '')
      );
      if (isDef(factory.errorComp)) {
        factory.error = true;
        forceRender(true);
      }
    });

    var res = factory(resolve, reject);

    if (isObject(res)) {
      if (isPromise(res)) {
        // () => Promise
        if (isUndef(factory.resolved)) {
          res.then(resolve, reject);
        }
      } else if (isPromise(res.component)) {
        res.component.then(resolve, reject);

        if (isDef(res.error)) {
          factory.errorComp = ensureCtor(res.error, baseCtor);
        }

        if (isDef(res.loading)) {
          factory.loadingComp = ensureCtor(res.loading, baseCtor);
          if (res.delay === 0) {
            factory.loading = true;
          } else {
            timerLoading = setTimeout(function () {
              timerLoading = null;
              if (isUndef(factory.resolved) && isUndef(factory.error)) {
                factory.loading = true;
                forceRender(false);
              }
            }, res.delay || 200);
          }
        }

        if (isDef(res.timeout)) {
          timerTimeout = setTimeout(function () {
            timerTimeout = null;
            if (isUndef(factory.resolved)) {
              reject(
                 ("timeout (" + (res.timeout) + "ms)")
                  
              );
            }
          }, res.timeout);
        }
      }
    }

    sync = false;
    // return in case resolved synchronously
    return factory.loading
      ? factory.loadingComp
      : factory.resolved
  }
}

/*  */

function isAsyncPlaceholder (node) {
  return node.isComment && node.asyncFactory
}

/*  */

function getFirstComponentChild (children) {
  if (Array.isArray(children)) {
    for (var i = 0; i < children.length; i++) {
      var c = children[i];
      if (isDef(c) && (isDef(c.componentOptions) || isAsyncPlaceholder(c))) {
        return c
      }
    }
  }
}

/*  */

/*  */

function initEvents (vm) {
  vm._events = Object.create(null);
  vm._hasHookEvent = false;
  // init parent attached events
  var listeners = vm.$options._parentListeners;
  if (listeners) {
    updateComponentListeners(vm, listeners);
  }
}

var target;

function add (event, fn) {
  target.$on(event, fn);
}

function remove$1 (event, fn) {
  target.$off(event, fn);
}

function createOnceHandler (event, fn) {
  var _target = target;
  return function onceHandler () {
    var res = fn.apply(null, arguments);
    if (res !== null) {
      _target.$off(event, onceHandler);
    }
  }
}

function updateComponentListeners (
  vm,
  listeners,
  oldListeners
) {
  target = vm;
  updateListeners(listeners, oldListeners || {}, add, remove$1, createOnceHandler, vm);
  target = undefined;
}

function eventsMixin (Vue) {
  var hookRE = /^hook:/;
  Vue.prototype.$on = function (event, fn) {
    var vm = this;
    if (Array.isArray(event)) {
      for (var i = 0, l = event.length; i < l; i++) {
        vm.$on(event[i], fn);
      }
    } else {
      (vm._events[event] || (vm._events[event] = [])).push(fn);
      // optimize hook:event cost by using a boolean flag marked at registration
      // instead of a hash lookup
      if (hookRE.test(event)) {
        vm._hasHookEvent = true;
      }
    }
    return vm
  };

  Vue.prototype.$once = function (event, fn) {
    var vm = this;
    function on () {
      vm.$off(event, on);
      fn.apply(vm, arguments);
    }
    on.fn = fn;
    vm.$on(event, on);
    return vm
  };

  Vue.prototype.$off = function (event, fn) {
    var vm = this;
    // all
    if (!arguments.length) {
      vm._events = Object.create(null);
      return vm
    }
    // array of events
    if (Array.isArray(event)) {
      for (var i$1 = 0, l = event.length; i$1 < l; i$1++) {
        vm.$off(event[i$1], fn);
      }
      return vm
    }
    // specific event
    var cbs = vm._events[event];
    if (!cbs) {
      return vm
    }
    if (!fn) {
      vm._events[event] = null;
      return vm
    }
    // specific handler
    var cb;
    var i = cbs.length;
    while (i--) {
      cb = cbs[i];
      if (cb === fn || cb.fn === fn) {
        cbs.splice(i, 1);
        break
      }
    }
    return vm
  };

  Vue.prototype.$emit = function (event) {
    var vm = this;
    {
      var lowerCaseEvent = event.toLowerCase();
      if (lowerCaseEvent !== event && vm._events[lowerCaseEvent]) {
        tip(
          "Event \"" + lowerCaseEvent + "\" is emitted in component " +
          (formatComponentName(vm)) + " but the handler is registered for \"" + event + "\". " +
          "Note that HTML attributes are case-insensitive and you cannot use " +
          "v-on to listen to camelCase events when using in-DOM templates. " +
          "You should probably use \"" + (hyphenate(event)) + "\" instead of \"" + event + "\"."
        );
      }
    }
    var cbs = vm._events[event];
    if (cbs) {
      cbs = cbs.length > 1 ? toArray(cbs) : cbs;
      var args = toArray(arguments, 1);
      var info = "event handler for \"" + event + "\"";
      for (var i = 0, l = cbs.length; i < l; i++) {
        invokeWithErrorHandling(cbs[i], vm, args, vm, info);
      }
    }
    return vm
  };
}

/*  */

var activeInstance = null;
var isUpdatingChildComponent = false;

function setActiveInstance(vm) {
  var prevActiveInstance = activeInstance;
  activeInstance = vm;
  return function () {
    activeInstance = prevActiveInstance;
  }
}

function initLifecycle (vm) {
  var options = vm.$options;

  // locate first non-abstract parent
  var parent = options.parent;
  if (parent && !options.abstract) {
    while (parent.$options.abstract && parent.$parent) {
      parent = parent.$parent;
    }
    parent.$children.push(vm);
  }

  vm.$parent = parent;
  vm.$root = parent ? parent.$root : vm;

  vm.$children = [];
  vm.$refs = {};

  vm._watcher = null;
  vm._inactive = null;
  vm._directInactive = false;
  vm._isMounted = false;
  vm._isDestroyed = false;
  vm._isBeingDestroyed = false;
}

function lifecycleMixin (Vue) {
  Vue.prototype._update = function (vnode, hydrating) {
    var vm = this;
    var prevEl = vm.$el;
    var prevVnode = vm._vnode;
    var restoreActiveInstance = setActiveInstance(vm);
    vm._vnode = vnode;
    // Vue.prototype.__patch__ is injected in entry points
    // based on the rendering backend used.
    if (!prevVnode) {
      // initial render
      vm.$el = vm.__patch__(vm.$el, vnode, hydrating, false /* removeOnly */);
    } else {
      // updates
      vm.$el = vm.__patch__(prevVnode, vnode);
    }
    restoreActiveInstance();
    // update __vue__ reference
    if (prevEl) {
      prevEl.__vue__ = null;
    }
    if (vm.$el) {
      vm.$el.__vue__ = vm;
    }
    // if parent is an HOC, update its $el as well
    if (vm.$vnode && vm.$parent && vm.$vnode === vm.$parent._vnode) {
      vm.$parent.$el = vm.$el;
    }
    // updated hook is called by the scheduler to ensure that children are
    // updated in a parent's updated hook.
  };

  Vue.prototype.$forceUpdate = function () {
    var vm = this;
    if (vm._watcher) {
      vm._watcher.update();
    }
  };

  Vue.prototype.$destroy = function () {
    var vm = this;
    if (vm._isBeingDestroyed) {
      return
    }
    callHook(vm, 'beforeDestroy');
    vm._isBeingDestroyed = true;
    // remove self from parent
    var parent = vm.$parent;
    if (parent && !parent._isBeingDestroyed && !vm.$options.abstract) {
      remove(parent.$children, vm);
    }
    // teardown watchers
    if (vm._watcher) {
      vm._watcher.teardown();
    }
    var i = vm._watchers.length;
    while (i--) {
      vm._watchers[i].teardown();
    }
    // remove reference from data ob
    // frozen object may not have observer.
    if (vm._data.__ob__) {
      vm._data.__ob__.vmCount--;
    }
    // call the last hook...
    vm._isDestroyed = true;
    // invoke destroy hooks on current rendered tree
    vm.__patch__(vm._vnode, null);
    // fire destroyed hook
    callHook(vm, 'destroyed');
    // turn off all instance listeners.
    vm.$off();
    // remove __vue__ reference
    if (vm.$el) {
      vm.$el.__vue__ = null;
    }
    // release circular reference (#6759)
    if (vm.$vnode) {
      vm.$vnode.parent = null;
    }
  };
}

function mountComponent (
  vm,
  el,
  hydrating
) {
  vm.$el = el;
  if (!vm.$options.render) {
    vm.$options.render = createEmptyVNode;
    {
      /* istanbul ignore if */
      if ((vm.$options.template && vm.$options.template.charAt(0) !== '#') ||
        vm.$options.el || el) {
        warn(
          'You are using the runtime-only build of Vue where the template ' +
          'compiler is not available. Either pre-compile the templates into ' +
          'render functions, or use the compiler-included build.',
          vm
        );
      } else {
        warn(
          'Failed to mount component: template or render function not defined.',
          vm
        );
      }
    }
  }
  callHook(vm, 'beforeMount');

  var updateComponent;
  /* istanbul ignore if */
  if ( config.performance && mark) {
    updateComponent = function () {
      var name = vm._name;
      var id = vm._uid;
      var startTag = "vue-perf-start:" + id;
      var endTag = "vue-perf-end:" + id;

      mark(startTag);
      var vnode = vm._render();
      mark(endTag);
      measure(("vue " + name + " render"), startTag, endTag);

      mark(startTag);
      vm._update(vnode, hydrating);
      mark(endTag);
      measure(("vue " + name + " patch"), startTag, endTag);
    };
  } else {
    updateComponent = function () {
      vm._update(vm._render(), hydrating);
    };
  }

  // we set this to vm._watcher inside the watcher's constructor
  // since the watcher's initial patch may call $forceUpdate (e.g. inside child
  // component's mounted hook), which relies on vm._watcher being already defined
  new Watcher(vm, updateComponent, noop, {
    before: function before () {
      if (vm._isMounted && !vm._isDestroyed) {
        callHook(vm, 'beforeUpdate');
      }
    }
  }, true /* isRenderWatcher */);
  hydrating = false;

  // manually mounted instance, call mounted on self
  // mounted is called for render-created child components in its inserted hook
  if (vm.$vnode == null) {
    vm._isMounted = true;
    callHook(vm, 'mounted');
  }
  return vm
}

function updateChildComponent (
  vm,
  propsData,
  listeners,
  parentVnode,
  renderChildren
) {
  {
    isUpdatingChildComponent = true;
  }

  // determine whether component has slot children
  // we need to do this before overwriting $options._renderChildren.

  // check if there are dynamic scopedSlots (hand-written or compiled but with
  // dynamic slot names). Static scoped slots compiled from template has the
  // "$stable" marker.
  var newScopedSlots = parentVnode.data.scopedSlots;
  var oldScopedSlots = vm.$scopedSlots;
  var hasDynamicScopedSlot = !!(
    (newScopedSlots && !newScopedSlots.$stable) ||
    (oldScopedSlots !== emptyObject && !oldScopedSlots.$stable) ||
    (newScopedSlots && vm.$scopedSlots.$key !== newScopedSlots.$key)
  );

  // Any static slot children from the parent may have changed during parent's
  // update. Dynamic scoped slots may also have changed. In such cases, a forced
  // update is necessary to ensure correctness.
  var needsForceUpdate = !!(
    renderChildren ||               // has new static slots
    vm.$options._renderChildren ||  // has old static slots
    hasDynamicScopedSlot
  );

  vm.$options._parentVnode = parentVnode;
  vm.$vnode = parentVnode; // update vm's placeholder node without re-render

  if (vm._vnode) { // update child tree's parent
    vm._vnode.parent = parentVnode;
  }
  vm.$options._renderChildren = renderChildren;

  // update $attrs and $listeners hash
  // these are also reactive so they may trigger child update if the child
  // used them during render
  vm.$attrs = parentVnode.data.attrs || emptyObject;
  vm.$listeners = listeners || emptyObject;

  // update props
  if (propsData && vm.$options.props) {
    toggleObserving(false);
    var props = vm._props;
    var propKeys = vm.$options._propKeys || [];
    for (var i = 0; i < propKeys.length; i++) {
      var key = propKeys[i];
      var propOptions = vm.$options.props; // wtf flow?
      props[key] = validateProp(key, propOptions, propsData, vm);
    }
    toggleObserving(true);
    // keep a copy of raw propsData
    vm.$options.propsData = propsData;
  }

  // update listeners
  listeners = listeners || emptyObject;
  var oldListeners = vm.$options._parentListeners;
  vm.$options._parentListeners = listeners;
  updateComponentListeners(vm, listeners, oldListeners);

  // resolve slots + force update if has children
  if (needsForceUpdate) {
    vm.$slots = resolveSlots(renderChildren, parentVnode.context);
    vm.$forceUpdate();
  }

  {
    isUpdatingChildComponent = false;
  }
}

function isInInactiveTree (vm) {
  while (vm && (vm = vm.$parent)) {
    if (vm._inactive) { return true }
  }
  return false
}

function activateChildComponent (vm, direct) {
  if (direct) {
    vm._directInactive = false;
    if (isInInactiveTree(vm)) {
      return
    }
  } else if (vm._directInactive) {
    return
  }
  if (vm._inactive || vm._inactive === null) {
    vm._inactive = false;
    for (var i = 0; i < vm.$children.length; i++) {
      activateChildComponent(vm.$children[i]);
    }
    callHook(vm, 'activated');
  }
}

function deactivateChildComponent (vm, direct) {
  if (direct) {
    vm._directInactive = true;
    if (isInInactiveTree(vm)) {
      return
    }
  }
  if (!vm._inactive) {
    vm._inactive = true;
    for (var i = 0; i < vm.$children.length; i++) {
      deactivateChildComponent(vm.$children[i]);
    }
    callHook(vm, 'deactivated');
  }
}

function callHook (vm, hook) {
  // #7573 disable dep collection when invoking lifecycle hooks
  pushTarget();
  var handlers = vm.$options[hook];
  var info = hook + " hook";
  if (handlers) {
    for (var i = 0, j = handlers.length; i < j; i++) {
      invokeWithErrorHandling(handlers[i], vm, null, vm, info);
    }
  }
  if (vm._hasHookEvent) {
    vm.$emit('hook:' + hook);
  }
  popTarget();
}

/*  */

var MAX_UPDATE_COUNT = 100;

var queue = [];
var activatedChildren = [];
var has = {};
var circular = {};
var waiting = false;
var flushing = false;
var index = 0;

/**
 * Reset the scheduler's state.
 */
function resetSchedulerState () {
  index = queue.length = activatedChildren.length = 0;
  has = {};
  {
    circular = {};
  }
  waiting = flushing = false;
}

// Async edge case #6566 requires saving the timestamp when event listeners are
// attached. However, calling performance.now() has a perf overhead especially
// if the page has thousands of event listeners. Instead, we take a timestamp
// every time the scheduler flushes and use that for all event listeners
// attached during that flush.
var currentFlushTimestamp = 0;

// Async edge case fix requires storing an event listener's attach timestamp.
var getNow = Date.now;

// Determine what event timestamp the browser is using. Annoyingly, the
// timestamp can either be hi-res (relative to page load) or low-res
// (relative to UNIX epoch), so in order to compare time we have to use the
// same timestamp type when saving the flush timestamp.
// All IE versions use low-res event timestamps, and have problematic clock
// implementations (#9632)
if (inBrowser && !isIE) {
  var performance = window.performance;
  if (
    performance &&
    typeof performance.now === 'function' &&
    getNow() > document.createEvent('Event').timeStamp
  ) {
    // if the event timestamp, although evaluated AFTER the Date.now(), is
    // smaller than it, it means the event is using a hi-res timestamp,
    // and we need to use the hi-res version for event listener timestamps as
    // well.
    getNow = function () { return performance.now(); };
  }
}

/**
 * Flush both queues and run the watchers.
 */
function flushSchedulerQueue () {
  currentFlushTimestamp = getNow();
  flushing = true;
  var watcher, id;

  // Sort queue before flush.
  // This ensures that:
  // 1. Components are updated from parent to child. (because parent is always
  //    created before the child)
  // 2. A component's user watchers are run before its render watcher (because
  //    user watchers are created before the render watcher)
  // 3. If a component is destroyed during a parent component's watcher run,
  //    its watchers can be skipped.
  queue.sort(function (a, b) { return a.id - b.id; });

  // do not cache length because more watchers might be pushed
  // as we run existing watchers
  for (index = 0; index < queue.length; index++) {
    watcher = queue[index];
    if (watcher.before) {
      watcher.before();
    }
    id = watcher.id;
    has[id] = null;
    watcher.run();
    // in dev build, check and stop circular updates.
    if ( has[id] != null) {
      circular[id] = (circular[id] || 0) + 1;
      if (circular[id] > MAX_UPDATE_COUNT) {
        warn(
          'You may have an infinite update loop ' + (
            watcher.user
              ? ("in watcher with expression \"" + (watcher.expression) + "\"")
              : "in a component render function."
          ),
          watcher.vm
        );
        break
      }
    }
  }

  // keep copies of post queues before resetting state
  var activatedQueue = activatedChildren.slice();
  var updatedQueue = queue.slice();

  resetSchedulerState();

  // call component updated and activated hooks
  callActivatedHooks(activatedQueue);
  callUpdatedHooks(updatedQueue);

  // devtool hook
  /* istanbul ignore if */
  if (devtools && config.devtools) {
    devtools.emit('flush');
  }
}

function callUpdatedHooks (queue) {
  var i = queue.length;
  while (i--) {
    var watcher = queue[i];
    var vm = watcher.vm;
    if (vm._watcher === watcher && vm._isMounted && !vm._isDestroyed) {
      callHook(vm, 'updated');
    }
  }
}

/**
 * Queue a kept-alive component that was activated during patch.
 * The queue will be processed after the entire tree has been patched.
 */
function queueActivatedComponent (vm) {
  // setting _inactive to false here so that a render function can
  // rely on checking whether it's in an inactive tree (e.g. router-view)
  vm._inactive = false;
  activatedChildren.push(vm);
}

function callActivatedHooks (queue) {
  for (var i = 0; i < queue.length; i++) {
    queue[i]._inactive = true;
    activateChildComponent(queue[i], true /* true */);
  }
}

/**
 * Push a watcher into the watcher queue.
 * Jobs with duplicate IDs will be skipped unless it's
 * pushed when the queue is being flushed.
 */
function queueWatcher (watcher) {
  var id = watcher.id;
  if (has[id] == null) {
    has[id] = true;
    if (!flushing) {
      queue.push(watcher);
    } else {
      // if already flushing, splice the watcher based on its id
      // if already past its id, it will be run next immediately.
      var i = queue.length - 1;
      while (i > index && queue[i].id > watcher.id) {
        i--;
      }
      queue.splice(i + 1, 0, watcher);
    }
    // queue the flush
    if (!waiting) {
      waiting = true;

      if ( !config.async) {
        flushSchedulerQueue();
        return
      }
      nextTick(flushSchedulerQueue);
    }
  }
}

/*  */



var uid$2 = 0;

/**
 * A watcher parses an expression, collects dependencies,
 * and fires callback when the expression value changes.
 * This is used for both the $watch() api and directives.
 */
var Watcher = function Watcher (
  vm,
  expOrFn,
  cb,
  options,
  isRenderWatcher
) {
  this.vm = vm;
  if (isRenderWatcher) {
    vm._watcher = this;
  }
  vm._watchers.push(this);
  // options
  if (options) {
    this.deep = !!options.deep;
    this.user = !!options.user;
    this.lazy = !!options.lazy;
    this.sync = !!options.sync;
    this.before = options.before;
  } else {
    this.deep = this.user = this.lazy = this.sync = false;
  }
  this.cb = cb;
  this.id = ++uid$2; // uid for batching
  this.active = true;
  this.dirty = this.lazy; // for lazy watchers
  this.deps = [];
  this.newDeps = [];
  this.depIds = new _Set();
  this.newDepIds = new _Set();
  this.expression =  expOrFn.toString()
    ;
  // parse expression for getter
  if (typeof expOrFn === 'function') {
    this.getter = expOrFn;
  } else {
    this.getter = parsePath(expOrFn);
    if (!this.getter) {
      this.getter = noop;
       warn(
        "Failed watching path: \"" + expOrFn + "\" " +
        'Watcher only accepts simple dot-delimited paths. ' +
        'For full control, use a function instead.',
        vm
      );
    }
  }
  this.value = this.lazy
    ? undefined
    : this.get();
};

/**
 * Evaluate the getter, and re-collect dependencies.
 */
Watcher.prototype.get = function get () {
  pushTarget(this);
  var value;
  var vm = this.vm;
  try {
    value = this.getter.call(vm, vm);
  } catch (e) {
    if (this.user) {
      handleError(e, vm, ("getter for watcher \"" + (this.expression) + "\""));
    } else {
      throw e
    }
  } finally {
    // "touch" every property so they are all tracked as
    // dependencies for deep watching
    if (this.deep) {
      traverse(value);
    }
    popTarget();
    this.cleanupDeps();
  }
  return value
};

/**
 * Add a dependency to this directive.
 */
Watcher.prototype.addDep = function addDep (dep) {
  var id = dep.id;
  if (!this.newDepIds.has(id)) {
    this.newDepIds.add(id);
    this.newDeps.push(dep);
    if (!this.depIds.has(id)) {
      dep.addSub(this);
    }
  }
};

/**
 * Clean up for dependency collection.
 */
Watcher.prototype.cleanupDeps = function cleanupDeps () {
  var i = this.deps.length;
  while (i--) {
    var dep = this.deps[i];
    if (!this.newDepIds.has(dep.id)) {
      dep.removeSub(this);
    }
  }
  var tmp = this.depIds;
  this.depIds = this.newDepIds;
  this.newDepIds = tmp;
  this.newDepIds.clear();
  tmp = this.deps;
  this.deps = this.newDeps;
  this.newDeps = tmp;
  this.newDeps.length = 0;
};

/**
 * Subscriber interface.
 * Will be called when a dependency changes.
 */
Watcher.prototype.update = function update () {
  /* istanbul ignore else */
  if (this.lazy) {
    this.dirty = true;
  } else if (this.sync) {
    this.run();
  } else {
    queueWatcher(this);
  }
};

/**
 * Scheduler job interface.
 * Will be called by the scheduler.
 */
Watcher.prototype.run = function run () {
  if (this.active) {
    var value = this.get();
    if (
      value !== this.value ||
      // Deep watchers and watchers on Object/Arrays should fire even
      // when the value is the same, because the value may
      // have mutated.
      isObject(value) ||
      this.deep
    ) {
      // set new value
      var oldValue = this.value;
      this.value = value;
      if (this.user) {
        try {
          this.cb.call(this.vm, value, oldValue);
        } catch (e) {
          handleError(e, this.vm, ("callback for watcher \"" + (this.expression) + "\""));
        }
      } else {
        this.cb.call(this.vm, value, oldValue);
      }
    }
  }
};

/**
 * Evaluate the value of the watcher.
 * This only gets called for lazy watchers.
 */
Watcher.prototype.evaluate = function evaluate () {
  this.value = this.get();
  this.dirty = false;
};

/**
 * Depend on all deps collected by this watcher.
 */
Watcher.prototype.depend = function depend () {
  var i = this.deps.length;
  while (i--) {
    this.deps[i].depend();
  }
};

/**
 * Remove self from all dependencies' subscriber list.
 */
Watcher.prototype.teardown = function teardown () {
  if (this.active) {
    // remove self from vm's watcher list
    // this is a somewhat expensive operation so we skip it
    // if the vm is being destroyed.
    if (!this.vm._isBeingDestroyed) {
      remove(this.vm._watchers, this);
    }
    var i = this.deps.length;
    while (i--) {
      this.deps[i].removeSub(this);
    }
    this.active = false;
  }
};

/*  */

var sharedPropertyDefinition = {
  enumerable: true,
  configurable: true,
  get: noop,
  set: noop
};

function proxy (target, sourceKey, key) {
  sharedPropertyDefinition.get = function proxyGetter () {
    return this[sourceKey][key]
  };
  sharedPropertyDefinition.set = function proxySetter (val) {
    this[sourceKey][key] = val;
  };
  Object.defineProperty(target, key, sharedPropertyDefinition);
}

function initState (vm) {
  vm._watchers = [];
  var opts = vm.$options;
  if (opts.props) { initProps(vm, opts.props); }
  if (opts.methods) { initMethods(vm, opts.methods); }
  if (opts.data) {
    initData(vm);
  } else {
    observe(vm._data = {}, true /* asRootData */);
  }
  if (opts.computed) { initComputed(vm, opts.computed); }
  if (opts.watch && opts.watch !== nativeWatch) {
    initWatch(vm, opts.watch);
  }
}

function initProps (vm, propsOptions) {
  var propsData = vm.$options.propsData || {};
  var props = vm._props = {};
  // cache prop keys so that future props updates can iterate using Array
  // instead of dynamic object key enumeration.
  var keys = vm.$options._propKeys = [];
  var isRoot = !vm.$parent;
  // root instance props should be converted
  if (!isRoot) {
    toggleObserving(false);
  }
  var loop = function ( key ) {
    keys.push(key);
    var value = validateProp(key, propsOptions, propsData, vm);
    /* istanbul ignore else */
    {
      var hyphenatedKey = hyphenate(key);
      if (isReservedAttribute(hyphenatedKey) ||
          config.isReservedAttr(hyphenatedKey)) {
        warn(
          ("\"" + hyphenatedKey + "\" is a reserved attribute and cannot be used as component prop."),
          vm
        );
      }
      defineReactive$$1(props, key, value, function () {
        if (!isRoot && !isUpdatingChildComponent) {
          warn(
            "Avoid mutating a prop directly since the value will be " +
            "overwritten whenever the parent component re-renders. " +
            "Instead, use a data or computed property based on the prop's " +
            "value. Prop being mutated: \"" + key + "\"",
            vm
          );
        }
      });
    }
    // static props are already proxied on the component's prototype
    // during Vue.extend(). We only need to proxy props defined at
    // instantiation here.
    if (!(key in vm)) {
      proxy(vm, "_props", key);
    }
  };

  for (var key in propsOptions) loop( key );
  toggleObserving(true);
}

function initData (vm) {
  var data = vm.$options.data;
  data = vm._data = typeof data === 'function'
    ? getData(data, vm)
    : data || {};
  if (!isPlainObject(data)) {
    data = {};
     warn(
      'data functions should return an object:\n' +
      'https://vuejs.org/v2/guide/components.html#data-Must-Be-a-Function',
      vm
    );
  }
  // proxy data on instance
  var keys = Object.keys(data);
  var props = vm.$options.props;
  var methods = vm.$options.methods;
  var i = keys.length;
  while (i--) {
    var key = keys[i];
    {
      if (methods && hasOwn(methods, key)) {
        warn(
          ("Method \"" + key + "\" has already been defined as a data property."),
          vm
        );
      }
    }
    if (props && hasOwn(props, key)) {
       warn(
        "The data property \"" + key + "\" is already declared as a prop. " +
        "Use prop default value instead.",
        vm
      );
    } else if (!isReserved(key)) {
      proxy(vm, "_data", key);
    }
  }
  // observe data
  observe(data, true /* asRootData */);
}

function getData (data, vm) {
  // #7573 disable dep collection when invoking data getters
  pushTarget();
  try {
    return data.call(vm, vm)
  } catch (e) {
    handleError(e, vm, "data()");
    return {}
  } finally {
    popTarget();
  }
}

var computedWatcherOptions = { lazy: true };

function initComputed (vm, computed) {
  // $flow-disable-line
  var watchers = vm._computedWatchers = Object.create(null);
  // computed properties are just getters during SSR
  var isSSR = isServerRendering();

  for (var key in computed) {
    var userDef = computed[key];
    var getter = typeof userDef === 'function' ? userDef : userDef.get;
    if ( getter == null) {
      warn(
        ("Getter is missing for computed property \"" + key + "\"."),
        vm
      );
    }

    if (!isSSR) {
      // create internal watcher for the computed property.
      watchers[key] = new Watcher(
        vm,
        getter || noop,
        noop,
        computedWatcherOptions
      );
    }

    // component-defined computed properties are already defined on the
    // component prototype. We only need to define computed properties defined
    // at instantiation here.
    if (!(key in vm)) {
      defineComputed(vm, key, userDef);
    } else {
      if (key in vm.$data) {
        warn(("The computed property \"" + key + "\" is already defined in data."), vm);
      } else if (vm.$options.props && key in vm.$options.props) {
        warn(("The computed property \"" + key + "\" is already defined as a prop."), vm);
      }
    }
  }
}

function defineComputed (
  target,
  key,
  userDef
) {
  var shouldCache = !isServerRendering();
  if (typeof userDef === 'function') {
    sharedPropertyDefinition.get = shouldCache
      ? createComputedGetter(key)
      : createGetterInvoker(userDef);
    sharedPropertyDefinition.set = noop;
  } else {
    sharedPropertyDefinition.get = userDef.get
      ? shouldCache && userDef.cache !== false
        ? createComputedGetter(key)
        : createGetterInvoker(userDef.get)
      : noop;
    sharedPropertyDefinition.set = userDef.set || noop;
  }
  if (
      sharedPropertyDefinition.set === noop) {
    sharedPropertyDefinition.set = function () {
      warn(
        ("Computed property \"" + key + "\" was assigned to but it has no setter."),
        this
      );
    };
  }
  Object.defineProperty(target, key, sharedPropertyDefinition);
}

function createComputedGetter (key) {
  return function computedGetter () {
    var watcher = this._computedWatchers && this._computedWatchers[key];
    if (watcher) {
      if (watcher.dirty) {
        watcher.evaluate();
      }
      if (Dep.target) {
        watcher.depend();
      }
      return watcher.value
    }
  }
}

function createGetterInvoker(fn) {
  return function computedGetter () {
    return fn.call(this, this)
  }
}

function initMethods (vm, methods) {
  var props = vm.$options.props;
  for (var key in methods) {
    {
      if (typeof methods[key] !== 'function') {
        warn(
          "Method \"" + key + "\" has type \"" + (typeof methods[key]) + "\" in the component definition. " +
          "Did you reference the function correctly?",
          vm
        );
      }
      if (props && hasOwn(props, key)) {
        warn(
          ("Method \"" + key + "\" has already been defined as a prop."),
          vm
        );
      }
      if ((key in vm) && isReserved(key)) {
        warn(
          "Method \"" + key + "\" conflicts with an existing Vue instance method. " +
          "Avoid defining component methods that start with _ or $."
        );
      }
    }
    vm[key] = typeof methods[key] !== 'function' ? noop : bind(methods[key], vm);
  }
}

function initWatch (vm, watch) {
  for (var key in watch) {
    var handler = watch[key];
    if (Array.isArray(handler)) {
      for (var i = 0; i < handler.length; i++) {
        createWatcher(vm, key, handler[i]);
      }
    } else {
      createWatcher(vm, key, handler);
    }
  }
}

function createWatcher (
  vm,
  expOrFn,
  handler,
  options
) {
  if (isPlainObject(handler)) {
    options = handler;
    handler = handler.handler;
  }
  if (typeof handler === 'string') {
    handler = vm[handler];
  }
  return vm.$watch(expOrFn, handler, options)
}

function stateMixin (Vue) {
  // flow somehow has problems with directly declared definition object
  // when using Object.defineProperty, so we have to procedurally build up
  // the object here.
  var dataDef = {};
  dataDef.get = function () { return this._data };
  var propsDef = {};
  propsDef.get = function () { return this._props };
  {
    dataDef.set = function () {
      warn(
        'Avoid replacing instance root $data. ' +
        'Use nested data properties instead.',
        this
      );
    };
    propsDef.set = function () {
      warn("$props is readonly.", this);
    };
  }
  Object.defineProperty(Vue.prototype, '$data', dataDef);
  Object.defineProperty(Vue.prototype, '$props', propsDef);

  Vue.prototype.$set = set;
  Vue.prototype.$delete = del;

  Vue.prototype.$watch = function (
    expOrFn,
    cb,
    options
  ) {
    var vm = this;
    if (isPlainObject(cb)) {
      return createWatcher(vm, expOrFn, cb, options)
    }
    options = options || {};
    options.user = true;
    var watcher = new Watcher(vm, expOrFn, cb, options);
    if (options.immediate) {
      try {
        cb.call(vm, watcher.value);
      } catch (error) {
        handleError(error, vm, ("callback for immediate watcher \"" + (watcher.expression) + "\""));
      }
    }
    return function unwatchFn () {
      watcher.teardown();
    }
  };
}

/*  */

var uid$3 = 0;

function initMixin (Vue) {
  Vue.prototype._init = function (options) {
    var vm = this;
    // a uid
    vm._uid = uid$3++;

    var startTag, endTag;
    /* istanbul ignore if */
    if ( config.performance && mark) {
      startTag = "vue-perf-start:" + (vm._uid);
      endTag = "vue-perf-end:" + (vm._uid);
      mark(startTag);
    }

    // a flag to avoid this being observed
    vm._isVue = true;
    // merge options
    if (options && options._isComponent) {
      // optimize internal component instantiation
      // since dynamic options merging is pretty slow, and none of the
      // internal component options needs special treatment.
      initInternalComponent(vm, options);
    } else {
      vm.$options = mergeOptions(
        resolveConstructorOptions(vm.constructor),
        options || {},
        vm
      );
    }
    /* istanbul ignore else */
    {
      initProxy(vm);
    }
    // expose real self
    vm._self = vm;
    initLifecycle(vm);
    initEvents(vm);
    initRender(vm);
    callHook(vm, 'beforeCreate');
    initInjections(vm); // resolve injections before data/props
    initState(vm);
    initProvide(vm); // resolve provide after data/props
    callHook(vm, 'created');

    /* istanbul ignore if */
    if ( config.performance && mark) {
      vm._name = formatComponentName(vm, false);
      mark(endTag);
      measure(("vue " + (vm._name) + " init"), startTag, endTag);
    }

    if (vm.$options.el) {
      vm.$mount(vm.$options.el);
    }
  };
}

function initInternalComponent (vm, options) {
  var opts = vm.$options = Object.create(vm.constructor.options);
  // doing this because it's faster than dynamic enumeration.
  var parentVnode = options._parentVnode;
  opts.parent = options.parent;
  opts._parentVnode = parentVnode;

  var vnodeComponentOptions = parentVnode.componentOptions;
  opts.propsData = vnodeComponentOptions.propsData;
  opts._parentListeners = vnodeComponentOptions.listeners;
  opts._renderChildren = vnodeComponentOptions.children;
  opts._componentTag = vnodeComponentOptions.tag;

  if (options.render) {
    opts.render = options.render;
    opts.staticRenderFns = options.staticRenderFns;
  }
}

function resolveConstructorOptions (Ctor) {
  var options = Ctor.options;
  if (Ctor.super) {
    var superOptions = resolveConstructorOptions(Ctor.super);
    var cachedSuperOptions = Ctor.superOptions;
    if (superOptions !== cachedSuperOptions) {
      // super option changed,
      // need to resolve new options.
      Ctor.superOptions = superOptions;
      // check if there are any late-modified/attached options (#4976)
      var modifiedOptions = resolveModifiedOptions(Ctor);
      // update base extend options
      if (modifiedOptions) {
        extend(Ctor.extendOptions, modifiedOptions);
      }
      options = Ctor.options = mergeOptions(superOptions, Ctor.extendOptions);
      if (options.name) {
        options.components[options.name] = Ctor;
      }
    }
  }
  return options
}

function resolveModifiedOptions (Ctor) {
  var modified;
  var latest = Ctor.options;
  var sealed = Ctor.sealedOptions;
  for (var key in latest) {
    if (latest[key] !== sealed[key]) {
      if (!modified) { modified = {}; }
      modified[key] = latest[key];
    }
  }
  return modified
}

function Vue (options) {
  if (
    !(this instanceof Vue)
  ) {
    warn('Vue is a constructor and should be called with the `new` keyword');
  }
  this._init(options);
}

initMixin(Vue);
stateMixin(Vue);
eventsMixin(Vue);
lifecycleMixin(Vue);
renderMixin(Vue);

/*  */

function initUse (Vue) {
  Vue.use = function (plugin) {
    var installedPlugins = (this._installedPlugins || (this._installedPlugins = []));
    if (installedPlugins.indexOf(plugin) > -1) {
      return this
    }

    // additional parameters
    var args = toArray(arguments, 1);
    args.unshift(this);
    if (typeof plugin.install === 'function') {
      plugin.install.apply(plugin, args);
    } else if (typeof plugin === 'function') {
      plugin.apply(null, args);
    }
    installedPlugins.push(plugin);
    return this
  };
}

/*  */

function initMixin$1 (Vue) {
  Vue.mixin = function (mixin) {
    this.options = mergeOptions(this.options, mixin);
    return this
  };
}

/*  */

function initExtend (Vue) {
  /**
   * Each instance constructor, including Vue, has a unique
   * cid. This enables us to create wrapped "child
   * constructors" for prototypal inheritance and cache them.
   */
  Vue.cid = 0;
  var cid = 1;

  /**
   * Class inheritance
   */
  Vue.extend = function (extendOptions) {
    extendOptions = extendOptions || {};
    var Super = this;
    var SuperId = Super.cid;
    var cachedCtors = extendOptions._Ctor || (extendOptions._Ctor = {});
    if (cachedCtors[SuperId]) {
      return cachedCtors[SuperId]
    }

    var name = extendOptions.name || Super.options.name;
    if ( name) {
      validateComponentName(name);
    }

    var Sub = function VueComponent (options) {
      this._init(options);
    };
    Sub.prototype = Object.create(Super.prototype);
    Sub.prototype.constructor = Sub;
    Sub.cid = cid++;
    Sub.options = mergeOptions(
      Super.options,
      extendOptions
    );
    Sub['super'] = Super;

    // For props and computed properties, we define the proxy getters on
    // the Vue instances at extension time, on the extended prototype. This
    // avoids Object.defineProperty calls for each instance created.
    if (Sub.options.props) {
      initProps$1(Sub);
    }
    if (Sub.options.computed) {
      initComputed$1(Sub);
    }

    // allow further extension/mixin/plugin usage
    Sub.extend = Super.extend;
    Sub.mixin = Super.mixin;
    Sub.use = Super.use;

    // create asset registers, so extended classes
    // can have their private assets too.
    ASSET_TYPES.forEach(function (type) {
      Sub[type] = Super[type];
    });
    // enable recursive self-lookup
    if (name) {
      Sub.options.components[name] = Sub;
    }

    // keep a reference to the super options at extension time.
    // later at instantiation we can check if Super's options have
    // been updated.
    Sub.superOptions = Super.options;
    Sub.extendOptions = extendOptions;
    Sub.sealedOptions = extend({}, Sub.options);

    // cache constructor
    cachedCtors[SuperId] = Sub;
    return Sub
  };
}

function initProps$1 (Comp) {
  var props = Comp.options.props;
  for (var key in props) {
    proxy(Comp.prototype, "_props", key);
  }
}

function initComputed$1 (Comp) {
  var computed = Comp.options.computed;
  for (var key in computed) {
    defineComputed(Comp.prototype, key, computed[key]);
  }
}

/*  */

function initAssetRegisters (Vue) {
  /**
   * Create asset registration methods.
   */
  ASSET_TYPES.forEach(function (type) {
    Vue[type] = function (
      id,
      definition
    ) {
      if (!definition) {
        return this.options[type + 's'][id]
      } else {
        /* istanbul ignore if */
        if ( type === 'component') {
          validateComponentName(id);
        }
        if (type === 'component' && isPlainObject(definition)) {
          definition.name = definition.name || id;
          definition = this.options._base.extend(definition);
        }
        if (type === 'directive' && typeof definition === 'function') {
          definition = { bind: definition, update: definition };
        }
        this.options[type + 's'][id] = definition;
        return definition
      }
    };
  });
}

/*  */



function getComponentName (opts) {
  return opts && (opts.Ctor.options.name || opts.tag)
}

function matches (pattern, name) {
  if (Array.isArray(pattern)) {
    return pattern.indexOf(name) > -1
  } else if (typeof pattern === 'string') {
    return pattern.split(',').indexOf(name) > -1
  } else if (isRegExp(pattern)) {
    return pattern.test(name)
  }
  /* istanbul ignore next */
  return false
}

function pruneCache (keepAliveInstance, filter) {
  var cache = keepAliveInstance.cache;
  var keys = keepAliveInstance.keys;
  var _vnode = keepAliveInstance._vnode;
  for (var key in cache) {
    var cachedNode = cache[key];
    if (cachedNode) {
      var name = getComponentName(cachedNode.componentOptions);
      if (name && !filter(name)) {
        pruneCacheEntry(cache, key, keys, _vnode);
      }
    }
  }
}

function pruneCacheEntry (
  cache,
  key,
  keys,
  current
) {
  var cached$$1 = cache[key];
  if (cached$$1 && (!current || cached$$1.tag !== current.tag)) {
    cached$$1.componentInstance.$destroy();
  }
  cache[key] = null;
  remove(keys, key);
}

var patternTypes = [String, RegExp, Array];

var KeepAlive = {
  name: 'keep-alive',
  abstract: true,

  props: {
    include: patternTypes,
    exclude: patternTypes,
    max: [String, Number]
  },

  created: function created () {
    this.cache = Object.create(null);
    this.keys = [];
  },

  destroyed: function destroyed () {
    for (var key in this.cache) {
      pruneCacheEntry(this.cache, key, this.keys);
    }
  },

  mounted: function mounted () {
    var this$1 = this;

    this.$watch('include', function (val) {
      pruneCache(this$1, function (name) { return matches(val, name); });
    });
    this.$watch('exclude', function (val) {
      pruneCache(this$1, function (name) { return !matches(val, name); });
    });
  },

  render: function render () {
    var slot = this.$slots.default;
    var vnode = getFirstComponentChild(slot);
    var componentOptions = vnode && vnode.componentOptions;
    if (componentOptions) {
      // check pattern
      var name = getComponentName(componentOptions);
      var ref = this;
      var include = ref.include;
      var exclude = ref.exclude;
      if (
        // not included
        (include && (!name || !matches(include, name))) ||
        // excluded
        (exclude && name && matches(exclude, name))
      ) {
        return vnode
      }

      var ref$1 = this;
      var cache = ref$1.cache;
      var keys = ref$1.keys;
      var key = vnode.key == null
        // same constructor may get registered as different local components
        // so cid alone is not enough (#3269)
        ? componentOptions.Ctor.cid + (componentOptions.tag ? ("::" + (componentOptions.tag)) : '')
        : vnode.key;
      if (cache[key]) {
        vnode.componentInstance = cache[key].componentInstance;
        // make current key freshest
        remove(keys, key);
        keys.push(key);
      } else {
        cache[key] = vnode;
        keys.push(key);
        // prune oldest entry
        if (this.max && keys.length > parseInt(this.max)) {
          pruneCacheEntry(cache, keys[0], keys, this._vnode);
        }
      }

      vnode.data.keepAlive = true;
    }
    return vnode || (slot && slot[0])
  }
};

var builtInComponents = {
  KeepAlive: KeepAlive
};

/*  */

function initGlobalAPI (Vue) {
  // config
  var configDef = {};
  configDef.get = function () { return config; };
  {
    configDef.set = function () {
      warn(
        'Do not replace the Vue.config object, set individual fields instead.'
      );
    };
  }
  Object.defineProperty(Vue, 'config', configDef);

  // exposed util methods.
  // NOTE: these are not considered part of the public API - avoid relying on
  // them unless you are aware of the risk.
  Vue.util = {
    warn: warn,
    extend: extend,
    mergeOptions: mergeOptions,
    defineReactive: defineReactive$$1
  };

  Vue.set = set;
  Vue.delete = del;
  Vue.nextTick = nextTick;

  // 2.6 explicit observable API
  Vue.observable = function (obj) {
    observe(obj);
    return obj
  };

  Vue.options = Object.create(null);
  ASSET_TYPES.forEach(function (type) {
    Vue.options[type + 's'] = Object.create(null);
  });

  // this is used to identify the "base" constructor to extend all plain-object
  // components with in Weex's multi-instance scenarios.
  Vue.options._base = Vue;

  extend(Vue.options.components, builtInComponents);

  initUse(Vue);
  initMixin$1(Vue);
  initExtend(Vue);
  initAssetRegisters(Vue);
}

initGlobalAPI(Vue);

Object.defineProperty(Vue.prototype, '$isServer', {
  get: isServerRendering
});

Object.defineProperty(Vue.prototype, '$ssrContext', {
  get: function get () {
    /* istanbul ignore next */
    return this.$vnode && this.$vnode.ssrContext
  }
});

// expose FunctionalRenderContext for ssr runtime helper installation
Object.defineProperty(Vue, 'FunctionalRenderContext', {
  value: FunctionalRenderContext
});

Vue.version = '2.6.12';

/*  */

// these are reserved for web because they are directly compiled away
// during template compilation
var isReservedAttr = makeMap('style,class');

// attributes that should be using props for binding
var acceptValue = makeMap('input,textarea,option,select,progress');
var mustUseProp = function (tag, type, attr) {
  return (
    (attr === 'value' && acceptValue(tag)) && type !== 'button' ||
    (attr === 'selected' && tag === 'option') ||
    (attr === 'checked' && tag === 'input') ||
    (attr === 'muted' && tag === 'video')
  )
};

var isEnumeratedAttr = makeMap('contenteditable,draggable,spellcheck');

var isValidContentEditableValue = makeMap('events,caret,typing,plaintext-only');

var convertEnumeratedValue = function (key, value) {
  return isFalsyAttrValue(value) || value === 'false'
    ? 'false'
    // allow arbitrary string value for contenteditable
    : key === 'contenteditable' && isValidContentEditableValue(value)
      ? value
      : 'true'
};

var isBooleanAttr = makeMap(
  'allowfullscreen,async,autofocus,autoplay,checked,compact,controls,declare,' +
  'default,defaultchecked,defaultmuted,defaultselected,defer,disabled,' +
  'enabled,formnovalidate,hidden,indeterminate,inert,ismap,itemscope,loop,multiple,' +
  'muted,nohref,noresize,noshade,novalidate,nowrap,open,pauseonexit,readonly,' +
  'required,reversed,scoped,seamless,selected,sortable,translate,' +
  'truespeed,typemustmatch,visible'
);

var xlinkNS = 'http://www.w3.org/1999/xlink';

var isXlink = function (name) {
  return name.charAt(5) === ':' && name.slice(0, 5) === 'xlink'
};

var getXlinkProp = function (name) {
  return isXlink(name) ? name.slice(6, name.length) : ''
};

var isFalsyAttrValue = function (val) {
  return val == null || val === false
};

/*  */

function genClassForVnode (vnode) {
  var data = vnode.data;
  var parentNode = vnode;
  var childNode = vnode;
  while (isDef(childNode.componentInstance)) {
    childNode = childNode.componentInstance._vnode;
    if (childNode && childNode.data) {
      data = mergeClassData(childNode.data, data);
    }
  }
  while (isDef(parentNode = parentNode.parent)) {
    if (parentNode && parentNode.data) {
      data = mergeClassData(data, parentNode.data);
    }
  }
  return renderClass(data.staticClass, data.class)
}

function mergeClassData (child, parent) {
  return {
    staticClass: concat(child.staticClass, parent.staticClass),
    class: isDef(child.class)
      ? [child.class, parent.class]
      : parent.class
  }
}

function renderClass (
  staticClass,
  dynamicClass
) {
  if (isDef(staticClass) || isDef(dynamicClass)) {
    return concat(staticClass, stringifyClass(dynamicClass))
  }
  /* istanbul ignore next */
  return ''
}

function concat (a, b) {
  return a ? b ? (a + ' ' + b) : a : (b || '')
}

function stringifyClass (value) {
  if (Array.isArray(value)) {
    return stringifyArray(value)
  }
  if (isObject(value)) {
    return stringifyObject(value)
  }
  if (typeof value === 'string') {
    return value
  }
  /* istanbul ignore next */
  return ''
}

function stringifyArray (value) {
  var res = '';
  var stringified;
  for (var i = 0, l = value.length; i < l; i++) {
    if (isDef(stringified = stringifyClass(value[i])) && stringified !== '') {
      if (res) { res += ' '; }
      res += stringified;
    }
  }
  return res
}

function stringifyObject (value) {
  var res = '';
  for (var key in value) {
    if (value[key]) {
      if (res) { res += ' '; }
      res += key;
    }
  }
  return res
}

/*  */

var namespaceMap = {
  svg: 'http://www.w3.org/2000/svg',
  math: 'http://www.w3.org/1998/Math/MathML'
};

var isHTMLTag = makeMap(
  'html,body,base,head,link,meta,style,title,' +
  'address,article,aside,footer,header,h1,h2,h3,h4,h5,h6,hgroup,nav,section,' +
  'div,dd,dl,dt,figcaption,figure,picture,hr,img,li,main,ol,p,pre,ul,' +
  'a,b,abbr,bdi,bdo,br,cite,code,data,dfn,em,i,kbd,mark,q,rp,rt,rtc,ruby,' +
  's,samp,small,span,strong,sub,sup,time,u,var,wbr,area,audio,map,track,video,' +
  'embed,object,param,source,canvas,script,noscript,del,ins,' +
  'caption,col,colgroup,table,thead,tbody,td,th,tr,' +
  'button,datalist,fieldset,form,input,label,legend,meter,optgroup,option,' +
  'output,progress,select,textarea,' +
  'details,dialog,menu,menuitem,summary,' +
  'content,element,shadow,template,blockquote,iframe,tfoot'
);

// this map is intentionally selective, only covering SVG elements that may
// contain child elements.
var isSVG = makeMap(
  'svg,animate,circle,clippath,cursor,defs,desc,ellipse,filter,font-face,' +
  'foreignObject,g,glyph,image,line,marker,mask,missing-glyph,path,pattern,' +
  'polygon,polyline,rect,switch,symbol,text,textpath,tspan,use,view',
  true
);

var isPreTag = function (tag) { return tag === 'pre'; };

var isReservedTag = function (tag) {
  return isHTMLTag(tag) || isSVG(tag)
};

function getTagNamespace (tag) {
  if (isSVG(tag)) {
    return 'svg'
  }
  // basic support for MathML
  // note it doesn't support other MathML elements being component roots
  if (tag === 'math') {
    return 'math'
  }
}

var unknownElementCache = Object.create(null);
function isUnknownElement (tag) {
  /* istanbul ignore if */
  if (!inBrowser) {
    return true
  }
  if (isReservedTag(tag)) {
    return false
  }
  tag = tag.toLowerCase();
  /* istanbul ignore if */
  if (unknownElementCache[tag] != null) {
    return unknownElementCache[tag]
  }
  var el = document.createElement(tag);
  if (tag.indexOf('-') > -1) {
    // http://stackoverflow.com/a/28210364/1070244
    return (unknownElementCache[tag] = (
      el.constructor === window.HTMLUnknownElement ||
      el.constructor === window.HTMLElement
    ))
  } else {
    return (unknownElementCache[tag] = /HTMLUnknownElement/.test(el.toString()))
  }
}

var isTextInputType = makeMap('text,number,password,search,email,tel,url');

/*  */

/**
 * Query an element selector if it's not an element already.
 */
function query (el) {
  if (typeof el === 'string') {
    var selected = document.querySelector(el);
    if (!selected) {
       warn(
        'Cannot find element: ' + el
      );
      return document.createElement('div')
    }
    return selected
  } else {
    return el
  }
}

/*  */

function createElement$1 (tagName, vnode) {
  var elm = document.createElement(tagName);
  if (tagName !== 'select') {
    return elm
  }
  // false or null will remove the attribute but undefined will not
  if (vnode.data && vnode.data.attrs && vnode.data.attrs.multiple !== undefined) {
    elm.setAttribute('multiple', 'multiple');
  }
  return elm
}

function createElementNS (namespace, tagName) {
  return document.createElementNS(namespaceMap[namespace], tagName)
}

function createTextNode (text) {
  return document.createTextNode(text)
}

function createComment (text) {
  return document.createComment(text)
}

function insertBefore (parentNode, newNode, referenceNode) {
  parentNode.insertBefore(newNode, referenceNode);
}

function removeChild (node, child) {
  node.removeChild(child);
}

function appendChild (node, child) {
  node.appendChild(child);
}

function parentNode (node) {
  return node.parentNode
}

function nextSibling (node) {
  return node.nextSibling
}

function tagName (node) {
  return node.tagName
}

function setTextContent (node, text) {
  node.textContent = text;
}

function setStyleScope (node, scopeId) {
  node.setAttribute(scopeId, '');
}

var nodeOps = /*#__PURE__*/Object.freeze({
  createElement: createElement$1,
  createElementNS: createElementNS,
  createTextNode: createTextNode,
  createComment: createComment,
  insertBefore: insertBefore,
  removeChild: removeChild,
  appendChild: appendChild,
  parentNode: parentNode,
  nextSibling: nextSibling,
  tagName: tagName,
  setTextContent: setTextContent,
  setStyleScope: setStyleScope
});

/*  */

var ref = {
  create: function create (_, vnode) {
    registerRef(vnode);
  },
  update: function update (oldVnode, vnode) {
    if (oldVnode.data.ref !== vnode.data.ref) {
      registerRef(oldVnode, true);
      registerRef(vnode);
    }
  },
  destroy: function destroy (vnode) {
    registerRef(vnode, true);
  }
};

function registerRef (vnode, isRemoval) {
  var key = vnode.data.ref;
  if (!isDef(key)) { return }

  var vm = vnode.context;
  var ref = vnode.componentInstance || vnode.elm;
  var refs = vm.$refs;
  if (isRemoval) {
    if (Array.isArray(refs[key])) {
      remove(refs[key], ref);
    } else if (refs[key] === ref) {
      refs[key] = undefined;
    }
  } else {
    if (vnode.data.refInFor) {
      if (!Array.isArray(refs[key])) {
        refs[key] = [ref];
      } else if (refs[key].indexOf(ref) < 0) {
        // $flow-disable-line
        refs[key].push(ref);
      }
    } else {
      refs[key] = ref;
    }
  }
}

/**
 * Virtual DOM patching algorithm based on Snabbdom by
 * Simon Friis Vindum (@paldepind)
 * Licensed under the MIT License
 * https://github.com/paldepind/snabbdom/blob/master/LICENSE
 *
 * modified by Evan You (@yyx990803)
 *
 * Not type-checking this because this file is perf-critical and the cost
 * of making flow understand it is not worth it.
 */

var emptyNode = new VNode('', {}, []);

var hooks = ['create', 'activate', 'update', 'remove', 'destroy'];

function sameVnode (a, b) {
  return (
    a.key === b.key && (
      (
        a.tag === b.tag &&
        a.isComment === b.isComment &&
        isDef(a.data) === isDef(b.data) &&
        sameInputType(a, b)
      ) || (
        isTrue(a.isAsyncPlaceholder) &&
        a.asyncFactory === b.asyncFactory &&
        isUndef(b.asyncFactory.error)
      )
    )
  )
}

function sameInputType (a, b) {
  if (a.tag !== 'input') { return true }
  var i;
  var typeA = isDef(i = a.data) && isDef(i = i.attrs) && i.type;
  var typeB = isDef(i = b.data) && isDef(i = i.attrs) && i.type;
  return typeA === typeB || isTextInputType(typeA) && isTextInputType(typeB)
}

function createKeyToOldIdx (children, beginIdx, endIdx) {
  var i, key;
  var map = {};
  for (i = beginIdx; i <= endIdx; ++i) {
    key = children[i].key;
    if (isDef(key)) { map[key] = i; }
  }
  return map
}

function createPatchFunction (backend) {
  var i, j;
  var cbs = {};

  var modules = backend.modules;
  var nodeOps = backend.nodeOps;

  for (i = 0; i < hooks.length; ++i) {
    cbs[hooks[i]] = [];
    for (j = 0; j < modules.length; ++j) {
      if (isDef(modules[j][hooks[i]])) {
        cbs[hooks[i]].push(modules[j][hooks[i]]);
      }
    }
  }

  function emptyNodeAt (elm) {
    return new VNode(nodeOps.tagName(elm).toLowerCase(), {}, [], undefined, elm)
  }

  function createRmCb (childElm, listeners) {
    function remove$$1 () {
      if (--remove$$1.listeners === 0) {
        removeNode(childElm);
      }
    }
    remove$$1.listeners = listeners;
    return remove$$1
  }

  function removeNode (el) {
    var parent = nodeOps.parentNode(el);
    // element may have already been removed due to v-html / v-text
    if (isDef(parent)) {
      nodeOps.removeChild(parent, el);
    }
  }

  function isUnknownElement$$1 (vnode, inVPre) {
    return (
      !inVPre &&
      !vnode.ns &&
      !(
        config.ignoredElements.length &&
        config.ignoredElements.some(function (ignore) {
          return isRegExp(ignore)
            ? ignore.test(vnode.tag)
            : ignore === vnode.tag
        })
      ) &&
      config.isUnknownElement(vnode.tag)
    )
  }

  var creatingElmInVPre = 0;

  function createElm (
    vnode,
    insertedVnodeQueue,
    parentElm,
    refElm,
    nested,
    ownerArray,
    index
  ) {
    if (isDef(vnode.elm) && isDef(ownerArray)) {
      // This vnode was used in a previous render!
      // now it's used as a new node, overwriting its elm would cause
      // potential patch errors down the road when it's used as an insertion
      // reference node. Instead, we clone the node on-demand before creating
      // associated DOM element for it.
      vnode = ownerArray[index] = cloneVNode(vnode);
    }

    vnode.isRootInsert = !nested; // for transition enter check
    if (createComponent(vnode, insertedVnodeQueue, parentElm, refElm)) {
      return
    }

    var data = vnode.data;
    var children = vnode.children;
    var tag = vnode.tag;
    if (isDef(tag)) {
      {
        if (data && data.pre) {
          creatingElmInVPre++;
        }
        if (isUnknownElement$$1(vnode, creatingElmInVPre)) {
          warn(
            'Unknown custom element: <' + tag + '> - did you ' +
            'register the component correctly? For recursive components, ' +
            'make sure to provide the "name" option.',
            vnode.context
          );
        }
      }

      vnode.elm = vnode.ns
        ? nodeOps.createElementNS(vnode.ns, tag)
        : nodeOps.createElement(tag, vnode);
      setScope(vnode);

      /* istanbul ignore if */
      {
        createChildren(vnode, children, insertedVnodeQueue);
        if (isDef(data)) {
          invokeCreateHooks(vnode, insertedVnodeQueue);
        }
        insert(parentElm, vnode.elm, refElm);
      }

      if ( data && data.pre) {
        creatingElmInVPre--;
      }
    } else if (isTrue(vnode.isComment)) {
      vnode.elm = nodeOps.createComment(vnode.text);
      insert(parentElm, vnode.elm, refElm);
    } else {
      vnode.elm = nodeOps.createTextNode(vnode.text);
      insert(parentElm, vnode.elm, refElm);
    }
  }

  function createComponent (vnode, insertedVnodeQueue, parentElm, refElm) {
    var i = vnode.data;
    if (isDef(i)) {
      var isReactivated = isDef(vnode.componentInstance) && i.keepAlive;
      if (isDef(i = i.hook) && isDef(i = i.init)) {
        i(vnode, false /* hydrating */);
      }
      // after calling the init hook, if the vnode is a child component
      // it should've created a child instance and mounted it. the child
      // component also has set the placeholder vnode's elm.
      // in that case we can just return the element and be done.
      if (isDef(vnode.componentInstance)) {
        initComponent(vnode, insertedVnodeQueue);
        insert(parentElm, vnode.elm, refElm);
        if (isTrue(isReactivated)) {
          reactivateComponent(vnode, insertedVnodeQueue, parentElm, refElm);
        }
        return true
      }
    }
  }

  function initComponent (vnode, insertedVnodeQueue) {
    if (isDef(vnode.data.pendingInsert)) {
      insertedVnodeQueue.push.apply(insertedVnodeQueue, vnode.data.pendingInsert);
      vnode.data.pendingInsert = null;
    }
    vnode.elm = vnode.componentInstance.$el;
    if (isPatchable(vnode)) {
      invokeCreateHooks(vnode, insertedVnodeQueue);
      setScope(vnode);
    } else {
      // empty component root.
      // skip all element-related modules except for ref (#3455)
      registerRef(vnode);
      // make sure to invoke the insert hook
      insertedVnodeQueue.push(vnode);
    }
  }

  function reactivateComponent (vnode, insertedVnodeQueue, parentElm, refElm) {
    var i;
    // hack for #4339: a reactivated component with inner transition
    // does not trigger because the inner node's created hooks are not called
    // again. It's not ideal to involve module-specific logic in here but
    // there doesn't seem to be a better way to do it.
    var innerNode = vnode;
    while (innerNode.componentInstance) {
      innerNode = innerNode.componentInstance._vnode;
      if (isDef(i = innerNode.data) && isDef(i = i.transition)) {
        for (i = 0; i < cbs.activate.length; ++i) {
          cbs.activate[i](emptyNode, innerNode);
        }
        insertedVnodeQueue.push(innerNode);
        break
      }
    }
    // unlike a newly created component,
    // a reactivated keep-alive component doesn't insert itself
    insert(parentElm, vnode.elm, refElm);
  }

  function insert (parent, elm, ref$$1) {
    if (isDef(parent)) {
      if (isDef(ref$$1)) {
        if (nodeOps.parentNode(ref$$1) === parent) {
          nodeOps.insertBefore(parent, elm, ref$$1);
        }
      } else {
        nodeOps.appendChild(parent, elm);
      }
    }
  }

  function createChildren (vnode, children, insertedVnodeQueue) {
    if (Array.isArray(children)) {
      {
        checkDuplicateKeys(children);
      }
      for (var i = 0; i < children.length; ++i) {
        createElm(children[i], insertedVnodeQueue, vnode.elm, null, true, children, i);
      }
    } else if (isPrimitive(vnode.text)) {
      nodeOps.appendChild(vnode.elm, nodeOps.createTextNode(String(vnode.text)));
    }
  }

  function isPatchable (vnode) {
    while (vnode.componentInstance) {
      vnode = vnode.componentInstance._vnode;
    }
    return isDef(vnode.tag)
  }

  function invokeCreateHooks (vnode, insertedVnodeQueue) {
    for (var i$1 = 0; i$1 < cbs.create.length; ++i$1) {
      cbs.create[i$1](emptyNode, vnode);
    }
    i = vnode.data.hook; // Reuse variable
    if (isDef(i)) {
      if (isDef(i.create)) { i.create(emptyNode, vnode); }
      if (isDef(i.insert)) { insertedVnodeQueue.push(vnode); }
    }
  }

  // set scope id attribute for scoped CSS.
  // this is implemented as a special case to avoid the overhead
  // of going through the normal attribute patching process.
  function setScope (vnode) {
    var i;
    if (isDef(i = vnode.fnScopeId)) {
      nodeOps.setStyleScope(vnode.elm, i);
    } else {
      var ancestor = vnode;
      while (ancestor) {
        if (isDef(i = ancestor.context) && isDef(i = i.$options._scopeId)) {
          nodeOps.setStyleScope(vnode.elm, i);
        }
        ancestor = ancestor.parent;
      }
    }
    // for slot content they should also get the scopeId from the host instance.
    if (isDef(i = activeInstance) &&
      i !== vnode.context &&
      i !== vnode.fnContext &&
      isDef(i = i.$options._scopeId)
    ) {
      nodeOps.setStyleScope(vnode.elm, i);
    }
  }

  function addVnodes (parentElm, refElm, vnodes, startIdx, endIdx, insertedVnodeQueue) {
    for (; startIdx <= endIdx; ++startIdx) {
      createElm(vnodes[startIdx], insertedVnodeQueue, parentElm, refElm, false, vnodes, startIdx);
    }
  }

  function invokeDestroyHook (vnode) {
    var i, j;
    var data = vnode.data;
    if (isDef(data)) {
      if (isDef(i = data.hook) && isDef(i = i.destroy)) { i(vnode); }
      for (i = 0; i < cbs.destroy.length; ++i) { cbs.destroy[i](vnode); }
    }
    if (isDef(i = vnode.children)) {
      for (j = 0; j < vnode.children.length; ++j) {
        invokeDestroyHook(vnode.children[j]);
      }
    }
  }

  function removeVnodes (vnodes, startIdx, endIdx) {
    for (; startIdx <= endIdx; ++startIdx) {
      var ch = vnodes[startIdx];
      if (isDef(ch)) {
        if (isDef(ch.tag)) {
          removeAndInvokeRemoveHook(ch);
          invokeDestroyHook(ch);
        } else { // Text node
          removeNode(ch.elm);
        }
      }
    }
  }

  function removeAndInvokeRemoveHook (vnode, rm) {
    if (isDef(rm) || isDef(vnode.data)) {
      var i;
      var listeners = cbs.remove.length + 1;
      if (isDef(rm)) {
        // we have a recursively passed down rm callback
        // increase the listeners count
        rm.listeners += listeners;
      } else {
        // directly removing
        rm = createRmCb(vnode.elm, listeners);
      }
      // recursively invoke hooks on child component root node
      if (isDef(i = vnode.componentInstance) && isDef(i = i._vnode) && isDef(i.data)) {
        removeAndInvokeRemoveHook(i, rm);
      }
      for (i = 0; i < cbs.remove.length; ++i) {
        cbs.remove[i](vnode, rm);
      }
      if (isDef(i = vnode.data.hook) && isDef(i = i.remove)) {
        i(vnode, rm);
      } else {
        rm();
      }
    } else {
      removeNode(vnode.elm);
    }
  }

  function updateChildren (parentElm, oldCh, newCh, insertedVnodeQueue, removeOnly) {
    var oldStartIdx = 0;
    var newStartIdx = 0;
    var oldEndIdx = oldCh.length - 1;
    var oldStartVnode = oldCh[0];
    var oldEndVnode = oldCh[oldEndIdx];
    var newEndIdx = newCh.length - 1;
    var newStartVnode = newCh[0];
    var newEndVnode = newCh[newEndIdx];
    var oldKeyToIdx, idxInOld, vnodeToMove, refElm;

    // removeOnly is a special flag used only by <transition-group>
    // to ensure removed elements stay in correct relative positions
    // during leaving transitions
    var canMove = !removeOnly;

    {
      checkDuplicateKeys(newCh);
    }

    while (oldStartIdx <= oldEndIdx && newStartIdx <= newEndIdx) {
      if (isUndef(oldStartVnode)) {
        oldStartVnode = oldCh[++oldStartIdx]; // Vnode has been moved left
      } else if (isUndef(oldEndVnode)) {
        oldEndVnode = oldCh[--oldEndIdx];
      } else if (sameVnode(oldStartVnode, newStartVnode)) {
        patchVnode(oldStartVnode, newStartVnode, insertedVnodeQueue, newCh, newStartIdx);
        oldStartVnode = oldCh[++oldStartIdx];
        newStartVnode = newCh[++newStartIdx];
      } else if (sameVnode(oldEndVnode, newEndVnode)) {
        patchVnode(oldEndVnode, newEndVnode, insertedVnodeQueue, newCh, newEndIdx);
        oldEndVnode = oldCh[--oldEndIdx];
        newEndVnode = newCh[--newEndIdx];
      } else if (sameVnode(oldStartVnode, newEndVnode)) { // Vnode moved right
        patchVnode(oldStartVnode, newEndVnode, insertedVnodeQueue, newCh, newEndIdx);
        canMove && nodeOps.insertBefore(parentElm, oldStartVnode.elm, nodeOps.nextSibling(oldEndVnode.elm));
        oldStartVnode = oldCh[++oldStartIdx];
        newEndVnode = newCh[--newEndIdx];
      } else if (sameVnode(oldEndVnode, newStartVnode)) { // Vnode moved left
        patchVnode(oldEndVnode, newStartVnode, insertedVnodeQueue, newCh, newStartIdx);
        canMove && nodeOps.insertBefore(parentElm, oldEndVnode.elm, oldStartVnode.elm);
        oldEndVnode = oldCh[--oldEndIdx];
        newStartVnode = newCh[++newStartIdx];
      } else {
        if (isUndef(oldKeyToIdx)) { oldKeyToIdx = createKeyToOldIdx(oldCh, oldStartIdx, oldEndIdx); }
        idxInOld = isDef(newStartVnode.key)
          ? oldKeyToIdx[newStartVnode.key]
          : findIdxInOld(newStartVnode, oldCh, oldStartIdx, oldEndIdx);
        if (isUndef(idxInOld)) { // New element
          createElm(newStartVnode, insertedVnodeQueue, parentElm, oldStartVnode.elm, false, newCh, newStartIdx);
        } else {
          vnodeToMove = oldCh[idxInOld];
          if (sameVnode(vnodeToMove, newStartVnode)) {
            patchVnode(vnodeToMove, newStartVnode, insertedVnodeQueue, newCh, newStartIdx);
            oldCh[idxInOld] = undefined;
            canMove && nodeOps.insertBefore(parentElm, vnodeToMove.elm, oldStartVnode.elm);
          } else {
            // same key but different element. treat as new element
            createElm(newStartVnode, insertedVnodeQueue, parentElm, oldStartVnode.elm, false, newCh, newStartIdx);
          }
        }
        newStartVnode = newCh[++newStartIdx];
      }
    }
    if (oldStartIdx > oldEndIdx) {
      refElm = isUndef(newCh[newEndIdx + 1]) ? null : newCh[newEndIdx + 1].elm;
      addVnodes(parentElm, refElm, newCh, newStartIdx, newEndIdx, insertedVnodeQueue);
    } else if (newStartIdx > newEndIdx) {
      removeVnodes(oldCh, oldStartIdx, oldEndIdx);
    }
  }

  function checkDuplicateKeys (children) {
    var seenKeys = {};
    for (var i = 0; i < children.length; i++) {
      var vnode = children[i];
      var key = vnode.key;
      if (isDef(key)) {
        if (seenKeys[key]) {
          warn(
            ("Duplicate keys detected: '" + key + "'. This may cause an update error."),
            vnode.context
          );
        } else {
          seenKeys[key] = true;
        }
      }
    }
  }

  function findIdxInOld (node, oldCh, start, end) {
    for (var i = start; i < end; i++) {
      var c = oldCh[i];
      if (isDef(c) && sameVnode(node, c)) { return i }
    }
  }

  function patchVnode (
    oldVnode,
    vnode,
    insertedVnodeQueue,
    ownerArray,
    index,
    removeOnly
  ) {
    if (oldVnode === vnode) {
      return
    }

    if (isDef(vnode.elm) && isDef(ownerArray)) {
      // clone reused vnode
      vnode = ownerArray[index] = cloneVNode(vnode);
    }

    var elm = vnode.elm = oldVnode.elm;

    if (isTrue(oldVnode.isAsyncPlaceholder)) {
      if (isDef(vnode.asyncFactory.resolved)) {
        hydrate(oldVnode.elm, vnode, insertedVnodeQueue);
      } else {
        vnode.isAsyncPlaceholder = true;
      }
      return
    }

    // reuse element for static trees.
    // note we only do this if the vnode is cloned -
    // if the new node is not cloned it means the render functions have been
    // reset by the hot-reload-api and we need to do a proper re-render.
    if (isTrue(vnode.isStatic) &&
      isTrue(oldVnode.isStatic) &&
      vnode.key === oldVnode.key &&
      (isTrue(vnode.isCloned) || isTrue(vnode.isOnce))
    ) {
      vnode.componentInstance = oldVnode.componentInstance;
      return
    }

    var i;
    var data = vnode.data;
    if (isDef(data) && isDef(i = data.hook) && isDef(i = i.prepatch)) {
      i(oldVnode, vnode);
    }

    var oldCh = oldVnode.children;
    var ch = vnode.children;
    if (isDef(data) && isPatchable(vnode)) {
      for (i = 0; i < cbs.update.length; ++i) { cbs.update[i](oldVnode, vnode); }
      if (isDef(i = data.hook) && isDef(i = i.update)) { i(oldVnode, vnode); }
    }
    if (isUndef(vnode.text)) {
      if (isDef(oldCh) && isDef(ch)) {
        if (oldCh !== ch) { updateChildren(elm, oldCh, ch, insertedVnodeQueue, removeOnly); }
      } else if (isDef(ch)) {
        {
          checkDuplicateKeys(ch);
        }
        if (isDef(oldVnode.text)) { nodeOps.setTextContent(elm, ''); }
        addVnodes(elm, null, ch, 0, ch.length - 1, insertedVnodeQueue);
      } else if (isDef(oldCh)) {
        removeVnodes(oldCh, 0, oldCh.length - 1);
      } else if (isDef(oldVnode.text)) {
        nodeOps.setTextContent(elm, '');
      }
    } else if (oldVnode.text !== vnode.text) {
      nodeOps.setTextContent(elm, vnode.text);
    }
    if (isDef(data)) {
      if (isDef(i = data.hook) && isDef(i = i.postpatch)) { i(oldVnode, vnode); }
    }
  }

  function invokeInsertHook (vnode, queue, initial) {
    // delay insert hooks for component root nodes, invoke them after the
    // element is really inserted
    if (isTrue(initial) && isDef(vnode.parent)) {
      vnode.parent.data.pendingInsert = queue;
    } else {
      for (var i = 0; i < queue.length; ++i) {
        queue[i].data.hook.insert(queue[i]);
      }
    }
  }

  var hydrationBailed = false;
  // list of modules that can skip create hook during hydration because they
  // are already rendered on the client or has no need for initialization
  // Note: style is excluded because it relies on initial clone for future
  // deep updates (#7063).
  var isRenderedModule = makeMap('attrs,class,staticClass,staticStyle,key');

  // Note: this is a browser-only function so we can assume elms are DOM nodes.
  function hydrate (elm, vnode, insertedVnodeQueue, inVPre) {
    var i;
    var tag = vnode.tag;
    var data = vnode.data;
    var children = vnode.children;
    inVPre = inVPre || (data && data.pre);
    vnode.elm = elm;

    if (isTrue(vnode.isComment) && isDef(vnode.asyncFactory)) {
      vnode.isAsyncPlaceholder = true;
      return true
    }
    // assert node match
    {
      if (!assertNodeMatch(elm, vnode, inVPre)) {
        return false
      }
    }
    if (isDef(data)) {
      if (isDef(i = data.hook) && isDef(i = i.init)) { i(vnode, true /* hydrating */); }
      if (isDef(i = vnode.componentInstance)) {
        // child component. it should have hydrated its own tree.
        initComponent(vnode, insertedVnodeQueue);
        return true
      }
    }
    if (isDef(tag)) {
      if (isDef(children)) {
        // empty element, allow client to pick up and populate children
        if (!elm.hasChildNodes()) {
          createChildren(vnode, children, insertedVnodeQueue);
        } else {
          // v-html and domProps: innerHTML
          if (isDef(i = data) && isDef(i = i.domProps) && isDef(i = i.innerHTML)) {
            if (i !== elm.innerHTML) {
              /* istanbul ignore if */
              if (
                typeof console !== 'undefined' &&
                !hydrationBailed
              ) {
                hydrationBailed = true;
                console.warn('Parent: ', elm);
                console.warn('server innerHTML: ', i);
                console.warn('client innerHTML: ', elm.innerHTML);
              }
              return false
            }
          } else {
            // iterate and compare children lists
            var childrenMatch = true;
            var childNode = elm.firstChild;
            for (var i$1 = 0; i$1 < children.length; i$1++) {
              if (!childNode || !hydrate(childNode, children[i$1], insertedVnodeQueue, inVPre)) {
                childrenMatch = false;
                break
              }
              childNode = childNode.nextSibling;
            }
            // if childNode is not null, it means the actual childNodes list is
            // longer than the virtual children list.
            if (!childrenMatch || childNode) {
              /* istanbul ignore if */
              if (
                typeof console !== 'undefined' &&
                !hydrationBailed
              ) {
                hydrationBailed = true;
                console.warn('Parent: ', elm);
                console.warn('Mismatching childNodes vs. VNodes: ', elm.childNodes, children);
              }
              return false
            }
          }
        }
      }
      if (isDef(data)) {
        var fullInvoke = false;
        for (var key in data) {
          if (!isRenderedModule(key)) {
            fullInvoke = true;
            invokeCreateHooks(vnode, insertedVnodeQueue);
            break
          }
        }
        if (!fullInvoke && data['class']) {
          // ensure collecting deps for deep class bindings for future updates
          traverse(data['class']);
        }
      }
    } else if (elm.data !== vnode.text) {
      elm.data = vnode.text;
    }
    return true
  }

  function assertNodeMatch (node, vnode, inVPre) {
    if (isDef(vnode.tag)) {
      return vnode.tag.indexOf('vue-component') === 0 || (
        !isUnknownElement$$1(vnode, inVPre) &&
        vnode.tag.toLowerCase() === (node.tagName && node.tagName.toLowerCase())
      )
    } else {
      return node.nodeType === (vnode.isComment ? 8 : 3)
    }
  }

  return function patch (oldVnode, vnode, hydrating, removeOnly) {
    if (isUndef(vnode)) {
      if (isDef(oldVnode)) { invokeDestroyHook(oldVnode); }
      return
    }

    var isInitialPatch = false;
    var insertedVnodeQueue = [];

    if (isUndef(oldVnode)) {
      // empty mount (likely as component), create new root element
      isInitialPatch = true;
      createElm(vnode, insertedVnodeQueue);
    } else {
      var isRealElement = isDef(oldVnode.nodeType);
      if (!isRealElement && sameVnode(oldVnode, vnode)) {
        // patch existing root node
        patchVnode(oldVnode, vnode, insertedVnodeQueue, null, null, removeOnly);
      } else {
        if (isRealElement) {
          // mounting to a real element
          // check if this is server-rendered content and if we can perform
          // a successful hydration.
          if (oldVnode.nodeType === 1 && oldVnode.hasAttribute(SSR_ATTR)) {
            oldVnode.removeAttribute(SSR_ATTR);
            hydrating = true;
          }
          if (isTrue(hydrating)) {
            if (hydrate(oldVnode, vnode, insertedVnodeQueue)) {
              invokeInsertHook(vnode, insertedVnodeQueue, true);
              return oldVnode
            } else {
              warn(
                'The client-side rendered virtual DOM tree is not matching ' +
                'server-rendered content. This is likely caused by incorrect ' +
                'HTML markup, for example nesting block-level elements inside ' +
                '<p>, or missing <tbody>. Bailing hydration and performing ' +
                'full client-side render.'
              );
            }
          }
          // either not server-rendered, or hydration failed.
          // create an empty node and replace it
          oldVnode = emptyNodeAt(oldVnode);
        }

        // replacing existing element
        var oldElm = oldVnode.elm;
        var parentElm = nodeOps.parentNode(oldElm);

        // create new node
        createElm(
          vnode,
          insertedVnodeQueue,
          // extremely rare edge case: do not insert if old element is in a
          // leaving transition. Only happens when combining transition +
          // keep-alive + HOCs. (#4590)
          oldElm._leaveCb ? null : parentElm,
          nodeOps.nextSibling(oldElm)
        );

        // update parent placeholder node element, recursively
        if (isDef(vnode.parent)) {
          var ancestor = vnode.parent;
          var patchable = isPatchable(vnode);
          while (ancestor) {
            for (var i = 0; i < cbs.destroy.length; ++i) {
              cbs.destroy[i](ancestor);
            }
            ancestor.elm = vnode.elm;
            if (patchable) {
              for (var i$1 = 0; i$1 < cbs.create.length; ++i$1) {
                cbs.create[i$1](emptyNode, ancestor);
              }
              // #6513
              // invoke insert hooks that may have been merged by create hooks.
              // e.g. for directives that uses the "inserted" hook.
              var insert = ancestor.data.hook.insert;
              if (insert.merged) {
                // start at index 1 to avoid re-invoking component mounted hook
                for (var i$2 = 1; i$2 < insert.fns.length; i$2++) {
                  insert.fns[i$2]();
                }
              }
            } else {
              registerRef(ancestor);
            }
            ancestor = ancestor.parent;
          }
        }

        // destroy old node
        if (isDef(parentElm)) {
          removeVnodes([oldVnode], 0, 0);
        } else if (isDef(oldVnode.tag)) {
          invokeDestroyHook(oldVnode);
        }
      }
    }

    invokeInsertHook(vnode, insertedVnodeQueue, isInitialPatch);
    return vnode.elm
  }
}

/*  */

var directives = {
  create: updateDirectives,
  update: updateDirectives,
  destroy: function unbindDirectives (vnode) {
    updateDirectives(vnode, emptyNode);
  }
};

function updateDirectives (oldVnode, vnode) {
  if (oldVnode.data.directives || vnode.data.directives) {
    _update(oldVnode, vnode);
  }
}

function _update (oldVnode, vnode) {
  var isCreate = oldVnode === emptyNode;
  var isDestroy = vnode === emptyNode;
  var oldDirs = normalizeDirectives$1(oldVnode.data.directives, oldVnode.context);
  var newDirs = normalizeDirectives$1(vnode.data.directives, vnode.context);

  var dirsWithInsert = [];
  var dirsWithPostpatch = [];

  var key, oldDir, dir;
  for (key in newDirs) {
    oldDir = oldDirs[key];
    dir = newDirs[key];
    if (!oldDir) {
      // new directive, bind
      callHook$1(dir, 'bind', vnode, oldVnode);
      if (dir.def && dir.def.inserted) {
        dirsWithInsert.push(dir);
      }
    } else {
      // existing directive, update
      dir.oldValue = oldDir.value;
      dir.oldArg = oldDir.arg;
      callHook$1(dir, 'update', vnode, oldVnode);
      if (dir.def && dir.def.componentUpdated) {
        dirsWithPostpatch.push(dir);
      }
    }
  }

  if (dirsWithInsert.length) {
    var callInsert = function () {
      for (var i = 0; i < dirsWithInsert.length; i++) {
        callHook$1(dirsWithInsert[i], 'inserted', vnode, oldVnode);
      }
    };
    if (isCreate) {
      mergeVNodeHook(vnode, 'insert', callInsert);
    } else {
      callInsert();
    }
  }

  if (dirsWithPostpatch.length) {
    mergeVNodeHook(vnode, 'postpatch', function () {
      for (var i = 0; i < dirsWithPostpatch.length; i++) {
        callHook$1(dirsWithPostpatch[i], 'componentUpdated', vnode, oldVnode);
      }
    });
  }

  if (!isCreate) {
    for (key in oldDirs) {
      if (!newDirs[key]) {
        // no longer present, unbind
        callHook$1(oldDirs[key], 'unbind', oldVnode, oldVnode, isDestroy);
      }
    }
  }
}

var emptyModifiers = Object.create(null);

function normalizeDirectives$1 (
  dirs,
  vm
) {
  var res = Object.create(null);
  if (!dirs) {
    // $flow-disable-line
    return res
  }
  var i, dir;
  for (i = 0; i < dirs.length; i++) {
    dir = dirs[i];
    if (!dir.modifiers) {
      // $flow-disable-line
      dir.modifiers = emptyModifiers;
    }
    res[getRawDirName(dir)] = dir;
    dir.def = resolveAsset(vm.$options, 'directives', dir.name, true);
  }
  // $flow-disable-line
  return res
}

function getRawDirName (dir) {
  return dir.rawName || ((dir.name) + "." + (Object.keys(dir.modifiers || {}).join('.')))
}

function callHook$1 (dir, hook, vnode, oldVnode, isDestroy) {
  var fn = dir.def && dir.def[hook];
  if (fn) {
    try {
      fn(vnode.elm, dir, vnode, oldVnode, isDestroy);
    } catch (e) {
      handleError(e, vnode.context, ("directive " + (dir.name) + " " + hook + " hook"));
    }
  }
}

var baseModules = [
  ref,
  directives
];

/*  */

function updateAttrs (oldVnode, vnode) {
  var opts = vnode.componentOptions;
  if (isDef(opts) && opts.Ctor.options.inheritAttrs === false) {
    return
  }
  if (isUndef(oldVnode.data.attrs) && isUndef(vnode.data.attrs)) {
    return
  }
  var key, cur, old;
  var elm = vnode.elm;
  var oldAttrs = oldVnode.data.attrs || {};
  var attrs = vnode.data.attrs || {};
  // clone observed objects, as the user probably wants to mutate it
  if (isDef(attrs.__ob__)) {
    attrs = vnode.data.attrs = extend({}, attrs);
  }

  for (key in attrs) {
    cur = attrs[key];
    old = oldAttrs[key];
    if (old !== cur) {
      setAttr(elm, key, cur);
    }
  }
  // #4391: in IE9, setting type can reset value for input[type=radio]
  // #6666: IE/Edge forces progress value down to 1 before setting a max
  /* istanbul ignore if */
  if ((isIE || isEdge) && attrs.value !== oldAttrs.value) {
    setAttr(elm, 'value', attrs.value);
  }
  for (key in oldAttrs) {
    if (isUndef(attrs[key])) {
      if (isXlink(key)) {
        elm.removeAttributeNS(xlinkNS, getXlinkProp(key));
      } else if (!isEnumeratedAttr(key)) {
        elm.removeAttribute(key);
      }
    }
  }
}

function setAttr (el, key, value) {
  if (el.tagName.indexOf('-') > -1) {
    baseSetAttr(el, key, value);
  } else if (isBooleanAttr(key)) {
    // set attribute for blank value
    // e.g. <option disabled>Select one</option>
    if (isFalsyAttrValue(value)) {
      el.removeAttribute(key);
    } else {
      // technically allowfullscreen is a boolean attribute for <iframe>,
      // but Flash expects a value of "true" when used on <embed> tag
      value = key === 'allowfullscreen' && el.tagName === 'EMBED'
        ? 'true'
        : key;
      el.setAttribute(key, value);
    }
  } else if (isEnumeratedAttr(key)) {
    el.setAttribute(key, convertEnumeratedValue(key, value));
  } else if (isXlink(key)) {
    if (isFalsyAttrValue(value)) {
      el.removeAttributeNS(xlinkNS, getXlinkProp(key));
    } else {
      el.setAttributeNS(xlinkNS, key, value);
    }
  } else {
    baseSetAttr(el, key, value);
  }
}

function baseSetAttr (el, key, value) {
  if (isFalsyAttrValue(value)) {
    el.removeAttribute(key);
  } else {
    // #7138: IE10 & 11 fires input event when setting placeholder on
    // <textarea>... block the first input event and remove the blocker
    // immediately.
    /* istanbul ignore if */
    if (
      isIE && !isIE9 &&
      el.tagName === 'TEXTAREA' &&
      key === 'placeholder' && value !== '' && !el.__ieph
    ) {
      var blocker = function (e) {
        e.stopImmediatePropagation();
        el.removeEventListener('input', blocker);
      };
      el.addEventListener('input', blocker);
      // $flow-disable-line
      el.__ieph = true; /* IE placeholder patched */
    }
    el.setAttribute(key, value);
  }
}

var attrs = {
  create: updateAttrs,
  update: updateAttrs
};

/*  */

function updateClass (oldVnode, vnode) {
  var el = vnode.elm;
  var data = vnode.data;
  var oldData = oldVnode.data;
  if (
    isUndef(data.staticClass) &&
    isUndef(data.class) && (
      isUndef(oldData) || (
        isUndef(oldData.staticClass) &&
        isUndef(oldData.class)
      )
    )
  ) {
    return
  }

  var cls = genClassForVnode(vnode);

  // handle transition classes
  var transitionClass = el._transitionClasses;
  if (isDef(transitionClass)) {
    cls = concat(cls, stringifyClass(transitionClass));
  }

  // set the class
  if (cls !== el._prevClass) {
    el.setAttribute('class', cls);
    el._prevClass = cls;
  }
}

var klass = {
  create: updateClass,
  update: updateClass
};

/*  */

var validDivisionCharRE = /[\w).+\-_$\]]/;

function parseFilters (exp) {
  var inSingle = false;
  var inDouble = false;
  var inTemplateString = false;
  var inRegex = false;
  var curly = 0;
  var square = 0;
  var paren = 0;
  var lastFilterIndex = 0;
  var c, prev, i, expression, filters;

  for (i = 0; i < exp.length; i++) {
    prev = c;
    c = exp.charCodeAt(i);
    if (inSingle) {
      if (c === 0x27 && prev !== 0x5C) { inSingle = false; }
    } else if (inDouble) {
      if (c === 0x22 && prev !== 0x5C) { inDouble = false; }
    } else if (inTemplateString) {
      if (c === 0x60 && prev !== 0x5C) { inTemplateString = false; }
    } else if (inRegex) {
      if (c === 0x2f && prev !== 0x5C) { inRegex = false; }
    } else if (
      c === 0x7C && // pipe
      exp.charCodeAt(i + 1) !== 0x7C &&
      exp.charCodeAt(i - 1) !== 0x7C &&
      !curly && !square && !paren
    ) {
      if (expression === undefined) {
        // first filter, end of expression
        lastFilterIndex = i + 1;
        expression = exp.slice(0, i).trim();
      } else {
        pushFilter();
      }
    } else {
      switch (c) {
        case 0x22: inDouble = true; break         // "
        case 0x27: inSingle = true; break         // '
        case 0x60: inTemplateString = true; break // `
        case 0x28: paren++; break                 // (
        case 0x29: paren--; break                 // )
        case 0x5B: square++; break                // [
        case 0x5D: square--; break                // ]
        case 0x7B: curly++; break                 // {
        case 0x7D: curly--; break                 // }
      }
      if (c === 0x2f) { // /
        var j = i - 1;
        var p = (void 0);
        // find first non-whitespace prev char
        for (; j >= 0; j--) {
          p = exp.charAt(j);
          if (p !== ' ') { break }
        }
        if (!p || !validDivisionCharRE.test(p)) {
          inRegex = true;
        }
      }
    }
  }

  if (expression === undefined) {
    expression = exp.slice(0, i).trim();
  } else if (lastFilterIndex !== 0) {
    pushFilter();
  }

  function pushFilter () {
    (filters || (filters = [])).push(exp.slice(lastFilterIndex, i).trim());
    lastFilterIndex = i + 1;
  }

  if (filters) {
    for (i = 0; i < filters.length; i++) {
      expression = wrapFilter(expression, filters[i]);
    }
  }

  return expression
}

function wrapFilter (exp, filter) {
  var i = filter.indexOf('(');
  if (i < 0) {
    // _f: resolveFilter
    return ("_f(\"" + filter + "\")(" + exp + ")")
  } else {
    var name = filter.slice(0, i);
    var args = filter.slice(i + 1);
    return ("_f(\"" + name + "\")(" + exp + (args !== ')' ? ',' + args : args))
  }
}

/*  */



/* eslint-disable no-unused-vars */
function baseWarn (msg, range) {
  console.error(("[Vue compiler]: " + msg));
}
/* eslint-enable no-unused-vars */

function pluckModuleFunction (
  modules,
  key
) {
  return modules
    ? modules.map(function (m) { return m[key]; }).filter(function (_) { return _; })
    : []
}

function addProp (el, name, value, range, dynamic) {
  (el.props || (el.props = [])).push(rangeSetItem({ name: name, value: value, dynamic: dynamic }, range));
  el.plain = false;
}

function addAttr (el, name, value, range, dynamic) {
  var attrs = dynamic
    ? (el.dynamicAttrs || (el.dynamicAttrs = []))
    : (el.attrs || (el.attrs = []));
  attrs.push(rangeSetItem({ name: name, value: value, dynamic: dynamic }, range));
  el.plain = false;
}

// add a raw attr (use this in preTransforms)
function addRawAttr (el, name, value, range) {
  el.attrsMap[name] = value;
  el.attrsList.push(rangeSetItem({ name: name, value: value }, range));
}

function addDirective (
  el,
  name,
  rawName,
  value,
  arg,
  isDynamicArg,
  modifiers,
  range
) {
  (el.directives || (el.directives = [])).push(rangeSetItem({
    name: name,
    rawName: rawName,
    value: value,
    arg: arg,
    isDynamicArg: isDynamicArg,
    modifiers: modifiers
  }, range));
  el.plain = false;
}

function prependModifierMarker (symbol, name, dynamic) {
  return dynamic
    ? ("_p(" + name + ",\"" + symbol + "\")")
    : symbol + name // mark the event as captured
}

function addHandler (
  el,
  name,
  value,
  modifiers,
  important,
  warn,
  range,
  dynamic
) {
  modifiers = modifiers || emptyObject;
  // warn prevent and passive modifier
  /* istanbul ignore if */
  if (
     warn &&
    modifiers.prevent && modifiers.passive
  ) {
    warn(
      'passive and prevent can\'t be used together. ' +
      'Passive handler can\'t prevent default event.',
      range
    );
  }

  // normalize click.right and click.middle since they don't actually fire
  // this is technically browser-specific, but at least for now browsers are
  // the only target envs that have right/middle clicks.
  if (modifiers.right) {
    if (dynamic) {
      name = "(" + name + ")==='click'?'contextmenu':(" + name + ")";
    } else if (name === 'click') {
      name = 'contextmenu';
      delete modifiers.right;
    }
  } else if (modifiers.middle) {
    if (dynamic) {
      name = "(" + name + ")==='click'?'mouseup':(" + name + ")";
    } else if (name === 'click') {
      name = 'mouseup';
    }
  }

  // check capture modifier
  if (modifiers.capture) {
    delete modifiers.capture;
    name = prependModifierMarker('!', name, dynamic);
  }
  if (modifiers.once) {
    delete modifiers.once;
    name = prependModifierMarker('~', name, dynamic);
  }
  /* istanbul ignore if */
  if (modifiers.passive) {
    delete modifiers.passive;
    name = prependModifierMarker('&', name, dynamic);
  }

  var events;
  if (modifiers.native) {
    delete modifiers.native;
    events = el.nativeEvents || (el.nativeEvents = {});
  } else {
    events = el.events || (el.events = {});
  }

  var newHandler = rangeSetItem({ value: value.trim(), dynamic: dynamic }, range);
  if (modifiers !== emptyObject) {
    newHandler.modifiers = modifiers;
  }

  var handlers = events[name];
  /* istanbul ignore if */
  if (Array.isArray(handlers)) {
    important ? handlers.unshift(newHandler) : handlers.push(newHandler);
  } else if (handlers) {
    events[name] = important ? [newHandler, handlers] : [handlers, newHandler];
  } else {
    events[name] = newHandler;
  }

  el.plain = false;
}

function getRawBindingAttr (
  el,
  name
) {
  return el.rawAttrsMap[':' + name] ||
    el.rawAttrsMap['v-bind:' + name] ||
    el.rawAttrsMap[name]
}

function getBindingAttr (
  el,
  name,
  getStatic
) {
  var dynamicValue =
    getAndRemoveAttr(el, ':' + name) ||
    getAndRemoveAttr(el, 'v-bind:' + name);
  if (dynamicValue != null) {
    return parseFilters(dynamicValue)
  } else if (getStatic !== false) {
    var staticValue = getAndRemoveAttr(el, name);
    if (staticValue != null) {
      return JSON.stringify(staticValue)
    }
  }
}

// note: this only removes the attr from the Array (attrsList) so that it
// doesn't get processed by processAttrs.
// By default it does NOT remove it from the map (attrsMap) because the map is
// needed during codegen.
function getAndRemoveAttr (
  el,
  name,
  removeFromMap
) {
  var val;
  if ((val = el.attrsMap[name]) != null) {
    var list = el.attrsList;
    for (var i = 0, l = list.length; i < l; i++) {
      if (list[i].name === name) {
        list.splice(i, 1);
        break
      }
    }
  }
  if (removeFromMap) {
    delete el.attrsMap[name];
  }
  return val
}

function getAndRemoveAttrByRegex (
  el,
  name
) {
  var list = el.attrsList;
  for (var i = 0, l = list.length; i < l; i++) {
    var attr = list[i];
    if (name.test(attr.name)) {
      list.splice(i, 1);
      return attr
    }
  }
}

function rangeSetItem (
  item,
  range
) {
  if (range) {
    if (range.start != null) {
      item.start = range.start;
    }
    if (range.end != null) {
      item.end = range.end;
    }
  }
  return item
}

/*  */

/**
 * Cross-platform code generation for component v-model
 */
function genComponentModel (
  el,
  value,
  modifiers
) {
  var ref = modifiers || {};
  var number = ref.number;
  var trim = ref.trim;

  var baseValueExpression = '$$v';
  var valueExpression = baseValueExpression;
  if (trim) {
    valueExpression =
      "(typeof " + baseValueExpression + " === 'string'" +
      "? " + baseValueExpression + ".trim()" +
      ": " + baseValueExpression + ")";
  }
  if (number) {
    valueExpression = "_n(" + valueExpression + ")";
  }
  var assignment = genAssignmentCode(value, valueExpression);

  el.model = {
    value: ("(" + value + ")"),
    expression: JSON.stringify(value),
    callback: ("function (" + baseValueExpression + ") {" + assignment + "}")
  };
}

/**
 * Cross-platform codegen helper for generating v-model value assignment code.
 */
function genAssignmentCode (
  value,
  assignment
) {
  var res = parseModel(value);
  if (res.key === null) {
    return (value + "=" + assignment)
  } else {
    return ("$set(" + (res.exp) + ", " + (res.key) + ", " + assignment + ")")
  }
}

/**
 * Parse a v-model expression into a base path and a final key segment.
 * Handles both dot-path and possible square brackets.
 *
 * Possible cases:
 *
 * - test
 * - test[key]
 * - test[test1[key]]
 * - test["a"][key]
 * - xxx.test[a[a].test1[key]]
 * - test.xxx.a["asa"][test1[key]]
 *
 */

var len, str, chr, index$1, expressionPos, expressionEndPos;



function parseModel (val) {
  // Fix https://github.com/vuejs/vue/pull/7730
  // allow v-model="obj.val " (trailing whitespace)
  val = val.trim();
  len = val.length;

  if (val.indexOf('[') < 0 || val.lastIndexOf(']') < len - 1) {
    index$1 = val.lastIndexOf('.');
    if (index$1 > -1) {
      return {
        exp: val.slice(0, index$1),
        key: '"' + val.slice(index$1 + 1) + '"'
      }
    } else {
      return {
        exp: val,
        key: null
      }
    }
  }

  str = val;
  index$1 = expressionPos = expressionEndPos = 0;

  while (!eof()) {
    chr = next();
    /* istanbul ignore if */
    if (isStringStart(chr)) {
      parseString(chr);
    } else if (chr === 0x5B) {
      parseBracket(chr);
    }
  }

  return {
    exp: val.slice(0, expressionPos),
    key: val.slice(expressionPos + 1, expressionEndPos)
  }
}

function next () {
  return str.charCodeAt(++index$1)
}

function eof () {
  return index$1 >= len
}

function isStringStart (chr) {
  return chr === 0x22 || chr === 0x27
}

function parseBracket (chr) {
  var inBracket = 1;
  expressionPos = index$1;
  while (!eof()) {
    chr = next();
    if (isStringStart(chr)) {
      parseString(chr);
      continue
    }
    if (chr === 0x5B) { inBracket++; }
    if (chr === 0x5D) { inBracket--; }
    if (inBracket === 0) {
      expressionEndPos = index$1;
      break
    }
  }
}

function parseString (chr) {
  var stringQuote = chr;
  while (!eof()) {
    chr = next();
    if (chr === stringQuote) {
      break
    }
  }
}

/*  */

var warn$1;

// in some cases, the event used has to be determined at runtime
// so we used some reserved tokens during compile.
var RANGE_TOKEN = '__r';
var CHECKBOX_RADIO_TOKEN = '__c';

function model (
  el,
  dir,
  _warn
) {
  warn$1 = _warn;
  var value = dir.value;
  var modifiers = dir.modifiers;
  var tag = el.tag;
  var type = el.attrsMap.type;

  {
    // inputs with type="file" are read only and setting the input's
    // value will throw an error.
    if (tag === 'input' && type === 'file') {
      warn$1(
        "<" + (el.tag) + " v-model=\"" + value + "\" type=\"file\">:\n" +
        "File inputs are read only. Use a v-on:change listener instead.",
        el.rawAttrsMap['v-model']
      );
    }
  }

  if (el.component) {
    genComponentModel(el, value, modifiers);
    // component v-model doesn't need extra runtime
    return false
  } else if (tag === 'select') {
    genSelect(el, value, modifiers);
  } else if (tag === 'input' && type === 'checkbox') {
    genCheckboxModel(el, value, modifiers);
  } else if (tag === 'input' && type === 'radio') {
    genRadioModel(el, value, modifiers);
  } else if (tag === 'input' || tag === 'textarea') {
    genDefaultModel(el, value, modifiers);
  } else if (!config.isReservedTag(tag)) {
    genComponentModel(el, value, modifiers);
    // component v-model doesn't need extra runtime
    return false
  } else {
    warn$1(
      "<" + (el.tag) + " v-model=\"" + value + "\">: " +
      "v-model is not supported on this element type. " +
      'If you are working with contenteditable, it\'s recommended to ' +
      'wrap a library dedicated for that purpose inside a custom component.',
      el.rawAttrsMap['v-model']
    );
  }

  // ensure runtime directive metadata
  return true
}

function genCheckboxModel (
  el,
  value,
  modifiers
) {
  var number = modifiers && modifiers.number;
  var valueBinding = getBindingAttr(el, 'value') || 'null';
  var trueValueBinding = getBindingAttr(el, 'true-value') || 'true';
  var falseValueBinding = getBindingAttr(el, 'false-value') || 'false';
  addProp(el, 'checked',
    "Array.isArray(" + value + ")" +
    "?_i(" + value + "," + valueBinding + ")>-1" + (
      trueValueBinding === 'true'
        ? (":(" + value + ")")
        : (":_q(" + value + "," + trueValueBinding + ")")
    )
  );
  addHandler(el, 'change',
    "var $$a=" + value + "," +
        '$$el=$event.target,' +
        "$$c=$$el.checked?(" + trueValueBinding + "):(" + falseValueBinding + ");" +
    'if(Array.isArray($$a)){' +
      "var $$v=" + (number ? '_n(' + valueBinding + ')' : valueBinding) + "," +
          '$$i=_i($$a,$$v);' +
      "if($$el.checked){$$i<0&&(" + (genAssignmentCode(value, '$$a.concat([$$v])')) + ")}" +
      "else{$$i>-1&&(" + (genAssignmentCode(value, '$$a.slice(0,$$i).concat($$a.slice($$i+1))')) + ")}" +
    "}else{" + (genAssignmentCode(value, '$$c')) + "}",
    null, true
  );
}

function genRadioModel (
  el,
  value,
  modifiers
) {
  var number = modifiers && modifiers.number;
  var valueBinding = getBindingAttr(el, 'value') || 'null';
  valueBinding = number ? ("_n(" + valueBinding + ")") : valueBinding;
  addProp(el, 'checked', ("_q(" + value + "," + valueBinding + ")"));
  addHandler(el, 'change', genAssignmentCode(value, valueBinding), null, true);
}

function genSelect (
  el,
  value,
  modifiers
) {
  var number = modifiers && modifiers.number;
  var selectedVal = "Array.prototype.filter" +
    ".call($event.target.options,function(o){return o.selected})" +
    ".map(function(o){var val = \"_value\" in o ? o._value : o.value;" +
    "return " + (number ? '_n(val)' : 'val') + "})";

  var assignment = '$event.target.multiple ? $$selectedVal : $$selectedVal[0]';
  var code = "var $$selectedVal = " + selectedVal + ";";
  code = code + " " + (genAssignmentCode(value, assignment));
  addHandler(el, 'change', code, null, true);
}

function genDefaultModel (
  el,
  value,
  modifiers
) {
  var type = el.attrsMap.type;

  // warn if v-bind:value conflicts with v-model
  // except for inputs with v-bind:type
  {
    var value$1 = el.attrsMap['v-bind:value'] || el.attrsMap[':value'];
    var typeBinding = el.attrsMap['v-bind:type'] || el.attrsMap[':type'];
    if (value$1 && !typeBinding) {
      var binding = el.attrsMap['v-bind:value'] ? 'v-bind:value' : ':value';
      warn$1(
        binding + "=\"" + value$1 + "\" conflicts with v-model on the same element " +
        'because the latter already expands to a value binding internally',
        el.rawAttrsMap[binding]
      );
    }
  }

  var ref = modifiers || {};
  var lazy = ref.lazy;
  var number = ref.number;
  var trim = ref.trim;
  var needCompositionGuard = !lazy && type !== 'range';
  var event = lazy
    ? 'change'
    : type === 'range'
      ? RANGE_TOKEN
      : 'input';

  var valueExpression = '$event.target.value';
  if (trim) {
    valueExpression = "$event.target.value.trim()";
  }
  if (number) {
    valueExpression = "_n(" + valueExpression + ")";
  }

  var code = genAssignmentCode(value, valueExpression);
  if (needCompositionGuard) {
    code = "if($event.target.composing)return;" + code;
  }

  addProp(el, 'value', ("(" + value + ")"));
  addHandler(el, event, code, null, true);
  if (trim || number) {
    addHandler(el, 'blur', '$forceUpdate()');
  }
}

/*  */

// normalize v-model event tokens that can only be determined at runtime.
// it's important to place the event as the first in the array because
// the whole point is ensuring the v-model callback gets called before
// user-attached handlers.
function normalizeEvents (on) {
  /* istanbul ignore if */
  if (isDef(on[RANGE_TOKEN])) {
    // IE input[type=range] only supports `change` event
    var event = isIE ? 'change' : 'input';
    on[event] = [].concat(on[RANGE_TOKEN], on[event] || []);
    delete on[RANGE_TOKEN];
  }
  // This was originally intended to fix #4521 but no longer necessary
  // after 2.5. Keeping it for backwards compat with generated code from < 2.4
  /* istanbul ignore if */
  if (isDef(on[CHECKBOX_RADIO_TOKEN])) {
    on.change = [].concat(on[CHECKBOX_RADIO_TOKEN], on.change || []);
    delete on[CHECKBOX_RADIO_TOKEN];
  }
}

var target$1;

function createOnceHandler$1 (event, handler, capture) {
  var _target = target$1; // save current target element in closure
  return function onceHandler () {
    var res = handler.apply(null, arguments);
    if (res !== null) {
      remove$2(event, onceHandler, capture, _target);
    }
  }
}

// #9446: Firefox <= 53 (in particular, ESR 52) has incorrect Event.timeStamp
// implementation and does not fire microtasks in between event propagation, so
// safe to exclude.
var useMicrotaskFix = isUsingMicroTask && !(isFF && Number(isFF[1]) <= 53);

function add$1 (
  name,
  handler,
  capture,
  passive
) {
  // async edge case #6566: inner click event triggers patch, event handler
  // attached to outer element during patch, and triggered again. This
  // happens because browsers fire microtask ticks between event propagation.
  // the solution is simple: we save the timestamp when a handler is attached,
  // and the handler would only fire if the event passed to it was fired
  // AFTER it was attached.
  if (useMicrotaskFix) {
    var attachedTimestamp = currentFlushTimestamp;
    var original = handler;
    handler = original._wrapper = function (e) {
      if (
        // no bubbling, should always fire.
        // this is just a safety net in case event.timeStamp is unreliable in
        // certain weird environments...
        e.target === e.currentTarget ||
        // event is fired after handler attachment
        e.timeStamp >= attachedTimestamp ||
        // bail for environments that have buggy event.timeStamp implementations
        // #9462 iOS 9 bug: event.timeStamp is 0 after history.pushState
        // #9681 QtWebEngine event.timeStamp is negative value
        e.timeStamp <= 0 ||
        // #9448 bail if event is fired in another document in a multi-page
        // electron/nw.js app, since event.timeStamp will be using a different
        // starting reference
        e.target.ownerDocument !== document
      ) {
        return original.apply(this, arguments)
      }
    };
  }
  target$1.addEventListener(
    name,
    handler,
    supportsPassive
      ? { capture: capture, passive: passive }
      : capture
  );
}

function remove$2 (
  name,
  handler,
  capture,
  _target
) {
  (_target || target$1).removeEventListener(
    name,
    handler._wrapper || handler,
    capture
  );
}

function updateDOMListeners (oldVnode, vnode) {
  if (isUndef(oldVnode.data.on) && isUndef(vnode.data.on)) {
    return
  }
  var on = vnode.data.on || {};
  var oldOn = oldVnode.data.on || {};
  target$1 = vnode.elm;
  normalizeEvents(on);
  updateListeners(on, oldOn, add$1, remove$2, createOnceHandler$1, vnode.context);
  target$1 = undefined;
}

var events = {
  create: updateDOMListeners,
  update: updateDOMListeners
};

/*  */

var svgContainer;

function updateDOMProps (oldVnode, vnode) {
  if (isUndef(oldVnode.data.domProps) && isUndef(vnode.data.domProps)) {
    return
  }
  var key, cur;
  var elm = vnode.elm;
  var oldProps = oldVnode.data.domProps || {};
  var props = vnode.data.domProps || {};
  // clone observed objects, as the user probably wants to mutate it
  if (isDef(props.__ob__)) {
    props = vnode.data.domProps = extend({}, props);
  }

  for (key in oldProps) {
    if (!(key in props)) {
      elm[key] = '';
    }
  }

  for (key in props) {
    cur = props[key];
    // ignore children if the node has textContent or innerHTML,
    // as these will throw away existing DOM nodes and cause removal errors
    // on subsequent patches (#3360)
    if (key === 'textContent' || key === 'innerHTML') {
      if (vnode.children) { vnode.children.length = 0; }
      if (cur === oldProps[key]) { continue }
      // #6601 work around Chrome version <= 55 bug where single textNode
      // replaced by innerHTML/textContent retains its parentNode property
      if (elm.childNodes.length === 1) {
        elm.removeChild(elm.childNodes[0]);
      }
    }

    if (key === 'value' && elm.tagName !== 'PROGRESS') {
      // store value as _value as well since
      // non-string values will be stringified
      elm._value = cur;
      // avoid resetting cursor position when value is the same
      var strCur = isUndef(cur) ? '' : String(cur);
      if (shouldUpdateValue(elm, strCur)) {
        elm.value = strCur;
      }
    } else if (key === 'innerHTML' && isSVG(elm.tagName) && isUndef(elm.innerHTML)) {
      // IE doesn't support innerHTML for SVG elements
      svgContainer = svgContainer || document.createElement('div');
      svgContainer.innerHTML = "<svg>" + cur + "</svg>";
      var svg = svgContainer.firstChild;
      while (elm.firstChild) {
        elm.removeChild(elm.firstChild);
      }
      while (svg.firstChild) {
        elm.appendChild(svg.firstChild);
      }
    } else if (
      // skip the update if old and new VDOM state is the same.
      // `value` is handled separately because the DOM value may be temporarily
      // out of sync with VDOM state due to focus, composition and modifiers.
      // This  #4521 by skipping the unnecessary `checked` update.
      cur !== oldProps[key]
    ) {
      // some property updates can throw
      // e.g. `value` on <progress> w/ non-finite value
      try {
        elm[key] = cur;
      } catch (e) {}
    }
  }
}

// check platforms/web/util/attrs.js acceptValue


function shouldUpdateValue (elm, checkVal) {
  return (!elm.composing && (
    elm.tagName === 'OPTION' ||
    isNotInFocusAndDirty(elm, checkVal) ||
    isDirtyWithModifiers(elm, checkVal)
  ))
}

function isNotInFocusAndDirty (elm, checkVal) {
  // return true when textbox (.number and .trim) loses focus and its value is
  // not equal to the updated value
  var notInFocus = true;
  // #6157
  // work around IE bug when accessing document.activeElement in an iframe
  try { notInFocus = document.activeElement !== elm; } catch (e) {}
  return notInFocus && elm.value !== checkVal
}

function isDirtyWithModifiers (elm, newVal) {
  var value = elm.value;
  var modifiers = elm._vModifiers; // injected by v-model runtime
  if (isDef(modifiers)) {
    if (modifiers.number) {
      return toNumber(value) !== toNumber(newVal)
    }
    if (modifiers.trim) {
      return value.trim() !== newVal.trim()
    }
  }
  return value !== newVal
}

var domProps = {
  create: updateDOMProps,
  update: updateDOMProps
};

/*  */

var parseStyleText = cached(function (cssText) {
  var res = {};
  var listDelimiter = /;(?![^(]*\))/g;
  var propertyDelimiter = /:(.+)/;
  cssText.split(listDelimiter).forEach(function (item) {
    if (item) {
      var tmp = item.split(propertyDelimiter);
      tmp.length > 1 && (res[tmp[0].trim()] = tmp[1].trim());
    }
  });
  return res
});

// merge static and dynamic style data on the same vnode
function normalizeStyleData (data) {
  var style = normalizeStyleBinding(data.style);
  // static style is pre-processed into an object during compilation
  // and is always a fresh object, so it's safe to merge into it
  return data.staticStyle
    ? extend(data.staticStyle, style)
    : style
}

// normalize possible array / string values into Object
function normalizeStyleBinding (bindingStyle) {
  if (Array.isArray(bindingStyle)) {
    return toObject(bindingStyle)
  }
  if (typeof bindingStyle === 'string') {
    return parseStyleText(bindingStyle)
  }
  return bindingStyle
}

/**
 * parent component style should be after child's
 * so that parent component's style could override it
 */
function getStyle (vnode, checkChild) {
  var res = {};
  var styleData;

  if (checkChild) {
    var childNode = vnode;
    while (childNode.componentInstance) {
      childNode = childNode.componentInstance._vnode;
      if (
        childNode && childNode.data &&
        (styleData = normalizeStyleData(childNode.data))
      ) {
        extend(res, styleData);
      }
    }
  }

  if ((styleData = normalizeStyleData(vnode.data))) {
    extend(res, styleData);
  }

  var parentNode = vnode;
  while ((parentNode = parentNode.parent)) {
    if (parentNode.data && (styleData = normalizeStyleData(parentNode.data))) {
      extend(res, styleData);
    }
  }
  return res
}

/*  */

var cssVarRE = /^--/;
var importantRE = /\s*!important$/;
var setProp = function (el, name, val) {
  /* istanbul ignore if */
  if (cssVarRE.test(name)) {
    el.style.setProperty(name, val);
  } else if (importantRE.test(val)) {
    el.style.setProperty(hyphenate(name), val.replace(importantRE, ''), 'important');
  } else {
    var normalizedName = normalize(name);
    if (Array.isArray(val)) {
      // Support values array created by autoprefixer, e.g.
      // {display: ["-webkit-box", "-ms-flexbox", "flex"]}
      // Set them one by one, and the browser will only set those it can recognize
      for (var i = 0, len = val.length; i < len; i++) {
        el.style[normalizedName] = val[i];
      }
    } else {
      el.style[normalizedName] = val;
    }
  }
};

var vendorNames = ['Webkit', 'Moz', 'ms'];

var emptyStyle;
var normalize = cached(function (prop) {
  emptyStyle = emptyStyle || document.createElement('div').style;
  prop = camelize(prop);
  if (prop !== 'filter' && (prop in emptyStyle)) {
    return prop
  }
  var capName = prop.charAt(0).toUpperCase() + prop.slice(1);
  for (var i = 0; i < vendorNames.length; i++) {
    var name = vendorNames[i] + capName;
    if (name in emptyStyle) {
      return name
    }
  }
});

function updateStyle (oldVnode, vnode) {
  var data = vnode.data;
  var oldData = oldVnode.data;

  if (isUndef(data.staticStyle) && isUndef(data.style) &&
    isUndef(oldData.staticStyle) && isUndef(oldData.style)
  ) {
    return
  }

  var cur, name;
  var el = vnode.elm;
  var oldStaticStyle = oldData.staticStyle;
  var oldStyleBinding = oldData.normalizedStyle || oldData.style || {};

  // if static style exists, stylebinding already merged into it when doing normalizeStyleData
  var oldStyle = oldStaticStyle || oldStyleBinding;

  var style = normalizeStyleBinding(vnode.data.style) || {};

  // store normalized style under a different key for next diff
  // make sure to clone it if it's reactive, since the user likely wants
  // to mutate it.
  vnode.data.normalizedStyle = isDef(style.__ob__)
    ? extend({}, style)
    : style;

  var newStyle = getStyle(vnode, true);

  for (name in oldStyle) {
    if (isUndef(newStyle[name])) {
      setProp(el, name, '');
    }
  }
  for (name in newStyle) {
    cur = newStyle[name];
    if (cur !== oldStyle[name]) {
      // ie9 setting to null has no effect, must use empty string
      setProp(el, name, cur == null ? '' : cur);
    }
  }
}

var style = {
  create: updateStyle,
  update: updateStyle
};

/*  */

var whitespaceRE = /\s+/;

/**
 * Add class with compatibility for SVG since classList is not supported on
 * SVG elements in IE
 */
function addClass (el, cls) {
  /* istanbul ignore if */
  if (!cls || !(cls = cls.trim())) {
    return
  }

  /* istanbul ignore else */
  if (el.classList) {
    if (cls.indexOf(' ') > -1) {
      cls.split(whitespaceRE).forEach(function (c) { return el.classList.add(c); });
    } else {
      el.classList.add(cls);
    }
  } else {
    var cur = " " + (el.getAttribute('class') || '') + " ";
    if (cur.indexOf(' ' + cls + ' ') < 0) {
      el.setAttribute('class', (cur + cls).trim());
    }
  }
}

/**
 * Remove class with compatibility for SVG since classList is not supported on
 * SVG elements in IE
 */
function removeClass (el, cls) {
  /* istanbul ignore if */
  if (!cls || !(cls = cls.trim())) {
    return
  }

  /* istanbul ignore else */
  if (el.classList) {
    if (cls.indexOf(' ') > -1) {
      cls.split(whitespaceRE).forEach(function (c) { return el.classList.remove(c); });
    } else {
      el.classList.remove(cls);
    }
    if (!el.classList.length) {
      el.removeAttribute('class');
    }
  } else {
    var cur = " " + (el.getAttribute('class') || '') + " ";
    var tar = ' ' + cls + ' ';
    while (cur.indexOf(tar) >= 0) {
      cur = cur.replace(tar, ' ');
    }
    cur = cur.trim();
    if (cur) {
      el.setAttribute('class', cur);
    } else {
      el.removeAttribute('class');
    }
  }
}

/*  */

function resolveTransition (def$$1) {
  if (!def$$1) {
    return
  }
  /* istanbul ignore else */
  if (typeof def$$1 === 'object') {
    var res = {};
    if (def$$1.css !== false) {
      extend(res, autoCssTransition(def$$1.name || 'v'));
    }
    extend(res, def$$1);
    return res
  } else if (typeof def$$1 === 'string') {
    return autoCssTransition(def$$1)
  }
}

var autoCssTransition = cached(function (name) {
  return {
    enterClass: (name + "-enter"),
    enterToClass: (name + "-enter-to"),
    enterActiveClass: (name + "-enter-active"),
    leaveClass: (name + "-leave"),
    leaveToClass: (name + "-leave-to"),
    leaveActiveClass: (name + "-leave-active")
  }
});

var hasTransition = inBrowser && !isIE9;
var TRANSITION = 'transition';
var ANIMATION = 'animation';

// Transition property/event sniffing
var transitionProp = 'transition';
var transitionEndEvent = 'transitionend';
var animationProp = 'animation';
var animationEndEvent = 'animationend';
if (hasTransition) {
  /* istanbul ignore if */
  if (window.ontransitionend === undefined &&
    window.onwebkittransitionend !== undefined
  ) {
    transitionProp = 'WebkitTransition';
    transitionEndEvent = 'webkitTransitionEnd';
  }
  if (window.onanimationend === undefined &&
    window.onwebkitanimationend !== undefined
  ) {
    animationProp = 'WebkitAnimation';
    animationEndEvent = 'webkitAnimationEnd';
  }
}

// binding to window is necessary to make hot reload work in IE in strict mode
var raf = inBrowser
  ? window.requestAnimationFrame
    ? window.requestAnimationFrame.bind(window)
    : setTimeout
  : /* istanbul ignore next */ function (fn) { return fn(); };

function nextFrame (fn) {
  raf(function () {
    raf(fn);
  });
}

function addTransitionClass (el, cls) {
  var transitionClasses = el._transitionClasses || (el._transitionClasses = []);
  if (transitionClasses.indexOf(cls) < 0) {
    transitionClasses.push(cls);
    addClass(el, cls);
  }
}

function removeTransitionClass (el, cls) {
  if (el._transitionClasses) {
    remove(el._transitionClasses, cls);
  }
  removeClass(el, cls);
}

function whenTransitionEnds (
  el,
  expectedType,
  cb
) {
  var ref = getTransitionInfo(el, expectedType);
  var type = ref.type;
  var timeout = ref.timeout;
  var propCount = ref.propCount;
  if (!type) { return cb() }
  var event = type === TRANSITION ? transitionEndEvent : animationEndEvent;
  var ended = 0;
  var end = function () {
    el.removeEventListener(event, onEnd);
    cb();
  };
  var onEnd = function (e) {
    if (e.target === el) {
      if (++ended >= propCount) {
        end();
      }
    }
  };
  setTimeout(function () {
    if (ended < propCount) {
      end();
    }
  }, timeout + 1);
  el.addEventListener(event, onEnd);
}

var transformRE = /\b(transform|all)(,|$)/;

function getTransitionInfo (el, expectedType) {
  var styles = window.getComputedStyle(el);
  // JSDOM may return undefined for transition properties
  var transitionDelays = (styles[transitionProp + 'Delay'] || '').split(', ');
  var transitionDurations = (styles[transitionProp + 'Duration'] || '').split(', ');
  var transitionTimeout = getTimeout(transitionDelays, transitionDurations);
  var animationDelays = (styles[animationProp + 'Delay'] || '').split(', ');
  var animationDurations = (styles[animationProp + 'Duration'] || '').split(', ');
  var animationTimeout = getTimeout(animationDelays, animationDurations);

  var type;
  var timeout = 0;
  var propCount = 0;
  /* istanbul ignore if */
  if (expectedType === TRANSITION) {
    if (transitionTimeout > 0) {
      type = TRANSITION;
      timeout = transitionTimeout;
      propCount = transitionDurations.length;
    }
  } else if (expectedType === ANIMATION) {
    if (animationTimeout > 0) {
      type = ANIMATION;
      timeout = animationTimeout;
      propCount = animationDurations.length;
    }
  } else {
    timeout = Math.max(transitionTimeout, animationTimeout);
    type = timeout > 0
      ? transitionTimeout > animationTimeout
        ? TRANSITION
        : ANIMATION
      : null;
    propCount = type
      ? type === TRANSITION
        ? transitionDurations.length
        : animationDurations.length
      : 0;
  }
  var hasTransform =
    type === TRANSITION &&
    transformRE.test(styles[transitionProp + 'Property']);
  return {
    type: type,
    timeout: timeout,
    propCount: propCount,
    hasTransform: hasTransform
  }
}

function getTimeout (delays, durations) {
  /* istanbul ignore next */
  while (delays.length < durations.length) {
    delays = delays.concat(delays);
  }

  return Math.max.apply(null, durations.map(function (d, i) {
    return toMs(d) + toMs(delays[i])
  }))
}

// Old versions of Chromium (below 61.0.3163.100) formats floating pointer numbers
// in a locale-dependent way, using a comma instead of a dot.
// If comma is not replaced with a dot, the input will be rounded down (i.e. acting
// as a floor function) causing unexpected behaviors
function toMs (s) {
  return Number(s.slice(0, -1).replace(',', '.')) * 1000
}

/*  */

function enter (vnode, toggleDisplay) {
  var el = vnode.elm;

  // call leave callback now
  if (isDef(el._leaveCb)) {
    el._leaveCb.cancelled = true;
    el._leaveCb();
  }

  var data = resolveTransition(vnode.data.transition);
  if (isUndef(data)) {
    return
  }

  /* istanbul ignore if */
  if (isDef(el._enterCb) || el.nodeType !== 1) {
    return
  }

  var css = data.css;
  var type = data.type;
  var enterClass = data.enterClass;
  var enterToClass = data.enterToClass;
  var enterActiveClass = data.enterActiveClass;
  var appearClass = data.appearClass;
  var appearToClass = data.appearToClass;
  var appearActiveClass = data.appearActiveClass;
  var beforeEnter = data.beforeEnter;
  var enter = data.enter;
  var afterEnter = data.afterEnter;
  var enterCancelled = data.enterCancelled;
  var beforeAppear = data.beforeAppear;
  var appear = data.appear;
  var afterAppear = data.afterAppear;
  var appearCancelled = data.appearCancelled;
  var duration = data.duration;

  // activeInstance will always be the <transition> component managing this
  // transition. One edge case to check is when the <transition> is placed
  // as the root node of a child component. In that case we need to check
  // <transition>'s parent for appear check.
  var context = activeInstance;
  var transitionNode = activeInstance.$vnode;
  while (transitionNode && transitionNode.parent) {
    context = transitionNode.context;
    transitionNode = transitionNode.parent;
  }

  var isAppear = !context._isMounted || !vnode.isRootInsert;

  if (isAppear && !appear && appear !== '') {
    return
  }

  var startClass = isAppear && appearClass
    ? appearClass
    : enterClass;
  var activeClass = isAppear && appearActiveClass
    ? appearActiveClass
    : enterActiveClass;
  var toClass = isAppear && appearToClass
    ? appearToClass
    : enterToClass;

  var beforeEnterHook = isAppear
    ? (beforeAppear || beforeEnter)
    : beforeEnter;
  var enterHook = isAppear
    ? (typeof appear === 'function' ? appear : enter)
    : enter;
  var afterEnterHook = isAppear
    ? (afterAppear || afterEnter)
    : afterEnter;
  var enterCancelledHook = isAppear
    ? (appearCancelled || enterCancelled)
    : enterCancelled;

  var explicitEnterDuration = toNumber(
    isObject(duration)
      ? duration.enter
      : duration
  );

  if ( explicitEnterDuration != null) {
    checkDuration(explicitEnterDuration, 'enter', vnode);
  }

  var expectsCSS = css !== false && !isIE9;
  var userWantsControl = getHookArgumentsLength(enterHook);

  var cb = el._enterCb = once(function () {
    if (expectsCSS) {
      removeTransitionClass(el, toClass);
      removeTransitionClass(el, activeClass);
    }
    if (cb.cancelled) {
      if (expectsCSS) {
        removeTransitionClass(el, startClass);
      }
      enterCancelledHook && enterCancelledHook(el);
    } else {
      afterEnterHook && afterEnterHook(el);
    }
    el._enterCb = null;
  });

  if (!vnode.data.show) {
    // remove pending leave element on enter by injecting an insert hook
    mergeVNodeHook(vnode, 'insert', function () {
      var parent = el.parentNode;
      var pendingNode = parent && parent._pending && parent._pending[vnode.key];
      if (pendingNode &&
        pendingNode.tag === vnode.tag &&
        pendingNode.elm._leaveCb
      ) {
        pendingNode.elm._leaveCb();
      }
      enterHook && enterHook(el, cb);
    });
  }

  // start enter transition
  beforeEnterHook && beforeEnterHook(el);
  if (expectsCSS) {
    addTransitionClass(el, startClass);
    addTransitionClass(el, activeClass);
    nextFrame(function () {
      removeTransitionClass(el, startClass);
      if (!cb.cancelled) {
        addTransitionClass(el, toClass);
        if (!userWantsControl) {
          if (isValidDuration(explicitEnterDuration)) {
            setTimeout(cb, explicitEnterDuration);
          } else {
            whenTransitionEnds(el, type, cb);
          }
        }
      }
    });
  }

  if (vnode.data.show) {
    toggleDisplay && toggleDisplay();
    enterHook && enterHook(el, cb);
  }

  if (!expectsCSS && !userWantsControl) {
    cb();
  }
}

function leave (vnode, rm) {
  var el = vnode.elm;

  // call enter callback now
  if (isDef(el._enterCb)) {
    el._enterCb.cancelled = true;
    el._enterCb();
  }

  var data = resolveTransition(vnode.data.transition);
  if (isUndef(data) || el.nodeType !== 1) {
    return rm()
  }

  /* istanbul ignore if */
  if (isDef(el._leaveCb)) {
    return
  }

  var css = data.css;
  var type = data.type;
  var leaveClass = data.leaveClass;
  var leaveToClass = data.leaveToClass;
  var leaveActiveClass = data.leaveActiveClass;
  var beforeLeave = data.beforeLeave;
  var leave = data.leave;
  var afterLeave = data.afterLeave;
  var leaveCancelled = data.leaveCancelled;
  var delayLeave = data.delayLeave;
  var duration = data.duration;

  var expectsCSS = css !== false && !isIE9;
  var userWantsControl = getHookArgumentsLength(leave);

  var explicitLeaveDuration = toNumber(
    isObject(duration)
      ? duration.leave
      : duration
  );

  if ( isDef(explicitLeaveDuration)) {
    checkDuration(explicitLeaveDuration, 'leave', vnode);
  }

  var cb = el._leaveCb = once(function () {
    if (el.parentNode && el.parentNode._pending) {
      el.parentNode._pending[vnode.key] = null;
    }
    if (expectsCSS) {
      removeTransitionClass(el, leaveToClass);
      removeTransitionClass(el, leaveActiveClass);
    }
    if (cb.cancelled) {
      if (expectsCSS) {
        removeTransitionClass(el, leaveClass);
      }
      leaveCancelled && leaveCancelled(el);
    } else {
      rm();
      afterLeave && afterLeave(el);
    }
    el._leaveCb = null;
  });

  if (delayLeave) {
    delayLeave(performLeave);
  } else {
    performLeave();
  }

  function performLeave () {
    // the delayed leave may have already been cancelled
    if (cb.cancelled) {
      return
    }
    // record leaving element
    if (!vnode.data.show && el.parentNode) {
      (el.parentNode._pending || (el.parentNode._pending = {}))[(vnode.key)] = vnode;
    }
    beforeLeave && beforeLeave(el);
    if (expectsCSS) {
      addTransitionClass(el, leaveClass);
      addTransitionClass(el, leaveActiveClass);
      nextFrame(function () {
        removeTransitionClass(el, leaveClass);
        if (!cb.cancelled) {
          addTransitionClass(el, leaveToClass);
          if (!userWantsControl) {
            if (isValidDuration(explicitLeaveDuration)) {
              setTimeout(cb, explicitLeaveDuration);
            } else {
              whenTransitionEnds(el, type, cb);
            }
          }
        }
      });
    }
    leave && leave(el, cb);
    if (!expectsCSS && !userWantsControl) {
      cb();
    }
  }
}

// only used in dev mode
function checkDuration (val, name, vnode) {
  if (typeof val !== 'number') {
    warn(
      "<transition> explicit " + name + " duration is not a valid number - " +
      "got " + (JSON.stringify(val)) + ".",
      vnode.context
    );
  } else if (isNaN(val)) {
    warn(
      "<transition> explicit " + name + " duration is NaN - " +
      'the duration expression might be incorrect.',
      vnode.context
    );
  }
}

function isValidDuration (val) {
  return typeof val === 'number' && !isNaN(val)
}

/**
 * Normalize a transition hook's argument length. The hook may be:
 * - a merged hook (invoker) with the original in .fns
 * - a wrapped component method (check ._length)
 * - a plain function (.length)
 */
function getHookArgumentsLength (fn) {
  if (isUndef(fn)) {
    return false
  }
  var invokerFns = fn.fns;
  if (isDef(invokerFns)) {
    // invoker
    return getHookArgumentsLength(
      Array.isArray(invokerFns)
        ? invokerFns[0]
        : invokerFns
    )
  } else {
    return (fn._length || fn.length) > 1
  }
}

function _enter (_, vnode) {
  if (vnode.data.show !== true) {
    enter(vnode);
  }
}

var transition = inBrowser ? {
  create: _enter,
  activate: _enter,
  remove: function remove$$1 (vnode, rm) {
    /* istanbul ignore else */
    if (vnode.data.show !== true) {
      leave(vnode, rm);
    } else {
      rm();
    }
  }
} : {};

var platformModules = [
  attrs,
  klass,
  events,
  domProps,
  style,
  transition
];

/*  */

// the directive module should be applied last, after all
// built-in modules have been applied.
var modules = platformModules.concat(baseModules);

var patch = createPatchFunction({ nodeOps: nodeOps, modules: modules });

/**
 * Not type checking this file because flow doesn't like attaching
 * properties to Elements.
 */

/* istanbul ignore if */
if (isIE9) {
  // http://www.matts411.com/post/internet-explorer-9-oninput/
  document.addEventListener('selectionchange', function () {
    var el = document.activeElement;
    if (el && el.vmodel) {
      trigger(el, 'input');
    }
  });
}

var directive = {
  inserted: function inserted (el, binding, vnode, oldVnode) {
    if (vnode.tag === 'select') {
      // #6903
      if (oldVnode.elm && !oldVnode.elm._vOptions) {
        mergeVNodeHook(vnode, 'postpatch', function () {
          directive.componentUpdated(el, binding, vnode);
        });
      } else {
        setSelected(el, binding, vnode.context);
      }
      el._vOptions = [].map.call(el.options, getValue);
    } else if (vnode.tag === 'textarea' || isTextInputType(el.type)) {
      el._vModifiers = binding.modifiers;
      if (!binding.modifiers.lazy) {
        el.addEventListener('compositionstart', onCompositionStart);
        el.addEventListener('compositionend', onCompositionEnd);
        // Safari < 10.2 & UIWebView doesn't fire compositionend when
        // switching focus before confirming composition choice
        // this also fixes the issue where some browsers e.g. iOS Chrome
        // fires "change" instead of "input" on autocomplete.
        el.addEventListener('change', onCompositionEnd);
        /* istanbul ignore if */
        if (isIE9) {
          el.vmodel = true;
        }
      }
    }
  },

  componentUpdated: function componentUpdated (el, binding, vnode) {
    if (vnode.tag === 'select') {
      setSelected(el, binding, vnode.context);
      // in case the options rendered by v-for have changed,
      // it's possible that the value is out-of-sync with the rendered options.
      // detect such cases and filter out values that no longer has a matching
      // option in the DOM.
      var prevOptions = el._vOptions;
      var curOptions = el._vOptions = [].map.call(el.options, getValue);
      if (curOptions.some(function (o, i) { return !looseEqual(o, prevOptions[i]); })) {
        // trigger change event if
        // no matching option found for at least one value
        var needReset = el.multiple
          ? binding.value.some(function (v) { return hasNoMatchingOption(v, curOptions); })
          : binding.value !== binding.oldValue && hasNoMatchingOption(binding.value, curOptions);
        if (needReset) {
          trigger(el, 'change');
        }
      }
    }
  }
};

function setSelected (el, binding, vm) {
  actuallySetSelected(el, binding, vm);
  /* istanbul ignore if */
  if (isIE || isEdge) {
    setTimeout(function () {
      actuallySetSelected(el, binding, vm);
    }, 0);
  }
}

function actuallySetSelected (el, binding, vm) {
  var value = binding.value;
  var isMultiple = el.multiple;
  if (isMultiple && !Array.isArray(value)) {
     warn(
      "<select multiple v-model=\"" + (binding.expression) + "\"> " +
      "expects an Array value for its binding, but got " + (Object.prototype.toString.call(value).slice(8, -1)),
      vm
    );
    return
  }
  var selected, option;
  for (var i = 0, l = el.options.length; i < l; i++) {
    option = el.options[i];
    if (isMultiple) {
      selected = looseIndexOf(value, getValue(option)) > -1;
      if (option.selected !== selected) {
        option.selected = selected;
      }
    } else {
      if (looseEqual(getValue(option), value)) {
        if (el.selectedIndex !== i) {
          el.selectedIndex = i;
        }
        return
      }
    }
  }
  if (!isMultiple) {
    el.selectedIndex = -1;
  }
}

function hasNoMatchingOption (value, options) {
  return options.every(function (o) { return !looseEqual(o, value); })
}

function getValue (option) {
  return '_value' in option
    ? option._value
    : option.value
}

function onCompositionStart (e) {
  e.target.composing = true;
}

function onCompositionEnd (e) {
  // prevent triggering an input event for no reason
  if (!e.target.composing) { return }
  e.target.composing = false;
  trigger(e.target, 'input');
}

function trigger (el, type) {
  var e = document.createEvent('HTMLEvents');
  e.initEvent(type, true, true);
  el.dispatchEvent(e);
}

/*  */

// recursively search for possible transition defined inside the component root
function locateNode (vnode) {
  return vnode.componentInstance && (!vnode.data || !vnode.data.transition)
    ? locateNode(vnode.componentInstance._vnode)
    : vnode
}

var show = {
  bind: function bind (el, ref, vnode) {
    var value = ref.value;

    vnode = locateNode(vnode);
    var transition$$1 = vnode.data && vnode.data.transition;
    var originalDisplay = el.__vOriginalDisplay =
      el.style.display === 'none' ? '' : el.style.display;
    if (value && transition$$1) {
      vnode.data.show = true;
      enter(vnode, function () {
        el.style.display = originalDisplay;
      });
    } else {
      el.style.display = value ? originalDisplay : 'none';
    }
  },

  update: function update (el, ref, vnode) {
    var value = ref.value;
    var oldValue = ref.oldValue;

    /* istanbul ignore if */
    if (!value === !oldValue) { return }
    vnode = locateNode(vnode);
    var transition$$1 = vnode.data && vnode.data.transition;
    if (transition$$1) {
      vnode.data.show = true;
      if (value) {
        enter(vnode, function () {
          el.style.display = el.__vOriginalDisplay;
        });
      } else {
        leave(vnode, function () {
          el.style.display = 'none';
        });
      }
    } else {
      el.style.display = value ? el.__vOriginalDisplay : 'none';
    }
  },

  unbind: function unbind (
    el,
    binding,
    vnode,
    oldVnode,
    isDestroy
  ) {
    if (!isDestroy) {
      el.style.display = el.__vOriginalDisplay;
    }
  }
};

var platformDirectives = {
  model: directive,
  show: show
};

/*  */

var transitionProps = {
  name: String,
  appear: Boolean,
  css: Boolean,
  mode: String,
  type: String,
  enterClass: String,
  leaveClass: String,
  enterToClass: String,
  leaveToClass: String,
  enterActiveClass: String,
  leaveActiveClass: String,
  appearClass: String,
  appearActiveClass: String,
  appearToClass: String,
  duration: [Number, String, Object]
};

// in case the child is also an abstract component, e.g. <keep-alive>
// we want to recursively retrieve the real component to be rendered
function getRealChild (vnode) {
  var compOptions = vnode && vnode.componentOptions;
  if (compOptions && compOptions.Ctor.options.abstract) {
    return getRealChild(getFirstComponentChild(compOptions.children))
  } else {
    return vnode
  }
}

function extractTransitionData (comp) {
  var data = {};
  var options = comp.$options;
  // props
  for (var key in options.propsData) {
    data[key] = comp[key];
  }
  // events.
  // extract listeners and pass them directly to the transition methods
  var listeners = options._parentListeners;
  for (var key$1 in listeners) {
    data[camelize(key$1)] = listeners[key$1];
  }
  return data
}

function placeholder (h, rawChild) {
  if (/\d-keep-alive$/.test(rawChild.tag)) {
    return h('keep-alive', {
      props: rawChild.componentOptions.propsData
    })
  }
}

function hasParentTransition (vnode) {
  while ((vnode = vnode.parent)) {
    if (vnode.data.transition) {
      return true
    }
  }
}

function isSameChild (child, oldChild) {
  return oldChild.key === child.key && oldChild.tag === child.tag
}

var isNotTextNode = function (c) { return c.tag || isAsyncPlaceholder(c); };

var isVShowDirective = function (d) { return d.name === 'show'; };

var Transition = {
  name: 'transition',
  props: transitionProps,
  abstract: true,

  render: function render (h) {
    var this$1 = this;

    var children = this.$slots.default;
    if (!children) {
      return
    }

    // filter out text nodes (possible whitespaces)
    children = children.filter(isNotTextNode);
    /* istanbul ignore if */
    if (!children.length) {
      return
    }

    // warn multiple elements
    if ( children.length > 1) {
      warn(
        '<transition> can only be used on a single element. Use ' +
        '<transition-group> for lists.',
        this.$parent
      );
    }

    var mode = this.mode;

    // warn invalid mode
    if (
      mode && mode !== 'in-out' && mode !== 'out-in'
    ) {
      warn(
        'invalid <transition> mode: ' + mode,
        this.$parent
      );
    }

    var rawChild = children[0];

    // if this is a component root node and the component's
    // parent container node also has transition, skip.
    if (hasParentTransition(this.$vnode)) {
      return rawChild
    }

    // apply transition data to child
    // use getRealChild() to ignore abstract components e.g. keep-alive
    var child = getRealChild(rawChild);
    /* istanbul ignore if */
    if (!child) {
      return rawChild
    }

    if (this._leaving) {
      return placeholder(h, rawChild)
    }

    // ensure a key that is unique to the vnode type and to this transition
    // component instance. This key will be used to remove pending leaving nodes
    // during entering.
    var id = "__transition-" + (this._uid) + "-";
    child.key = child.key == null
      ? child.isComment
        ? id + 'comment'
        : id + child.tag
      : isPrimitive(child.key)
        ? (String(child.key).indexOf(id) === 0 ? child.key : id + child.key)
        : child.key;

    var data = (child.data || (child.data = {})).transition = extractTransitionData(this);
    var oldRawChild = this._vnode;
    var oldChild = getRealChild(oldRawChild);

    // mark v-show
    // so that the transition module can hand over the control to the directive
    if (child.data.directives && child.data.directives.some(isVShowDirective)) {
      child.data.show = true;
    }

    if (
      oldChild &&
      oldChild.data &&
      !isSameChild(child, oldChild) &&
      !isAsyncPlaceholder(oldChild) &&
      // #6687 component root is a comment node
      !(oldChild.componentInstance && oldChild.componentInstance._vnode.isComment)
    ) {
      // replace old child transition data with fresh one
      // important for dynamic transitions!
      var oldData = oldChild.data.transition = extend({}, data);
      // handle transition mode
      if (mode === 'out-in') {
        // return placeholder node and queue update when leave finishes
        this._leaving = true;
        mergeVNodeHook(oldData, 'afterLeave', function () {
          this$1._leaving = false;
          this$1.$forceUpdate();
        });
        return placeholder(h, rawChild)
      } else if (mode === 'in-out') {
        if (isAsyncPlaceholder(child)) {
          return oldRawChild
        }
        var delayedLeave;
        var performLeave = function () { delayedLeave(); };
        mergeVNodeHook(data, 'afterEnter', performLeave);
        mergeVNodeHook(data, 'enterCancelled', performLeave);
        mergeVNodeHook(oldData, 'delayLeave', function (leave) { delayedLeave = leave; });
      }
    }

    return rawChild
  }
};

/*  */

var props = extend({
  tag: String,
  moveClass: String
}, transitionProps);

delete props.mode;

var TransitionGroup = {
  props: props,

  beforeMount: function beforeMount () {
    var this$1 = this;

    var update = this._update;
    this._update = function (vnode, hydrating) {
      var restoreActiveInstance = setActiveInstance(this$1);
      // force removing pass
      this$1.__patch__(
        this$1._vnode,
        this$1.kept,
        false, // hydrating
        true // removeOnly (!important, avoids unnecessary moves)
      );
      this$1._vnode = this$1.kept;
      restoreActiveInstance();
      update.call(this$1, vnode, hydrating);
    };
  },

  render: function render (h) {
    var tag = this.tag || this.$vnode.data.tag || 'span';
    var map = Object.create(null);
    var prevChildren = this.prevChildren = this.children;
    var rawChildren = this.$slots.default || [];
    var children = this.children = [];
    var transitionData = extractTransitionData(this);

    for (var i = 0; i < rawChildren.length; i++) {
      var c = rawChildren[i];
      if (c.tag) {
        if (c.key != null && String(c.key).indexOf('__vlist') !== 0) {
          children.push(c);
          map[c.key] = c
          ;(c.data || (c.data = {})).transition = transitionData;
        } else {
          var opts = c.componentOptions;
          var name = opts ? (opts.Ctor.options.name || opts.tag || '') : c.tag;
          warn(("<transition-group> children must be keyed: <" + name + ">"));
        }
      }
    }

    if (prevChildren) {
      var kept = [];
      var removed = [];
      for (var i$1 = 0; i$1 < prevChildren.length; i$1++) {
        var c$1 = prevChildren[i$1];
        c$1.data.transition = transitionData;
        c$1.data.pos = c$1.elm.getBoundingClientRect();
        if (map[c$1.key]) {
          kept.push(c$1);
        } else {
          removed.push(c$1);
        }
      }
      this.kept = h(tag, null, kept);
      this.removed = removed;
    }

    return h(tag, null, children)
  },

  updated: function updated () {
    var children = this.prevChildren;
    var moveClass = this.moveClass || ((this.name || 'v') + '-move');
    if (!children.length || !this.hasMove(children[0].elm, moveClass)) {
      return
    }

    // we divide the work into three loops to avoid mixing DOM reads and writes
    // in each iteration - which helps prevent layout thrashing.
    children.forEach(callPendingCbs);
    children.forEach(recordPosition);
    children.forEach(applyTranslation);

    // force reflow to put everything in position
    // assign to this to avoid being removed in tree-shaking
    // $flow-disable-line
    this._reflow = document.body.offsetHeight;

    children.forEach(function (c) {
      if (c.data.moved) {
        var el = c.elm;
        var s = el.style;
        addTransitionClass(el, moveClass);
        s.transform = s.WebkitTransform = s.transitionDuration = '';
        el.addEventListener(transitionEndEvent, el._moveCb = function cb (e) {
          if (e && e.target !== el) {
            return
          }
          if (!e || /transform$/.test(e.propertyName)) {
            el.removeEventListener(transitionEndEvent, cb);
            el._moveCb = null;
            removeTransitionClass(el, moveClass);
          }
        });
      }
    });
  },

  methods: {
    hasMove: function hasMove (el, moveClass) {
      /* istanbul ignore if */
      if (!hasTransition) {
        return false
      }
      /* istanbul ignore if */
      if (this._hasMove) {
        return this._hasMove
      }
      // Detect whether an element with the move class applied has
      // CSS transitions. Since the element may be inside an entering
      // transition at this very moment, we make a clone of it and remove
      // all other transition classes applied to ensure only the move class
      // is applied.
      var clone = el.cloneNode();
      if (el._transitionClasses) {
        el._transitionClasses.forEach(function (cls) { removeClass(clone, cls); });
      }
      addClass(clone, moveClass);
      clone.style.display = 'none';
      this.$el.appendChild(clone);
      var info = getTransitionInfo(clone);
      this.$el.removeChild(clone);
      return (this._hasMove = info.hasTransform)
    }
  }
};

function callPendingCbs (c) {
  /* istanbul ignore if */
  if (c.elm._moveCb) {
    c.elm._moveCb();
  }
  /* istanbul ignore if */
  if (c.elm._enterCb) {
    c.elm._enterCb();
  }
}

function recordPosition (c) {
  c.data.newPos = c.elm.getBoundingClientRect();
}

function applyTranslation (c) {
  var oldPos = c.data.pos;
  var newPos = c.data.newPos;
  var dx = oldPos.left - newPos.left;
  var dy = oldPos.top - newPos.top;
  if (dx || dy) {
    c.data.moved = true;
    var s = c.elm.style;
    s.transform = s.WebkitTransform = "translate(" + dx + "px," + dy + "px)";
    s.transitionDuration = '0s';
  }
}

var platformComponents = {
  Transition: Transition,
  TransitionGroup: TransitionGroup
};

/*  */

// install platform specific utils
Vue.config.mustUseProp = mustUseProp;
Vue.config.isReservedTag = isReservedTag;
Vue.config.isReservedAttr = isReservedAttr;
Vue.config.getTagNamespace = getTagNamespace;
Vue.config.isUnknownElement = isUnknownElement;

// install platform runtime directives & components
extend(Vue.options.directives, platformDirectives);
extend(Vue.options.components, platformComponents);

// install platform patch function
Vue.prototype.__patch__ = inBrowser ? patch : noop;

// public mount method
Vue.prototype.$mount = function (
  el,
  hydrating
) {
  el = el && inBrowser ? query(el) : undefined;
  return mountComponent(this, el, hydrating)
};

// devtools global hook
/* istanbul ignore next */
if (inBrowser) {
  setTimeout(function () {
    if (config.devtools) {
      if (devtools) {
        devtools.emit('init', Vue);
      } else {
        console[console.info ? 'info' : 'log'](
          'Download the Vue Devtools extension for a better development experience:\n' +
          'https://github.com/vuejs/vue-devtools'
        );
      }
    }
    if (
      config.productionTip !== false &&
      typeof console !== 'undefined'
    ) {
      console[console.info ? 'info' : 'log'](
        "You are running Vue in development mode.\n" +
        "Make sure to turn on production mode when deploying for production.\n" +
        "See more tips at https://vuejs.org/guide/deployment.html"
      );
    }
  }, 0);
}

/*  */

var defaultTagRE = /\{\{((?:.|\r?\n)+?)\}\}/g;
var regexEscapeRE = /[-.*+?^${}()|[\]\/\\]/g;

var buildRegex = cached(function (delimiters) {
  var open = delimiters[0].replace(regexEscapeRE, '\\$&');
  var close = delimiters[1].replace(regexEscapeRE, '\\$&');
  return new RegExp(open + '((?:.|\\n)+?)' + close, 'g')
});



function parseText (
  text,
  delimiters
) {
  var tagRE = delimiters ? buildRegex(delimiters) : defaultTagRE;
  if (!tagRE.test(text)) {
    return
  }
  var tokens = [];
  var rawTokens = [];
  var lastIndex = tagRE.lastIndex = 0;
  var match, index, tokenValue;
  while ((match = tagRE.exec(text))) {
    index = match.index;
    // push text token
    if (index > lastIndex) {
      rawTokens.push(tokenValue = text.slice(lastIndex, index));
      tokens.push(JSON.stringify(tokenValue));
    }
    // tag token
    var exp = parseFilters(match[1].trim());
    tokens.push(("_s(" + exp + ")"));
    rawTokens.push({ '@binding': exp });
    lastIndex = index + match[0].length;
  }
  if (lastIndex < text.length) {
    rawTokens.push(tokenValue = text.slice(lastIndex));
    tokens.push(JSON.stringify(tokenValue));
  }
  return {
    expression: tokens.join('+'),
    tokens: rawTokens
  }
}

/*  */

function transformNode (el, options) {
  var warn = options.warn || baseWarn;
  var staticClass = getAndRemoveAttr(el, 'class');
  if ( staticClass) {
    var res = parseText(staticClass, options.delimiters);
    if (res) {
      warn(
        "class=\"" + staticClass + "\": " +
        'Interpolation inside attributes has been removed. ' +
        'Use v-bind or the colon shorthand instead. For example, ' +
        'instead of <div class="{{ val }}">, use <div :class="val">.',
        el.rawAttrsMap['class']
      );
    }
  }
  if (staticClass) {
    el.staticClass = JSON.stringify(staticClass);
  }
  var classBinding = getBindingAttr(el, 'class', false /* getStatic */);
  if (classBinding) {
    el.classBinding = classBinding;
  }
}

function genData (el) {
  var data = '';
  if (el.staticClass) {
    data += "staticClass:" + (el.staticClass) + ",";
  }
  if (el.classBinding) {
    data += "class:" + (el.classBinding) + ",";
  }
  return data
}

var klass$1 = {
  staticKeys: ['staticClass'],
  transformNode: transformNode,
  genData: genData
};

/*  */

function transformNode$1 (el, options) {
  var warn = options.warn || baseWarn;
  var staticStyle = getAndRemoveAttr(el, 'style');
  if (staticStyle) {
    /* istanbul ignore if */
    {
      var res = parseText(staticStyle, options.delimiters);
      if (res) {
        warn(
          "style=\"" + staticStyle + "\": " +
          'Interpolation inside attributes has been removed. ' +
          'Use v-bind or the colon shorthand instead. For example, ' +
          'instead of <div style="{{ val }}">, use <div :style="val">.',
          el.rawAttrsMap['style']
        );
      }
    }
    el.staticStyle = JSON.stringify(parseStyleText(staticStyle));
  }

  var styleBinding = getBindingAttr(el, 'style', false /* getStatic */);
  if (styleBinding) {
    el.styleBinding = styleBinding;
  }
}

function genData$1 (el) {
  var data = '';
  if (el.staticStyle) {
    data += "staticStyle:" + (el.staticStyle) + ",";
  }
  if (el.styleBinding) {
    data += "style:(" + (el.styleBinding) + "),";
  }
  return data
}

var style$1 = {
  staticKeys: ['staticStyle'],
  transformNode: transformNode$1,
  genData: genData$1
};

/*  */

var decoder;

var he = {
  decode: function decode (html) {
    decoder = decoder || document.createElement('div');
    decoder.innerHTML = html;
    return decoder.textContent
  }
};

/*  */

var isUnaryTag = makeMap(
  'area,base,br,col,embed,frame,hr,img,input,isindex,keygen,' +
  'link,meta,param,source,track,wbr'
);

// Elements that you can, intentionally, leave open
// (and which close themselves)
var canBeLeftOpenTag = makeMap(
  'colgroup,dd,dt,li,options,p,td,tfoot,th,thead,tr,source'
);

// HTML5 tags https://html.spec.whatwg.org/multipage/indices.html#elements-3
// Phrasing Content https://html.spec.whatwg.org/multipage/dom.html#phrasing-content
var isNonPhrasingTag = makeMap(
  'address,article,aside,base,blockquote,body,caption,col,colgroup,dd,' +
  'details,dialog,div,dl,dt,fieldset,figcaption,figure,footer,form,' +
  'h1,h2,h3,h4,h5,h6,head,header,hgroup,hr,html,legend,li,menuitem,meta,' +
  'optgroup,option,param,rp,rt,source,style,summary,tbody,td,tfoot,th,thead,' +
  'title,tr,track'
);

/**
 * Not type-checking this file because it's mostly vendor code.
 */

// Regular Expressions for parsing tags and attributes
var attribute = /^\s*([^\s"'<>\/=]+)(?:\s*(=)\s*(?:"([^"]*)"+|'([^']*)'+|([^\s"'=<>`]+)))?/;
var dynamicArgAttribute = /^\s*((?:v-[\w-]+:|@|:|#)\[[^=]+\][^\s"'<>\/=]*)(?:\s*(=)\s*(?:"([^"]*)"+|'([^']*)'+|([^\s"'=<>`]+)))?/;
var ncname = "[a-zA-Z_][\\-\\.0-9_a-zA-Z" + (unicodeRegExp.source) + "]*";
var qnameCapture = "((?:" + ncname + "\\:)?" + ncname + ")";
var startTagOpen = new RegExp(("^<" + qnameCapture));
var startTagClose = /^\s*(\/?)>/;
var endTag = new RegExp(("^<\\/" + qnameCapture + "[^>]*>"));
var doctype = /^<!DOCTYPE [^>]+>/i;
// #7298: escape - to avoid being passed as HTML comment when inlined in page
var comment = /^<!\--/;
var conditionalComment = /^<!\[/;

// Special Elements (can contain anything)
var isPlainTextElement = makeMap('script,style,textarea', true);
var reCache = {};

var decodingMap = {
  '&lt;': '<',
  '&gt;': '>',
  '&quot;': '"',
  '&amp;': '&',
  '&#10;': '\n',
  '&#9;': '\t',
  '&#39;': "'"
};
var encodedAttr = /&(?:lt|gt|quot|amp|#39);/g;
var encodedAttrWithNewLines = /&(?:lt|gt|quot|amp|#39|#10|#9);/g;

// #5992
var isIgnoreNewlineTag = makeMap('pre,textarea', true);
var shouldIgnoreFirstNewline = function (tag, html) { return tag && isIgnoreNewlineTag(tag) && html[0] === '\n'; };

function decodeAttr (value, shouldDecodeNewlines) {
  var re = shouldDecodeNewlines ? encodedAttrWithNewLines : encodedAttr;
  return value.replace(re, function (match) { return decodingMap[match]; })
}

function parseHTML (html, options) {
  var stack = [];
  var expectHTML = options.expectHTML;
  var isUnaryTag$$1 = options.isUnaryTag || no;
  var canBeLeftOpenTag$$1 = options.canBeLeftOpenTag || no;
  var index = 0;
  var last, lastTag;
  while (html) {
    last = html;
    // Make sure we're not in a plaintext content element like script/style
    if (!lastTag || !isPlainTextElement(lastTag)) {
      var textEnd = html.indexOf('<');
      if (textEnd === 0) {
        // Comment:
        if (comment.test(html)) {
          var commentEnd = html.indexOf('-->');

          if (commentEnd >= 0) {
            if (options.shouldKeepComment) {
              options.comment(html.substring(4, commentEnd), index, index + commentEnd + 3);
            }
            advance(commentEnd + 3);
            continue
          }
        }

        // http://en.wikipedia.org/wiki/Conditional_comment#Downlevel-revealed_conditional_comment
        if (conditionalComment.test(html)) {
          var conditionalEnd = html.indexOf(']>');

          if (conditionalEnd >= 0) {
            advance(conditionalEnd + 2);
            continue
          }
        }

        // Doctype:
        var doctypeMatch = html.match(doctype);
        if (doctypeMatch) {
          advance(doctypeMatch[0].length);
          continue
        }

        // End tag:
        var endTagMatch = html.match(endTag);
        if (endTagMatch) {
          var curIndex = index;
          advance(endTagMatch[0].length);
          parseEndTag(endTagMatch[1], curIndex, index);
          continue
        }

        // Start tag:
        var startTagMatch = parseStartTag();
        if (startTagMatch) {
          handleStartTag(startTagMatch);
          if (shouldIgnoreFirstNewline(startTagMatch.tagName, html)) {
            advance(1);
          }
          continue
        }
      }

      var text = (void 0), rest = (void 0), next = (void 0);
      if (textEnd >= 0) {
        rest = html.slice(textEnd);
        while (
          !endTag.test(rest) &&
          !startTagOpen.test(rest) &&
          !comment.test(rest) &&
          !conditionalComment.test(rest)
        ) {
          // < in plain text, be forgiving and treat it as text
          next = rest.indexOf('<', 1);
          if (next < 0) { break }
          textEnd += next;
          rest = html.slice(textEnd);
        }
        text = html.substring(0, textEnd);
      }

      if (textEnd < 0) {
        text = html;
      }

      if (text) {
        advance(text.length);
      }

      if (options.chars && text) {
        options.chars(text, index - text.length, index);
      }
    } else {
      var endTagLength = 0;
      var stackedTag = lastTag.toLowerCase();
      var reStackedTag = reCache[stackedTag] || (reCache[stackedTag] = new RegExp('([\\s\\S]*?)(</' + stackedTag + '[^>]*>)', 'i'));
      var rest$1 = html.replace(reStackedTag, function (all, text, endTag) {
        endTagLength = endTag.length;
        if (!isPlainTextElement(stackedTag) && stackedTag !== 'noscript') {
          text = text
            .replace(/<!\--([\s\S]*?)-->/g, '$1') // #7298
            .replace(/<!\[CDATA\[([\s\S]*?)]]>/g, '$1');
        }
        if (shouldIgnoreFirstNewline(stackedTag, text)) {
          text = text.slice(1);
        }
        if (options.chars) {
          options.chars(text);
        }
        return ''
      });
      index += html.length - rest$1.length;
      html = rest$1;
      parseEndTag(stackedTag, index - endTagLength, index);
    }

    if (html === last) {
      options.chars && options.chars(html);
      if ( !stack.length && options.warn) {
        options.warn(("Mal-formatted tag at end of template: \"" + html + "\""), { start: index + html.length });
      }
      break
    }
  }

  // Clean up any remaining tags
  parseEndTag();

  function advance (n) {
    index += n;
    html = html.substring(n);
  }

  function parseStartTag () {
    var start = html.match(startTagOpen);
    if (start) {
      var match = {
        tagName: start[1],
        attrs: [],
        start: index
      };
      advance(start[0].length);
      var end, attr;
      while (!(end = html.match(startTagClose)) && (attr = html.match(dynamicArgAttribute) || html.match(attribute))) {
        attr.start = index;
        advance(attr[0].length);
        attr.end = index;
        match.attrs.push(attr);
      }
      if (end) {
        match.unarySlash = end[1];
        advance(end[0].length);
        match.end = index;
        return match
      }
    }
  }

  function handleStartTag (match) {
    var tagName = match.tagName;
    var unarySlash = match.unarySlash;

    if (expectHTML) {
      if (lastTag === 'p' && isNonPhrasingTag(tagName)) {
        parseEndTag(lastTag);
      }
      if (canBeLeftOpenTag$$1(tagName) && lastTag === tagName) {
        parseEndTag(tagName);
      }
    }

    var unary = isUnaryTag$$1(tagName) || !!unarySlash;

    var l = match.attrs.length;
    var attrs = new Array(l);
    for (var i = 0; i < l; i++) {
      var args = match.attrs[i];
      var value = args[3] || args[4] || args[5] || '';
      var shouldDecodeNewlines = tagName === 'a' && args[1] === 'href'
        ? options.shouldDecodeNewlinesForHref
        : options.shouldDecodeNewlines;
      attrs[i] = {
        name: args[1],
        value: decodeAttr(value, shouldDecodeNewlines)
      };
      if ( options.outputSourceRange) {
        attrs[i].start = args.start + args[0].match(/^\s*/).length;
        attrs[i].end = args.end;
      }
    }

    if (!unary) {
      stack.push({ tag: tagName, lowerCasedTag: tagName.toLowerCase(), attrs: attrs, start: match.start, end: match.end });
      lastTag = tagName;
    }

    if (options.start) {
      options.start(tagName, attrs, unary, match.start, match.end);
    }
  }

  function parseEndTag (tagName, start, end) {
    var pos, lowerCasedTagName;
    if (start == null) { start = index; }
    if (end == null) { end = index; }

    // Find the closest opened tag of the same type
    if (tagName) {
      lowerCasedTagName = tagName.toLowerCase();
      for (pos = stack.length - 1; pos >= 0; pos--) {
        if (stack[pos].lowerCasedTag === lowerCasedTagName) {
          break
        }
      }
    } else {
      // If no tag name is provided, clean shop
      pos = 0;
    }

    if (pos >= 0) {
      // Close all the open elements, up the stack
      for (var i = stack.length - 1; i >= pos; i--) {
        if (
          (i > pos || !tagName) &&
          options.warn
        ) {
          options.warn(
            ("tag <" + (stack[i].tag) + "> has no matching end tag."),
            { start: stack[i].start, end: stack[i].end }
          );
        }
        if (options.end) {
          options.end(stack[i].tag, start, end);
        }
      }

      // Remove the open elements from the stack
      stack.length = pos;
      lastTag = pos && stack[pos - 1].tag;
    } else if (lowerCasedTagName === 'br') {
      if (options.start) {
        options.start(tagName, [], true, start, end);
      }
    } else if (lowerCasedTagName === 'p') {
      if (options.start) {
        options.start(tagName, [], false, start, end);
      }
      if (options.end) {
        options.end(tagName, start, end);
      }
    }
  }
}

/*  */

var onRE = /^@|^v-on:/;
var dirRE = /^v-|^@|^:|^#/;
var forAliasRE = /([\s\S]*?)\s+(?:in|of)\s+([\s\S]*)/;
var forIteratorRE = /,([^,\}\]]*)(?:,([^,\}\]]*))?$/;
var stripParensRE = /^\(|\)$/g;
var dynamicArgRE = /^\[.*\]$/;

var argRE = /:(.*)$/;
var bindRE = /^:|^\.|^v-bind:/;
var modifierRE = /\.[^.\]]+(?=[^\]]*$)/g;

var slotRE = /^v-slot(:|$)|^#/;

var lineBreakRE = /[\r\n]/;
var whitespaceRE$1 = /\s+/g;

var invalidAttributeRE = /[\s"'<>\/=]/;

var decodeHTMLCached = cached(he.decode);

var emptySlotScopeToken = "_empty_";

// configurable state
var warn$2;
var delimiters;
var transforms;
var preTransforms;
var postTransforms;
var platformIsPreTag;
var platformMustUseProp;
var platformGetTagNamespace;
var maybeComponent;

function createASTElement (
  tag,
  attrs,
  parent
) {
  return {
    type: 1,
    tag: tag,
    attrsList: attrs,
    attrsMap: makeAttrsMap(attrs),
    rawAttrsMap: {},
    parent: parent,
    children: []
  }
}

/**
 * Convert HTML string to AST.
 */
function parse (
  template,
  options
) {
  warn$2 = options.warn || baseWarn;

  platformIsPreTag = options.isPreTag || no;
  platformMustUseProp = options.mustUseProp || no;
  platformGetTagNamespace = options.getTagNamespace || no;
  var isReservedTag = options.isReservedTag || no;
  maybeComponent = function (el) { return !!el.component || !isReservedTag(el.tag); };

  transforms = pluckModuleFunction(options.modules, 'transformNode');
  preTransforms = pluckModuleFunction(options.modules, 'preTransformNode');
  postTransforms = pluckModuleFunction(options.modules, 'postTransformNode');

  delimiters = options.delimiters;

  var stack = [];
  var preserveWhitespace = options.preserveWhitespace !== false;
  var whitespaceOption = options.whitespace;
  var root;
  var currentParent;
  var inVPre = false;
  var inPre = false;
  var warned = false;

  function warnOnce (msg, range) {
    if (!warned) {
      warned = true;
      warn$2(msg, range);
    }
  }

  function closeElement (element) {
    trimEndingWhitespace(element);
    if (!inVPre && !element.processed) {
      element = processElement(element, options);
    }
    // tree management
    if (!stack.length && element !== root) {
      // allow root elements with v-if, v-else-if and v-else
      if (root.if && (element.elseif || element.else)) {
        {
          checkRootConstraints(element);
        }
        addIfCondition(root, {
          exp: element.elseif,
          block: element
        });
      } else {
        warnOnce(
          "Component template should contain exactly one root element. " +
          "If you are using v-if on multiple elements, " +
          "use v-else-if to chain them instead.",
          { start: element.start }
        );
      }
    }
    if (currentParent && !element.forbidden) {
      if (element.elseif || element.else) {
        processIfConditions(element, currentParent);
      } else {
        if (element.slotScope) {
          // scoped slot
          // keep it in the children list so that v-else(-if) conditions can
          // find it as the prev node.
          var name = element.slotTarget || '"default"'
          ;(currentParent.scopedSlots || (currentParent.scopedSlots = {}))[name] = element;
        }
        currentParent.children.push(element);
        element.parent = currentParent;
      }
    }

    // final children cleanup
    // filter out scoped slots
    element.children = element.children.filter(function (c) { return !(c).slotScope; });
    // remove trailing whitespace node again
    trimEndingWhitespace(element);

    // check pre state
    if (element.pre) {
      inVPre = false;
    }
    if (platformIsPreTag(element.tag)) {
      inPre = false;
    }
    // apply post-transforms
    for (var i = 0; i < postTransforms.length; i++) {
      postTransforms[i](element, options);
    }
  }

  function trimEndingWhitespace (el) {
    // remove trailing whitespace node
    if (!inPre) {
      var lastNode;
      while (
        (lastNode = el.children[el.children.length - 1]) &&
        lastNode.type === 3 &&
        lastNode.text === ' '
      ) {
        el.children.pop();
      }
    }
  }

  function checkRootConstraints (el) {
    if (el.tag === 'slot' || el.tag === 'template') {
      warnOnce(
        "Cannot use <" + (el.tag) + "> as component root element because it may " +
        'contain multiple nodes.',
        { start: el.start }
      );
    }
    if (el.attrsMap.hasOwnProperty('v-for')) {
      warnOnce(
        'Cannot use v-for on stateful component root element because ' +
        'it renders multiple elements.',
        el.rawAttrsMap['v-for']
      );
    }
  }

  parseHTML(template, {
    warn: warn$2,
    expectHTML: options.expectHTML,
    isUnaryTag: options.isUnaryTag,
    canBeLeftOpenTag: options.canBeLeftOpenTag,
    shouldDecodeNewlines: options.shouldDecodeNewlines,
    shouldDecodeNewlinesForHref: options.shouldDecodeNewlinesForHref,
    shouldKeepComment: options.comments,
    outputSourceRange: options.outputSourceRange,
    start: function start (tag, attrs, unary, start$1, end) {
      // check namespace.
      // inherit parent ns if there is one
      var ns = (currentParent && currentParent.ns) || platformGetTagNamespace(tag);

      // handle IE svg bug
      /* istanbul ignore if */
      if (isIE && ns === 'svg') {
        attrs = guardIESVGBug(attrs);
      }

      var element = createASTElement(tag, attrs, currentParent);
      if (ns) {
        element.ns = ns;
      }

      {
        if (options.outputSourceRange) {
          element.start = start$1;
          element.end = end;
          element.rawAttrsMap = element.attrsList.reduce(function (cumulated, attr) {
            cumulated[attr.name] = attr;
            return cumulated
          }, {});
        }
        attrs.forEach(function (attr) {
          if (invalidAttributeRE.test(attr.name)) {
            warn$2(
              "Invalid dynamic argument expression: attribute names cannot contain " +
              "spaces, quotes, <, >, / or =.",
              {
                start: attr.start + attr.name.indexOf("["),
                end: attr.start + attr.name.length
              }
            );
          }
        });
      }

      if (isForbiddenTag(element) && !isServerRendering()) {
        element.forbidden = true;
         warn$2(
          'Templates should only be responsible for mapping the state to the ' +
          'UI. Avoid placing tags with side-effects in your templates, such as ' +
          "<" + tag + ">" + ', as they will not be parsed.',
          { start: element.start }
        );
      }

      // apply pre-transforms
      for (var i = 0; i < preTransforms.length; i++) {
        element = preTransforms[i](element, options) || element;
      }

      if (!inVPre) {
        processPre(element);
        if (element.pre) {
          inVPre = true;
        }
      }
      if (platformIsPreTag(element.tag)) {
        inPre = true;
      }
      if (inVPre) {
        processRawAttrs(element);
      } else if (!element.processed) {
        // structural directives
        processFor(element);
        processIf(element);
        processOnce(element);
      }

      if (!root) {
        root = element;
        {
          checkRootConstraints(root);
        }
      }

      if (!unary) {
        currentParent = element;
        stack.push(element);
      } else {
        closeElement(element);
      }
    },

    end: function end (tag, start, end$1) {
      var element = stack[stack.length - 1];
      // pop stack
      stack.length -= 1;
      currentParent = stack[stack.length - 1];
      if ( options.outputSourceRange) {
        element.end = end$1;
      }
      closeElement(element);
    },

    chars: function chars (text, start, end) {
      if (!currentParent) {
        {
          if (text === template) {
            warnOnce(
              'Component template requires a root element, rather than just text.',
              { start: start }
            );
          } else if ((text = text.trim())) {
            warnOnce(
              ("text \"" + text + "\" outside root element will be ignored."),
              { start: start }
            );
          }
        }
        return
      }
      // IE textarea placeholder bug
      /* istanbul ignore if */
      if (isIE &&
        currentParent.tag === 'textarea' &&
        currentParent.attrsMap.placeholder === text
      ) {
        return
      }
      var children = currentParent.children;
      if (inPre || text.trim()) {
        text = isTextTag(currentParent) ? text : decodeHTMLCached(text);
      } else if (!children.length) {
        // remove the whitespace-only node right after an opening tag
        text = '';
      } else if (whitespaceOption) {
        if (whitespaceOption === 'condense') {
          // in condense mode, remove the whitespace node if it contains
          // line break, otherwise condense to a single space
          text = lineBreakRE.test(text) ? '' : ' ';
        } else {
          text = ' ';
        }
      } else {
        text = preserveWhitespace ? ' ' : '';
      }
      if (text) {
        if (!inPre && whitespaceOption === 'condense') {
          // condense consecutive whitespaces into single space
          text = text.replace(whitespaceRE$1, ' ');
        }
        var res;
        var child;
        if (!inVPre && text !== ' ' && (res = parseText(text, delimiters))) {
          child = {
            type: 2,
            expression: res.expression,
            tokens: res.tokens,
            text: text
          };
        } else if (text !== ' ' || !children.length || children[children.length - 1].text !== ' ') {
          child = {
            type: 3,
            text: text
          };
        }
        if (child) {
          if ( options.outputSourceRange) {
            child.start = start;
            child.end = end;
          }
          children.push(child);
        }
      }
    },
    comment: function comment (text, start, end) {
      // adding anything as a sibling to the root node is forbidden
      // comments should still be allowed, but ignored
      if (currentParent) {
        var child = {
          type: 3,
          text: text,
          isComment: true
        };
        if ( options.outputSourceRange) {
          child.start = start;
          child.end = end;
        }
        currentParent.children.push(child);
      }
    }
  });
  return root
}

function processPre (el) {
  if (getAndRemoveAttr(el, 'v-pre') != null) {
    el.pre = true;
  }
}

function processRawAttrs (el) {
  var list = el.attrsList;
  var len = list.length;
  if (len) {
    var attrs = el.attrs = new Array(len);
    for (var i = 0; i < len; i++) {
      attrs[i] = {
        name: list[i].name,
        value: JSON.stringify(list[i].value)
      };
      if (list[i].start != null) {
        attrs[i].start = list[i].start;
        attrs[i].end = list[i].end;
      }
    }
  } else if (!el.pre) {
    // non root node in pre blocks with no attributes
    el.plain = true;
  }
}

function processElement (
  element,
  options
) {
  processKey(element);

  // determine whether this is a plain element after
  // removing structural attributes
  element.plain = (
    !element.key &&
    !element.scopedSlots &&
    !element.attrsList.length
  );

  processRef(element);
  processSlotContent(element);
  processSlotOutlet(element);
  processComponent(element);
  for (var i = 0; i < transforms.length; i++) {
    element = transforms[i](element, options) || element;
  }
  processAttrs(element);
  return element
}

function processKey (el) {
  var exp = getBindingAttr(el, 'key');
  if (exp) {
    {
      if (el.tag === 'template') {
        warn$2(
          "<template> cannot be keyed. Place the key on real elements instead.",
          getRawBindingAttr(el, 'key')
        );
      }
      if (el.for) {
        var iterator = el.iterator2 || el.iterator1;
        var parent = el.parent;
        if (iterator && iterator === exp && parent && parent.tag === 'transition-group') {
          warn$2(
            "Do not use v-for index as key on <transition-group> children, " +
            "this is the same as not using keys.",
            getRawBindingAttr(el, 'key'),
            true /* tip */
          );
        }
      }
    }
    el.key = exp;
  }
}

function processRef (el) {
  var ref = getBindingAttr(el, 'ref');
  if (ref) {
    el.ref = ref;
    el.refInFor = checkInFor(el);
  }
}

function processFor (el) {
  var exp;
  if ((exp = getAndRemoveAttr(el, 'v-for'))) {
    var res = parseFor(exp);
    if (res) {
      extend(el, res);
    } else {
      warn$2(
        ("Invalid v-for expression: " + exp),
        el.rawAttrsMap['v-for']
      );
    }
  }
}



function parseFor (exp) {
  var inMatch = exp.match(forAliasRE);
  if (!inMatch) { return }
  var res = {};
  res.for = inMatch[2].trim();
  var alias = inMatch[1].trim().replace(stripParensRE, '');
  var iteratorMatch = alias.match(forIteratorRE);
  if (iteratorMatch) {
    res.alias = alias.replace(forIteratorRE, '').trim();
    res.iterator1 = iteratorMatch[1].trim();
    if (iteratorMatch[2]) {
      res.iterator2 = iteratorMatch[2].trim();
    }
  } else {
    res.alias = alias;
  }
  return res
}

function processIf (el) {
  var exp = getAndRemoveAttr(el, 'v-if');
  if (exp) {
    el.if = exp;
    addIfCondition(el, {
      exp: exp,
      block: el
    });
  } else {
    if (getAndRemoveAttr(el, 'v-else') != null) {
      el.else = true;
    }
    var elseif = getAndRemoveAttr(el, 'v-else-if');
    if (elseif) {
      el.elseif = elseif;
    }
  }
}

function processIfConditions (el, parent) {
  var prev = findPrevElement(parent.children);
  if (prev && prev.if) {
    addIfCondition(prev, {
      exp: el.elseif,
      block: el
    });
  } else {
    warn$2(
      "v-" + (el.elseif ? ('else-if="' + el.elseif + '"') : 'else') + " " +
      "used on element <" + (el.tag) + "> without corresponding v-if.",
      el.rawAttrsMap[el.elseif ? 'v-else-if' : 'v-else']
    );
  }
}

function findPrevElement (children) {
  var i = children.length;
  while (i--) {
    if (children[i].type === 1) {
      return children[i]
    } else {
      if ( children[i].text !== ' ') {
        warn$2(
          "text \"" + (children[i].text.trim()) + "\" between v-if and v-else(-if) " +
          "will be ignored.",
          children[i]
        );
      }
      children.pop();
    }
  }
}

function addIfCondition (el, condition) {
  if (!el.ifConditions) {
    el.ifConditions = [];
  }
  el.ifConditions.push(condition);
}

function processOnce (el) {
  var once$$1 = getAndRemoveAttr(el, 'v-once');
  if (once$$1 != null) {
    el.once = true;
  }
}

// handle content being passed to a component as slot,
// e.g. <template slot="xxx">, <div slot-scope="xxx">
function processSlotContent (el) {
  var slotScope;
  if (el.tag === 'template') {
    slotScope = getAndRemoveAttr(el, 'scope');
    /* istanbul ignore if */
    if ( slotScope) {
      warn$2(
        "the \"scope\" attribute for scoped slots have been deprecated and " +
        "replaced by \"slot-scope\" since 2.5. The new \"slot-scope\" attribute " +
        "can also be used on plain elements in addition to <template> to " +
        "denote scoped slots.",
        el.rawAttrsMap['scope'],
        true
      );
    }
    el.slotScope = slotScope || getAndRemoveAttr(el, 'slot-scope');
  } else if ((slotScope = getAndRemoveAttr(el, 'slot-scope'))) {
    /* istanbul ignore if */
    if ( el.attrsMap['v-for']) {
      warn$2(
        "Ambiguous combined usage of slot-scope and v-for on <" + (el.tag) + "> " +
        "(v-for takes higher priority). Use a wrapper <template> for the " +
        "scoped slot to make it clearer.",
        el.rawAttrsMap['slot-scope'],
        true
      );
    }
    el.slotScope = slotScope;
  }

  // slot="xxx"
  var slotTarget = getBindingAttr(el, 'slot');
  if (slotTarget) {
    el.slotTarget = slotTarget === '""' ? '"default"' : slotTarget;
    el.slotTargetDynamic = !!(el.attrsMap[':slot'] || el.attrsMap['v-bind:slot']);
    // preserve slot as an attribute for native shadow DOM compat
    // only for non-scoped slots.
    if (el.tag !== 'template' && !el.slotScope) {
      addAttr(el, 'slot', slotTarget, getRawBindingAttr(el, 'slot'));
    }
  }

  // 2.6 v-slot syntax
  {
    if (el.tag === 'template') {
      // v-slot on <template>
      var slotBinding = getAndRemoveAttrByRegex(el, slotRE);
      if (slotBinding) {
        {
          if (el.slotTarget || el.slotScope) {
            warn$2(
              "Unexpected mixed usage of different slot syntaxes.",
              el
            );
          }
          if (el.parent && !maybeComponent(el.parent)) {
            warn$2(
              "<template v-slot> can only appear at the root level inside " +
              "the receiving component",
              el
            );
          }
        }
        var ref = getSlotName(slotBinding);
        var name = ref.name;
        var dynamic = ref.dynamic;
        el.slotTarget = name;
        el.slotTargetDynamic = dynamic;
        el.slotScope = slotBinding.value || emptySlotScopeToken; // force it into a scoped slot for perf
      }
    } else {
      // v-slot on component, denotes default slot
      var slotBinding$1 = getAndRemoveAttrByRegex(el, slotRE);
      if (slotBinding$1) {
        {
          if (!maybeComponent(el)) {
            warn$2(
              "v-slot can only be used on components or <template>.",
              slotBinding$1
            );
          }
          if (el.slotScope || el.slotTarget) {
            warn$2(
              "Unexpected mixed usage of different slot syntaxes.",
              el
            );
          }
          if (el.scopedSlots) {
            warn$2(
              "To avoid scope ambiguity, the default slot should also use " +
              "<template> syntax when there are other named slots.",
              slotBinding$1
            );
          }
        }
        // add the component's children to its default slot
        var slots = el.scopedSlots || (el.scopedSlots = {});
        var ref$1 = getSlotName(slotBinding$1);
        var name$1 = ref$1.name;
        var dynamic$1 = ref$1.dynamic;
        var slotContainer = slots[name$1] = createASTElement('template', [], el);
        slotContainer.slotTarget = name$1;
        slotContainer.slotTargetDynamic = dynamic$1;
        slotContainer.children = el.children.filter(function (c) {
          if (!c.slotScope) {
            c.parent = slotContainer;
            return true
          }
        });
        slotContainer.slotScope = slotBinding$1.value || emptySlotScopeToken;
        // remove children as they are returned from scopedSlots now
        el.children = [];
        // mark el non-plain so data gets generated
        el.plain = false;
      }
    }
  }
}

function getSlotName (binding) {
  var name = binding.name.replace(slotRE, '');
  if (!name) {
    if (binding.name[0] !== '#') {
      name = 'default';
    } else {
      warn$2(
        "v-slot shorthand syntax requires a slot name.",
        binding
      );
    }
  }
  return dynamicArgRE.test(name)
    // dynamic [name]
    ? { name: name.slice(1, -1), dynamic: true }
    // static name
    : { name: ("\"" + name + "\""), dynamic: false }
}

// handle <slot/> outlets
function processSlotOutlet (el) {
  if (el.tag === 'slot') {
    el.slotName = getBindingAttr(el, 'name');
    if ( el.key) {
      warn$2(
        "`key` does not work on <slot> because slots are abstract outlets " +
        "and can possibly expand into multiple elements. " +
        "Use the key on a wrapping element instead.",
        getRawBindingAttr(el, 'key')
      );
    }
  }
}

function processComponent (el) {
  var binding;
  if ((binding = getBindingAttr(el, 'is'))) {
    el.component = binding;
  }
  if (getAndRemoveAttr(el, 'inline-template') != null) {
    el.inlineTemplate = true;
  }
}

function processAttrs (el) {
  var list = el.attrsList;
  var i, l, name, rawName, value, modifiers, syncGen, isDynamic;
  for (i = 0, l = list.length; i < l; i++) {
    name = rawName = list[i].name;
    value = list[i].value;
    if (dirRE.test(name)) {
      // mark element as dynamic
      el.hasBindings = true;
      // modifiers
      modifiers = parseModifiers(name.replace(dirRE, ''));
      // support .foo shorthand syntax for the .prop modifier
      if (modifiers) {
        name = name.replace(modifierRE, '');
      }
      if (bindRE.test(name)) { // v-bind
        name = name.replace(bindRE, '');
        value = parseFilters(value);
        isDynamic = dynamicArgRE.test(name);
        if (isDynamic) {
          name = name.slice(1, -1);
        }
        if (
          
          value.trim().length === 0
        ) {
          warn$2(
            ("The value for a v-bind expression cannot be empty. Found in \"v-bind:" + name + "\"")
          );
        }
        if (modifiers) {
          if (modifiers.prop && !isDynamic) {
            name = camelize(name);
            if (name === 'innerHtml') { name = 'innerHTML'; }
          }
          if (modifiers.camel && !isDynamic) {
            name = camelize(name);
          }
          if (modifiers.sync) {
            syncGen = genAssignmentCode(value, "$event");
            if (!isDynamic) {
              addHandler(
                el,
                ("update:" + (camelize(name))),
                syncGen,
                null,
                false,
                warn$2,
                list[i]
              );
              if (hyphenate(name) !== camelize(name)) {
                addHandler(
                  el,
                  ("update:" + (hyphenate(name))),
                  syncGen,
                  null,
                  false,
                  warn$2,
                  list[i]
                );
              }
            } else {
              // handler w/ dynamic event name
              addHandler(
                el,
                ("\"update:\"+(" + name + ")"),
                syncGen,
                null,
                false,
                warn$2,
                list[i],
                true // dynamic
              );
            }
          }
        }
        if ((modifiers && modifiers.prop) || (
          !el.component && platformMustUseProp(el.tag, el.attrsMap.type, name)
        )) {
          addProp(el, name, value, list[i], isDynamic);
        } else {
          addAttr(el, name, value, list[i], isDynamic);
        }
      } else if (onRE.test(name)) { // v-on
        name = name.replace(onRE, '');
        isDynamic = dynamicArgRE.test(name);
        if (isDynamic) {
          name = name.slice(1, -1);
        }
        addHandler(el, name, value, modifiers, false, warn$2, list[i], isDynamic);
      } else { // normal directives
        name = name.replace(dirRE, '');
        // parse arg
        var argMatch = name.match(argRE);
        var arg = argMatch && argMatch[1];
        isDynamic = false;
        if (arg) {
          name = name.slice(0, -(arg.length + 1));
          if (dynamicArgRE.test(arg)) {
            arg = arg.slice(1, -1);
            isDynamic = true;
          }
        }
        addDirective(el, name, rawName, value, arg, isDynamic, modifiers, list[i]);
        if ( name === 'model') {
          checkForAliasModel(el, value);
        }
      }
    } else {
      // literal attribute
      {
        var res = parseText(value, delimiters);
        if (res) {
          warn$2(
            name + "=\"" + value + "\": " +
            'Interpolation inside attributes has been removed. ' +
            'Use v-bind or the colon shorthand instead. For example, ' +
            'instead of <div id="{{ val }}">, use <div :id="val">.',
            list[i]
          );
        }
      }
      addAttr(el, name, JSON.stringify(value), list[i]);
      // #6887 firefox doesn't update muted state if set via attribute
      // even immediately after element creation
      if (!el.component &&
          name === 'muted' &&
          platformMustUseProp(el.tag, el.attrsMap.type, name)) {
        addProp(el, name, 'true', list[i]);
      }
    }
  }
}

function checkInFor (el) {
  var parent = el;
  while (parent) {
    if (parent.for !== undefined) {
      return true
    }
    parent = parent.parent;
  }
  return false
}

function parseModifiers (name) {
  var match = name.match(modifierRE);
  if (match) {
    var ret = {};
    match.forEach(function (m) { ret[m.slice(1)] = true; });
    return ret
  }
}

function makeAttrsMap (attrs) {
  var map = {};
  for (var i = 0, l = attrs.length; i < l; i++) {
    if (
      
      map[attrs[i].name] && !isIE && !isEdge
    ) {
      warn$2('duplicate attribute: ' + attrs[i].name, attrs[i]);
    }
    map[attrs[i].name] = attrs[i].value;
  }
  return map
}

// for script (e.g. type="x/template") or style, do not decode content
function isTextTag (el) {
  return el.tag === 'script' || el.tag === 'style'
}

function isForbiddenTag (el) {
  return (
    el.tag === 'style' ||
    (el.tag === 'script' && (
      !el.attrsMap.type ||
      el.attrsMap.type === 'text/javascript'
    ))
  )
}

var ieNSBug = /^xmlns:NS\d+/;
var ieNSPrefix = /^NS\d+:/;

/* istanbul ignore next */
function guardIESVGBug (attrs) {
  var res = [];
  for (var i = 0; i < attrs.length; i++) {
    var attr = attrs[i];
    if (!ieNSBug.test(attr.name)) {
      attr.name = attr.name.replace(ieNSPrefix, '');
      res.push(attr);
    }
  }
  return res
}

function checkForAliasModel (el, value) {
  var _el = el;
  while (_el) {
    if (_el.for && _el.alias === value) {
      warn$2(
        "<" + (el.tag) + " v-model=\"" + value + "\">: " +
        "You are binding v-model directly to a v-for iteration alias. " +
        "This will not be able to modify the v-for source array because " +
        "writing to the alias is like modifying a function local variable. " +
        "Consider using an array of objects and use v-model on an object property instead.",
        el.rawAttrsMap['v-model']
      );
    }
    _el = _el.parent;
  }
}

/*  */

function preTransformNode (el, options) {
  if (el.tag === 'input') {
    var map = el.attrsMap;
    if (!map['v-model']) {
      return
    }

    var typeBinding;
    if (map[':type'] || map['v-bind:type']) {
      typeBinding = getBindingAttr(el, 'type');
    }
    if (!map.type && !typeBinding && map['v-bind']) {
      typeBinding = "(" + (map['v-bind']) + ").type";
    }

    if (typeBinding) {
      var ifCondition = getAndRemoveAttr(el, 'v-if', true);
      var ifConditionExtra = ifCondition ? ("&&(" + ifCondition + ")") : "";
      var hasElse = getAndRemoveAttr(el, 'v-else', true) != null;
      var elseIfCondition = getAndRemoveAttr(el, 'v-else-if', true);
      // 1. checkbox
      var branch0 = cloneASTElement(el);
      // process for on the main node
      processFor(branch0);
      addRawAttr(branch0, 'type', 'checkbox');
      processElement(branch0, options);
      branch0.processed = true; // prevent it from double-processed
      branch0.if = "(" + typeBinding + ")==='checkbox'" + ifConditionExtra;
      addIfCondition(branch0, {
        exp: branch0.if,
        block: branch0
      });
      // 2. add radio else-if condition
      var branch1 = cloneASTElement(el);
      getAndRemoveAttr(branch1, 'v-for', true);
      addRawAttr(branch1, 'type', 'radio');
      processElement(branch1, options);
      addIfCondition(branch0, {
        exp: "(" + typeBinding + ")==='radio'" + ifConditionExtra,
        block: branch1
      });
      // 3. other
      var branch2 = cloneASTElement(el);
      getAndRemoveAttr(branch2, 'v-for', true);
      addRawAttr(branch2, ':type', typeBinding);
      processElement(branch2, options);
      addIfCondition(branch0, {
        exp: ifCondition,
        block: branch2
      });

      if (hasElse) {
        branch0.else = true;
      } else if (elseIfCondition) {
        branch0.elseif = elseIfCondition;
      }

      return branch0
    }
  }
}

function cloneASTElement (el) {
  return createASTElement(el.tag, el.attrsList.slice(), el.parent)
}

var model$1 = {
  preTransformNode: preTransformNode
};

var modules$1 = [
  klass$1,
  style$1,
  model$1
];

/*  */

function text (el, dir) {
  if (dir.value) {
    addProp(el, 'textContent', ("_s(" + (dir.value) + ")"), dir);
  }
}

/*  */

function html (el, dir) {
  if (dir.value) {
    addProp(el, 'innerHTML', ("_s(" + (dir.value) + ")"), dir);
  }
}

var directives$1 = {
  model: model,
  text: text,
  html: html
};

/*  */

var baseOptions = {
  expectHTML: true,
  modules: modules$1,
  directives: directives$1,
  isPreTag: isPreTag,
  isUnaryTag: isUnaryTag,
  mustUseProp: mustUseProp,
  canBeLeftOpenTag: canBeLeftOpenTag,
  isReservedTag: isReservedTag,
  getTagNamespace: getTagNamespace,
  staticKeys: genStaticKeys(modules$1)
};

/*  */

var isStaticKey;
var isPlatformReservedTag;

var genStaticKeysCached = cached(genStaticKeys$1);

/**
 * Goal of the optimizer: walk the generated template AST tree
 * and detect sub-trees that are purely static, i.e. parts of
 * the DOM that never needs to change.
 *
 * Once we detect these sub-trees, we can:
 *
 * 1. Hoist them into constants, so that we no longer need to
 *    create fresh nodes for them on each re-render;
 * 2. Completely skip them in the patching process.
 */
function optimize (root, options) {
  if (!root) { return }
  isStaticKey = genStaticKeysCached(options.staticKeys || '');
  isPlatformReservedTag = options.isReservedTag || no;
  // first pass: mark all non-static nodes.
  markStatic$1(root);
  // second pass: mark static roots.
  markStaticRoots(root, false);
}

function genStaticKeys$1 (keys) {
  return makeMap(
    'type,tag,attrsList,attrsMap,plain,parent,children,attrs,start,end,rawAttrsMap' +
    (keys ? ',' + keys : '')
  )
}

function markStatic$1 (node) {
  node.static = isStatic(node);
  if (node.type === 1) {
    // do not make component slot content static. this avoids
    // 1. components not able to mutate slot nodes
    // 2. static slot content fails for hot-reloading
    if (
      !isPlatformReservedTag(node.tag) &&
      node.tag !== 'slot' &&
      node.attrsMap['inline-template'] == null
    ) {
      return
    }
    for (var i = 0, l = node.children.length; i < l; i++) {
      var child = node.children[i];
      markStatic$1(child);
      if (!child.static) {
        node.static = false;
      }
    }
    if (node.ifConditions) {
      for (var i$1 = 1, l$1 = node.ifConditions.length; i$1 < l$1; i$1++) {
        var block = node.ifConditions[i$1].block;
        markStatic$1(block);
        if (!block.static) {
          node.static = false;
        }
      }
    }
  }
}

function markStaticRoots (node, isInFor) {
  if (node.type === 1) {
    if (node.static || node.once) {
      node.staticInFor = isInFor;
    }
    // For a node to qualify as a static root, it should have children that
    // are not just static text. Otherwise the cost of hoisting out will
    // outweigh the benefits and it's better off to just always render it fresh.
    if (node.static && node.children.length && !(
      node.children.length === 1 &&
      node.children[0].type === 3
    )) {
      node.staticRoot = true;
      return
    } else {
      node.staticRoot = false;
    }
    if (node.children) {
      for (var i = 0, l = node.children.length; i < l; i++) {
        markStaticRoots(node.children[i], isInFor || !!node.for);
      }
    }
    if (node.ifConditions) {
      for (var i$1 = 1, l$1 = node.ifConditions.length; i$1 < l$1; i$1++) {
        markStaticRoots(node.ifConditions[i$1].block, isInFor);
      }
    }
  }
}

function isStatic (node) {
  if (node.type === 2) { // expression
    return false
  }
  if (node.type === 3) { // text
    return true
  }
  return !!(node.pre || (
    !node.hasBindings && // no dynamic bindings
    !node.if && !node.for && // not v-if or v-for or v-else
    !isBuiltInTag(node.tag) && // not a built-in
    isPlatformReservedTag(node.tag) && // not a component
    !isDirectChildOfTemplateFor(node) &&
    Object.keys(node).every(isStaticKey)
  ))
}

function isDirectChildOfTemplateFor (node) {
  while (node.parent) {
    node = node.parent;
    if (node.tag !== 'template') {
      return false
    }
    if (node.for) {
      return true
    }
  }
  return false
}

/*  */

var fnExpRE = /^([\w$_]+|\([^)]*?\))\s*=>|^function(?:\s+[\w$]+)?\s*\(/;
var fnInvokeRE = /\([^)]*?\);*$/;
var simplePathRE = /^[A-Za-z_$][\w$]*(?:\.[A-Za-z_$][\w$]*|\['[^']*?']|\["[^"]*?"]|\[\d+]|\[[A-Za-z_$][\w$]*])*$/;

// KeyboardEvent.keyCode aliases
var keyCodes = {
  esc: 27,
  tab: 9,
  enter: 13,
  space: 32,
  up: 38,
  left: 37,
  right: 39,
  down: 40,
  'delete': [8, 46]
};

// KeyboardEvent.key aliases
var keyNames = {
  // #7880: IE11 and Edge use `Esc` for Escape key name.
  esc: ['Esc', 'Escape'],
  tab: 'Tab',
  enter: 'Enter',
  // #9112: IE11 uses `Spacebar` for Space key name.
  space: [' ', 'Spacebar'],
  // #7806: IE11 uses key names without `Arrow` prefix for arrow keys.
  up: ['Up', 'ArrowUp'],
  left: ['Left', 'ArrowLeft'],
  right: ['Right', 'ArrowRight'],
  down: ['Down', 'ArrowDown'],
  // #9112: IE11 uses `Del` for Delete key name.
  'delete': ['Backspace', 'Delete', 'Del']
};

// #4868: modifiers that prevent the execution of the listener
// need to explicitly return null so that we can determine whether to remove
// the listener for .once
var genGuard = function (condition) { return ("if(" + condition + ")return null;"); };

var modifierCode = {
  stop: '$event.stopPropagation();',
  prevent: '$event.preventDefault();',
  self: genGuard("$event.target !== $event.currentTarget"),
  ctrl: genGuard("!$event.ctrlKey"),
  shift: genGuard("!$event.shiftKey"),
  alt: genGuard("!$event.altKey"),
  meta: genGuard("!$event.metaKey"),
  left: genGuard("'button' in $event && $event.button !== 0"),
  middle: genGuard("'button' in $event && $event.button !== 1"),
  right: genGuard("'button' in $event && $event.button !== 2")
};

function genHandlers (
  events,
  isNative
) {
  var prefix = isNative ? 'nativeOn:' : 'on:';
  var staticHandlers = "";
  var dynamicHandlers = "";
  for (var name in events) {
    var handlerCode = genHandler(events[name]);
    if (events[name] && events[name].dynamic) {
      dynamicHandlers += name + "," + handlerCode + ",";
    } else {
      staticHandlers += "\"" + name + "\":" + handlerCode + ",";
    }
  }
  staticHandlers = "{" + (staticHandlers.slice(0, -1)) + "}";
  if (dynamicHandlers) {
    return prefix + "_d(" + staticHandlers + ",[" + (dynamicHandlers.slice(0, -1)) + "])"
  } else {
    return prefix + staticHandlers
  }
}

function genHandler (handler) {
  if (!handler) {
    return 'function(){}'
  }

  if (Array.isArray(handler)) {
    return ("[" + (handler.map(function (handler) { return genHandler(handler); }).join(',')) + "]")
  }

  var isMethodPath = simplePathRE.test(handler.value);
  var isFunctionExpression = fnExpRE.test(handler.value);
  var isFunctionInvocation = simplePathRE.test(handler.value.replace(fnInvokeRE, ''));

  if (!handler.modifiers) {
    if (isMethodPath || isFunctionExpression) {
      return handler.value
    }
    return ("function($event){" + (isFunctionInvocation ? ("return " + (handler.value)) : handler.value) + "}") // inline statement
  } else {
    var code = '';
    var genModifierCode = '';
    var keys = [];
    for (var key in handler.modifiers) {
      if (modifierCode[key]) {
        genModifierCode += modifierCode[key];
        // left/right
        if (keyCodes[key]) {
          keys.push(key);
        }
      } else if (key === 'exact') {
        var modifiers = (handler.modifiers);
        genModifierCode += genGuard(
          ['ctrl', 'shift', 'alt', 'meta']
            .filter(function (keyModifier) { return !modifiers[keyModifier]; })
            .map(function (keyModifier) { return ("$event." + keyModifier + "Key"); })
            .join('||')
        );
      } else {
        keys.push(key);
      }
    }
    if (keys.length) {
      code += genKeyFilter(keys);
    }
    // Make sure modifiers like prevent and stop get executed after key filtering
    if (genModifierCode) {
      code += genModifierCode;
    }
    var handlerCode = isMethodPath
      ? ("return " + (handler.value) + "($event)")
      : isFunctionExpression
        ? ("return (" + (handler.value) + ")($event)")
        : isFunctionInvocation
          ? ("return " + (handler.value))
          : handler.value;
    return ("function($event){" + code + handlerCode + "}")
  }
}

function genKeyFilter (keys) {
  return (
    // make sure the key filters only apply to KeyboardEvents
    // #9441: can't use 'keyCode' in $event because Chrome autofill fires fake
    // key events that do not have keyCode property...
    "if(!$event.type.indexOf('key')&&" +
    (keys.map(genFilterCode).join('&&')) + ")return null;"
  )
}

function genFilterCode (key) {
  var keyVal = parseInt(key, 10);
  if (keyVal) {
    return ("$event.keyCode!==" + keyVal)
  }
  var keyCode = keyCodes[key];
  var keyName = keyNames[key];
  return (
    "_k($event.keyCode," +
    (JSON.stringify(key)) + "," +
    (JSON.stringify(keyCode)) + "," +
    "$event.key," +
    "" + (JSON.stringify(keyName)) +
    ")"
  )
}

/*  */

function on (el, dir) {
  if ( dir.modifiers) {
    warn("v-on without argument does not support modifiers.");
  }
  el.wrapListeners = function (code) { return ("_g(" + code + "," + (dir.value) + ")"); };
}

/*  */

function bind$1 (el, dir) {
  el.wrapData = function (code) {
    return ("_b(" + code + ",'" + (el.tag) + "'," + (dir.value) + "," + (dir.modifiers && dir.modifiers.prop ? 'true' : 'false') + (dir.modifiers && dir.modifiers.sync ? ',true' : '') + ")")
  };
}

/*  */

var baseDirectives = {
  on: on,
  bind: bind$1,
  cloak: noop
};

/*  */





var CodegenState = function CodegenState (options) {
  this.options = options;
  this.warn = options.warn || baseWarn;
  this.transforms = pluckModuleFunction(options.modules, 'transformCode');
  this.dataGenFns = pluckModuleFunction(options.modules, 'genData');
  this.directives = extend(extend({}, baseDirectives), options.directives);
  var isReservedTag = options.isReservedTag || no;
  this.maybeComponent = function (el) { return !!el.component || !isReservedTag(el.tag); };
  this.onceId = 0;
  this.staticRenderFns = [];
  this.pre = false;
};



function generate (
  ast,
  options
) {
  var state = new CodegenState(options);
  var code = ast ? genElement(ast, state) : '_c("div")';
  return {
    render: ("with(this){return " + code + "}"),
    staticRenderFns: state.staticRenderFns
  }
}

function genElement (el, state) {
  if (el.parent) {
    el.pre = el.pre || el.parent.pre;
  }

  if (el.staticRoot && !el.staticProcessed) {
    return genStatic(el, state)
  } else if (el.once && !el.onceProcessed) {
    return genOnce(el, state)
  } else if (el.for && !el.forProcessed) {
    return genFor(el, state)
  } else if (el.if && !el.ifProcessed) {
    return genIf(el, state)
  } else if (el.tag === 'template' && !el.slotTarget && !state.pre) {
    return genChildren(el, state) || 'void 0'
  } else if (el.tag === 'slot') {
    return genSlot(el, state)
  } else {
    // component or element
    var code;
    if (el.component) {
      code = genComponent(el.component, el, state);
    } else {
      var data;
      if (!el.plain || (el.pre && state.maybeComponent(el))) {
        data = genData$2(el, state);
      }

      var children = el.inlineTemplate ? null : genChildren(el, state, true);
      code = "_c('" + (el.tag) + "'" + (data ? ("," + data) : '') + (children ? ("," + children) : '') + ")";
    }
    // module transforms
    for (var i = 0; i < state.transforms.length; i++) {
      code = state.transforms[i](el, code);
    }
    return code
  }
}

// hoist static sub-trees out
function genStatic (el, state) {
  el.staticProcessed = true;
  // Some elements (templates) need to behave differently inside of a v-pre
  // node.  All pre nodes are static roots, so we can use this as a location to
  // wrap a state change and reset it upon exiting the pre node.
  var originalPreState = state.pre;
  if (el.pre) {
    state.pre = el.pre;
  }
  state.staticRenderFns.push(("with(this){return " + (genElement(el, state)) + "}"));
  state.pre = originalPreState;
  return ("_m(" + (state.staticRenderFns.length - 1) + (el.staticInFor ? ',true' : '') + ")")
}

// v-once
function genOnce (el, state) {
  el.onceProcessed = true;
  if (el.if && !el.ifProcessed) {
    return genIf(el, state)
  } else if (el.staticInFor) {
    var key = '';
    var parent = el.parent;
    while (parent) {
      if (parent.for) {
        key = parent.key;
        break
      }
      parent = parent.parent;
    }
    if (!key) {
       state.warn(
        "v-once can only be used inside v-for that is keyed. ",
        el.rawAttrsMap['v-once']
      );
      return genElement(el, state)
    }
    return ("_o(" + (genElement(el, state)) + "," + (state.onceId++) + "," + key + ")")
  } else {
    return genStatic(el, state)
  }
}

function genIf (
  el,
  state,
  altGen,
  altEmpty
) {
  el.ifProcessed = true; // avoid recursion
  return genIfConditions(el.ifConditions.slice(), state, altGen, altEmpty)
}

function genIfConditions (
  conditions,
  state,
  altGen,
  altEmpty
) {
  if (!conditions.length) {
    return altEmpty || '_e()'
  }

  var condition = conditions.shift();
  if (condition.exp) {
    return ("(" + (condition.exp) + ")?" + (genTernaryExp(condition.block)) + ":" + (genIfConditions(conditions, state, altGen, altEmpty)))
  } else {
    return ("" + (genTernaryExp(condition.block)))
  }

  // v-if with v-once should generate code like (a)?_m(0):_m(1)
  function genTernaryExp (el) {
    return altGen
      ? altGen(el, state)
      : el.once
        ? genOnce(el, state)
        : genElement(el, state)
  }
}

function genFor (
  el,
  state,
  altGen,
  altHelper
) {
  var exp = el.for;
  var alias = el.alias;
  var iterator1 = el.iterator1 ? ("," + (el.iterator1)) : '';
  var iterator2 = el.iterator2 ? ("," + (el.iterator2)) : '';

  if (
    state.maybeComponent(el) &&
    el.tag !== 'slot' &&
    el.tag !== 'template' &&
    !el.key
  ) {
    state.warn(
      "<" + (el.tag) + " v-for=\"" + alias + " in " + exp + "\">: component lists rendered with " +
      "v-for should have explicit keys. " +
      "See https://vuejs.org/guide/list.html#key for more info.",
      el.rawAttrsMap['v-for'],
      true /* tip */
    );
  }

  el.forProcessed = true; // avoid recursion
  return (altHelper || '_l') + "((" + exp + ")," +
    "function(" + alias + iterator1 + iterator2 + "){" +
      "return " + ((altGen || genElement)(el, state)) +
    '})'
}

function genData$2 (el, state) {
  var data = '{';

  // directives first.
  // directives may mutate the el's other properties before they are generated.
  var dirs = genDirectives(el, state);
  if (dirs) { data += dirs + ','; }

  // key
  if (el.key) {
    data += "key:" + (el.key) + ",";
  }
  // ref
  if (el.ref) {
    data += "ref:" + (el.ref) + ",";
  }
  if (el.refInFor) {
    data += "refInFor:true,";
  }
  // pre
  if (el.pre) {
    data += "pre:true,";
  }
  // record original tag name for components using "is" attribute
  if (el.component) {
    data += "tag:\"" + (el.tag) + "\",";
  }
  // module data generation functions
  for (var i = 0; i < state.dataGenFns.length; i++) {
    data += state.dataGenFns[i](el);
  }
  // attributes
  if (el.attrs) {
    data += "attrs:" + (genProps(el.attrs)) + ",";
  }
  // DOM props
  if (el.props) {
    data += "domProps:" + (genProps(el.props)) + ",";
  }
  // event handlers
  if (el.events) {
    data += (genHandlers(el.events, false)) + ",";
  }
  if (el.nativeEvents) {
    data += (genHandlers(el.nativeEvents, true)) + ",";
  }
  // slot target
  // only for non-scoped slots
  if (el.slotTarget && !el.slotScope) {
    data += "slot:" + (el.slotTarget) + ",";
  }
  // scoped slots
  if (el.scopedSlots) {
    data += (genScopedSlots(el, el.scopedSlots, state)) + ",";
  }
  // component v-model
  if (el.model) {
    data += "model:{value:" + (el.model.value) + ",callback:" + (el.model.callback) + ",expression:" + (el.model.expression) + "},";
  }
  // inline-template
  if (el.inlineTemplate) {
    var inlineTemplate = genInlineTemplate(el, state);
    if (inlineTemplate) {
      data += inlineTemplate + ",";
    }
  }
  data = data.replace(/,$/, '') + '}';
  // v-bind dynamic argument wrap
  // v-bind with dynamic arguments must be applied using the same v-bind object
  // merge helper so that class/style/mustUseProp attrs are handled correctly.
  if (el.dynamicAttrs) {
    data = "_b(" + data + ",\"" + (el.tag) + "\"," + (genProps(el.dynamicAttrs)) + ")";
  }
  // v-bind data wrap
  if (el.wrapData) {
    data = el.wrapData(data);
  }
  // v-on data wrap
  if (el.wrapListeners) {
    data = el.wrapListeners(data);
  }
  return data
}

function genDirectives (el, state) {
  var dirs = el.directives;
  if (!dirs) { return }
  var res = 'directives:[';
  var hasRuntime = false;
  var i, l, dir, needRuntime;
  for (i = 0, l = dirs.length; i < l; i++) {
    dir = dirs[i];
    needRuntime = true;
    var gen = state.directives[dir.name];
    if (gen) {
      // compile-time directive that manipulates AST.
      // returns true if it also needs a runtime counterpart.
      needRuntime = !!gen(el, dir, state.warn);
    }
    if (needRuntime) {
      hasRuntime = true;
      res += "{name:\"" + (dir.name) + "\",rawName:\"" + (dir.rawName) + "\"" + (dir.value ? (",value:(" + (dir.value) + "),expression:" + (JSON.stringify(dir.value))) : '') + (dir.arg ? (",arg:" + (dir.isDynamicArg ? dir.arg : ("\"" + (dir.arg) + "\""))) : '') + (dir.modifiers ? (",modifiers:" + (JSON.stringify(dir.modifiers))) : '') + "},";
    }
  }
  if (hasRuntime) {
    return res.slice(0, -1) + ']'
  }
}

function genInlineTemplate (el, state) {
  var ast = el.children[0];
  if ( (
    el.children.length !== 1 || ast.type !== 1
  )) {
    state.warn(
      'Inline-template components must have exactly one child element.',
      { start: el.start }
    );
  }
  if (ast && ast.type === 1) {
    var inlineRenderFns = generate(ast, state.options);
    return ("inlineTemplate:{render:function(){" + (inlineRenderFns.render) + "},staticRenderFns:[" + (inlineRenderFns.staticRenderFns.map(function (code) { return ("function(){" + code + "}"); }).join(',')) + "]}")
  }
}

function genScopedSlots (
  el,
  slots,
  state
) {
  // by default scoped slots are considered "stable", this allows child
  // components with only scoped slots to skip forced updates from parent.
  // but in some cases we have to bail-out of this optimization
  // for example if the slot contains dynamic names, has v-if or v-for on them...
  var needsForceUpdate = el.for || Object.keys(slots).some(function (key) {
    var slot = slots[key];
    return (
      slot.slotTargetDynamic ||
      slot.if ||
      slot.for ||
      containsSlotChild(slot) // is passing down slot from parent which may be dynamic
    )
  });

  // #9534: if a component with scoped slots is inside a conditional branch,
  // it's possible for the same component to be reused but with different
  // compiled slot content. To avoid that, we generate a unique key based on
  // the generated code of all the slot contents.
  var needsKey = !!el.if;

  // OR when it is inside another scoped slot or v-for (the reactivity may be
  // disconnected due to the intermediate scope variable)
  // #9438, #9506
  // TODO: this can be further optimized by properly analyzing in-scope bindings
  // and skip force updating ones that do not actually use scope variables.
  if (!needsForceUpdate) {
    var parent = el.parent;
    while (parent) {
      if (
        (parent.slotScope && parent.slotScope !== emptySlotScopeToken) ||
        parent.for
      ) {
        needsForceUpdate = true;
        break
      }
      if (parent.if) {
        needsKey = true;
      }
      parent = parent.parent;
    }
  }

  var generatedSlots = Object.keys(slots)
    .map(function (key) { return genScopedSlot(slots[key], state); })
    .join(',');

  return ("scopedSlots:_u([" + generatedSlots + "]" + (needsForceUpdate ? ",null,true" : "") + (!needsForceUpdate && needsKey ? (",null,false," + (hash(generatedSlots))) : "") + ")")
}

function hash(str) {
  var hash = 5381;
  var i = str.length;
  while(i) {
    hash = (hash * 33) ^ str.charCodeAt(--i);
  }
  return hash >>> 0
}

function containsSlotChild (el) {
  if (el.type === 1) {
    if (el.tag === 'slot') {
      return true
    }
    return el.children.some(containsSlotChild)
  }
  return false
}

function genScopedSlot (
  el,
  state
) {
  var isLegacySyntax = el.attrsMap['slot-scope'];
  if (el.if && !el.ifProcessed && !isLegacySyntax) {
    return genIf(el, state, genScopedSlot, "null")
  }
  if (el.for && !el.forProcessed) {
    return genFor(el, state, genScopedSlot)
  }
  var slotScope = el.slotScope === emptySlotScopeToken
    ? ""
    : String(el.slotScope);
  var fn = "function(" + slotScope + "){" +
    "return " + (el.tag === 'template'
      ? el.if && isLegacySyntax
        ? ("(" + (el.if) + ")?" + (genChildren(el, state) || 'undefined') + ":undefined")
        : genChildren(el, state) || 'undefined'
      : genElement(el, state)) + "}";
  // reverse proxy v-slot without scope on this.$slots
  var reverseProxy = slotScope ? "" : ",proxy:true";
  return ("{key:" + (el.slotTarget || "\"default\"") + ",fn:" + fn + reverseProxy + "}")
}

function genChildren (
  el,
  state,
  checkSkip,
  altGenElement,
  altGenNode
) {
  var children = el.children;
  if (children.length) {
    var el$1 = children[0];
    // optimize single v-for
    if (children.length === 1 &&
      el$1.for &&
      el$1.tag !== 'template' &&
      el$1.tag !== 'slot'
    ) {
      var normalizationType = checkSkip
        ? state.maybeComponent(el$1) ? ",1" : ",0"
        : "";
      return ("" + ((altGenElement || genElement)(el$1, state)) + normalizationType)
    }
    var normalizationType$1 = checkSkip
      ? getNormalizationType(children, state.maybeComponent)
      : 0;
    var gen = altGenNode || genNode;
    return ("[" + (children.map(function (c) { return gen(c, state); }).join(',')) + "]" + (normalizationType$1 ? ("," + normalizationType$1) : ''))
  }
}

// determine the normalization needed for the children array.
// 0: no normalization needed
// 1: simple normalization needed (possible 1-level deep nested array)
// 2: full normalization needed
function getNormalizationType (
  children,
  maybeComponent
) {
  var res = 0;
  for (var i = 0; i < children.length; i++) {
    var el = children[i];
    if (el.type !== 1) {
      continue
    }
    if (needsNormalization(el) ||
        (el.ifConditions && el.ifConditions.some(function (c) { return needsNormalization(c.block); }))) {
      res = 2;
      break
    }
    if (maybeComponent(el) ||
        (el.ifConditions && el.ifConditions.some(function (c) { return maybeComponent(c.block); }))) {
      res = 1;
    }
  }
  return res
}

function needsNormalization (el) {
  return el.for !== undefined || el.tag === 'template' || el.tag === 'slot'
}

function genNode (node, state) {
  if (node.type === 1) {
    return genElement(node, state)
  } else if (node.type === 3 && node.isComment) {
    return genComment(node)
  } else {
    return genText(node)
  }
}

function genText (text) {
  return ("_v(" + (text.type === 2
    ? text.expression // no need for () because already wrapped in _s()
    : transformSpecialNewlines(JSON.stringify(text.text))) + ")")
}

function genComment (comment) {
  return ("_e(" + (JSON.stringify(comment.text)) + ")")
}

function genSlot (el, state) {
  var slotName = el.slotName || '"default"';
  var children = genChildren(el, state);
  var res = "_t(" + slotName + (children ? ("," + children) : '');
  var attrs = el.attrs || el.dynamicAttrs
    ? genProps((el.attrs || []).concat(el.dynamicAttrs || []).map(function (attr) { return ({
        // slot props are camelized
        name: camelize(attr.name),
        value: attr.value,
        dynamic: attr.dynamic
      }); }))
    : null;
  var bind$$1 = el.attrsMap['v-bind'];
  if ((attrs || bind$$1) && !children) {
    res += ",null";
  }
  if (attrs) {
    res += "," + attrs;
  }
  if (bind$$1) {
    res += (attrs ? '' : ',null') + "," + bind$$1;
  }
  return res + ')'
}

// componentName is el.component, take it as argument to shun flow's pessimistic refinement
function genComponent (
  componentName,
  el,
  state
) {
  var children = el.inlineTemplate ? null : genChildren(el, state, true);
  return ("_c(" + componentName + "," + (genData$2(el, state)) + (children ? ("," + children) : '') + ")")
}

function genProps (props) {
  var staticProps = "";
  var dynamicProps = "";
  for (var i = 0; i < props.length; i++) {
    var prop = props[i];
    var value = transformSpecialNewlines(prop.value);
    if (prop.dynamic) {
      dynamicProps += (prop.name) + "," + value + ",";
    } else {
      staticProps += "\"" + (prop.name) + "\":" + value + ",";
    }
  }
  staticProps = "{" + (staticProps.slice(0, -1)) + "}";
  if (dynamicProps) {
    return ("_d(" + staticProps + ",[" + (dynamicProps.slice(0, -1)) + "])")
  } else {
    return staticProps
  }
}

// #3895, #4268
function transformSpecialNewlines (text) {
  return text
    .replace(/\u2028/g, '\\u2028')
    .replace(/\u2029/g, '\\u2029')
}

/*  */



// these keywords should not appear inside expressions, but operators like
// typeof, instanceof and in are allowed
var prohibitedKeywordRE = new RegExp('\\b' + (
  'do,if,for,let,new,try,var,case,else,with,await,break,catch,class,const,' +
  'super,throw,while,yield,delete,export,import,return,switch,default,' +
  'extends,finally,continue,debugger,function,arguments'
).split(',').join('\\b|\\b') + '\\b');

// these unary operators should not be used as property/method names
var unaryOperatorsRE = new RegExp('\\b' + (
  'delete,typeof,void'
).split(',').join('\\s*\\([^\\)]*\\)|\\b') + '\\s*\\([^\\)]*\\)');

// strip strings in expressions
var stripStringRE = /'(?:[^'\\]|\\.)*'|"(?:[^"\\]|\\.)*"|`(?:[^`\\]|\\.)*\$\{|\}(?:[^`\\]|\\.)*`|`(?:[^`\\]|\\.)*`/g;

// detect problematic expressions in a template
function detectErrors (ast, warn) {
  if (ast) {
    checkNode(ast, warn);
  }
}

function checkNode (node, warn) {
  if (node.type === 1) {
    for (var name in node.attrsMap) {
      if (dirRE.test(name)) {
        var value = node.attrsMap[name];
        if (value) {
          var range = node.rawAttrsMap[name];
          if (name === 'v-for') {
            checkFor(node, ("v-for=\"" + value + "\""), warn, range);
          } else if (name === 'v-slot' || name[0] === '#') {
            checkFunctionParameterExpression(value, (name + "=\"" + value + "\""), warn, range);
          } else if (onRE.test(name)) {
            checkEvent(value, (name + "=\"" + value + "\""), warn, range);
          } else {
            checkExpression(value, (name + "=\"" + value + "\""), warn, range);
          }
        }
      }
    }
    if (node.children) {
      for (var i = 0; i < node.children.length; i++) {
        checkNode(node.children[i], warn);
      }
    }
  } else if (node.type === 2) {
    checkExpression(node.expression, node.text, warn, node);
  }
}

function checkEvent (exp, text, warn, range) {
  var stripped = exp.replace(stripStringRE, '');
  var keywordMatch = stripped.match(unaryOperatorsRE);
  if (keywordMatch && stripped.charAt(keywordMatch.index - 1) !== '$') {
    warn(
      "avoid using JavaScript unary operator as property name: " +
      "\"" + (keywordMatch[0]) + "\" in expression " + (text.trim()),
      range
    );
  }
  checkExpression(exp, text, warn, range);
}

function checkFor (node, text, warn, range) {
  checkExpression(node.for || '', text, warn, range);
  checkIdentifier(node.alias, 'v-for alias', text, warn, range);
  checkIdentifier(node.iterator1, 'v-for iterator', text, warn, range);
  checkIdentifier(node.iterator2, 'v-for iterator', text, warn, range);
}

function checkIdentifier (
  ident,
  type,
  text,
  warn,
  range
) {
  if (typeof ident === 'string') {
    try {
      new Function(("var " + ident + "=_"));
    } catch (e) {
      warn(("invalid " + type + " \"" + ident + "\" in expression: " + (text.trim())), range);
    }
  }
}

function checkExpression (exp, text, warn, range) {
  try {
    new Function(("return " + exp));
  } catch (e) {
    var keywordMatch = exp.replace(stripStringRE, '').match(prohibitedKeywordRE);
    if (keywordMatch) {
      warn(
        "avoid using JavaScript keyword as property name: " +
        "\"" + (keywordMatch[0]) + "\"\n  Raw expression: " + (text.trim()),
        range
      );
    } else {
      warn(
        "invalid expression: " + (e.message) + " in\n\n" +
        "    " + exp + "\n\n" +
        "  Raw expression: " + (text.trim()) + "\n",
        range
      );
    }
  }
}

function checkFunctionParameterExpression (exp, text, warn, range) {
  try {
    new Function(exp, '');
  } catch (e) {
    warn(
      "invalid function parameter expression: " + (e.message) + " in\n\n" +
      "    " + exp + "\n\n" +
      "  Raw expression: " + (text.trim()) + "\n",
      range
    );
  }
}

/*  */

var range = 2;

function generateCodeFrame (
  source,
  start,
  end
) {
  if ( start === void 0 ) start = 0;
  if ( end === void 0 ) end = source.length;

  var lines = source.split(/\r?\n/);
  var count = 0;
  var res = [];
  for (var i = 0; i < lines.length; i++) {
    count += lines[i].length + 1;
    if (count >= start) {
      for (var j = i - range; j <= i + range || end > count; j++) {
        if (j < 0 || j >= lines.length) { continue }
        res.push(("" + (j + 1) + (repeat$1(" ", 3 - String(j + 1).length)) + "|  " + (lines[j])));
        var lineLength = lines[j].length;
        if (j === i) {
          // push underline
          var pad = start - (count - lineLength) + 1;
          var length = end > count ? lineLength - pad : end - start;
          res.push("   |  " + repeat$1(" ", pad) + repeat$1("^", length));
        } else if (j > i) {
          if (end > count) {
            var length$1 = Math.min(end - count, lineLength);
            res.push("   |  " + repeat$1("^", length$1));
          }
          count += lineLength + 1;
        }
      }
      break
    }
  }
  return res.join('\n')
}

function repeat$1 (str, n) {
  var result = '';
  if (n > 0) {
    while (true) { // eslint-disable-line
      if (n & 1) { result += str; }
      n >>>= 1;
      if (n <= 0) { break }
      str += str;
    }
  }
  return result
}

/*  */



function createFunction (code, errors) {
  try {
    return new Function(code)
  } catch (err) {
    errors.push({ err: err, code: code });
    return noop
  }
}

function createCompileToFunctionFn (compile) {
  var cache = Object.create(null);

  return function compileToFunctions (
    template,
    options,
    vm
  ) {
    options = extend({}, options);
    var warn$$1 = options.warn || warn;
    delete options.warn;

    /* istanbul ignore if */
    {
      // detect possible CSP restriction
      try {
        new Function('return 1');
      } catch (e) {
        if (e.toString().match(/unsafe-eval|CSP/)) {
          warn$$1(
            'It seems you are using the standalone build of Vue.js in an ' +
            'environment with Content Security Policy that prohibits unsafe-eval. ' +
            'The template compiler cannot work in this environment. Consider ' +
            'relaxing the policy to allow unsafe-eval or pre-compiling your ' +
            'templates into render functions.'
          );
        }
      }
    }

    // check cache
    var key = options.delimiters
      ? String(options.delimiters) + template
      : template;
    if (cache[key]) {
      return cache[key]
    }

    // compile
    var compiled = compile(template, options);

    // check compilation errors/tips
    {
      if (compiled.errors && compiled.errors.length) {
        if (options.outputSourceRange) {
          compiled.errors.forEach(function (e) {
            warn$$1(
              "Error compiling template:\n\n" + (e.msg) + "\n\n" +
              generateCodeFrame(template, e.start, e.end),
              vm
            );
          });
        } else {
          warn$$1(
            "Error compiling template:\n\n" + template + "\n\n" +
            compiled.errors.map(function (e) { return ("- " + e); }).join('\n') + '\n',
            vm
          );
        }
      }
      if (compiled.tips && compiled.tips.length) {
        if (options.outputSourceRange) {
          compiled.tips.forEach(function (e) { return tip(e.msg, vm); });
        } else {
          compiled.tips.forEach(function (msg) { return tip(msg, vm); });
        }
      }
    }

    // turn code into functions
    var res = {};
    var fnGenErrors = [];
    res.render = createFunction(compiled.render, fnGenErrors);
    res.staticRenderFns = compiled.staticRenderFns.map(function (code) {
      return createFunction(code, fnGenErrors)
    });

    // check function generation errors.
    // this should only happen if there is a bug in the compiler itself.
    // mostly for codegen development use
    /* istanbul ignore if */
    {
      if ((!compiled.errors || !compiled.errors.length) && fnGenErrors.length) {
        warn$$1(
          "Failed to generate render function:\n\n" +
          fnGenErrors.map(function (ref) {
            var err = ref.err;
            var code = ref.code;

            return ((err.toString()) + " in\n\n" + code + "\n");
        }).join('\n'),
          vm
        );
      }
    }

    return (cache[key] = res)
  }
}

/*  */

function createCompilerCreator (baseCompile) {
  return function createCompiler (baseOptions) {
    function compile (
      template,
      options
    ) {
      var finalOptions = Object.create(baseOptions);
      var errors = [];
      var tips = [];

      var warn = function (msg, range, tip) {
        (tip ? tips : errors).push(msg);
      };

      if (options) {
        if ( options.outputSourceRange) {
          // $flow-disable-line
          var leadingSpaceLength = template.match(/^\s*/)[0].length;

          warn = function (msg, range, tip) {
            var data = { msg: msg };
            if (range) {
              if (range.start != null) {
                data.start = range.start + leadingSpaceLength;
              }
              if (range.end != null) {
                data.end = range.end + leadingSpaceLength;
              }
            }
            (tip ? tips : errors).push(data);
          };
        }
        // merge custom modules
        if (options.modules) {
          finalOptions.modules =
            (baseOptions.modules || []).concat(options.modules);
        }
        // merge custom directives
        if (options.directives) {
          finalOptions.directives = extend(
            Object.create(baseOptions.directives || null),
            options.directives
          );
        }
        // copy other options
        for (var key in options) {
          if (key !== 'modules' && key !== 'directives') {
            finalOptions[key] = options[key];
          }
        }
      }

      finalOptions.warn = warn;

      var compiled = baseCompile(template.trim(), finalOptions);
      {
        detectErrors(compiled.ast, warn);
      }
      compiled.errors = errors;
      compiled.tips = tips;
      return compiled
    }

    return {
      compile: compile,
      compileToFunctions: createCompileToFunctionFn(compile)
    }
  }
}

/*  */

// `createCompilerCreator` allows creating compilers that use alternative
// parser/optimizer/codegen, e.g the SSR optimizing compiler.
// Here we just export a default compiler using the default parts.
var createCompiler = createCompilerCreator(function baseCompile (
  template,
  options
) {
  var ast = parse(template.trim(), options);
  if (options.optimize !== false) {
    optimize(ast, options);
  }
  var code = generate(ast, options);
  return {
    ast: ast,
    render: code.render,
    staticRenderFns: code.staticRenderFns
  }
});

/*  */

var ref$1 = createCompiler(baseOptions);
var compileToFunctions = ref$1.compileToFunctions;

/*  */

// check whether current browser encodes a char inside attribute values
var div;
function getShouldDecode (href) {
  div = div || document.createElement('div');
  div.innerHTML = href ? "<a href=\"\n\"/>" : "<div a=\"\n\"/>";
  return div.innerHTML.indexOf('&#10;') > 0
}

// #3663: IE encodes newlines inside attribute values while other browsers don't
var shouldDecodeNewlines = inBrowser ? getShouldDecode(false) : false;
// #6828: chrome encodes content in a[href]
var shouldDecodeNewlinesForHref = inBrowser ? getShouldDecode(true) : false;

/*  */

var idToTemplate = cached(function (id) {
  var el = query(id);
  return el && el.innerHTML
});

var mount = Vue.prototype.$mount;
Vue.prototype.$mount = function (
  el,
  hydrating
) {
  el = el && query(el);

  /* istanbul ignore if */
  if (el === document.body || el === document.documentElement) {
     warn(
      "Do not mount Vue to <html> or <body> - mount to normal elements instead."
    );
    return this
  }

  var options = this.$options;
  // resolve template/el and convert to render function
  if (!options.render) {
    var template = options.template;
    if (template) {
      if (typeof template === 'string') {
        if (template.charAt(0) === '#') {
          template = idToTemplate(template);
          /* istanbul ignore if */
          if ( !template) {
            warn(
              ("Template element not found or is empty: " + (options.template)),
              this
            );
          }
        }
      } else if (template.nodeType) {
        template = template.innerHTML;
      } else {
        {
          warn('invalid template option:' + template, this);
        }
        return this
      }
    } else if (el) {
      template = getOuterHTML(el);
    }
    if (template) {
      /* istanbul ignore if */
      if ( config.performance && mark) {
        mark('compile');
      }

      var ref = compileToFunctions(template, {
        outputSourceRange: "development" !== 'production',
        shouldDecodeNewlines: shouldDecodeNewlines,
        shouldDecodeNewlinesForHref: shouldDecodeNewlinesForHref,
        delimiters: options.delimiters,
        comments: options.comments
      }, this);
      var render = ref.render;
      var staticRenderFns = ref.staticRenderFns;
      options.render = render;
      options.staticRenderFns = staticRenderFns;

      /* istanbul ignore if */
      if ( config.performance && mark) {
        mark('compile end');
        measure(("vue " + (this._name) + " compile"), 'compile', 'compile end');
      }
    }
  }
  return mount.call(this, el, hydrating)
};

/**
 * Get outerHTML of elements, taking care
 * of SVG elements in IE as well.
 */
function getOuterHTML (el) {
  if (el.outerHTML) {
    return el.outerHTML
  } else {
    var container = document.createElement('div');
    container.appendChild(el.cloneNode(true));
    return container.innerHTML
  }
}

Vue.compile = compileToFunctions;

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css_248z = "a {\n  color: dodgerblue;\n}\n\n.container {\n  width: 100%;\n}\n\n@media (min-width: 640px) {\n  .container {\n    max-width: 640px;\n  }\n}\n\n@media (min-width: 768px) {\n  .container {\n    max-width: 768px;\n  }\n}\n\n@media (min-width: 1024px) {\n  .container {\n    max-width: 1024px;\n  }\n}\n\n@media (min-width: 1280px) {\n  .container {\n    max-width: 1280px;\n  }\n}\n\n.space-y-0 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(0px * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(0px * var(--space-y-reverse));\n}\n\n.space-x-0 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(0px * var(--space-x-reverse));\n  margin-left: calc(0px * calc(1 - var(--space-x-reverse)));\n}\n\n.space-y-1 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(0.25rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(0.25rem * var(--space-y-reverse));\n}\n\n.space-x-1 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(0.25rem * var(--space-x-reverse));\n  margin-left: calc(0.25rem * calc(1 - var(--space-x-reverse)));\n}\n\n.space-y-2 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(0.5rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(0.5rem * var(--space-y-reverse));\n}\n\n.space-x-2 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(0.5rem * var(--space-x-reverse));\n  margin-left: calc(0.5rem * calc(1 - var(--space-x-reverse)));\n}\n\n.space-y-3 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(0.75rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(0.75rem * var(--space-y-reverse));\n}\n\n.space-x-3 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(0.75rem * var(--space-x-reverse));\n  margin-left: calc(0.75rem * calc(1 - var(--space-x-reverse)));\n}\n\n.space-y-4 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(1rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(1rem * var(--space-y-reverse));\n}\n\n.space-x-4 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(1rem * var(--space-x-reverse));\n  margin-left: calc(1rem * calc(1 - var(--space-x-reverse)));\n}\n\n.space-y-5 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(1.25rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(1.25rem * var(--space-y-reverse));\n}\n\n.space-x-5 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(1.25rem * var(--space-x-reverse));\n  margin-left: calc(1.25rem * calc(1 - var(--space-x-reverse)));\n}\n\n.space-y-6 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(1.5rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(1.5rem * var(--space-y-reverse));\n}\n\n.space-x-6 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(1.5rem * var(--space-x-reverse));\n  margin-left: calc(1.5rem * calc(1 - var(--space-x-reverse)));\n}\n\n.space-y-8 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(2rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(2rem * var(--space-y-reverse));\n}\n\n.space-x-8 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(2rem * var(--space-x-reverse));\n  margin-left: calc(2rem * calc(1 - var(--space-x-reverse)));\n}\n\n.space-y-10 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(2.5rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(2.5rem * var(--space-y-reverse));\n}\n\n.space-x-10 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(2.5rem * var(--space-x-reverse));\n  margin-left: calc(2.5rem * calc(1 - var(--space-x-reverse)));\n}\n\n.space-y-12 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(3rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(3rem * var(--space-y-reverse));\n}\n\n.space-x-12 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(3rem * var(--space-x-reverse));\n  margin-left: calc(3rem * calc(1 - var(--space-x-reverse)));\n}\n\n.space-y-16 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(4rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(4rem * var(--space-y-reverse));\n}\n\n.space-x-16 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(4rem * var(--space-x-reverse));\n  margin-left: calc(4rem * calc(1 - var(--space-x-reverse)));\n}\n\n.space-y-20 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(5rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(5rem * var(--space-y-reverse));\n}\n\n.space-x-20 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(5rem * var(--space-x-reverse));\n  margin-left: calc(5rem * calc(1 - var(--space-x-reverse)));\n}\n\n.space-y-24 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(6rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(6rem * var(--space-y-reverse));\n}\n\n.space-x-24 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(6rem * var(--space-x-reverse));\n  margin-left: calc(6rem * calc(1 - var(--space-x-reverse)));\n}\n\n.space-y-32 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(8rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(8rem * var(--space-y-reverse));\n}\n\n.space-x-32 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(8rem * var(--space-x-reverse));\n  margin-left: calc(8rem * calc(1 - var(--space-x-reverse)));\n}\n\n.space-y-40 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(10rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(10rem * var(--space-y-reverse));\n}\n\n.space-x-40 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(10rem * var(--space-x-reverse));\n  margin-left: calc(10rem * calc(1 - var(--space-x-reverse)));\n}\n\n.space-y-48 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(12rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(12rem * var(--space-y-reverse));\n}\n\n.space-x-48 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(12rem * var(--space-x-reverse));\n  margin-left: calc(12rem * calc(1 - var(--space-x-reverse)));\n}\n\n.space-y-56 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(14rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(14rem * var(--space-y-reverse));\n}\n\n.space-x-56 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(14rem * var(--space-x-reverse));\n  margin-left: calc(14rem * calc(1 - var(--space-x-reverse)));\n}\n\n.space-y-64 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(16rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(16rem * var(--space-y-reverse));\n}\n\n.space-x-64 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(16rem * var(--space-x-reverse));\n  margin-left: calc(16rem * calc(1 - var(--space-x-reverse)));\n}\n\n.space-y-px > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(1px * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(1px * var(--space-y-reverse));\n}\n\n.space-x-px > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(1px * var(--space-x-reverse));\n  margin-left: calc(1px * calc(1 - var(--space-x-reverse)));\n}\n\n.-space-y-1 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(-0.25rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(-0.25rem * var(--space-y-reverse));\n}\n\n.-space-x-1 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(-0.25rem * var(--space-x-reverse));\n  margin-left: calc(-0.25rem * calc(1 - var(--space-x-reverse)));\n}\n\n.-space-y-2 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(-0.5rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(-0.5rem * var(--space-y-reverse));\n}\n\n.-space-x-2 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(-0.5rem * var(--space-x-reverse));\n  margin-left: calc(-0.5rem * calc(1 - var(--space-x-reverse)));\n}\n\n.-space-y-3 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(-0.75rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(-0.75rem * var(--space-y-reverse));\n}\n\n.-space-x-3 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(-0.75rem * var(--space-x-reverse));\n  margin-left: calc(-0.75rem * calc(1 - var(--space-x-reverse)));\n}\n\n.-space-y-4 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(-1rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(-1rem * var(--space-y-reverse));\n}\n\n.-space-x-4 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(-1rem * var(--space-x-reverse));\n  margin-left: calc(-1rem * calc(1 - var(--space-x-reverse)));\n}\n\n.-space-y-5 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(-1.25rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(-1.25rem * var(--space-y-reverse));\n}\n\n.-space-x-5 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(-1.25rem * var(--space-x-reverse));\n  margin-left: calc(-1.25rem * calc(1 - var(--space-x-reverse)));\n}\n\n.-space-y-6 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(-1.5rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(-1.5rem * var(--space-y-reverse));\n}\n\n.-space-x-6 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(-1.5rem * var(--space-x-reverse));\n  margin-left: calc(-1.5rem * calc(1 - var(--space-x-reverse)));\n}\n\n.-space-y-8 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(-2rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(-2rem * var(--space-y-reverse));\n}\n\n.-space-x-8 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(-2rem * var(--space-x-reverse));\n  margin-left: calc(-2rem * calc(1 - var(--space-x-reverse)));\n}\n\n.-space-y-10 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(-2.5rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(-2.5rem * var(--space-y-reverse));\n}\n\n.-space-x-10 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(-2.5rem * var(--space-x-reverse));\n  margin-left: calc(-2.5rem * calc(1 - var(--space-x-reverse)));\n}\n\n.-space-y-12 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(-3rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(-3rem * var(--space-y-reverse));\n}\n\n.-space-x-12 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(-3rem * var(--space-x-reverse));\n  margin-left: calc(-3rem * calc(1 - var(--space-x-reverse)));\n}\n\n.-space-y-16 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(-4rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(-4rem * var(--space-y-reverse));\n}\n\n.-space-x-16 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(-4rem * var(--space-x-reverse));\n  margin-left: calc(-4rem * calc(1 - var(--space-x-reverse)));\n}\n\n.-space-y-20 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(-5rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(-5rem * var(--space-y-reverse));\n}\n\n.-space-x-20 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(-5rem * var(--space-x-reverse));\n  margin-left: calc(-5rem * calc(1 - var(--space-x-reverse)));\n}\n\n.-space-y-24 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(-6rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(-6rem * var(--space-y-reverse));\n}\n\n.-space-x-24 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(-6rem * var(--space-x-reverse));\n  margin-left: calc(-6rem * calc(1 - var(--space-x-reverse)));\n}\n\n.-space-y-32 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(-8rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(-8rem * var(--space-y-reverse));\n}\n\n.-space-x-32 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(-8rem * var(--space-x-reverse));\n  margin-left: calc(-8rem * calc(1 - var(--space-x-reverse)));\n}\n\n.-space-y-40 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(-10rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(-10rem * var(--space-y-reverse));\n}\n\n.-space-x-40 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(-10rem * var(--space-x-reverse));\n  margin-left: calc(-10rem * calc(1 - var(--space-x-reverse)));\n}\n\n.-space-y-48 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(-12rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(-12rem * var(--space-y-reverse));\n}\n\n.-space-x-48 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(-12rem * var(--space-x-reverse));\n  margin-left: calc(-12rem * calc(1 - var(--space-x-reverse)));\n}\n\n.-space-y-56 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(-14rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(-14rem * var(--space-y-reverse));\n}\n\n.-space-x-56 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(-14rem * var(--space-x-reverse));\n  margin-left: calc(-14rem * calc(1 - var(--space-x-reverse)));\n}\n\n.-space-y-64 > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(-16rem * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(-16rem * var(--space-y-reverse));\n}\n\n.-space-x-64 > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(-16rem * var(--space-x-reverse));\n  margin-left: calc(-16rem * calc(1 - var(--space-x-reverse)));\n}\n\n.-space-y-px > :not(template) ~ :not(template) {\n  --space-y-reverse: 0;\n  margin-top: calc(-1px * calc(1 - var(--space-y-reverse)));\n  margin-bottom: calc(-1px * var(--space-y-reverse));\n}\n\n.-space-x-px > :not(template) ~ :not(template) {\n  --space-x-reverse: 0;\n  margin-right: calc(-1px * var(--space-x-reverse));\n  margin-left: calc(-1px * calc(1 - var(--space-x-reverse)));\n}\n\n.space-y-reverse > :not(template) ~ :not(template) {\n  --space-y-reverse: 1;\n}\n\n.space-x-reverse > :not(template) ~ :not(template) {\n  --space-x-reverse: 1;\n}\n\n.divide-y-0 > :not(template) ~ :not(template) {\n  --divide-y-reverse: 0;\n  border-top-width: calc(0px * calc(1 - var(--divide-y-reverse)));\n  border-bottom-width: calc(0px * var(--divide-y-reverse));\n}\n\n.divide-x-0 > :not(template) ~ :not(template) {\n  --divide-x-reverse: 0;\n  border-right-width: calc(0px * var(--divide-x-reverse));\n  border-left-width: calc(0px * calc(1 - var(--divide-x-reverse)));\n}\n\n.divide-y-2 > :not(template) ~ :not(template) {\n  --divide-y-reverse: 0;\n  border-top-width: calc(2px * calc(1 - var(--divide-y-reverse)));\n  border-bottom-width: calc(2px * var(--divide-y-reverse));\n}\n\n.divide-x-2 > :not(template) ~ :not(template) {\n  --divide-x-reverse: 0;\n  border-right-width: calc(2px * var(--divide-x-reverse));\n  border-left-width: calc(2px * calc(1 - var(--divide-x-reverse)));\n}\n\n.divide-y-4 > :not(template) ~ :not(template) {\n  --divide-y-reverse: 0;\n  border-top-width: calc(4px * calc(1 - var(--divide-y-reverse)));\n  border-bottom-width: calc(4px * var(--divide-y-reverse));\n}\n\n.divide-x-4 > :not(template) ~ :not(template) {\n  --divide-x-reverse: 0;\n  border-right-width: calc(4px * var(--divide-x-reverse));\n  border-left-width: calc(4px * calc(1 - var(--divide-x-reverse)));\n}\n\n.divide-y-8 > :not(template) ~ :not(template) {\n  --divide-y-reverse: 0;\n  border-top-width: calc(8px * calc(1 - var(--divide-y-reverse)));\n  border-bottom-width: calc(8px * var(--divide-y-reverse));\n}\n\n.divide-x-8 > :not(template) ~ :not(template) {\n  --divide-x-reverse: 0;\n  border-right-width: calc(8px * var(--divide-x-reverse));\n  border-left-width: calc(8px * calc(1 - var(--divide-x-reverse)));\n}\n\n.divide-y > :not(template) ~ :not(template) {\n  --divide-y-reverse: 0;\n  border-top-width: calc(1px * calc(1 - var(--divide-y-reverse)));\n  border-bottom-width: calc(1px * var(--divide-y-reverse));\n}\n\n.divide-x > :not(template) ~ :not(template) {\n  --divide-x-reverse: 0;\n  border-right-width: calc(1px * var(--divide-x-reverse));\n  border-left-width: calc(1px * calc(1 - var(--divide-x-reverse)));\n}\n\n.divide-y-reverse > :not(template) ~ :not(template) {\n  --divide-y-reverse: 1;\n}\n\n.divide-x-reverse > :not(template) ~ :not(template) {\n  --divide-x-reverse: 1;\n}\n\n.divide-transparent > :not(template) ~ :not(template) {\n  border-color: transparent;\n}\n\n.divide-current > :not(template) ~ :not(template) {\n  border-color: currentColor;\n}\n\n.divide-black > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #000;\n  border-color: rgba(0, 0, 0, var(--divide-opacity));\n}\n\n.divide-white > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #fff;\n  border-color: rgba(255, 255, 255, var(--divide-opacity));\n}\n\n.divide-gray-100 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #f7fafc;\n  border-color: rgba(247, 250, 252, var(--divide-opacity));\n}\n\n.divide-gray-200 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #edf2f7;\n  border-color: rgba(237, 242, 247, var(--divide-opacity));\n}\n\n.divide-gray-300 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #e2e8f0;\n  border-color: rgba(226, 232, 240, var(--divide-opacity));\n}\n\n.divide-gray-400 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #cbd5e0;\n  border-color: rgba(203, 213, 224, var(--divide-opacity));\n}\n\n.divide-gray-500 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #a0aec0;\n  border-color: rgba(160, 174, 192, var(--divide-opacity));\n}\n\n.divide-gray-600 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #718096;\n  border-color: rgba(113, 128, 150, var(--divide-opacity));\n}\n\n.divide-gray-700 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #4a5568;\n  border-color: rgba(74, 85, 104, var(--divide-opacity));\n}\n\n.divide-gray-800 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #2d3748;\n  border-color: rgba(45, 55, 72, var(--divide-opacity));\n}\n\n.divide-gray-900 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #1a202c;\n  border-color: rgba(26, 32, 44, var(--divide-opacity));\n}\n\n.divide-red-100 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #fff5f5;\n  border-color: rgba(255, 245, 245, var(--divide-opacity));\n}\n\n.divide-red-200 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #fed7d7;\n  border-color: rgba(254, 215, 215, var(--divide-opacity));\n}\n\n.divide-red-300 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #feb2b2;\n  border-color: rgba(254, 178, 178, var(--divide-opacity));\n}\n\n.divide-red-400 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #fc8181;\n  border-color: rgba(252, 129, 129, var(--divide-opacity));\n}\n\n.divide-red-500 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #f56565;\n  border-color: rgba(245, 101, 101, var(--divide-opacity));\n}\n\n.divide-red-600 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #e53e3e;\n  border-color: rgba(229, 62, 62, var(--divide-opacity));\n}\n\n.divide-red-700 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #c53030;\n  border-color: rgba(197, 48, 48, var(--divide-opacity));\n}\n\n.divide-red-800 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #9b2c2c;\n  border-color: rgba(155, 44, 44, var(--divide-opacity));\n}\n\n.divide-red-900 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #742a2a;\n  border-color: rgba(116, 42, 42, var(--divide-opacity));\n}\n\n.divide-orange-100 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #fffaf0;\n  border-color: rgba(255, 250, 240, var(--divide-opacity));\n}\n\n.divide-orange-200 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #feebc8;\n  border-color: rgba(254, 235, 200, var(--divide-opacity));\n}\n\n.divide-orange-300 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #fbd38d;\n  border-color: rgba(251, 211, 141, var(--divide-opacity));\n}\n\n.divide-orange-400 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #f6ad55;\n  border-color: rgba(246, 173, 85, var(--divide-opacity));\n}\n\n.divide-orange-500 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #ed8936;\n  border-color: rgba(237, 137, 54, var(--divide-opacity));\n}\n\n.divide-orange-600 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #dd6b20;\n  border-color: rgba(221, 107, 32, var(--divide-opacity));\n}\n\n.divide-orange-700 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #c05621;\n  border-color: rgba(192, 86, 33, var(--divide-opacity));\n}\n\n.divide-orange-800 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #9c4221;\n  border-color: rgba(156, 66, 33, var(--divide-opacity));\n}\n\n.divide-orange-900 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #7b341e;\n  border-color: rgba(123, 52, 30, var(--divide-opacity));\n}\n\n.divide-yellow-100 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #fffff0;\n  border-color: rgba(255, 255, 240, var(--divide-opacity));\n}\n\n.divide-yellow-200 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #fefcbf;\n  border-color: rgba(254, 252, 191, var(--divide-opacity));\n}\n\n.divide-yellow-300 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #faf089;\n  border-color: rgba(250, 240, 137, var(--divide-opacity));\n}\n\n.divide-yellow-400 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #f6e05e;\n  border-color: rgba(246, 224, 94, var(--divide-opacity));\n}\n\n.divide-yellow-500 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #ecc94b;\n  border-color: rgba(236, 201, 75, var(--divide-opacity));\n}\n\n.divide-yellow-600 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #d69e2e;\n  border-color: rgba(214, 158, 46, var(--divide-opacity));\n}\n\n.divide-yellow-700 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #b7791f;\n  border-color: rgba(183, 121, 31, var(--divide-opacity));\n}\n\n.divide-yellow-800 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #975a16;\n  border-color: rgba(151, 90, 22, var(--divide-opacity));\n}\n\n.divide-yellow-900 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #744210;\n  border-color: rgba(116, 66, 16, var(--divide-opacity));\n}\n\n.divide-green-100 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #f0fff4;\n  border-color: rgba(240, 255, 244, var(--divide-opacity));\n}\n\n.divide-green-200 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #c6f6d5;\n  border-color: rgba(198, 246, 213, var(--divide-opacity));\n}\n\n.divide-green-300 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #9ae6b4;\n  border-color: rgba(154, 230, 180, var(--divide-opacity));\n}\n\n.divide-green-400 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #68d391;\n  border-color: rgba(104, 211, 145, var(--divide-opacity));\n}\n\n.divide-green-500 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #48bb78;\n  border-color: rgba(72, 187, 120, var(--divide-opacity));\n}\n\n.divide-green-600 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #38a169;\n  border-color: rgba(56, 161, 105, var(--divide-opacity));\n}\n\n.divide-green-700 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #2f855a;\n  border-color: rgba(47, 133, 90, var(--divide-opacity));\n}\n\n.divide-green-800 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #276749;\n  border-color: rgba(39, 103, 73, var(--divide-opacity));\n}\n\n.divide-green-900 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #22543d;\n  border-color: rgba(34, 84, 61, var(--divide-opacity));\n}\n\n.divide-teal-100 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #e6fffa;\n  border-color: rgba(230, 255, 250, var(--divide-opacity));\n}\n\n.divide-teal-200 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #b2f5ea;\n  border-color: rgba(178, 245, 234, var(--divide-opacity));\n}\n\n.divide-teal-300 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #81e6d9;\n  border-color: rgba(129, 230, 217, var(--divide-opacity));\n}\n\n.divide-teal-400 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #4fd1c5;\n  border-color: rgba(79, 209, 197, var(--divide-opacity));\n}\n\n.divide-teal-500 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #38b2ac;\n  border-color: rgba(56, 178, 172, var(--divide-opacity));\n}\n\n.divide-teal-600 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #319795;\n  border-color: rgba(49, 151, 149, var(--divide-opacity));\n}\n\n.divide-teal-700 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #2c7a7b;\n  border-color: rgba(44, 122, 123, var(--divide-opacity));\n}\n\n.divide-teal-800 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #285e61;\n  border-color: rgba(40, 94, 97, var(--divide-opacity));\n}\n\n.divide-teal-900 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #234e52;\n  border-color: rgba(35, 78, 82, var(--divide-opacity));\n}\n\n.divide-blue-100 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #ebf8ff;\n  border-color: rgba(235, 248, 255, var(--divide-opacity));\n}\n\n.divide-blue-200 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #bee3f8;\n  border-color: rgba(190, 227, 248, var(--divide-opacity));\n}\n\n.divide-blue-300 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #90cdf4;\n  border-color: rgba(144, 205, 244, var(--divide-opacity));\n}\n\n.divide-blue-400 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #63b3ed;\n  border-color: rgba(99, 179, 237, var(--divide-opacity));\n}\n\n.divide-blue-500 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #4299e1;\n  border-color: rgba(66, 153, 225, var(--divide-opacity));\n}\n\n.divide-blue-600 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #3182ce;\n  border-color: rgba(49, 130, 206, var(--divide-opacity));\n}\n\n.divide-blue-700 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #2b6cb0;\n  border-color: rgba(43, 108, 176, var(--divide-opacity));\n}\n\n.divide-blue-800 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #2c5282;\n  border-color: rgba(44, 82, 130, var(--divide-opacity));\n}\n\n.divide-blue-900 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #2a4365;\n  border-color: rgba(42, 67, 101, var(--divide-opacity));\n}\n\n.divide-indigo-100 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #ebf4ff;\n  border-color: rgba(235, 244, 255, var(--divide-opacity));\n}\n\n.divide-indigo-200 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #c3dafe;\n  border-color: rgba(195, 218, 254, var(--divide-opacity));\n}\n\n.divide-indigo-300 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #a3bffa;\n  border-color: rgba(163, 191, 250, var(--divide-opacity));\n}\n\n.divide-indigo-400 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #7f9cf5;\n  border-color: rgba(127, 156, 245, var(--divide-opacity));\n}\n\n.divide-indigo-500 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #667eea;\n  border-color: rgba(102, 126, 234, var(--divide-opacity));\n}\n\n.divide-indigo-600 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #5a67d8;\n  border-color: rgba(90, 103, 216, var(--divide-opacity));\n}\n\n.divide-indigo-700 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #4c51bf;\n  border-color: rgba(76, 81, 191, var(--divide-opacity));\n}\n\n.divide-indigo-800 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #434190;\n  border-color: rgba(67, 65, 144, var(--divide-opacity));\n}\n\n.divide-indigo-900 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #3c366b;\n  border-color: rgba(60, 54, 107, var(--divide-opacity));\n}\n\n.divide-purple-100 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #faf5ff;\n  border-color: rgba(250, 245, 255, var(--divide-opacity));\n}\n\n.divide-purple-200 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #e9d8fd;\n  border-color: rgba(233, 216, 253, var(--divide-opacity));\n}\n\n.divide-purple-300 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #d6bcfa;\n  border-color: rgba(214, 188, 250, var(--divide-opacity));\n}\n\n.divide-purple-400 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #b794f4;\n  border-color: rgba(183, 148, 244, var(--divide-opacity));\n}\n\n.divide-purple-500 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #9f7aea;\n  border-color: rgba(159, 122, 234, var(--divide-opacity));\n}\n\n.divide-purple-600 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #805ad5;\n  border-color: rgba(128, 90, 213, var(--divide-opacity));\n}\n\n.divide-purple-700 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #6b46c1;\n  border-color: rgba(107, 70, 193, var(--divide-opacity));\n}\n\n.divide-purple-800 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #553c9a;\n  border-color: rgba(85, 60, 154, var(--divide-opacity));\n}\n\n.divide-purple-900 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #44337a;\n  border-color: rgba(68, 51, 122, var(--divide-opacity));\n}\n\n.divide-pink-100 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #fff5f7;\n  border-color: rgba(255, 245, 247, var(--divide-opacity));\n}\n\n.divide-pink-200 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #fed7e2;\n  border-color: rgba(254, 215, 226, var(--divide-opacity));\n}\n\n.divide-pink-300 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #fbb6ce;\n  border-color: rgba(251, 182, 206, var(--divide-opacity));\n}\n\n.divide-pink-400 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #f687b3;\n  border-color: rgba(246, 135, 179, var(--divide-opacity));\n}\n\n.divide-pink-500 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #ed64a6;\n  border-color: rgba(237, 100, 166, var(--divide-opacity));\n}\n\n.divide-pink-600 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #d53f8c;\n  border-color: rgba(213, 63, 140, var(--divide-opacity));\n}\n\n.divide-pink-700 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #b83280;\n  border-color: rgba(184, 50, 128, var(--divide-opacity));\n}\n\n.divide-pink-800 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #97266d;\n  border-color: rgba(151, 38, 109, var(--divide-opacity));\n}\n\n.divide-pink-900 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: #702459;\n  border-color: rgba(112, 36, 89, var(--divide-opacity));\n}\n\n.divide-grayscale-80 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: hsl(0, 0%, 8%);\n  border-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--divide-opacity));\n}\n\n.divide-grayscale-100 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: hsl(0, 0%, 10%);\n  border-color: rgba(25.5, 25.5, 25.5, var(--divide-opacity));\n}\n\n.divide-grayscale-200 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: hsl(0, 0%, 20%);\n  border-color: rgba(51, 51, 51, var(--divide-opacity));\n}\n\n.divide-grayscale-300 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: hsl(0, 0%, 30%);\n  border-color: rgba(76.5, 76.5, 76.5, var(--divide-opacity));\n}\n\n.divide-grayscale-400 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: hsl(0, 0%, 40%);\n  border-color: rgba(102, 102, 102, var(--divide-opacity));\n}\n\n.divide-grayscale-500 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: hsl(0, 0%, 50%);\n  border-color: rgba(127.5, 127.5, 127.5, var(--divide-opacity));\n}\n\n.divide-grayscale-600 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: hsl(0, 0%, 60%);\n  border-color: rgba(153, 153, 153, var(--divide-opacity));\n}\n\n.divide-grayscale-700 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: hsl(0, 0%, 70%);\n  border-color: rgba(178.5, 178.5, 178.5, var(--divide-opacity));\n}\n\n.divide-grayscale-800 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: hsl(0, 0%, 80%);\n  border-color: rgba(204, 204, 204, var(--divide-opacity));\n}\n\n.divide-grayscale-840 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: hsl(0, 0%, 84%);\n  border-color: rgba(214.2, 214.2, 214.2, var(--divide-opacity));\n}\n\n.divide-grayscale-870 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: hsl(0, 0%, 87%);\n  border-color: rgba(221.85, 221.85, 221.85, var(--divide-opacity));\n}\n\n.divide-grayscale-900 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: hsl(0, 0%, 90%);\n  border-color: rgba(229.5, 229.5, 229.5, var(--divide-opacity));\n}\n\n.divide-grayscale-930 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: hsl(0, 0%, 93%);\n  border-color: rgba(237.15, 237.15, 237.15, var(--divide-opacity));\n}\n\n.divide-primary > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n  border-color: hsl(210, 100%, 52%);\n  border-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--divide-opacity));\n}\n\n.divide-background-main > :not(template) ~ :not(template) {\n  border-color: var(--main-background);\n}\n\n.divide-background-secondary > :not(template) ~ :not(template) {\n  border-color: var(--secondary-background);\n}\n\n.divide-foreground > :not(template) ~ :not(template) {\n  border-color: var(--foreground);\n}\n\n.divide-panels-bg > :not(template) ~ :not(template) {\n  border-color: var(--panels-background);\n}\n\n.divide-solid > :not(template) ~ :not(template) {\n  border-style: solid;\n}\n\n.divide-dashed > :not(template) ~ :not(template) {\n  border-style: dashed;\n}\n\n.divide-dotted > :not(template) ~ :not(template) {\n  border-style: dotted;\n}\n\n.divide-double > :not(template) ~ :not(template) {\n  border-style: double;\n}\n\n.divide-none > :not(template) ~ :not(template) {\n  border-style: none;\n}\n\n.divide-opacity-0 > :not(template) ~ :not(template) {\n  --divide-opacity: 0;\n}\n\n.divide-opacity-25 > :not(template) ~ :not(template) {\n  --divide-opacity: 0.25;\n}\n\n.divide-opacity-50 > :not(template) ~ :not(template) {\n  --divide-opacity: 0.5;\n}\n\n.divide-opacity-75 > :not(template) ~ :not(template) {\n  --divide-opacity: 0.75;\n}\n\n.divide-opacity-100 > :not(template) ~ :not(template) {\n  --divide-opacity: 1;\n}\n\n.sr-only {\n  position: absolute;\n  width: 1px;\n  height: 1px;\n  padding: 0;\n  margin: -1px;\n  overflow: hidden;\n  clip: rect(0, 0, 0, 0);\n  white-space: nowrap;\n  border-width: 0;\n}\n\n.not-sr-only {\n  position: static;\n  width: auto;\n  height: auto;\n  padding: 0;\n  margin: 0;\n  overflow: visible;\n  clip: auto;\n  white-space: normal;\n}\n\n.focus\\:sr-only:focus {\n  position: absolute;\n  width: 1px;\n  height: 1px;\n  padding: 0;\n  margin: -1px;\n  overflow: hidden;\n  clip: rect(0, 0, 0, 0);\n  white-space: nowrap;\n  border-width: 0;\n}\n\n.focus\\:not-sr-only:focus {\n  position: static;\n  width: auto;\n  height: auto;\n  padding: 0;\n  margin: 0;\n  overflow: visible;\n  clip: auto;\n  white-space: normal;\n}\n\n.appearance-none {\n  -webkit-appearance: none;\n     -moz-appearance: none;\n          appearance: none;\n}\n\n.bg-fixed {\n  background-attachment: fixed;\n}\n\n.bg-local {\n  background-attachment: local;\n}\n\n.bg-scroll {\n  background-attachment: scroll;\n}\n\n.bg-clip-border {\n  background-clip: border-box;\n}\n\n.bg-clip-padding {\n  background-clip: padding-box;\n}\n\n.bg-clip-content {\n  background-clip: content-box;\n}\n\n.bg-clip-text {\n  -webkit-background-clip: text;\n          background-clip: text;\n}\n\n.bg-transparent {\n  background-color: transparent;\n}\n\n.bg-current {\n  background-color: currentColor;\n}\n\n.bg-black {\n  --bg-opacity: 1;\n  background-color: #000;\n  background-color: rgba(0, 0, 0, var(--bg-opacity));\n}\n\n.bg-white {\n  --bg-opacity: 1;\n  background-color: #fff;\n  background-color: rgba(255, 255, 255, var(--bg-opacity));\n}\n\n.bg-gray-100 {\n  --bg-opacity: 1;\n  background-color: #f7fafc;\n  background-color: rgba(247, 250, 252, var(--bg-opacity));\n}\n\n.bg-gray-200 {\n  --bg-opacity: 1;\n  background-color: #edf2f7;\n  background-color: rgba(237, 242, 247, var(--bg-opacity));\n}\n\n.bg-gray-300 {\n  --bg-opacity: 1;\n  background-color: #e2e8f0;\n  background-color: rgba(226, 232, 240, var(--bg-opacity));\n}\n\n.bg-gray-400 {\n  --bg-opacity: 1;\n  background-color: #cbd5e0;\n  background-color: rgba(203, 213, 224, var(--bg-opacity));\n}\n\n.bg-gray-500 {\n  --bg-opacity: 1;\n  background-color: #a0aec0;\n  background-color: rgba(160, 174, 192, var(--bg-opacity));\n}\n\n.bg-gray-600 {\n  --bg-opacity: 1;\n  background-color: #718096;\n  background-color: rgba(113, 128, 150, var(--bg-opacity));\n}\n\n.bg-gray-700 {\n  --bg-opacity: 1;\n  background-color: #4a5568;\n  background-color: rgba(74, 85, 104, var(--bg-opacity));\n}\n\n.bg-gray-800 {\n  --bg-opacity: 1;\n  background-color: #2d3748;\n  background-color: rgba(45, 55, 72, var(--bg-opacity));\n}\n\n.bg-gray-900 {\n  --bg-opacity: 1;\n  background-color: #1a202c;\n  background-color: rgba(26, 32, 44, var(--bg-opacity));\n}\n\n.bg-red-100 {\n  --bg-opacity: 1;\n  background-color: #fff5f5;\n  background-color: rgba(255, 245, 245, var(--bg-opacity));\n}\n\n.bg-red-200 {\n  --bg-opacity: 1;\n  background-color: #fed7d7;\n  background-color: rgba(254, 215, 215, var(--bg-opacity));\n}\n\n.bg-red-300 {\n  --bg-opacity: 1;\n  background-color: #feb2b2;\n  background-color: rgba(254, 178, 178, var(--bg-opacity));\n}\n\n.bg-red-400 {\n  --bg-opacity: 1;\n  background-color: #fc8181;\n  background-color: rgba(252, 129, 129, var(--bg-opacity));\n}\n\n.bg-red-500 {\n  --bg-opacity: 1;\n  background-color: #f56565;\n  background-color: rgba(245, 101, 101, var(--bg-opacity));\n}\n\n.bg-red-600 {\n  --bg-opacity: 1;\n  background-color: #e53e3e;\n  background-color: rgba(229, 62, 62, var(--bg-opacity));\n}\n\n.bg-red-700 {\n  --bg-opacity: 1;\n  background-color: #c53030;\n  background-color: rgba(197, 48, 48, var(--bg-opacity));\n}\n\n.bg-red-800 {\n  --bg-opacity: 1;\n  background-color: #9b2c2c;\n  background-color: rgba(155, 44, 44, var(--bg-opacity));\n}\n\n.bg-red-900 {\n  --bg-opacity: 1;\n  background-color: #742a2a;\n  background-color: rgba(116, 42, 42, var(--bg-opacity));\n}\n\n.bg-orange-100 {\n  --bg-opacity: 1;\n  background-color: #fffaf0;\n  background-color: rgba(255, 250, 240, var(--bg-opacity));\n}\n\n.bg-orange-200 {\n  --bg-opacity: 1;\n  background-color: #feebc8;\n  background-color: rgba(254, 235, 200, var(--bg-opacity));\n}\n\n.bg-orange-300 {\n  --bg-opacity: 1;\n  background-color: #fbd38d;\n  background-color: rgba(251, 211, 141, var(--bg-opacity));\n}\n\n.bg-orange-400 {\n  --bg-opacity: 1;\n  background-color: #f6ad55;\n  background-color: rgba(246, 173, 85, var(--bg-opacity));\n}\n\n.bg-orange-500 {\n  --bg-opacity: 1;\n  background-color: #ed8936;\n  background-color: rgba(237, 137, 54, var(--bg-opacity));\n}\n\n.bg-orange-600 {\n  --bg-opacity: 1;\n  background-color: #dd6b20;\n  background-color: rgba(221, 107, 32, var(--bg-opacity));\n}\n\n.bg-orange-700 {\n  --bg-opacity: 1;\n  background-color: #c05621;\n  background-color: rgba(192, 86, 33, var(--bg-opacity));\n}\n\n.bg-orange-800 {\n  --bg-opacity: 1;\n  background-color: #9c4221;\n  background-color: rgba(156, 66, 33, var(--bg-opacity));\n}\n\n.bg-orange-900 {\n  --bg-opacity: 1;\n  background-color: #7b341e;\n  background-color: rgba(123, 52, 30, var(--bg-opacity));\n}\n\n.bg-yellow-100 {\n  --bg-opacity: 1;\n  background-color: #fffff0;\n  background-color: rgba(255, 255, 240, var(--bg-opacity));\n}\n\n.bg-yellow-200 {\n  --bg-opacity: 1;\n  background-color: #fefcbf;\n  background-color: rgba(254, 252, 191, var(--bg-opacity));\n}\n\n.bg-yellow-300 {\n  --bg-opacity: 1;\n  background-color: #faf089;\n  background-color: rgba(250, 240, 137, var(--bg-opacity));\n}\n\n.bg-yellow-400 {\n  --bg-opacity: 1;\n  background-color: #f6e05e;\n  background-color: rgba(246, 224, 94, var(--bg-opacity));\n}\n\n.bg-yellow-500 {\n  --bg-opacity: 1;\n  background-color: #ecc94b;\n  background-color: rgba(236, 201, 75, var(--bg-opacity));\n}\n\n.bg-yellow-600 {\n  --bg-opacity: 1;\n  background-color: #d69e2e;\n  background-color: rgba(214, 158, 46, var(--bg-opacity));\n}\n\n.bg-yellow-700 {\n  --bg-opacity: 1;\n  background-color: #b7791f;\n  background-color: rgba(183, 121, 31, var(--bg-opacity));\n}\n\n.bg-yellow-800 {\n  --bg-opacity: 1;\n  background-color: #975a16;\n  background-color: rgba(151, 90, 22, var(--bg-opacity));\n}\n\n.bg-yellow-900 {\n  --bg-opacity: 1;\n  background-color: #744210;\n  background-color: rgba(116, 66, 16, var(--bg-opacity));\n}\n\n.bg-green-100 {\n  --bg-opacity: 1;\n  background-color: #f0fff4;\n  background-color: rgba(240, 255, 244, var(--bg-opacity));\n}\n\n.bg-green-200 {\n  --bg-opacity: 1;\n  background-color: #c6f6d5;\n  background-color: rgba(198, 246, 213, var(--bg-opacity));\n}\n\n.bg-green-300 {\n  --bg-opacity: 1;\n  background-color: #9ae6b4;\n  background-color: rgba(154, 230, 180, var(--bg-opacity));\n}\n\n.bg-green-400 {\n  --bg-opacity: 1;\n  background-color: #68d391;\n  background-color: rgba(104, 211, 145, var(--bg-opacity));\n}\n\n.bg-green-500 {\n  --bg-opacity: 1;\n  background-color: #48bb78;\n  background-color: rgba(72, 187, 120, var(--bg-opacity));\n}\n\n.bg-green-600 {\n  --bg-opacity: 1;\n  background-color: #38a169;\n  background-color: rgba(56, 161, 105, var(--bg-opacity));\n}\n\n.bg-green-700 {\n  --bg-opacity: 1;\n  background-color: #2f855a;\n  background-color: rgba(47, 133, 90, var(--bg-opacity));\n}\n\n.bg-green-800 {\n  --bg-opacity: 1;\n  background-color: #276749;\n  background-color: rgba(39, 103, 73, var(--bg-opacity));\n}\n\n.bg-green-900 {\n  --bg-opacity: 1;\n  background-color: #22543d;\n  background-color: rgba(34, 84, 61, var(--bg-opacity));\n}\n\n.bg-teal-100 {\n  --bg-opacity: 1;\n  background-color: #e6fffa;\n  background-color: rgba(230, 255, 250, var(--bg-opacity));\n}\n\n.bg-teal-200 {\n  --bg-opacity: 1;\n  background-color: #b2f5ea;\n  background-color: rgba(178, 245, 234, var(--bg-opacity));\n}\n\n.bg-teal-300 {\n  --bg-opacity: 1;\n  background-color: #81e6d9;\n  background-color: rgba(129, 230, 217, var(--bg-opacity));\n}\n\n.bg-teal-400 {\n  --bg-opacity: 1;\n  background-color: #4fd1c5;\n  background-color: rgba(79, 209, 197, var(--bg-opacity));\n}\n\n.bg-teal-500 {\n  --bg-opacity: 1;\n  background-color: #38b2ac;\n  background-color: rgba(56, 178, 172, var(--bg-opacity));\n}\n\n.bg-teal-600 {\n  --bg-opacity: 1;\n  background-color: #319795;\n  background-color: rgba(49, 151, 149, var(--bg-opacity));\n}\n\n.bg-teal-700 {\n  --bg-opacity: 1;\n  background-color: #2c7a7b;\n  background-color: rgba(44, 122, 123, var(--bg-opacity));\n}\n\n.bg-teal-800 {\n  --bg-opacity: 1;\n  background-color: #285e61;\n  background-color: rgba(40, 94, 97, var(--bg-opacity));\n}\n\n.bg-teal-900 {\n  --bg-opacity: 1;\n  background-color: #234e52;\n  background-color: rgba(35, 78, 82, var(--bg-opacity));\n}\n\n.bg-blue-100 {\n  --bg-opacity: 1;\n  background-color: #ebf8ff;\n  background-color: rgba(235, 248, 255, var(--bg-opacity));\n}\n\n.bg-blue-200 {\n  --bg-opacity: 1;\n  background-color: #bee3f8;\n  background-color: rgba(190, 227, 248, var(--bg-opacity));\n}\n\n.bg-blue-300 {\n  --bg-opacity: 1;\n  background-color: #90cdf4;\n  background-color: rgba(144, 205, 244, var(--bg-opacity));\n}\n\n.bg-blue-400 {\n  --bg-opacity: 1;\n  background-color: #63b3ed;\n  background-color: rgba(99, 179, 237, var(--bg-opacity));\n}\n\n.bg-blue-500 {\n  --bg-opacity: 1;\n  background-color: #4299e1;\n  background-color: rgba(66, 153, 225, var(--bg-opacity));\n}\n\n.bg-blue-600 {\n  --bg-opacity: 1;\n  background-color: #3182ce;\n  background-color: rgba(49, 130, 206, var(--bg-opacity));\n}\n\n.bg-blue-700 {\n  --bg-opacity: 1;\n  background-color: #2b6cb0;\n  background-color: rgba(43, 108, 176, var(--bg-opacity));\n}\n\n.bg-blue-800 {\n  --bg-opacity: 1;\n  background-color: #2c5282;\n  background-color: rgba(44, 82, 130, var(--bg-opacity));\n}\n\n.bg-blue-900 {\n  --bg-opacity: 1;\n  background-color: #2a4365;\n  background-color: rgba(42, 67, 101, var(--bg-opacity));\n}\n\n.bg-indigo-100 {\n  --bg-opacity: 1;\n  background-color: #ebf4ff;\n  background-color: rgba(235, 244, 255, var(--bg-opacity));\n}\n\n.bg-indigo-200 {\n  --bg-opacity: 1;\n  background-color: #c3dafe;\n  background-color: rgba(195, 218, 254, var(--bg-opacity));\n}\n\n.bg-indigo-300 {\n  --bg-opacity: 1;\n  background-color: #a3bffa;\n  background-color: rgba(163, 191, 250, var(--bg-opacity));\n}\n\n.bg-indigo-400 {\n  --bg-opacity: 1;\n  background-color: #7f9cf5;\n  background-color: rgba(127, 156, 245, var(--bg-opacity));\n}\n\n.bg-indigo-500 {\n  --bg-opacity: 1;\n  background-color: #667eea;\n  background-color: rgba(102, 126, 234, var(--bg-opacity));\n}\n\n.bg-indigo-600 {\n  --bg-opacity: 1;\n  background-color: #5a67d8;\n  background-color: rgba(90, 103, 216, var(--bg-opacity));\n}\n\n.bg-indigo-700 {\n  --bg-opacity: 1;\n  background-color: #4c51bf;\n  background-color: rgba(76, 81, 191, var(--bg-opacity));\n}\n\n.bg-indigo-800 {\n  --bg-opacity: 1;\n  background-color: #434190;\n  background-color: rgba(67, 65, 144, var(--bg-opacity));\n}\n\n.bg-indigo-900 {\n  --bg-opacity: 1;\n  background-color: #3c366b;\n  background-color: rgba(60, 54, 107, var(--bg-opacity));\n}\n\n.bg-purple-100 {\n  --bg-opacity: 1;\n  background-color: #faf5ff;\n  background-color: rgba(250, 245, 255, var(--bg-opacity));\n}\n\n.bg-purple-200 {\n  --bg-opacity: 1;\n  background-color: #e9d8fd;\n  background-color: rgba(233, 216, 253, var(--bg-opacity));\n}\n\n.bg-purple-300 {\n  --bg-opacity: 1;\n  background-color: #d6bcfa;\n  background-color: rgba(214, 188, 250, var(--bg-opacity));\n}\n\n.bg-purple-400 {\n  --bg-opacity: 1;\n  background-color: #b794f4;\n  background-color: rgba(183, 148, 244, var(--bg-opacity));\n}\n\n.bg-purple-500 {\n  --bg-opacity: 1;\n  background-color: #9f7aea;\n  background-color: rgba(159, 122, 234, var(--bg-opacity));\n}\n\n.bg-purple-600 {\n  --bg-opacity: 1;\n  background-color: #805ad5;\n  background-color: rgba(128, 90, 213, var(--bg-opacity));\n}\n\n.bg-purple-700 {\n  --bg-opacity: 1;\n  background-color: #6b46c1;\n  background-color: rgba(107, 70, 193, var(--bg-opacity));\n}\n\n.bg-purple-800 {\n  --bg-opacity: 1;\n  background-color: #553c9a;\n  background-color: rgba(85, 60, 154, var(--bg-opacity));\n}\n\n.bg-purple-900 {\n  --bg-opacity: 1;\n  background-color: #44337a;\n  background-color: rgba(68, 51, 122, var(--bg-opacity));\n}\n\n.bg-pink-100 {\n  --bg-opacity: 1;\n  background-color: #fff5f7;\n  background-color: rgba(255, 245, 247, var(--bg-opacity));\n}\n\n.bg-pink-200 {\n  --bg-opacity: 1;\n  background-color: #fed7e2;\n  background-color: rgba(254, 215, 226, var(--bg-opacity));\n}\n\n.bg-pink-300 {\n  --bg-opacity: 1;\n  background-color: #fbb6ce;\n  background-color: rgba(251, 182, 206, var(--bg-opacity));\n}\n\n.bg-pink-400 {\n  --bg-opacity: 1;\n  background-color: #f687b3;\n  background-color: rgba(246, 135, 179, var(--bg-opacity));\n}\n\n.bg-pink-500 {\n  --bg-opacity: 1;\n  background-color: #ed64a6;\n  background-color: rgba(237, 100, 166, var(--bg-opacity));\n}\n\n.bg-pink-600 {\n  --bg-opacity: 1;\n  background-color: #d53f8c;\n  background-color: rgba(213, 63, 140, var(--bg-opacity));\n}\n\n.bg-pink-700 {\n  --bg-opacity: 1;\n  background-color: #b83280;\n  background-color: rgba(184, 50, 128, var(--bg-opacity));\n}\n\n.bg-pink-800 {\n  --bg-opacity: 1;\n  background-color: #97266d;\n  background-color: rgba(151, 38, 109, var(--bg-opacity));\n}\n\n.bg-pink-900 {\n  --bg-opacity: 1;\n  background-color: #702459;\n  background-color: rgba(112, 36, 89, var(--bg-opacity));\n}\n\n.bg-grayscale-80 {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 8%);\n  background-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--bg-opacity));\n}\n\n.bg-grayscale-100 {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 10%);\n  background-color: rgba(25.5, 25.5, 25.5, var(--bg-opacity));\n}\n\n.bg-grayscale-200 {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 20%);\n  background-color: rgba(51, 51, 51, var(--bg-opacity));\n}\n\n.bg-grayscale-300 {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 30%);\n  background-color: rgba(76.5, 76.5, 76.5, var(--bg-opacity));\n}\n\n.bg-grayscale-400 {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 40%);\n  background-color: rgba(102, 102, 102, var(--bg-opacity));\n}\n\n.bg-grayscale-500 {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 50%);\n  background-color: rgba(127.5, 127.5, 127.5, var(--bg-opacity));\n}\n\n.bg-grayscale-600 {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 60%);\n  background-color: rgba(153, 153, 153, var(--bg-opacity));\n}\n\n.bg-grayscale-700 {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 70%);\n  background-color: rgba(178.5, 178.5, 178.5, var(--bg-opacity));\n}\n\n.bg-grayscale-800 {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 80%);\n  background-color: rgba(204, 204, 204, var(--bg-opacity));\n}\n\n.bg-grayscale-840 {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 84%);\n  background-color: rgba(214.2, 214.2, 214.2, var(--bg-opacity));\n}\n\n.bg-grayscale-870 {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 87%);\n  background-color: rgba(221.85, 221.85, 221.85, var(--bg-opacity));\n}\n\n.bg-grayscale-900 {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 90%);\n  background-color: rgba(229.5, 229.5, 229.5, var(--bg-opacity));\n}\n\n.bg-grayscale-930 {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 93%);\n  background-color: rgba(237.15, 237.15, 237.15, var(--bg-opacity));\n}\n\n.bg-primary {\n  --bg-opacity: 1;\n  background-color: hsl(210, 100%, 52%);\n  background-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--bg-opacity));\n}\n\n.bg-background-main {\n  background-color: var(--main-background);\n}\n\n.bg-background-secondary {\n  background-color: var(--secondary-background);\n}\n\n.bg-foreground {\n  background-color: var(--foreground);\n}\n\n.bg-panels-bg {\n  background-color: var(--panels-background);\n}\n\n.hover\\:bg-transparent:hover {\n  background-color: transparent;\n}\n\n.hover\\:bg-current:hover {\n  background-color: currentColor;\n}\n\n.hover\\:bg-black:hover {\n  --bg-opacity: 1;\n  background-color: #000;\n  background-color: rgba(0, 0, 0, var(--bg-opacity));\n}\n\n.hover\\:bg-white:hover {\n  --bg-opacity: 1;\n  background-color: #fff;\n  background-color: rgba(255, 255, 255, var(--bg-opacity));\n}\n\n.hover\\:bg-gray-100:hover {\n  --bg-opacity: 1;\n  background-color: #f7fafc;\n  background-color: rgba(247, 250, 252, var(--bg-opacity));\n}\n\n.hover\\:bg-gray-200:hover {\n  --bg-opacity: 1;\n  background-color: #edf2f7;\n  background-color: rgba(237, 242, 247, var(--bg-opacity));\n}\n\n.hover\\:bg-gray-300:hover {\n  --bg-opacity: 1;\n  background-color: #e2e8f0;\n  background-color: rgba(226, 232, 240, var(--bg-opacity));\n}\n\n.hover\\:bg-gray-400:hover {\n  --bg-opacity: 1;\n  background-color: #cbd5e0;\n  background-color: rgba(203, 213, 224, var(--bg-opacity));\n}\n\n.hover\\:bg-gray-500:hover {\n  --bg-opacity: 1;\n  background-color: #a0aec0;\n  background-color: rgba(160, 174, 192, var(--bg-opacity));\n}\n\n.hover\\:bg-gray-600:hover {\n  --bg-opacity: 1;\n  background-color: #718096;\n  background-color: rgba(113, 128, 150, var(--bg-opacity));\n}\n\n.hover\\:bg-gray-700:hover {\n  --bg-opacity: 1;\n  background-color: #4a5568;\n  background-color: rgba(74, 85, 104, var(--bg-opacity));\n}\n\n.hover\\:bg-gray-800:hover {\n  --bg-opacity: 1;\n  background-color: #2d3748;\n  background-color: rgba(45, 55, 72, var(--bg-opacity));\n}\n\n.hover\\:bg-gray-900:hover {\n  --bg-opacity: 1;\n  background-color: #1a202c;\n  background-color: rgba(26, 32, 44, var(--bg-opacity));\n}\n\n.hover\\:bg-red-100:hover {\n  --bg-opacity: 1;\n  background-color: #fff5f5;\n  background-color: rgba(255, 245, 245, var(--bg-opacity));\n}\n\n.hover\\:bg-red-200:hover {\n  --bg-opacity: 1;\n  background-color: #fed7d7;\n  background-color: rgba(254, 215, 215, var(--bg-opacity));\n}\n\n.hover\\:bg-red-300:hover {\n  --bg-opacity: 1;\n  background-color: #feb2b2;\n  background-color: rgba(254, 178, 178, var(--bg-opacity));\n}\n\n.hover\\:bg-red-400:hover {\n  --bg-opacity: 1;\n  background-color: #fc8181;\n  background-color: rgba(252, 129, 129, var(--bg-opacity));\n}\n\n.hover\\:bg-red-500:hover {\n  --bg-opacity: 1;\n  background-color: #f56565;\n  background-color: rgba(245, 101, 101, var(--bg-opacity));\n}\n\n.hover\\:bg-red-600:hover {\n  --bg-opacity: 1;\n  background-color: #e53e3e;\n  background-color: rgba(229, 62, 62, var(--bg-opacity));\n}\n\n.hover\\:bg-red-700:hover {\n  --bg-opacity: 1;\n  background-color: #c53030;\n  background-color: rgba(197, 48, 48, var(--bg-opacity));\n}\n\n.hover\\:bg-red-800:hover {\n  --bg-opacity: 1;\n  background-color: #9b2c2c;\n  background-color: rgba(155, 44, 44, var(--bg-opacity));\n}\n\n.hover\\:bg-red-900:hover {\n  --bg-opacity: 1;\n  background-color: #742a2a;\n  background-color: rgba(116, 42, 42, var(--bg-opacity));\n}\n\n.hover\\:bg-orange-100:hover {\n  --bg-opacity: 1;\n  background-color: #fffaf0;\n  background-color: rgba(255, 250, 240, var(--bg-opacity));\n}\n\n.hover\\:bg-orange-200:hover {\n  --bg-opacity: 1;\n  background-color: #feebc8;\n  background-color: rgba(254, 235, 200, var(--bg-opacity));\n}\n\n.hover\\:bg-orange-300:hover {\n  --bg-opacity: 1;\n  background-color: #fbd38d;\n  background-color: rgba(251, 211, 141, var(--bg-opacity));\n}\n\n.hover\\:bg-orange-400:hover {\n  --bg-opacity: 1;\n  background-color: #f6ad55;\n  background-color: rgba(246, 173, 85, var(--bg-opacity));\n}\n\n.hover\\:bg-orange-500:hover {\n  --bg-opacity: 1;\n  background-color: #ed8936;\n  background-color: rgba(237, 137, 54, var(--bg-opacity));\n}\n\n.hover\\:bg-orange-600:hover {\n  --bg-opacity: 1;\n  background-color: #dd6b20;\n  background-color: rgba(221, 107, 32, var(--bg-opacity));\n}\n\n.hover\\:bg-orange-700:hover {\n  --bg-opacity: 1;\n  background-color: #c05621;\n  background-color: rgba(192, 86, 33, var(--bg-opacity));\n}\n\n.hover\\:bg-orange-800:hover {\n  --bg-opacity: 1;\n  background-color: #9c4221;\n  background-color: rgba(156, 66, 33, var(--bg-opacity));\n}\n\n.hover\\:bg-orange-900:hover {\n  --bg-opacity: 1;\n  background-color: #7b341e;\n  background-color: rgba(123, 52, 30, var(--bg-opacity));\n}\n\n.hover\\:bg-yellow-100:hover {\n  --bg-opacity: 1;\n  background-color: #fffff0;\n  background-color: rgba(255, 255, 240, var(--bg-opacity));\n}\n\n.hover\\:bg-yellow-200:hover {\n  --bg-opacity: 1;\n  background-color: #fefcbf;\n  background-color: rgba(254, 252, 191, var(--bg-opacity));\n}\n\n.hover\\:bg-yellow-300:hover {\n  --bg-opacity: 1;\n  background-color: #faf089;\n  background-color: rgba(250, 240, 137, var(--bg-opacity));\n}\n\n.hover\\:bg-yellow-400:hover {\n  --bg-opacity: 1;\n  background-color: #f6e05e;\n  background-color: rgba(246, 224, 94, var(--bg-opacity));\n}\n\n.hover\\:bg-yellow-500:hover {\n  --bg-opacity: 1;\n  background-color: #ecc94b;\n  background-color: rgba(236, 201, 75, var(--bg-opacity));\n}\n\n.hover\\:bg-yellow-600:hover {\n  --bg-opacity: 1;\n  background-color: #d69e2e;\n  background-color: rgba(214, 158, 46, var(--bg-opacity));\n}\n\n.hover\\:bg-yellow-700:hover {\n  --bg-opacity: 1;\n  background-color: #b7791f;\n  background-color: rgba(183, 121, 31, var(--bg-opacity));\n}\n\n.hover\\:bg-yellow-800:hover {\n  --bg-opacity: 1;\n  background-color: #975a16;\n  background-color: rgba(151, 90, 22, var(--bg-opacity));\n}\n\n.hover\\:bg-yellow-900:hover {\n  --bg-opacity: 1;\n  background-color: #744210;\n  background-color: rgba(116, 66, 16, var(--bg-opacity));\n}\n\n.hover\\:bg-green-100:hover {\n  --bg-opacity: 1;\n  background-color: #f0fff4;\n  background-color: rgba(240, 255, 244, var(--bg-opacity));\n}\n\n.hover\\:bg-green-200:hover {\n  --bg-opacity: 1;\n  background-color: #c6f6d5;\n  background-color: rgba(198, 246, 213, var(--bg-opacity));\n}\n\n.hover\\:bg-green-300:hover {\n  --bg-opacity: 1;\n  background-color: #9ae6b4;\n  background-color: rgba(154, 230, 180, var(--bg-opacity));\n}\n\n.hover\\:bg-green-400:hover {\n  --bg-opacity: 1;\n  background-color: #68d391;\n  background-color: rgba(104, 211, 145, var(--bg-opacity));\n}\n\n.hover\\:bg-green-500:hover {\n  --bg-opacity: 1;\n  background-color: #48bb78;\n  background-color: rgba(72, 187, 120, var(--bg-opacity));\n}\n\n.hover\\:bg-green-600:hover {\n  --bg-opacity: 1;\n  background-color: #38a169;\n  background-color: rgba(56, 161, 105, var(--bg-opacity));\n}\n\n.hover\\:bg-green-700:hover {\n  --bg-opacity: 1;\n  background-color: #2f855a;\n  background-color: rgba(47, 133, 90, var(--bg-opacity));\n}\n\n.hover\\:bg-green-800:hover {\n  --bg-opacity: 1;\n  background-color: #276749;\n  background-color: rgba(39, 103, 73, var(--bg-opacity));\n}\n\n.hover\\:bg-green-900:hover {\n  --bg-opacity: 1;\n  background-color: #22543d;\n  background-color: rgba(34, 84, 61, var(--bg-opacity));\n}\n\n.hover\\:bg-teal-100:hover {\n  --bg-opacity: 1;\n  background-color: #e6fffa;\n  background-color: rgba(230, 255, 250, var(--bg-opacity));\n}\n\n.hover\\:bg-teal-200:hover {\n  --bg-opacity: 1;\n  background-color: #b2f5ea;\n  background-color: rgba(178, 245, 234, var(--bg-opacity));\n}\n\n.hover\\:bg-teal-300:hover {\n  --bg-opacity: 1;\n  background-color: #81e6d9;\n  background-color: rgba(129, 230, 217, var(--bg-opacity));\n}\n\n.hover\\:bg-teal-400:hover {\n  --bg-opacity: 1;\n  background-color: #4fd1c5;\n  background-color: rgba(79, 209, 197, var(--bg-opacity));\n}\n\n.hover\\:bg-teal-500:hover {\n  --bg-opacity: 1;\n  background-color: #38b2ac;\n  background-color: rgba(56, 178, 172, var(--bg-opacity));\n}\n\n.hover\\:bg-teal-600:hover {\n  --bg-opacity: 1;\n  background-color: #319795;\n  background-color: rgba(49, 151, 149, var(--bg-opacity));\n}\n\n.hover\\:bg-teal-700:hover {\n  --bg-opacity: 1;\n  background-color: #2c7a7b;\n  background-color: rgba(44, 122, 123, var(--bg-opacity));\n}\n\n.hover\\:bg-teal-800:hover {\n  --bg-opacity: 1;\n  background-color: #285e61;\n  background-color: rgba(40, 94, 97, var(--bg-opacity));\n}\n\n.hover\\:bg-teal-900:hover {\n  --bg-opacity: 1;\n  background-color: #234e52;\n  background-color: rgba(35, 78, 82, var(--bg-opacity));\n}\n\n.hover\\:bg-blue-100:hover {\n  --bg-opacity: 1;\n  background-color: #ebf8ff;\n  background-color: rgba(235, 248, 255, var(--bg-opacity));\n}\n\n.hover\\:bg-blue-200:hover {\n  --bg-opacity: 1;\n  background-color: #bee3f8;\n  background-color: rgba(190, 227, 248, var(--bg-opacity));\n}\n\n.hover\\:bg-blue-300:hover {\n  --bg-opacity: 1;\n  background-color: #90cdf4;\n  background-color: rgba(144, 205, 244, var(--bg-opacity));\n}\n\n.hover\\:bg-blue-400:hover {\n  --bg-opacity: 1;\n  background-color: #63b3ed;\n  background-color: rgba(99, 179, 237, var(--bg-opacity));\n}\n\n.hover\\:bg-blue-500:hover {\n  --bg-opacity: 1;\n  background-color: #4299e1;\n  background-color: rgba(66, 153, 225, var(--bg-opacity));\n}\n\n.hover\\:bg-blue-600:hover {\n  --bg-opacity: 1;\n  background-color: #3182ce;\n  background-color: rgba(49, 130, 206, var(--bg-opacity));\n}\n\n.hover\\:bg-blue-700:hover {\n  --bg-opacity: 1;\n  background-color: #2b6cb0;\n  background-color: rgba(43, 108, 176, var(--bg-opacity));\n}\n\n.hover\\:bg-blue-800:hover {\n  --bg-opacity: 1;\n  background-color: #2c5282;\n  background-color: rgba(44, 82, 130, var(--bg-opacity));\n}\n\n.hover\\:bg-blue-900:hover {\n  --bg-opacity: 1;\n  background-color: #2a4365;\n  background-color: rgba(42, 67, 101, var(--bg-opacity));\n}\n\n.hover\\:bg-indigo-100:hover {\n  --bg-opacity: 1;\n  background-color: #ebf4ff;\n  background-color: rgba(235, 244, 255, var(--bg-opacity));\n}\n\n.hover\\:bg-indigo-200:hover {\n  --bg-opacity: 1;\n  background-color: #c3dafe;\n  background-color: rgba(195, 218, 254, var(--bg-opacity));\n}\n\n.hover\\:bg-indigo-300:hover {\n  --bg-opacity: 1;\n  background-color: #a3bffa;\n  background-color: rgba(163, 191, 250, var(--bg-opacity));\n}\n\n.hover\\:bg-indigo-400:hover {\n  --bg-opacity: 1;\n  background-color: #7f9cf5;\n  background-color: rgba(127, 156, 245, var(--bg-opacity));\n}\n\n.hover\\:bg-indigo-500:hover {\n  --bg-opacity: 1;\n  background-color: #667eea;\n  background-color: rgba(102, 126, 234, var(--bg-opacity));\n}\n\n.hover\\:bg-indigo-600:hover {\n  --bg-opacity: 1;\n  background-color: #5a67d8;\n  background-color: rgba(90, 103, 216, var(--bg-opacity));\n}\n\n.hover\\:bg-indigo-700:hover {\n  --bg-opacity: 1;\n  background-color: #4c51bf;\n  background-color: rgba(76, 81, 191, var(--bg-opacity));\n}\n\n.hover\\:bg-indigo-800:hover {\n  --bg-opacity: 1;\n  background-color: #434190;\n  background-color: rgba(67, 65, 144, var(--bg-opacity));\n}\n\n.hover\\:bg-indigo-900:hover {\n  --bg-opacity: 1;\n  background-color: #3c366b;\n  background-color: rgba(60, 54, 107, var(--bg-opacity));\n}\n\n.hover\\:bg-purple-100:hover {\n  --bg-opacity: 1;\n  background-color: #faf5ff;\n  background-color: rgba(250, 245, 255, var(--bg-opacity));\n}\n\n.hover\\:bg-purple-200:hover {\n  --bg-opacity: 1;\n  background-color: #e9d8fd;\n  background-color: rgba(233, 216, 253, var(--bg-opacity));\n}\n\n.hover\\:bg-purple-300:hover {\n  --bg-opacity: 1;\n  background-color: #d6bcfa;\n  background-color: rgba(214, 188, 250, var(--bg-opacity));\n}\n\n.hover\\:bg-purple-400:hover {\n  --bg-opacity: 1;\n  background-color: #b794f4;\n  background-color: rgba(183, 148, 244, var(--bg-opacity));\n}\n\n.hover\\:bg-purple-500:hover {\n  --bg-opacity: 1;\n  background-color: #9f7aea;\n  background-color: rgba(159, 122, 234, var(--bg-opacity));\n}\n\n.hover\\:bg-purple-600:hover {\n  --bg-opacity: 1;\n  background-color: #805ad5;\n  background-color: rgba(128, 90, 213, var(--bg-opacity));\n}\n\n.hover\\:bg-purple-700:hover {\n  --bg-opacity: 1;\n  background-color: #6b46c1;\n  background-color: rgba(107, 70, 193, var(--bg-opacity));\n}\n\n.hover\\:bg-purple-800:hover {\n  --bg-opacity: 1;\n  background-color: #553c9a;\n  background-color: rgba(85, 60, 154, var(--bg-opacity));\n}\n\n.hover\\:bg-purple-900:hover {\n  --bg-opacity: 1;\n  background-color: #44337a;\n  background-color: rgba(68, 51, 122, var(--bg-opacity));\n}\n\n.hover\\:bg-pink-100:hover {\n  --bg-opacity: 1;\n  background-color: #fff5f7;\n  background-color: rgba(255, 245, 247, var(--bg-opacity));\n}\n\n.hover\\:bg-pink-200:hover {\n  --bg-opacity: 1;\n  background-color: #fed7e2;\n  background-color: rgba(254, 215, 226, var(--bg-opacity));\n}\n\n.hover\\:bg-pink-300:hover {\n  --bg-opacity: 1;\n  background-color: #fbb6ce;\n  background-color: rgba(251, 182, 206, var(--bg-opacity));\n}\n\n.hover\\:bg-pink-400:hover {\n  --bg-opacity: 1;\n  background-color: #f687b3;\n  background-color: rgba(246, 135, 179, var(--bg-opacity));\n}\n\n.hover\\:bg-pink-500:hover {\n  --bg-opacity: 1;\n  background-color: #ed64a6;\n  background-color: rgba(237, 100, 166, var(--bg-opacity));\n}\n\n.hover\\:bg-pink-600:hover {\n  --bg-opacity: 1;\n  background-color: #d53f8c;\n  background-color: rgba(213, 63, 140, var(--bg-opacity));\n}\n\n.hover\\:bg-pink-700:hover {\n  --bg-opacity: 1;\n  background-color: #b83280;\n  background-color: rgba(184, 50, 128, var(--bg-opacity));\n}\n\n.hover\\:bg-pink-800:hover {\n  --bg-opacity: 1;\n  background-color: #97266d;\n  background-color: rgba(151, 38, 109, var(--bg-opacity));\n}\n\n.hover\\:bg-pink-900:hover {\n  --bg-opacity: 1;\n  background-color: #702459;\n  background-color: rgba(112, 36, 89, var(--bg-opacity));\n}\n\n.hover\\:bg-grayscale-80:hover {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 8%);\n  background-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--bg-opacity));\n}\n\n.hover\\:bg-grayscale-100:hover {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 10%);\n  background-color: rgba(25.5, 25.5, 25.5, var(--bg-opacity));\n}\n\n.hover\\:bg-grayscale-200:hover {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 20%);\n  background-color: rgba(51, 51, 51, var(--bg-opacity));\n}\n\n.hover\\:bg-grayscale-300:hover {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 30%);\n  background-color: rgba(76.5, 76.5, 76.5, var(--bg-opacity));\n}\n\n.hover\\:bg-grayscale-400:hover {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 40%);\n  background-color: rgba(102, 102, 102, var(--bg-opacity));\n}\n\n.hover\\:bg-grayscale-500:hover {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 50%);\n  background-color: rgba(127.5, 127.5, 127.5, var(--bg-opacity));\n}\n\n.hover\\:bg-grayscale-600:hover {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 60%);\n  background-color: rgba(153, 153, 153, var(--bg-opacity));\n}\n\n.hover\\:bg-grayscale-700:hover {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 70%);\n  background-color: rgba(178.5, 178.5, 178.5, var(--bg-opacity));\n}\n\n.hover\\:bg-grayscale-800:hover {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 80%);\n  background-color: rgba(204, 204, 204, var(--bg-opacity));\n}\n\n.hover\\:bg-grayscale-840:hover {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 84%);\n  background-color: rgba(214.2, 214.2, 214.2, var(--bg-opacity));\n}\n\n.hover\\:bg-grayscale-870:hover {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 87%);\n  background-color: rgba(221.85, 221.85, 221.85, var(--bg-opacity));\n}\n\n.hover\\:bg-grayscale-900:hover {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 90%);\n  background-color: rgba(229.5, 229.5, 229.5, var(--bg-opacity));\n}\n\n.hover\\:bg-grayscale-930:hover {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 93%);\n  background-color: rgba(237.15, 237.15, 237.15, var(--bg-opacity));\n}\n\n.hover\\:bg-primary:hover {\n  --bg-opacity: 1;\n  background-color: hsl(210, 100%, 52%);\n  background-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--bg-opacity));\n}\n\n.hover\\:bg-background-main:hover {\n  background-color: var(--main-background);\n}\n\n.hover\\:bg-background-secondary:hover {\n  background-color: var(--secondary-background);\n}\n\n.hover\\:bg-foreground:hover {\n  background-color: var(--foreground);\n}\n\n.hover\\:bg-panels-bg:hover {\n  background-color: var(--panels-background);\n}\n\n.focus\\:bg-transparent:focus {\n  background-color: transparent;\n}\n\n.focus\\:bg-current:focus {\n  background-color: currentColor;\n}\n\n.focus\\:bg-black:focus {\n  --bg-opacity: 1;\n  background-color: #000;\n  background-color: rgba(0, 0, 0, var(--bg-opacity));\n}\n\n.focus\\:bg-white:focus {\n  --bg-opacity: 1;\n  background-color: #fff;\n  background-color: rgba(255, 255, 255, var(--bg-opacity));\n}\n\n.focus\\:bg-gray-100:focus {\n  --bg-opacity: 1;\n  background-color: #f7fafc;\n  background-color: rgba(247, 250, 252, var(--bg-opacity));\n}\n\n.focus\\:bg-gray-200:focus {\n  --bg-opacity: 1;\n  background-color: #edf2f7;\n  background-color: rgba(237, 242, 247, var(--bg-opacity));\n}\n\n.focus\\:bg-gray-300:focus {\n  --bg-opacity: 1;\n  background-color: #e2e8f0;\n  background-color: rgba(226, 232, 240, var(--bg-opacity));\n}\n\n.focus\\:bg-gray-400:focus {\n  --bg-opacity: 1;\n  background-color: #cbd5e0;\n  background-color: rgba(203, 213, 224, var(--bg-opacity));\n}\n\n.focus\\:bg-gray-500:focus {\n  --bg-opacity: 1;\n  background-color: #a0aec0;\n  background-color: rgba(160, 174, 192, var(--bg-opacity));\n}\n\n.focus\\:bg-gray-600:focus {\n  --bg-opacity: 1;\n  background-color: #718096;\n  background-color: rgba(113, 128, 150, var(--bg-opacity));\n}\n\n.focus\\:bg-gray-700:focus {\n  --bg-opacity: 1;\n  background-color: #4a5568;\n  background-color: rgba(74, 85, 104, var(--bg-opacity));\n}\n\n.focus\\:bg-gray-800:focus {\n  --bg-opacity: 1;\n  background-color: #2d3748;\n  background-color: rgba(45, 55, 72, var(--bg-opacity));\n}\n\n.focus\\:bg-gray-900:focus {\n  --bg-opacity: 1;\n  background-color: #1a202c;\n  background-color: rgba(26, 32, 44, var(--bg-opacity));\n}\n\n.focus\\:bg-red-100:focus {\n  --bg-opacity: 1;\n  background-color: #fff5f5;\n  background-color: rgba(255, 245, 245, var(--bg-opacity));\n}\n\n.focus\\:bg-red-200:focus {\n  --bg-opacity: 1;\n  background-color: #fed7d7;\n  background-color: rgba(254, 215, 215, var(--bg-opacity));\n}\n\n.focus\\:bg-red-300:focus {\n  --bg-opacity: 1;\n  background-color: #feb2b2;\n  background-color: rgba(254, 178, 178, var(--bg-opacity));\n}\n\n.focus\\:bg-red-400:focus {\n  --bg-opacity: 1;\n  background-color: #fc8181;\n  background-color: rgba(252, 129, 129, var(--bg-opacity));\n}\n\n.focus\\:bg-red-500:focus {\n  --bg-opacity: 1;\n  background-color: #f56565;\n  background-color: rgba(245, 101, 101, var(--bg-opacity));\n}\n\n.focus\\:bg-red-600:focus {\n  --bg-opacity: 1;\n  background-color: #e53e3e;\n  background-color: rgba(229, 62, 62, var(--bg-opacity));\n}\n\n.focus\\:bg-red-700:focus {\n  --bg-opacity: 1;\n  background-color: #c53030;\n  background-color: rgba(197, 48, 48, var(--bg-opacity));\n}\n\n.focus\\:bg-red-800:focus {\n  --bg-opacity: 1;\n  background-color: #9b2c2c;\n  background-color: rgba(155, 44, 44, var(--bg-opacity));\n}\n\n.focus\\:bg-red-900:focus {\n  --bg-opacity: 1;\n  background-color: #742a2a;\n  background-color: rgba(116, 42, 42, var(--bg-opacity));\n}\n\n.focus\\:bg-orange-100:focus {\n  --bg-opacity: 1;\n  background-color: #fffaf0;\n  background-color: rgba(255, 250, 240, var(--bg-opacity));\n}\n\n.focus\\:bg-orange-200:focus {\n  --bg-opacity: 1;\n  background-color: #feebc8;\n  background-color: rgba(254, 235, 200, var(--bg-opacity));\n}\n\n.focus\\:bg-orange-300:focus {\n  --bg-opacity: 1;\n  background-color: #fbd38d;\n  background-color: rgba(251, 211, 141, var(--bg-opacity));\n}\n\n.focus\\:bg-orange-400:focus {\n  --bg-opacity: 1;\n  background-color: #f6ad55;\n  background-color: rgba(246, 173, 85, var(--bg-opacity));\n}\n\n.focus\\:bg-orange-500:focus {\n  --bg-opacity: 1;\n  background-color: #ed8936;\n  background-color: rgba(237, 137, 54, var(--bg-opacity));\n}\n\n.focus\\:bg-orange-600:focus {\n  --bg-opacity: 1;\n  background-color: #dd6b20;\n  background-color: rgba(221, 107, 32, var(--bg-opacity));\n}\n\n.focus\\:bg-orange-700:focus {\n  --bg-opacity: 1;\n  background-color: #c05621;\n  background-color: rgba(192, 86, 33, var(--bg-opacity));\n}\n\n.focus\\:bg-orange-800:focus {\n  --bg-opacity: 1;\n  background-color: #9c4221;\n  background-color: rgba(156, 66, 33, var(--bg-opacity));\n}\n\n.focus\\:bg-orange-900:focus {\n  --bg-opacity: 1;\n  background-color: #7b341e;\n  background-color: rgba(123, 52, 30, var(--bg-opacity));\n}\n\n.focus\\:bg-yellow-100:focus {\n  --bg-opacity: 1;\n  background-color: #fffff0;\n  background-color: rgba(255, 255, 240, var(--bg-opacity));\n}\n\n.focus\\:bg-yellow-200:focus {\n  --bg-opacity: 1;\n  background-color: #fefcbf;\n  background-color: rgba(254, 252, 191, var(--bg-opacity));\n}\n\n.focus\\:bg-yellow-300:focus {\n  --bg-opacity: 1;\n  background-color: #faf089;\n  background-color: rgba(250, 240, 137, var(--bg-opacity));\n}\n\n.focus\\:bg-yellow-400:focus {\n  --bg-opacity: 1;\n  background-color: #f6e05e;\n  background-color: rgba(246, 224, 94, var(--bg-opacity));\n}\n\n.focus\\:bg-yellow-500:focus {\n  --bg-opacity: 1;\n  background-color: #ecc94b;\n  background-color: rgba(236, 201, 75, var(--bg-opacity));\n}\n\n.focus\\:bg-yellow-600:focus {\n  --bg-opacity: 1;\n  background-color: #d69e2e;\n  background-color: rgba(214, 158, 46, var(--bg-opacity));\n}\n\n.focus\\:bg-yellow-700:focus {\n  --bg-opacity: 1;\n  background-color: #b7791f;\n  background-color: rgba(183, 121, 31, var(--bg-opacity));\n}\n\n.focus\\:bg-yellow-800:focus {\n  --bg-opacity: 1;\n  background-color: #975a16;\n  background-color: rgba(151, 90, 22, var(--bg-opacity));\n}\n\n.focus\\:bg-yellow-900:focus {\n  --bg-opacity: 1;\n  background-color: #744210;\n  background-color: rgba(116, 66, 16, var(--bg-opacity));\n}\n\n.focus\\:bg-green-100:focus {\n  --bg-opacity: 1;\n  background-color: #f0fff4;\n  background-color: rgba(240, 255, 244, var(--bg-opacity));\n}\n\n.focus\\:bg-green-200:focus {\n  --bg-opacity: 1;\n  background-color: #c6f6d5;\n  background-color: rgba(198, 246, 213, var(--bg-opacity));\n}\n\n.focus\\:bg-green-300:focus {\n  --bg-opacity: 1;\n  background-color: #9ae6b4;\n  background-color: rgba(154, 230, 180, var(--bg-opacity));\n}\n\n.focus\\:bg-green-400:focus {\n  --bg-opacity: 1;\n  background-color: #68d391;\n  background-color: rgba(104, 211, 145, var(--bg-opacity));\n}\n\n.focus\\:bg-green-500:focus {\n  --bg-opacity: 1;\n  background-color: #48bb78;\n  background-color: rgba(72, 187, 120, var(--bg-opacity));\n}\n\n.focus\\:bg-green-600:focus {\n  --bg-opacity: 1;\n  background-color: #38a169;\n  background-color: rgba(56, 161, 105, var(--bg-opacity));\n}\n\n.focus\\:bg-green-700:focus {\n  --bg-opacity: 1;\n  background-color: #2f855a;\n  background-color: rgba(47, 133, 90, var(--bg-opacity));\n}\n\n.focus\\:bg-green-800:focus {\n  --bg-opacity: 1;\n  background-color: #276749;\n  background-color: rgba(39, 103, 73, var(--bg-opacity));\n}\n\n.focus\\:bg-green-900:focus {\n  --bg-opacity: 1;\n  background-color: #22543d;\n  background-color: rgba(34, 84, 61, var(--bg-opacity));\n}\n\n.focus\\:bg-teal-100:focus {\n  --bg-opacity: 1;\n  background-color: #e6fffa;\n  background-color: rgba(230, 255, 250, var(--bg-opacity));\n}\n\n.focus\\:bg-teal-200:focus {\n  --bg-opacity: 1;\n  background-color: #b2f5ea;\n  background-color: rgba(178, 245, 234, var(--bg-opacity));\n}\n\n.focus\\:bg-teal-300:focus {\n  --bg-opacity: 1;\n  background-color: #81e6d9;\n  background-color: rgba(129, 230, 217, var(--bg-opacity));\n}\n\n.focus\\:bg-teal-400:focus {\n  --bg-opacity: 1;\n  background-color: #4fd1c5;\n  background-color: rgba(79, 209, 197, var(--bg-opacity));\n}\n\n.focus\\:bg-teal-500:focus {\n  --bg-opacity: 1;\n  background-color: #38b2ac;\n  background-color: rgba(56, 178, 172, var(--bg-opacity));\n}\n\n.focus\\:bg-teal-600:focus {\n  --bg-opacity: 1;\n  background-color: #319795;\n  background-color: rgba(49, 151, 149, var(--bg-opacity));\n}\n\n.focus\\:bg-teal-700:focus {\n  --bg-opacity: 1;\n  background-color: #2c7a7b;\n  background-color: rgba(44, 122, 123, var(--bg-opacity));\n}\n\n.focus\\:bg-teal-800:focus {\n  --bg-opacity: 1;\n  background-color: #285e61;\n  background-color: rgba(40, 94, 97, var(--bg-opacity));\n}\n\n.focus\\:bg-teal-900:focus {\n  --bg-opacity: 1;\n  background-color: #234e52;\n  background-color: rgba(35, 78, 82, var(--bg-opacity));\n}\n\n.focus\\:bg-blue-100:focus {\n  --bg-opacity: 1;\n  background-color: #ebf8ff;\n  background-color: rgba(235, 248, 255, var(--bg-opacity));\n}\n\n.focus\\:bg-blue-200:focus {\n  --bg-opacity: 1;\n  background-color: #bee3f8;\n  background-color: rgba(190, 227, 248, var(--bg-opacity));\n}\n\n.focus\\:bg-blue-300:focus {\n  --bg-opacity: 1;\n  background-color: #90cdf4;\n  background-color: rgba(144, 205, 244, var(--bg-opacity));\n}\n\n.focus\\:bg-blue-400:focus {\n  --bg-opacity: 1;\n  background-color: #63b3ed;\n  background-color: rgba(99, 179, 237, var(--bg-opacity));\n}\n\n.focus\\:bg-blue-500:focus {\n  --bg-opacity: 1;\n  background-color: #4299e1;\n  background-color: rgba(66, 153, 225, var(--bg-opacity));\n}\n\n.focus\\:bg-blue-600:focus {\n  --bg-opacity: 1;\n  background-color: #3182ce;\n  background-color: rgba(49, 130, 206, var(--bg-opacity));\n}\n\n.focus\\:bg-blue-700:focus {\n  --bg-opacity: 1;\n  background-color: #2b6cb0;\n  background-color: rgba(43, 108, 176, var(--bg-opacity));\n}\n\n.focus\\:bg-blue-800:focus {\n  --bg-opacity: 1;\n  background-color: #2c5282;\n  background-color: rgba(44, 82, 130, var(--bg-opacity));\n}\n\n.focus\\:bg-blue-900:focus {\n  --bg-opacity: 1;\n  background-color: #2a4365;\n  background-color: rgba(42, 67, 101, var(--bg-opacity));\n}\n\n.focus\\:bg-indigo-100:focus {\n  --bg-opacity: 1;\n  background-color: #ebf4ff;\n  background-color: rgba(235, 244, 255, var(--bg-opacity));\n}\n\n.focus\\:bg-indigo-200:focus {\n  --bg-opacity: 1;\n  background-color: #c3dafe;\n  background-color: rgba(195, 218, 254, var(--bg-opacity));\n}\n\n.focus\\:bg-indigo-300:focus {\n  --bg-opacity: 1;\n  background-color: #a3bffa;\n  background-color: rgba(163, 191, 250, var(--bg-opacity));\n}\n\n.focus\\:bg-indigo-400:focus {\n  --bg-opacity: 1;\n  background-color: #7f9cf5;\n  background-color: rgba(127, 156, 245, var(--bg-opacity));\n}\n\n.focus\\:bg-indigo-500:focus {\n  --bg-opacity: 1;\n  background-color: #667eea;\n  background-color: rgba(102, 126, 234, var(--bg-opacity));\n}\n\n.focus\\:bg-indigo-600:focus {\n  --bg-opacity: 1;\n  background-color: #5a67d8;\n  background-color: rgba(90, 103, 216, var(--bg-opacity));\n}\n\n.focus\\:bg-indigo-700:focus {\n  --bg-opacity: 1;\n  background-color: #4c51bf;\n  background-color: rgba(76, 81, 191, var(--bg-opacity));\n}\n\n.focus\\:bg-indigo-800:focus {\n  --bg-opacity: 1;\n  background-color: #434190;\n  background-color: rgba(67, 65, 144, var(--bg-opacity));\n}\n\n.focus\\:bg-indigo-900:focus {\n  --bg-opacity: 1;\n  background-color: #3c366b;\n  background-color: rgba(60, 54, 107, var(--bg-opacity));\n}\n\n.focus\\:bg-purple-100:focus {\n  --bg-opacity: 1;\n  background-color: #faf5ff;\n  background-color: rgba(250, 245, 255, var(--bg-opacity));\n}\n\n.focus\\:bg-purple-200:focus {\n  --bg-opacity: 1;\n  background-color: #e9d8fd;\n  background-color: rgba(233, 216, 253, var(--bg-opacity));\n}\n\n.focus\\:bg-purple-300:focus {\n  --bg-opacity: 1;\n  background-color: #d6bcfa;\n  background-color: rgba(214, 188, 250, var(--bg-opacity));\n}\n\n.focus\\:bg-purple-400:focus {\n  --bg-opacity: 1;\n  background-color: #b794f4;\n  background-color: rgba(183, 148, 244, var(--bg-opacity));\n}\n\n.focus\\:bg-purple-500:focus {\n  --bg-opacity: 1;\n  background-color: #9f7aea;\n  background-color: rgba(159, 122, 234, var(--bg-opacity));\n}\n\n.focus\\:bg-purple-600:focus {\n  --bg-opacity: 1;\n  background-color: #805ad5;\n  background-color: rgba(128, 90, 213, var(--bg-opacity));\n}\n\n.focus\\:bg-purple-700:focus {\n  --bg-opacity: 1;\n  background-color: #6b46c1;\n  background-color: rgba(107, 70, 193, var(--bg-opacity));\n}\n\n.focus\\:bg-purple-800:focus {\n  --bg-opacity: 1;\n  background-color: #553c9a;\n  background-color: rgba(85, 60, 154, var(--bg-opacity));\n}\n\n.focus\\:bg-purple-900:focus {\n  --bg-opacity: 1;\n  background-color: #44337a;\n  background-color: rgba(68, 51, 122, var(--bg-opacity));\n}\n\n.focus\\:bg-pink-100:focus {\n  --bg-opacity: 1;\n  background-color: #fff5f7;\n  background-color: rgba(255, 245, 247, var(--bg-opacity));\n}\n\n.focus\\:bg-pink-200:focus {\n  --bg-opacity: 1;\n  background-color: #fed7e2;\n  background-color: rgba(254, 215, 226, var(--bg-opacity));\n}\n\n.focus\\:bg-pink-300:focus {\n  --bg-opacity: 1;\n  background-color: #fbb6ce;\n  background-color: rgba(251, 182, 206, var(--bg-opacity));\n}\n\n.focus\\:bg-pink-400:focus {\n  --bg-opacity: 1;\n  background-color: #f687b3;\n  background-color: rgba(246, 135, 179, var(--bg-opacity));\n}\n\n.focus\\:bg-pink-500:focus {\n  --bg-opacity: 1;\n  background-color: #ed64a6;\n  background-color: rgba(237, 100, 166, var(--bg-opacity));\n}\n\n.focus\\:bg-pink-600:focus {\n  --bg-opacity: 1;\n  background-color: #d53f8c;\n  background-color: rgba(213, 63, 140, var(--bg-opacity));\n}\n\n.focus\\:bg-pink-700:focus {\n  --bg-opacity: 1;\n  background-color: #b83280;\n  background-color: rgba(184, 50, 128, var(--bg-opacity));\n}\n\n.focus\\:bg-pink-800:focus {\n  --bg-opacity: 1;\n  background-color: #97266d;\n  background-color: rgba(151, 38, 109, var(--bg-opacity));\n}\n\n.focus\\:bg-pink-900:focus {\n  --bg-opacity: 1;\n  background-color: #702459;\n  background-color: rgba(112, 36, 89, var(--bg-opacity));\n}\n\n.focus\\:bg-grayscale-80:focus {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 8%);\n  background-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--bg-opacity));\n}\n\n.focus\\:bg-grayscale-100:focus {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 10%);\n  background-color: rgba(25.5, 25.5, 25.5, var(--bg-opacity));\n}\n\n.focus\\:bg-grayscale-200:focus {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 20%);\n  background-color: rgba(51, 51, 51, var(--bg-opacity));\n}\n\n.focus\\:bg-grayscale-300:focus {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 30%);\n  background-color: rgba(76.5, 76.5, 76.5, var(--bg-opacity));\n}\n\n.focus\\:bg-grayscale-400:focus {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 40%);\n  background-color: rgba(102, 102, 102, var(--bg-opacity));\n}\n\n.focus\\:bg-grayscale-500:focus {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 50%);\n  background-color: rgba(127.5, 127.5, 127.5, var(--bg-opacity));\n}\n\n.focus\\:bg-grayscale-600:focus {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 60%);\n  background-color: rgba(153, 153, 153, var(--bg-opacity));\n}\n\n.focus\\:bg-grayscale-700:focus {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 70%);\n  background-color: rgba(178.5, 178.5, 178.5, var(--bg-opacity));\n}\n\n.focus\\:bg-grayscale-800:focus {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 80%);\n  background-color: rgba(204, 204, 204, var(--bg-opacity));\n}\n\n.focus\\:bg-grayscale-840:focus {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 84%);\n  background-color: rgba(214.2, 214.2, 214.2, var(--bg-opacity));\n}\n\n.focus\\:bg-grayscale-870:focus {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 87%);\n  background-color: rgba(221.85, 221.85, 221.85, var(--bg-opacity));\n}\n\n.focus\\:bg-grayscale-900:focus {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 90%);\n  background-color: rgba(229.5, 229.5, 229.5, var(--bg-opacity));\n}\n\n.focus\\:bg-grayscale-930:focus {\n  --bg-opacity: 1;\n  background-color: hsl(0, 0%, 93%);\n  background-color: rgba(237.15, 237.15, 237.15, var(--bg-opacity));\n}\n\n.focus\\:bg-primary:focus {\n  --bg-opacity: 1;\n  background-color: hsl(210, 100%, 52%);\n  background-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--bg-opacity));\n}\n\n.focus\\:bg-background-main:focus {\n  background-color: var(--main-background);\n}\n\n.focus\\:bg-background-secondary:focus {\n  background-color: var(--secondary-background);\n}\n\n.focus\\:bg-foreground:focus {\n  background-color: var(--foreground);\n}\n\n.focus\\:bg-panels-bg:focus {\n  background-color: var(--panels-background);\n}\n\n.bg-none {\n  background-image: none;\n}\n\n.bg-gradient-to-t {\n  background-image: linear-gradient(to top, var(--gradient-color-stops));\n}\n\n.bg-gradient-to-tr {\n  background-image: linear-gradient(to top right, var(--gradient-color-stops));\n}\n\n.bg-gradient-to-r {\n  background-image: linear-gradient(to right, var(--gradient-color-stops));\n}\n\n.bg-gradient-to-br {\n  background-image: linear-gradient(to bottom right, var(--gradient-color-stops));\n}\n\n.bg-gradient-to-b {\n  background-image: linear-gradient(to bottom, var(--gradient-color-stops));\n}\n\n.bg-gradient-to-bl {\n  background-image: linear-gradient(to bottom left, var(--gradient-color-stops));\n}\n\n.bg-gradient-to-l {\n  background-image: linear-gradient(to left, var(--gradient-color-stops));\n}\n\n.bg-gradient-to-tl {\n  background-image: linear-gradient(to top left, var(--gradient-color-stops));\n}\n\n.from-transparent {\n  --gradient-from-color: transparent;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n}\n\n.from-current {\n  --gradient-from-color: currentColor;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.from-black {\n  --gradient-from-color: #000;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n}\n\n.from-white {\n  --gradient-from-color: #fff;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.from-gray-100 {\n  --gradient-from-color: #f7fafc;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n}\n\n.from-gray-200 {\n  --gradient-from-color: #edf2f7;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n}\n\n.from-gray-300 {\n  --gradient-from-color: #e2e8f0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n}\n\n.from-gray-400 {\n  --gradient-from-color: #cbd5e0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n}\n\n.from-gray-500 {\n  --gradient-from-color: #a0aec0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n}\n\n.from-gray-600 {\n  --gradient-from-color: #718096;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n}\n\n.from-gray-700 {\n  --gradient-from-color: #4a5568;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n}\n\n.from-gray-800 {\n  --gradient-from-color: #2d3748;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n}\n\n.from-gray-900 {\n  --gradient-from-color: #1a202c;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n}\n\n.from-red-100 {\n  --gradient-from-color: #fff5f5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n}\n\n.from-red-200 {\n  --gradient-from-color: #fed7d7;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n}\n\n.from-red-300 {\n  --gradient-from-color: #feb2b2;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n}\n\n.from-red-400 {\n  --gradient-from-color: #fc8181;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n}\n\n.from-red-500 {\n  --gradient-from-color: #f56565;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n}\n\n.from-red-600 {\n  --gradient-from-color: #e53e3e;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n}\n\n.from-red-700 {\n  --gradient-from-color: #c53030;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n}\n\n.from-red-800 {\n  --gradient-from-color: #9b2c2c;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n}\n\n.from-red-900 {\n  --gradient-from-color: #742a2a;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n}\n\n.from-orange-100 {\n  --gradient-from-color: #fffaf0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n}\n\n.from-orange-200 {\n  --gradient-from-color: #feebc8;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n}\n\n.from-orange-300 {\n  --gradient-from-color: #fbd38d;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n}\n\n.from-orange-400 {\n  --gradient-from-color: #f6ad55;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n}\n\n.from-orange-500 {\n  --gradient-from-color: #ed8936;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n}\n\n.from-orange-600 {\n  --gradient-from-color: #dd6b20;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n}\n\n.from-orange-700 {\n  --gradient-from-color: #c05621;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n}\n\n.from-orange-800 {\n  --gradient-from-color: #9c4221;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n}\n\n.from-orange-900 {\n  --gradient-from-color: #7b341e;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n}\n\n.from-yellow-100 {\n  --gradient-from-color: #fffff0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n}\n\n.from-yellow-200 {\n  --gradient-from-color: #fefcbf;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n}\n\n.from-yellow-300 {\n  --gradient-from-color: #faf089;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n}\n\n.from-yellow-400 {\n  --gradient-from-color: #f6e05e;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n}\n\n.from-yellow-500 {\n  --gradient-from-color: #ecc94b;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n}\n\n.from-yellow-600 {\n  --gradient-from-color: #d69e2e;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n}\n\n.from-yellow-700 {\n  --gradient-from-color: #b7791f;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n}\n\n.from-yellow-800 {\n  --gradient-from-color: #975a16;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n}\n\n.from-yellow-900 {\n  --gradient-from-color: #744210;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n}\n\n.from-green-100 {\n  --gradient-from-color: #f0fff4;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n}\n\n.from-green-200 {\n  --gradient-from-color: #c6f6d5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n}\n\n.from-green-300 {\n  --gradient-from-color: #9ae6b4;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n}\n\n.from-green-400 {\n  --gradient-from-color: #68d391;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n}\n\n.from-green-500 {\n  --gradient-from-color: #48bb78;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n}\n\n.from-green-600 {\n  --gradient-from-color: #38a169;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n}\n\n.from-green-700 {\n  --gradient-from-color: #2f855a;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n}\n\n.from-green-800 {\n  --gradient-from-color: #276749;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n}\n\n.from-green-900 {\n  --gradient-from-color: #22543d;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n}\n\n.from-teal-100 {\n  --gradient-from-color: #e6fffa;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n}\n\n.from-teal-200 {\n  --gradient-from-color: #b2f5ea;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n}\n\n.from-teal-300 {\n  --gradient-from-color: #81e6d9;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n}\n\n.from-teal-400 {\n  --gradient-from-color: #4fd1c5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n}\n\n.from-teal-500 {\n  --gradient-from-color: #38b2ac;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n}\n\n.from-teal-600 {\n  --gradient-from-color: #319795;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n}\n\n.from-teal-700 {\n  --gradient-from-color: #2c7a7b;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n}\n\n.from-teal-800 {\n  --gradient-from-color: #285e61;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n}\n\n.from-teal-900 {\n  --gradient-from-color: #234e52;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n}\n\n.from-blue-100 {\n  --gradient-from-color: #ebf8ff;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n}\n\n.from-blue-200 {\n  --gradient-from-color: #bee3f8;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n}\n\n.from-blue-300 {\n  --gradient-from-color: #90cdf4;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n}\n\n.from-blue-400 {\n  --gradient-from-color: #63b3ed;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n}\n\n.from-blue-500 {\n  --gradient-from-color: #4299e1;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n}\n\n.from-blue-600 {\n  --gradient-from-color: #3182ce;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n}\n\n.from-blue-700 {\n  --gradient-from-color: #2b6cb0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n}\n\n.from-blue-800 {\n  --gradient-from-color: #2c5282;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n}\n\n.from-blue-900 {\n  --gradient-from-color: #2a4365;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n}\n\n.from-indigo-100 {\n  --gradient-from-color: #ebf4ff;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n}\n\n.from-indigo-200 {\n  --gradient-from-color: #c3dafe;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n}\n\n.from-indigo-300 {\n  --gradient-from-color: #a3bffa;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n}\n\n.from-indigo-400 {\n  --gradient-from-color: #7f9cf5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n}\n\n.from-indigo-500 {\n  --gradient-from-color: #667eea;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n}\n\n.from-indigo-600 {\n  --gradient-from-color: #5a67d8;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n}\n\n.from-indigo-700 {\n  --gradient-from-color: #4c51bf;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n}\n\n.from-indigo-800 {\n  --gradient-from-color: #434190;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n}\n\n.from-indigo-900 {\n  --gradient-from-color: #3c366b;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n}\n\n.from-purple-100 {\n  --gradient-from-color: #faf5ff;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n}\n\n.from-purple-200 {\n  --gradient-from-color: #e9d8fd;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n}\n\n.from-purple-300 {\n  --gradient-from-color: #d6bcfa;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n}\n\n.from-purple-400 {\n  --gradient-from-color: #b794f4;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n}\n\n.from-purple-500 {\n  --gradient-from-color: #9f7aea;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n}\n\n.from-purple-600 {\n  --gradient-from-color: #805ad5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n}\n\n.from-purple-700 {\n  --gradient-from-color: #6b46c1;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n}\n\n.from-purple-800 {\n  --gradient-from-color: #553c9a;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n}\n\n.from-purple-900 {\n  --gradient-from-color: #44337a;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n}\n\n.from-pink-100 {\n  --gradient-from-color: #fff5f7;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n}\n\n.from-pink-200 {\n  --gradient-from-color: #fed7e2;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n}\n\n.from-pink-300 {\n  --gradient-from-color: #fbb6ce;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n}\n\n.from-pink-400 {\n  --gradient-from-color: #f687b3;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n}\n\n.from-pink-500 {\n  --gradient-from-color: #ed64a6;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n}\n\n.from-pink-600 {\n  --gradient-from-color: #d53f8c;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n}\n\n.from-pink-700 {\n  --gradient-from-color: #b83280;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n}\n\n.from-pink-800 {\n  --gradient-from-color: #97266d;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n}\n\n.from-pink-900 {\n  --gradient-from-color: #702459;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n}\n\n.from-grayscale-80 {\n  --gradient-from-color: hsl(0, 0%, 8%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n}\n\n.from-grayscale-100 {\n  --gradient-from-color: hsl(0, 0%, 10%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n}\n\n.from-grayscale-200 {\n  --gradient-from-color: hsl(0, 0%, 20%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n}\n\n.from-grayscale-300 {\n  --gradient-from-color: hsl(0, 0%, 30%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n}\n\n.from-grayscale-400 {\n  --gradient-from-color: hsl(0, 0%, 40%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n}\n\n.from-grayscale-500 {\n  --gradient-from-color: hsl(0, 0%, 50%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n}\n\n.from-grayscale-600 {\n  --gradient-from-color: hsl(0, 0%, 60%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n}\n\n.from-grayscale-700 {\n  --gradient-from-color: hsl(0, 0%, 70%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n}\n\n.from-grayscale-800 {\n  --gradient-from-color: hsl(0, 0%, 80%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n}\n\n.from-grayscale-840 {\n  --gradient-from-color: hsl(0, 0%, 84%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n}\n\n.from-grayscale-870 {\n  --gradient-from-color: hsl(0, 0%, 87%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n}\n\n.from-grayscale-900 {\n  --gradient-from-color: hsl(0, 0%, 90%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n}\n\n.from-grayscale-930 {\n  --gradient-from-color: hsl(0, 0%, 93%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n}\n\n.from-primary {\n  --gradient-from-color: hsl(210, 100%, 52%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n}\n\n.from-background-main {\n  --gradient-from-color: var(--main-background);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.from-background-secondary {\n  --gradient-from-color: var(--secondary-background);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.from-foreground {\n  --gradient-from-color: var(--foreground);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.from-panels-bg {\n  --gradient-from-color: var(--panels-background);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.via-transparent {\n  --gradient-via-color: transparent;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n}\n\n.via-current {\n  --gradient-via-color: currentColor;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.via-black {\n  --gradient-via-color: #000;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n}\n\n.via-white {\n  --gradient-via-color: #fff;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.via-gray-100 {\n  --gradient-via-color: #f7fafc;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n}\n\n.via-gray-200 {\n  --gradient-via-color: #edf2f7;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n}\n\n.via-gray-300 {\n  --gradient-via-color: #e2e8f0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n}\n\n.via-gray-400 {\n  --gradient-via-color: #cbd5e0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n}\n\n.via-gray-500 {\n  --gradient-via-color: #a0aec0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n}\n\n.via-gray-600 {\n  --gradient-via-color: #718096;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n}\n\n.via-gray-700 {\n  --gradient-via-color: #4a5568;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n}\n\n.via-gray-800 {\n  --gradient-via-color: #2d3748;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n}\n\n.via-gray-900 {\n  --gradient-via-color: #1a202c;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n}\n\n.via-red-100 {\n  --gradient-via-color: #fff5f5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n}\n\n.via-red-200 {\n  --gradient-via-color: #fed7d7;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n}\n\n.via-red-300 {\n  --gradient-via-color: #feb2b2;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n}\n\n.via-red-400 {\n  --gradient-via-color: #fc8181;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n}\n\n.via-red-500 {\n  --gradient-via-color: #f56565;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n}\n\n.via-red-600 {\n  --gradient-via-color: #e53e3e;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n}\n\n.via-red-700 {\n  --gradient-via-color: #c53030;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n}\n\n.via-red-800 {\n  --gradient-via-color: #9b2c2c;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n}\n\n.via-red-900 {\n  --gradient-via-color: #742a2a;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n}\n\n.via-orange-100 {\n  --gradient-via-color: #fffaf0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n}\n\n.via-orange-200 {\n  --gradient-via-color: #feebc8;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n}\n\n.via-orange-300 {\n  --gradient-via-color: #fbd38d;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n}\n\n.via-orange-400 {\n  --gradient-via-color: #f6ad55;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n}\n\n.via-orange-500 {\n  --gradient-via-color: #ed8936;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n}\n\n.via-orange-600 {\n  --gradient-via-color: #dd6b20;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n}\n\n.via-orange-700 {\n  --gradient-via-color: #c05621;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n}\n\n.via-orange-800 {\n  --gradient-via-color: #9c4221;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n}\n\n.via-orange-900 {\n  --gradient-via-color: #7b341e;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n}\n\n.via-yellow-100 {\n  --gradient-via-color: #fffff0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n}\n\n.via-yellow-200 {\n  --gradient-via-color: #fefcbf;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n}\n\n.via-yellow-300 {\n  --gradient-via-color: #faf089;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n}\n\n.via-yellow-400 {\n  --gradient-via-color: #f6e05e;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n}\n\n.via-yellow-500 {\n  --gradient-via-color: #ecc94b;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n}\n\n.via-yellow-600 {\n  --gradient-via-color: #d69e2e;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n}\n\n.via-yellow-700 {\n  --gradient-via-color: #b7791f;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n}\n\n.via-yellow-800 {\n  --gradient-via-color: #975a16;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n}\n\n.via-yellow-900 {\n  --gradient-via-color: #744210;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n}\n\n.via-green-100 {\n  --gradient-via-color: #f0fff4;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n}\n\n.via-green-200 {\n  --gradient-via-color: #c6f6d5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n}\n\n.via-green-300 {\n  --gradient-via-color: #9ae6b4;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n}\n\n.via-green-400 {\n  --gradient-via-color: #68d391;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n}\n\n.via-green-500 {\n  --gradient-via-color: #48bb78;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n}\n\n.via-green-600 {\n  --gradient-via-color: #38a169;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n}\n\n.via-green-700 {\n  --gradient-via-color: #2f855a;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n}\n\n.via-green-800 {\n  --gradient-via-color: #276749;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n}\n\n.via-green-900 {\n  --gradient-via-color: #22543d;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n}\n\n.via-teal-100 {\n  --gradient-via-color: #e6fffa;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n}\n\n.via-teal-200 {\n  --gradient-via-color: #b2f5ea;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n}\n\n.via-teal-300 {\n  --gradient-via-color: #81e6d9;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n}\n\n.via-teal-400 {\n  --gradient-via-color: #4fd1c5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n}\n\n.via-teal-500 {\n  --gradient-via-color: #38b2ac;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n}\n\n.via-teal-600 {\n  --gradient-via-color: #319795;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n}\n\n.via-teal-700 {\n  --gradient-via-color: #2c7a7b;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n}\n\n.via-teal-800 {\n  --gradient-via-color: #285e61;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n}\n\n.via-teal-900 {\n  --gradient-via-color: #234e52;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n}\n\n.via-blue-100 {\n  --gradient-via-color: #ebf8ff;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n}\n\n.via-blue-200 {\n  --gradient-via-color: #bee3f8;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n}\n\n.via-blue-300 {\n  --gradient-via-color: #90cdf4;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n}\n\n.via-blue-400 {\n  --gradient-via-color: #63b3ed;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n}\n\n.via-blue-500 {\n  --gradient-via-color: #4299e1;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n}\n\n.via-blue-600 {\n  --gradient-via-color: #3182ce;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n}\n\n.via-blue-700 {\n  --gradient-via-color: #2b6cb0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n}\n\n.via-blue-800 {\n  --gradient-via-color: #2c5282;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n}\n\n.via-blue-900 {\n  --gradient-via-color: #2a4365;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n}\n\n.via-indigo-100 {\n  --gradient-via-color: #ebf4ff;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n}\n\n.via-indigo-200 {\n  --gradient-via-color: #c3dafe;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n}\n\n.via-indigo-300 {\n  --gradient-via-color: #a3bffa;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n}\n\n.via-indigo-400 {\n  --gradient-via-color: #7f9cf5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n}\n\n.via-indigo-500 {\n  --gradient-via-color: #667eea;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n}\n\n.via-indigo-600 {\n  --gradient-via-color: #5a67d8;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n}\n\n.via-indigo-700 {\n  --gradient-via-color: #4c51bf;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n}\n\n.via-indigo-800 {\n  --gradient-via-color: #434190;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n}\n\n.via-indigo-900 {\n  --gradient-via-color: #3c366b;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n}\n\n.via-purple-100 {\n  --gradient-via-color: #faf5ff;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n}\n\n.via-purple-200 {\n  --gradient-via-color: #e9d8fd;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n}\n\n.via-purple-300 {\n  --gradient-via-color: #d6bcfa;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n}\n\n.via-purple-400 {\n  --gradient-via-color: #b794f4;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n}\n\n.via-purple-500 {\n  --gradient-via-color: #9f7aea;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n}\n\n.via-purple-600 {\n  --gradient-via-color: #805ad5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n}\n\n.via-purple-700 {\n  --gradient-via-color: #6b46c1;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n}\n\n.via-purple-800 {\n  --gradient-via-color: #553c9a;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n}\n\n.via-purple-900 {\n  --gradient-via-color: #44337a;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n}\n\n.via-pink-100 {\n  --gradient-via-color: #fff5f7;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n}\n\n.via-pink-200 {\n  --gradient-via-color: #fed7e2;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n}\n\n.via-pink-300 {\n  --gradient-via-color: #fbb6ce;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n}\n\n.via-pink-400 {\n  --gradient-via-color: #f687b3;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n}\n\n.via-pink-500 {\n  --gradient-via-color: #ed64a6;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n}\n\n.via-pink-600 {\n  --gradient-via-color: #d53f8c;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n}\n\n.via-pink-700 {\n  --gradient-via-color: #b83280;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n}\n\n.via-pink-800 {\n  --gradient-via-color: #97266d;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n}\n\n.via-pink-900 {\n  --gradient-via-color: #702459;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n}\n\n.via-grayscale-80 {\n  --gradient-via-color: hsl(0, 0%, 8%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n}\n\n.via-grayscale-100 {\n  --gradient-via-color: hsl(0, 0%, 10%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n}\n\n.via-grayscale-200 {\n  --gradient-via-color: hsl(0, 0%, 20%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n}\n\n.via-grayscale-300 {\n  --gradient-via-color: hsl(0, 0%, 30%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n}\n\n.via-grayscale-400 {\n  --gradient-via-color: hsl(0, 0%, 40%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n}\n\n.via-grayscale-500 {\n  --gradient-via-color: hsl(0, 0%, 50%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n}\n\n.via-grayscale-600 {\n  --gradient-via-color: hsl(0, 0%, 60%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n}\n\n.via-grayscale-700 {\n  --gradient-via-color: hsl(0, 0%, 70%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n}\n\n.via-grayscale-800 {\n  --gradient-via-color: hsl(0, 0%, 80%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n}\n\n.via-grayscale-840 {\n  --gradient-via-color: hsl(0, 0%, 84%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n}\n\n.via-grayscale-870 {\n  --gradient-via-color: hsl(0, 0%, 87%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n}\n\n.via-grayscale-900 {\n  --gradient-via-color: hsl(0, 0%, 90%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n}\n\n.via-grayscale-930 {\n  --gradient-via-color: hsl(0, 0%, 93%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n}\n\n.via-primary {\n  --gradient-via-color: hsl(210, 100%, 52%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n}\n\n.via-background-main {\n  --gradient-via-color: var(--main-background);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.via-background-secondary {\n  --gradient-via-color: var(--secondary-background);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.via-foreground {\n  --gradient-via-color: var(--foreground);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.via-panels-bg {\n  --gradient-via-color: var(--panels-background);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.to-transparent {\n  --gradient-to-color: transparent;\n}\n\n.to-current {\n  --gradient-to-color: currentColor;\n}\n\n.to-black {\n  --gradient-to-color: #000;\n}\n\n.to-white {\n  --gradient-to-color: #fff;\n}\n\n.to-gray-100 {\n  --gradient-to-color: #f7fafc;\n}\n\n.to-gray-200 {\n  --gradient-to-color: #edf2f7;\n}\n\n.to-gray-300 {\n  --gradient-to-color: #e2e8f0;\n}\n\n.to-gray-400 {\n  --gradient-to-color: #cbd5e0;\n}\n\n.to-gray-500 {\n  --gradient-to-color: #a0aec0;\n}\n\n.to-gray-600 {\n  --gradient-to-color: #718096;\n}\n\n.to-gray-700 {\n  --gradient-to-color: #4a5568;\n}\n\n.to-gray-800 {\n  --gradient-to-color: #2d3748;\n}\n\n.to-gray-900 {\n  --gradient-to-color: #1a202c;\n}\n\n.to-red-100 {\n  --gradient-to-color: #fff5f5;\n}\n\n.to-red-200 {\n  --gradient-to-color: #fed7d7;\n}\n\n.to-red-300 {\n  --gradient-to-color: #feb2b2;\n}\n\n.to-red-400 {\n  --gradient-to-color: #fc8181;\n}\n\n.to-red-500 {\n  --gradient-to-color: #f56565;\n}\n\n.to-red-600 {\n  --gradient-to-color: #e53e3e;\n}\n\n.to-red-700 {\n  --gradient-to-color: #c53030;\n}\n\n.to-red-800 {\n  --gradient-to-color: #9b2c2c;\n}\n\n.to-red-900 {\n  --gradient-to-color: #742a2a;\n}\n\n.to-orange-100 {\n  --gradient-to-color: #fffaf0;\n}\n\n.to-orange-200 {\n  --gradient-to-color: #feebc8;\n}\n\n.to-orange-300 {\n  --gradient-to-color: #fbd38d;\n}\n\n.to-orange-400 {\n  --gradient-to-color: #f6ad55;\n}\n\n.to-orange-500 {\n  --gradient-to-color: #ed8936;\n}\n\n.to-orange-600 {\n  --gradient-to-color: #dd6b20;\n}\n\n.to-orange-700 {\n  --gradient-to-color: #c05621;\n}\n\n.to-orange-800 {\n  --gradient-to-color: #9c4221;\n}\n\n.to-orange-900 {\n  --gradient-to-color: #7b341e;\n}\n\n.to-yellow-100 {\n  --gradient-to-color: #fffff0;\n}\n\n.to-yellow-200 {\n  --gradient-to-color: #fefcbf;\n}\n\n.to-yellow-300 {\n  --gradient-to-color: #faf089;\n}\n\n.to-yellow-400 {\n  --gradient-to-color: #f6e05e;\n}\n\n.to-yellow-500 {\n  --gradient-to-color: #ecc94b;\n}\n\n.to-yellow-600 {\n  --gradient-to-color: #d69e2e;\n}\n\n.to-yellow-700 {\n  --gradient-to-color: #b7791f;\n}\n\n.to-yellow-800 {\n  --gradient-to-color: #975a16;\n}\n\n.to-yellow-900 {\n  --gradient-to-color: #744210;\n}\n\n.to-green-100 {\n  --gradient-to-color: #f0fff4;\n}\n\n.to-green-200 {\n  --gradient-to-color: #c6f6d5;\n}\n\n.to-green-300 {\n  --gradient-to-color: #9ae6b4;\n}\n\n.to-green-400 {\n  --gradient-to-color: #68d391;\n}\n\n.to-green-500 {\n  --gradient-to-color: #48bb78;\n}\n\n.to-green-600 {\n  --gradient-to-color: #38a169;\n}\n\n.to-green-700 {\n  --gradient-to-color: #2f855a;\n}\n\n.to-green-800 {\n  --gradient-to-color: #276749;\n}\n\n.to-green-900 {\n  --gradient-to-color: #22543d;\n}\n\n.to-teal-100 {\n  --gradient-to-color: #e6fffa;\n}\n\n.to-teal-200 {\n  --gradient-to-color: #b2f5ea;\n}\n\n.to-teal-300 {\n  --gradient-to-color: #81e6d9;\n}\n\n.to-teal-400 {\n  --gradient-to-color: #4fd1c5;\n}\n\n.to-teal-500 {\n  --gradient-to-color: #38b2ac;\n}\n\n.to-teal-600 {\n  --gradient-to-color: #319795;\n}\n\n.to-teal-700 {\n  --gradient-to-color: #2c7a7b;\n}\n\n.to-teal-800 {\n  --gradient-to-color: #285e61;\n}\n\n.to-teal-900 {\n  --gradient-to-color: #234e52;\n}\n\n.to-blue-100 {\n  --gradient-to-color: #ebf8ff;\n}\n\n.to-blue-200 {\n  --gradient-to-color: #bee3f8;\n}\n\n.to-blue-300 {\n  --gradient-to-color: #90cdf4;\n}\n\n.to-blue-400 {\n  --gradient-to-color: #63b3ed;\n}\n\n.to-blue-500 {\n  --gradient-to-color: #4299e1;\n}\n\n.to-blue-600 {\n  --gradient-to-color: #3182ce;\n}\n\n.to-blue-700 {\n  --gradient-to-color: #2b6cb0;\n}\n\n.to-blue-800 {\n  --gradient-to-color: #2c5282;\n}\n\n.to-blue-900 {\n  --gradient-to-color: #2a4365;\n}\n\n.to-indigo-100 {\n  --gradient-to-color: #ebf4ff;\n}\n\n.to-indigo-200 {\n  --gradient-to-color: #c3dafe;\n}\n\n.to-indigo-300 {\n  --gradient-to-color: #a3bffa;\n}\n\n.to-indigo-400 {\n  --gradient-to-color: #7f9cf5;\n}\n\n.to-indigo-500 {\n  --gradient-to-color: #667eea;\n}\n\n.to-indigo-600 {\n  --gradient-to-color: #5a67d8;\n}\n\n.to-indigo-700 {\n  --gradient-to-color: #4c51bf;\n}\n\n.to-indigo-800 {\n  --gradient-to-color: #434190;\n}\n\n.to-indigo-900 {\n  --gradient-to-color: #3c366b;\n}\n\n.to-purple-100 {\n  --gradient-to-color: #faf5ff;\n}\n\n.to-purple-200 {\n  --gradient-to-color: #e9d8fd;\n}\n\n.to-purple-300 {\n  --gradient-to-color: #d6bcfa;\n}\n\n.to-purple-400 {\n  --gradient-to-color: #b794f4;\n}\n\n.to-purple-500 {\n  --gradient-to-color: #9f7aea;\n}\n\n.to-purple-600 {\n  --gradient-to-color: #805ad5;\n}\n\n.to-purple-700 {\n  --gradient-to-color: #6b46c1;\n}\n\n.to-purple-800 {\n  --gradient-to-color: #553c9a;\n}\n\n.to-purple-900 {\n  --gradient-to-color: #44337a;\n}\n\n.to-pink-100 {\n  --gradient-to-color: #fff5f7;\n}\n\n.to-pink-200 {\n  --gradient-to-color: #fed7e2;\n}\n\n.to-pink-300 {\n  --gradient-to-color: #fbb6ce;\n}\n\n.to-pink-400 {\n  --gradient-to-color: #f687b3;\n}\n\n.to-pink-500 {\n  --gradient-to-color: #ed64a6;\n}\n\n.to-pink-600 {\n  --gradient-to-color: #d53f8c;\n}\n\n.to-pink-700 {\n  --gradient-to-color: #b83280;\n}\n\n.to-pink-800 {\n  --gradient-to-color: #97266d;\n}\n\n.to-pink-900 {\n  --gradient-to-color: #702459;\n}\n\n.to-grayscale-80 {\n  --gradient-to-color: hsl(0, 0%, 8%);\n}\n\n.to-grayscale-100 {\n  --gradient-to-color: hsl(0, 0%, 10%);\n}\n\n.to-grayscale-200 {\n  --gradient-to-color: hsl(0, 0%, 20%);\n}\n\n.to-grayscale-300 {\n  --gradient-to-color: hsl(0, 0%, 30%);\n}\n\n.to-grayscale-400 {\n  --gradient-to-color: hsl(0, 0%, 40%);\n}\n\n.to-grayscale-500 {\n  --gradient-to-color: hsl(0, 0%, 50%);\n}\n\n.to-grayscale-600 {\n  --gradient-to-color: hsl(0, 0%, 60%);\n}\n\n.to-grayscale-700 {\n  --gradient-to-color: hsl(0, 0%, 70%);\n}\n\n.to-grayscale-800 {\n  --gradient-to-color: hsl(0, 0%, 80%);\n}\n\n.to-grayscale-840 {\n  --gradient-to-color: hsl(0, 0%, 84%);\n}\n\n.to-grayscale-870 {\n  --gradient-to-color: hsl(0, 0%, 87%);\n}\n\n.to-grayscale-900 {\n  --gradient-to-color: hsl(0, 0%, 90%);\n}\n\n.to-grayscale-930 {\n  --gradient-to-color: hsl(0, 0%, 93%);\n}\n\n.to-primary {\n  --gradient-to-color: hsl(210, 100%, 52%);\n}\n\n.to-background-main {\n  --gradient-to-color: var(--main-background);\n}\n\n.to-background-secondary {\n  --gradient-to-color: var(--secondary-background);\n}\n\n.to-foreground {\n  --gradient-to-color: var(--foreground);\n}\n\n.to-panels-bg {\n  --gradient-to-color: var(--panels-background);\n}\n\n.hover\\:from-transparent:hover {\n  --gradient-from-color: transparent;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n}\n\n.hover\\:from-current:hover {\n  --gradient-from-color: currentColor;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.hover\\:from-black:hover {\n  --gradient-from-color: #000;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n}\n\n.hover\\:from-white:hover {\n  --gradient-from-color: #fff;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.hover\\:from-gray-100:hover {\n  --gradient-from-color: #f7fafc;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n}\n\n.hover\\:from-gray-200:hover {\n  --gradient-from-color: #edf2f7;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n}\n\n.hover\\:from-gray-300:hover {\n  --gradient-from-color: #e2e8f0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n}\n\n.hover\\:from-gray-400:hover {\n  --gradient-from-color: #cbd5e0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n}\n\n.hover\\:from-gray-500:hover {\n  --gradient-from-color: #a0aec0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n}\n\n.hover\\:from-gray-600:hover {\n  --gradient-from-color: #718096;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n}\n\n.hover\\:from-gray-700:hover {\n  --gradient-from-color: #4a5568;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n}\n\n.hover\\:from-gray-800:hover {\n  --gradient-from-color: #2d3748;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n}\n\n.hover\\:from-gray-900:hover {\n  --gradient-from-color: #1a202c;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n}\n\n.hover\\:from-red-100:hover {\n  --gradient-from-color: #fff5f5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n}\n\n.hover\\:from-red-200:hover {\n  --gradient-from-color: #fed7d7;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n}\n\n.hover\\:from-red-300:hover {\n  --gradient-from-color: #feb2b2;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n}\n\n.hover\\:from-red-400:hover {\n  --gradient-from-color: #fc8181;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n}\n\n.hover\\:from-red-500:hover {\n  --gradient-from-color: #f56565;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n}\n\n.hover\\:from-red-600:hover {\n  --gradient-from-color: #e53e3e;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n}\n\n.hover\\:from-red-700:hover {\n  --gradient-from-color: #c53030;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n}\n\n.hover\\:from-red-800:hover {\n  --gradient-from-color: #9b2c2c;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n}\n\n.hover\\:from-red-900:hover {\n  --gradient-from-color: #742a2a;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n}\n\n.hover\\:from-orange-100:hover {\n  --gradient-from-color: #fffaf0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n}\n\n.hover\\:from-orange-200:hover {\n  --gradient-from-color: #feebc8;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n}\n\n.hover\\:from-orange-300:hover {\n  --gradient-from-color: #fbd38d;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n}\n\n.hover\\:from-orange-400:hover {\n  --gradient-from-color: #f6ad55;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n}\n\n.hover\\:from-orange-500:hover {\n  --gradient-from-color: #ed8936;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n}\n\n.hover\\:from-orange-600:hover {\n  --gradient-from-color: #dd6b20;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n}\n\n.hover\\:from-orange-700:hover {\n  --gradient-from-color: #c05621;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n}\n\n.hover\\:from-orange-800:hover {\n  --gradient-from-color: #9c4221;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n}\n\n.hover\\:from-orange-900:hover {\n  --gradient-from-color: #7b341e;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n}\n\n.hover\\:from-yellow-100:hover {\n  --gradient-from-color: #fffff0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n}\n\n.hover\\:from-yellow-200:hover {\n  --gradient-from-color: #fefcbf;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n}\n\n.hover\\:from-yellow-300:hover {\n  --gradient-from-color: #faf089;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n}\n\n.hover\\:from-yellow-400:hover {\n  --gradient-from-color: #f6e05e;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n}\n\n.hover\\:from-yellow-500:hover {\n  --gradient-from-color: #ecc94b;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n}\n\n.hover\\:from-yellow-600:hover {\n  --gradient-from-color: #d69e2e;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n}\n\n.hover\\:from-yellow-700:hover {\n  --gradient-from-color: #b7791f;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n}\n\n.hover\\:from-yellow-800:hover {\n  --gradient-from-color: #975a16;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n}\n\n.hover\\:from-yellow-900:hover {\n  --gradient-from-color: #744210;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n}\n\n.hover\\:from-green-100:hover {\n  --gradient-from-color: #f0fff4;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n}\n\n.hover\\:from-green-200:hover {\n  --gradient-from-color: #c6f6d5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n}\n\n.hover\\:from-green-300:hover {\n  --gradient-from-color: #9ae6b4;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n}\n\n.hover\\:from-green-400:hover {\n  --gradient-from-color: #68d391;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n}\n\n.hover\\:from-green-500:hover {\n  --gradient-from-color: #48bb78;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n}\n\n.hover\\:from-green-600:hover {\n  --gradient-from-color: #38a169;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n}\n\n.hover\\:from-green-700:hover {\n  --gradient-from-color: #2f855a;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n}\n\n.hover\\:from-green-800:hover {\n  --gradient-from-color: #276749;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n}\n\n.hover\\:from-green-900:hover {\n  --gradient-from-color: #22543d;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n}\n\n.hover\\:from-teal-100:hover {\n  --gradient-from-color: #e6fffa;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n}\n\n.hover\\:from-teal-200:hover {\n  --gradient-from-color: #b2f5ea;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n}\n\n.hover\\:from-teal-300:hover {\n  --gradient-from-color: #81e6d9;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n}\n\n.hover\\:from-teal-400:hover {\n  --gradient-from-color: #4fd1c5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n}\n\n.hover\\:from-teal-500:hover {\n  --gradient-from-color: #38b2ac;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n}\n\n.hover\\:from-teal-600:hover {\n  --gradient-from-color: #319795;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n}\n\n.hover\\:from-teal-700:hover {\n  --gradient-from-color: #2c7a7b;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n}\n\n.hover\\:from-teal-800:hover {\n  --gradient-from-color: #285e61;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n}\n\n.hover\\:from-teal-900:hover {\n  --gradient-from-color: #234e52;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n}\n\n.hover\\:from-blue-100:hover {\n  --gradient-from-color: #ebf8ff;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n}\n\n.hover\\:from-blue-200:hover {\n  --gradient-from-color: #bee3f8;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n}\n\n.hover\\:from-blue-300:hover {\n  --gradient-from-color: #90cdf4;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n}\n\n.hover\\:from-blue-400:hover {\n  --gradient-from-color: #63b3ed;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n}\n\n.hover\\:from-blue-500:hover {\n  --gradient-from-color: #4299e1;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n}\n\n.hover\\:from-blue-600:hover {\n  --gradient-from-color: #3182ce;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n}\n\n.hover\\:from-blue-700:hover {\n  --gradient-from-color: #2b6cb0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n}\n\n.hover\\:from-blue-800:hover {\n  --gradient-from-color: #2c5282;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n}\n\n.hover\\:from-blue-900:hover {\n  --gradient-from-color: #2a4365;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n}\n\n.hover\\:from-indigo-100:hover {\n  --gradient-from-color: #ebf4ff;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n}\n\n.hover\\:from-indigo-200:hover {\n  --gradient-from-color: #c3dafe;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n}\n\n.hover\\:from-indigo-300:hover {\n  --gradient-from-color: #a3bffa;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n}\n\n.hover\\:from-indigo-400:hover {\n  --gradient-from-color: #7f9cf5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n}\n\n.hover\\:from-indigo-500:hover {\n  --gradient-from-color: #667eea;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n}\n\n.hover\\:from-indigo-600:hover {\n  --gradient-from-color: #5a67d8;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n}\n\n.hover\\:from-indigo-700:hover {\n  --gradient-from-color: #4c51bf;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n}\n\n.hover\\:from-indigo-800:hover {\n  --gradient-from-color: #434190;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n}\n\n.hover\\:from-indigo-900:hover {\n  --gradient-from-color: #3c366b;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n}\n\n.hover\\:from-purple-100:hover {\n  --gradient-from-color: #faf5ff;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n}\n\n.hover\\:from-purple-200:hover {\n  --gradient-from-color: #e9d8fd;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n}\n\n.hover\\:from-purple-300:hover {\n  --gradient-from-color: #d6bcfa;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n}\n\n.hover\\:from-purple-400:hover {\n  --gradient-from-color: #b794f4;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n}\n\n.hover\\:from-purple-500:hover {\n  --gradient-from-color: #9f7aea;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n}\n\n.hover\\:from-purple-600:hover {\n  --gradient-from-color: #805ad5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n}\n\n.hover\\:from-purple-700:hover {\n  --gradient-from-color: #6b46c1;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n}\n\n.hover\\:from-purple-800:hover {\n  --gradient-from-color: #553c9a;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n}\n\n.hover\\:from-purple-900:hover {\n  --gradient-from-color: #44337a;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n}\n\n.hover\\:from-pink-100:hover {\n  --gradient-from-color: #fff5f7;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n}\n\n.hover\\:from-pink-200:hover {\n  --gradient-from-color: #fed7e2;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n}\n\n.hover\\:from-pink-300:hover {\n  --gradient-from-color: #fbb6ce;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n}\n\n.hover\\:from-pink-400:hover {\n  --gradient-from-color: #f687b3;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n}\n\n.hover\\:from-pink-500:hover {\n  --gradient-from-color: #ed64a6;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n}\n\n.hover\\:from-pink-600:hover {\n  --gradient-from-color: #d53f8c;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n}\n\n.hover\\:from-pink-700:hover {\n  --gradient-from-color: #b83280;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n}\n\n.hover\\:from-pink-800:hover {\n  --gradient-from-color: #97266d;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n}\n\n.hover\\:from-pink-900:hover {\n  --gradient-from-color: #702459;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n}\n\n.hover\\:from-grayscale-80:hover {\n  --gradient-from-color: hsl(0, 0%, 8%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n}\n\n.hover\\:from-grayscale-100:hover {\n  --gradient-from-color: hsl(0, 0%, 10%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n}\n\n.hover\\:from-grayscale-200:hover {\n  --gradient-from-color: hsl(0, 0%, 20%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n}\n\n.hover\\:from-grayscale-300:hover {\n  --gradient-from-color: hsl(0, 0%, 30%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n}\n\n.hover\\:from-grayscale-400:hover {\n  --gradient-from-color: hsl(0, 0%, 40%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n}\n\n.hover\\:from-grayscale-500:hover {\n  --gradient-from-color: hsl(0, 0%, 50%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n}\n\n.hover\\:from-grayscale-600:hover {\n  --gradient-from-color: hsl(0, 0%, 60%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n}\n\n.hover\\:from-grayscale-700:hover {\n  --gradient-from-color: hsl(0, 0%, 70%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n}\n\n.hover\\:from-grayscale-800:hover {\n  --gradient-from-color: hsl(0, 0%, 80%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n}\n\n.hover\\:from-grayscale-840:hover {\n  --gradient-from-color: hsl(0, 0%, 84%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n}\n\n.hover\\:from-grayscale-870:hover {\n  --gradient-from-color: hsl(0, 0%, 87%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n}\n\n.hover\\:from-grayscale-900:hover {\n  --gradient-from-color: hsl(0, 0%, 90%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n}\n\n.hover\\:from-grayscale-930:hover {\n  --gradient-from-color: hsl(0, 0%, 93%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n}\n\n.hover\\:from-primary:hover {\n  --gradient-from-color: hsl(210, 100%, 52%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n}\n\n.hover\\:from-background-main:hover {\n  --gradient-from-color: var(--main-background);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.hover\\:from-background-secondary:hover {\n  --gradient-from-color: var(--secondary-background);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.hover\\:from-foreground:hover {\n  --gradient-from-color: var(--foreground);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.hover\\:from-panels-bg:hover {\n  --gradient-from-color: var(--panels-background);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.hover\\:via-transparent:hover {\n  --gradient-via-color: transparent;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n}\n\n.hover\\:via-current:hover {\n  --gradient-via-color: currentColor;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.hover\\:via-black:hover {\n  --gradient-via-color: #000;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n}\n\n.hover\\:via-white:hover {\n  --gradient-via-color: #fff;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.hover\\:via-gray-100:hover {\n  --gradient-via-color: #f7fafc;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n}\n\n.hover\\:via-gray-200:hover {\n  --gradient-via-color: #edf2f7;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n}\n\n.hover\\:via-gray-300:hover {\n  --gradient-via-color: #e2e8f0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n}\n\n.hover\\:via-gray-400:hover {\n  --gradient-via-color: #cbd5e0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n}\n\n.hover\\:via-gray-500:hover {\n  --gradient-via-color: #a0aec0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n}\n\n.hover\\:via-gray-600:hover {\n  --gradient-via-color: #718096;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n}\n\n.hover\\:via-gray-700:hover {\n  --gradient-via-color: #4a5568;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n}\n\n.hover\\:via-gray-800:hover {\n  --gradient-via-color: #2d3748;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n}\n\n.hover\\:via-gray-900:hover {\n  --gradient-via-color: #1a202c;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n}\n\n.hover\\:via-red-100:hover {\n  --gradient-via-color: #fff5f5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n}\n\n.hover\\:via-red-200:hover {\n  --gradient-via-color: #fed7d7;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n}\n\n.hover\\:via-red-300:hover {\n  --gradient-via-color: #feb2b2;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n}\n\n.hover\\:via-red-400:hover {\n  --gradient-via-color: #fc8181;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n}\n\n.hover\\:via-red-500:hover {\n  --gradient-via-color: #f56565;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n}\n\n.hover\\:via-red-600:hover {\n  --gradient-via-color: #e53e3e;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n}\n\n.hover\\:via-red-700:hover {\n  --gradient-via-color: #c53030;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n}\n\n.hover\\:via-red-800:hover {\n  --gradient-via-color: #9b2c2c;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n}\n\n.hover\\:via-red-900:hover {\n  --gradient-via-color: #742a2a;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n}\n\n.hover\\:via-orange-100:hover {\n  --gradient-via-color: #fffaf0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n}\n\n.hover\\:via-orange-200:hover {\n  --gradient-via-color: #feebc8;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n}\n\n.hover\\:via-orange-300:hover {\n  --gradient-via-color: #fbd38d;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n}\n\n.hover\\:via-orange-400:hover {\n  --gradient-via-color: #f6ad55;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n}\n\n.hover\\:via-orange-500:hover {\n  --gradient-via-color: #ed8936;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n}\n\n.hover\\:via-orange-600:hover {\n  --gradient-via-color: #dd6b20;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n}\n\n.hover\\:via-orange-700:hover {\n  --gradient-via-color: #c05621;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n}\n\n.hover\\:via-orange-800:hover {\n  --gradient-via-color: #9c4221;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n}\n\n.hover\\:via-orange-900:hover {\n  --gradient-via-color: #7b341e;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n}\n\n.hover\\:via-yellow-100:hover {\n  --gradient-via-color: #fffff0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n}\n\n.hover\\:via-yellow-200:hover {\n  --gradient-via-color: #fefcbf;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n}\n\n.hover\\:via-yellow-300:hover {\n  --gradient-via-color: #faf089;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n}\n\n.hover\\:via-yellow-400:hover {\n  --gradient-via-color: #f6e05e;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n}\n\n.hover\\:via-yellow-500:hover {\n  --gradient-via-color: #ecc94b;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n}\n\n.hover\\:via-yellow-600:hover {\n  --gradient-via-color: #d69e2e;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n}\n\n.hover\\:via-yellow-700:hover {\n  --gradient-via-color: #b7791f;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n}\n\n.hover\\:via-yellow-800:hover {\n  --gradient-via-color: #975a16;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n}\n\n.hover\\:via-yellow-900:hover {\n  --gradient-via-color: #744210;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n}\n\n.hover\\:via-green-100:hover {\n  --gradient-via-color: #f0fff4;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n}\n\n.hover\\:via-green-200:hover {\n  --gradient-via-color: #c6f6d5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n}\n\n.hover\\:via-green-300:hover {\n  --gradient-via-color: #9ae6b4;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n}\n\n.hover\\:via-green-400:hover {\n  --gradient-via-color: #68d391;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n}\n\n.hover\\:via-green-500:hover {\n  --gradient-via-color: #48bb78;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n}\n\n.hover\\:via-green-600:hover {\n  --gradient-via-color: #38a169;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n}\n\n.hover\\:via-green-700:hover {\n  --gradient-via-color: #2f855a;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n}\n\n.hover\\:via-green-800:hover {\n  --gradient-via-color: #276749;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n}\n\n.hover\\:via-green-900:hover {\n  --gradient-via-color: #22543d;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n}\n\n.hover\\:via-teal-100:hover {\n  --gradient-via-color: #e6fffa;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n}\n\n.hover\\:via-teal-200:hover {\n  --gradient-via-color: #b2f5ea;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n}\n\n.hover\\:via-teal-300:hover {\n  --gradient-via-color: #81e6d9;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n}\n\n.hover\\:via-teal-400:hover {\n  --gradient-via-color: #4fd1c5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n}\n\n.hover\\:via-teal-500:hover {\n  --gradient-via-color: #38b2ac;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n}\n\n.hover\\:via-teal-600:hover {\n  --gradient-via-color: #319795;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n}\n\n.hover\\:via-teal-700:hover {\n  --gradient-via-color: #2c7a7b;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n}\n\n.hover\\:via-teal-800:hover {\n  --gradient-via-color: #285e61;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n}\n\n.hover\\:via-teal-900:hover {\n  --gradient-via-color: #234e52;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n}\n\n.hover\\:via-blue-100:hover {\n  --gradient-via-color: #ebf8ff;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n}\n\n.hover\\:via-blue-200:hover {\n  --gradient-via-color: #bee3f8;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n}\n\n.hover\\:via-blue-300:hover {\n  --gradient-via-color: #90cdf4;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n}\n\n.hover\\:via-blue-400:hover {\n  --gradient-via-color: #63b3ed;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n}\n\n.hover\\:via-blue-500:hover {\n  --gradient-via-color: #4299e1;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n}\n\n.hover\\:via-blue-600:hover {\n  --gradient-via-color: #3182ce;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n}\n\n.hover\\:via-blue-700:hover {\n  --gradient-via-color: #2b6cb0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n}\n\n.hover\\:via-blue-800:hover {\n  --gradient-via-color: #2c5282;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n}\n\n.hover\\:via-blue-900:hover {\n  --gradient-via-color: #2a4365;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n}\n\n.hover\\:via-indigo-100:hover {\n  --gradient-via-color: #ebf4ff;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n}\n\n.hover\\:via-indigo-200:hover {\n  --gradient-via-color: #c3dafe;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n}\n\n.hover\\:via-indigo-300:hover {\n  --gradient-via-color: #a3bffa;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n}\n\n.hover\\:via-indigo-400:hover {\n  --gradient-via-color: #7f9cf5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n}\n\n.hover\\:via-indigo-500:hover {\n  --gradient-via-color: #667eea;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n}\n\n.hover\\:via-indigo-600:hover {\n  --gradient-via-color: #5a67d8;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n}\n\n.hover\\:via-indigo-700:hover {\n  --gradient-via-color: #4c51bf;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n}\n\n.hover\\:via-indigo-800:hover {\n  --gradient-via-color: #434190;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n}\n\n.hover\\:via-indigo-900:hover {\n  --gradient-via-color: #3c366b;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n}\n\n.hover\\:via-purple-100:hover {\n  --gradient-via-color: #faf5ff;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n}\n\n.hover\\:via-purple-200:hover {\n  --gradient-via-color: #e9d8fd;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n}\n\n.hover\\:via-purple-300:hover {\n  --gradient-via-color: #d6bcfa;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n}\n\n.hover\\:via-purple-400:hover {\n  --gradient-via-color: #b794f4;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n}\n\n.hover\\:via-purple-500:hover {\n  --gradient-via-color: #9f7aea;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n}\n\n.hover\\:via-purple-600:hover {\n  --gradient-via-color: #805ad5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n}\n\n.hover\\:via-purple-700:hover {\n  --gradient-via-color: #6b46c1;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n}\n\n.hover\\:via-purple-800:hover {\n  --gradient-via-color: #553c9a;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n}\n\n.hover\\:via-purple-900:hover {\n  --gradient-via-color: #44337a;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n}\n\n.hover\\:via-pink-100:hover {\n  --gradient-via-color: #fff5f7;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n}\n\n.hover\\:via-pink-200:hover {\n  --gradient-via-color: #fed7e2;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n}\n\n.hover\\:via-pink-300:hover {\n  --gradient-via-color: #fbb6ce;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n}\n\n.hover\\:via-pink-400:hover {\n  --gradient-via-color: #f687b3;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n}\n\n.hover\\:via-pink-500:hover {\n  --gradient-via-color: #ed64a6;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n}\n\n.hover\\:via-pink-600:hover {\n  --gradient-via-color: #d53f8c;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n}\n\n.hover\\:via-pink-700:hover {\n  --gradient-via-color: #b83280;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n}\n\n.hover\\:via-pink-800:hover {\n  --gradient-via-color: #97266d;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n}\n\n.hover\\:via-pink-900:hover {\n  --gradient-via-color: #702459;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n}\n\n.hover\\:via-grayscale-80:hover {\n  --gradient-via-color: hsl(0, 0%, 8%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n}\n\n.hover\\:via-grayscale-100:hover {\n  --gradient-via-color: hsl(0, 0%, 10%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n}\n\n.hover\\:via-grayscale-200:hover {\n  --gradient-via-color: hsl(0, 0%, 20%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n}\n\n.hover\\:via-grayscale-300:hover {\n  --gradient-via-color: hsl(0, 0%, 30%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n}\n\n.hover\\:via-grayscale-400:hover {\n  --gradient-via-color: hsl(0, 0%, 40%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n}\n\n.hover\\:via-grayscale-500:hover {\n  --gradient-via-color: hsl(0, 0%, 50%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n}\n\n.hover\\:via-grayscale-600:hover {\n  --gradient-via-color: hsl(0, 0%, 60%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n}\n\n.hover\\:via-grayscale-700:hover {\n  --gradient-via-color: hsl(0, 0%, 70%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n}\n\n.hover\\:via-grayscale-800:hover {\n  --gradient-via-color: hsl(0, 0%, 80%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n}\n\n.hover\\:via-grayscale-840:hover {\n  --gradient-via-color: hsl(0, 0%, 84%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n}\n\n.hover\\:via-grayscale-870:hover {\n  --gradient-via-color: hsl(0, 0%, 87%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n}\n\n.hover\\:via-grayscale-900:hover {\n  --gradient-via-color: hsl(0, 0%, 90%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n}\n\n.hover\\:via-grayscale-930:hover {\n  --gradient-via-color: hsl(0, 0%, 93%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n}\n\n.hover\\:via-primary:hover {\n  --gradient-via-color: hsl(210, 100%, 52%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n}\n\n.hover\\:via-background-main:hover {\n  --gradient-via-color: var(--main-background);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.hover\\:via-background-secondary:hover {\n  --gradient-via-color: var(--secondary-background);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.hover\\:via-foreground:hover {\n  --gradient-via-color: var(--foreground);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.hover\\:via-panels-bg:hover {\n  --gradient-via-color: var(--panels-background);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.hover\\:to-transparent:hover {\n  --gradient-to-color: transparent;\n}\n\n.hover\\:to-current:hover {\n  --gradient-to-color: currentColor;\n}\n\n.hover\\:to-black:hover {\n  --gradient-to-color: #000;\n}\n\n.hover\\:to-white:hover {\n  --gradient-to-color: #fff;\n}\n\n.hover\\:to-gray-100:hover {\n  --gradient-to-color: #f7fafc;\n}\n\n.hover\\:to-gray-200:hover {\n  --gradient-to-color: #edf2f7;\n}\n\n.hover\\:to-gray-300:hover {\n  --gradient-to-color: #e2e8f0;\n}\n\n.hover\\:to-gray-400:hover {\n  --gradient-to-color: #cbd5e0;\n}\n\n.hover\\:to-gray-500:hover {\n  --gradient-to-color: #a0aec0;\n}\n\n.hover\\:to-gray-600:hover {\n  --gradient-to-color: #718096;\n}\n\n.hover\\:to-gray-700:hover {\n  --gradient-to-color: #4a5568;\n}\n\n.hover\\:to-gray-800:hover {\n  --gradient-to-color: #2d3748;\n}\n\n.hover\\:to-gray-900:hover {\n  --gradient-to-color: #1a202c;\n}\n\n.hover\\:to-red-100:hover {\n  --gradient-to-color: #fff5f5;\n}\n\n.hover\\:to-red-200:hover {\n  --gradient-to-color: #fed7d7;\n}\n\n.hover\\:to-red-300:hover {\n  --gradient-to-color: #feb2b2;\n}\n\n.hover\\:to-red-400:hover {\n  --gradient-to-color: #fc8181;\n}\n\n.hover\\:to-red-500:hover {\n  --gradient-to-color: #f56565;\n}\n\n.hover\\:to-red-600:hover {\n  --gradient-to-color: #e53e3e;\n}\n\n.hover\\:to-red-700:hover {\n  --gradient-to-color: #c53030;\n}\n\n.hover\\:to-red-800:hover {\n  --gradient-to-color: #9b2c2c;\n}\n\n.hover\\:to-red-900:hover {\n  --gradient-to-color: #742a2a;\n}\n\n.hover\\:to-orange-100:hover {\n  --gradient-to-color: #fffaf0;\n}\n\n.hover\\:to-orange-200:hover {\n  --gradient-to-color: #feebc8;\n}\n\n.hover\\:to-orange-300:hover {\n  --gradient-to-color: #fbd38d;\n}\n\n.hover\\:to-orange-400:hover {\n  --gradient-to-color: #f6ad55;\n}\n\n.hover\\:to-orange-500:hover {\n  --gradient-to-color: #ed8936;\n}\n\n.hover\\:to-orange-600:hover {\n  --gradient-to-color: #dd6b20;\n}\n\n.hover\\:to-orange-700:hover {\n  --gradient-to-color: #c05621;\n}\n\n.hover\\:to-orange-800:hover {\n  --gradient-to-color: #9c4221;\n}\n\n.hover\\:to-orange-900:hover {\n  --gradient-to-color: #7b341e;\n}\n\n.hover\\:to-yellow-100:hover {\n  --gradient-to-color: #fffff0;\n}\n\n.hover\\:to-yellow-200:hover {\n  --gradient-to-color: #fefcbf;\n}\n\n.hover\\:to-yellow-300:hover {\n  --gradient-to-color: #faf089;\n}\n\n.hover\\:to-yellow-400:hover {\n  --gradient-to-color: #f6e05e;\n}\n\n.hover\\:to-yellow-500:hover {\n  --gradient-to-color: #ecc94b;\n}\n\n.hover\\:to-yellow-600:hover {\n  --gradient-to-color: #d69e2e;\n}\n\n.hover\\:to-yellow-700:hover {\n  --gradient-to-color: #b7791f;\n}\n\n.hover\\:to-yellow-800:hover {\n  --gradient-to-color: #975a16;\n}\n\n.hover\\:to-yellow-900:hover {\n  --gradient-to-color: #744210;\n}\n\n.hover\\:to-green-100:hover {\n  --gradient-to-color: #f0fff4;\n}\n\n.hover\\:to-green-200:hover {\n  --gradient-to-color: #c6f6d5;\n}\n\n.hover\\:to-green-300:hover {\n  --gradient-to-color: #9ae6b4;\n}\n\n.hover\\:to-green-400:hover {\n  --gradient-to-color: #68d391;\n}\n\n.hover\\:to-green-500:hover {\n  --gradient-to-color: #48bb78;\n}\n\n.hover\\:to-green-600:hover {\n  --gradient-to-color: #38a169;\n}\n\n.hover\\:to-green-700:hover {\n  --gradient-to-color: #2f855a;\n}\n\n.hover\\:to-green-800:hover {\n  --gradient-to-color: #276749;\n}\n\n.hover\\:to-green-900:hover {\n  --gradient-to-color: #22543d;\n}\n\n.hover\\:to-teal-100:hover {\n  --gradient-to-color: #e6fffa;\n}\n\n.hover\\:to-teal-200:hover {\n  --gradient-to-color: #b2f5ea;\n}\n\n.hover\\:to-teal-300:hover {\n  --gradient-to-color: #81e6d9;\n}\n\n.hover\\:to-teal-400:hover {\n  --gradient-to-color: #4fd1c5;\n}\n\n.hover\\:to-teal-500:hover {\n  --gradient-to-color: #38b2ac;\n}\n\n.hover\\:to-teal-600:hover {\n  --gradient-to-color: #319795;\n}\n\n.hover\\:to-teal-700:hover {\n  --gradient-to-color: #2c7a7b;\n}\n\n.hover\\:to-teal-800:hover {\n  --gradient-to-color: #285e61;\n}\n\n.hover\\:to-teal-900:hover {\n  --gradient-to-color: #234e52;\n}\n\n.hover\\:to-blue-100:hover {\n  --gradient-to-color: #ebf8ff;\n}\n\n.hover\\:to-blue-200:hover {\n  --gradient-to-color: #bee3f8;\n}\n\n.hover\\:to-blue-300:hover {\n  --gradient-to-color: #90cdf4;\n}\n\n.hover\\:to-blue-400:hover {\n  --gradient-to-color: #63b3ed;\n}\n\n.hover\\:to-blue-500:hover {\n  --gradient-to-color: #4299e1;\n}\n\n.hover\\:to-blue-600:hover {\n  --gradient-to-color: #3182ce;\n}\n\n.hover\\:to-blue-700:hover {\n  --gradient-to-color: #2b6cb0;\n}\n\n.hover\\:to-blue-800:hover {\n  --gradient-to-color: #2c5282;\n}\n\n.hover\\:to-blue-900:hover {\n  --gradient-to-color: #2a4365;\n}\n\n.hover\\:to-indigo-100:hover {\n  --gradient-to-color: #ebf4ff;\n}\n\n.hover\\:to-indigo-200:hover {\n  --gradient-to-color: #c3dafe;\n}\n\n.hover\\:to-indigo-300:hover {\n  --gradient-to-color: #a3bffa;\n}\n\n.hover\\:to-indigo-400:hover {\n  --gradient-to-color: #7f9cf5;\n}\n\n.hover\\:to-indigo-500:hover {\n  --gradient-to-color: #667eea;\n}\n\n.hover\\:to-indigo-600:hover {\n  --gradient-to-color: #5a67d8;\n}\n\n.hover\\:to-indigo-700:hover {\n  --gradient-to-color: #4c51bf;\n}\n\n.hover\\:to-indigo-800:hover {\n  --gradient-to-color: #434190;\n}\n\n.hover\\:to-indigo-900:hover {\n  --gradient-to-color: #3c366b;\n}\n\n.hover\\:to-purple-100:hover {\n  --gradient-to-color: #faf5ff;\n}\n\n.hover\\:to-purple-200:hover {\n  --gradient-to-color: #e9d8fd;\n}\n\n.hover\\:to-purple-300:hover {\n  --gradient-to-color: #d6bcfa;\n}\n\n.hover\\:to-purple-400:hover {\n  --gradient-to-color: #b794f4;\n}\n\n.hover\\:to-purple-500:hover {\n  --gradient-to-color: #9f7aea;\n}\n\n.hover\\:to-purple-600:hover {\n  --gradient-to-color: #805ad5;\n}\n\n.hover\\:to-purple-700:hover {\n  --gradient-to-color: #6b46c1;\n}\n\n.hover\\:to-purple-800:hover {\n  --gradient-to-color: #553c9a;\n}\n\n.hover\\:to-purple-900:hover {\n  --gradient-to-color: #44337a;\n}\n\n.hover\\:to-pink-100:hover {\n  --gradient-to-color: #fff5f7;\n}\n\n.hover\\:to-pink-200:hover {\n  --gradient-to-color: #fed7e2;\n}\n\n.hover\\:to-pink-300:hover {\n  --gradient-to-color: #fbb6ce;\n}\n\n.hover\\:to-pink-400:hover {\n  --gradient-to-color: #f687b3;\n}\n\n.hover\\:to-pink-500:hover {\n  --gradient-to-color: #ed64a6;\n}\n\n.hover\\:to-pink-600:hover {\n  --gradient-to-color: #d53f8c;\n}\n\n.hover\\:to-pink-700:hover {\n  --gradient-to-color: #b83280;\n}\n\n.hover\\:to-pink-800:hover {\n  --gradient-to-color: #97266d;\n}\n\n.hover\\:to-pink-900:hover {\n  --gradient-to-color: #702459;\n}\n\n.hover\\:to-grayscale-80:hover {\n  --gradient-to-color: hsl(0, 0%, 8%);\n}\n\n.hover\\:to-grayscale-100:hover {\n  --gradient-to-color: hsl(0, 0%, 10%);\n}\n\n.hover\\:to-grayscale-200:hover {\n  --gradient-to-color: hsl(0, 0%, 20%);\n}\n\n.hover\\:to-grayscale-300:hover {\n  --gradient-to-color: hsl(0, 0%, 30%);\n}\n\n.hover\\:to-grayscale-400:hover {\n  --gradient-to-color: hsl(0, 0%, 40%);\n}\n\n.hover\\:to-grayscale-500:hover {\n  --gradient-to-color: hsl(0, 0%, 50%);\n}\n\n.hover\\:to-grayscale-600:hover {\n  --gradient-to-color: hsl(0, 0%, 60%);\n}\n\n.hover\\:to-grayscale-700:hover {\n  --gradient-to-color: hsl(0, 0%, 70%);\n}\n\n.hover\\:to-grayscale-800:hover {\n  --gradient-to-color: hsl(0, 0%, 80%);\n}\n\n.hover\\:to-grayscale-840:hover {\n  --gradient-to-color: hsl(0, 0%, 84%);\n}\n\n.hover\\:to-grayscale-870:hover {\n  --gradient-to-color: hsl(0, 0%, 87%);\n}\n\n.hover\\:to-grayscale-900:hover {\n  --gradient-to-color: hsl(0, 0%, 90%);\n}\n\n.hover\\:to-grayscale-930:hover {\n  --gradient-to-color: hsl(0, 0%, 93%);\n}\n\n.hover\\:to-primary:hover {\n  --gradient-to-color: hsl(210, 100%, 52%);\n}\n\n.hover\\:to-background-main:hover {\n  --gradient-to-color: var(--main-background);\n}\n\n.hover\\:to-background-secondary:hover {\n  --gradient-to-color: var(--secondary-background);\n}\n\n.hover\\:to-foreground:hover {\n  --gradient-to-color: var(--foreground);\n}\n\n.hover\\:to-panels-bg:hover {\n  --gradient-to-color: var(--panels-background);\n}\n\n.focus\\:from-transparent:focus {\n  --gradient-from-color: transparent;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n}\n\n.focus\\:from-current:focus {\n  --gradient-from-color: currentColor;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.focus\\:from-black:focus {\n  --gradient-from-color: #000;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n}\n\n.focus\\:from-white:focus {\n  --gradient-from-color: #fff;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.focus\\:from-gray-100:focus {\n  --gradient-from-color: #f7fafc;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n}\n\n.focus\\:from-gray-200:focus {\n  --gradient-from-color: #edf2f7;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n}\n\n.focus\\:from-gray-300:focus {\n  --gradient-from-color: #e2e8f0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n}\n\n.focus\\:from-gray-400:focus {\n  --gradient-from-color: #cbd5e0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n}\n\n.focus\\:from-gray-500:focus {\n  --gradient-from-color: #a0aec0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n}\n\n.focus\\:from-gray-600:focus {\n  --gradient-from-color: #718096;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n}\n\n.focus\\:from-gray-700:focus {\n  --gradient-from-color: #4a5568;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n}\n\n.focus\\:from-gray-800:focus {\n  --gradient-from-color: #2d3748;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n}\n\n.focus\\:from-gray-900:focus {\n  --gradient-from-color: #1a202c;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n}\n\n.focus\\:from-red-100:focus {\n  --gradient-from-color: #fff5f5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n}\n\n.focus\\:from-red-200:focus {\n  --gradient-from-color: #fed7d7;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n}\n\n.focus\\:from-red-300:focus {\n  --gradient-from-color: #feb2b2;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n}\n\n.focus\\:from-red-400:focus {\n  --gradient-from-color: #fc8181;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n}\n\n.focus\\:from-red-500:focus {\n  --gradient-from-color: #f56565;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n}\n\n.focus\\:from-red-600:focus {\n  --gradient-from-color: #e53e3e;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n}\n\n.focus\\:from-red-700:focus {\n  --gradient-from-color: #c53030;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n}\n\n.focus\\:from-red-800:focus {\n  --gradient-from-color: #9b2c2c;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n}\n\n.focus\\:from-red-900:focus {\n  --gradient-from-color: #742a2a;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n}\n\n.focus\\:from-orange-100:focus {\n  --gradient-from-color: #fffaf0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n}\n\n.focus\\:from-orange-200:focus {\n  --gradient-from-color: #feebc8;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n}\n\n.focus\\:from-orange-300:focus {\n  --gradient-from-color: #fbd38d;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n}\n\n.focus\\:from-orange-400:focus {\n  --gradient-from-color: #f6ad55;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n}\n\n.focus\\:from-orange-500:focus {\n  --gradient-from-color: #ed8936;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n}\n\n.focus\\:from-orange-600:focus {\n  --gradient-from-color: #dd6b20;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n}\n\n.focus\\:from-orange-700:focus {\n  --gradient-from-color: #c05621;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n}\n\n.focus\\:from-orange-800:focus {\n  --gradient-from-color: #9c4221;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n}\n\n.focus\\:from-orange-900:focus {\n  --gradient-from-color: #7b341e;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n}\n\n.focus\\:from-yellow-100:focus {\n  --gradient-from-color: #fffff0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n}\n\n.focus\\:from-yellow-200:focus {\n  --gradient-from-color: #fefcbf;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n}\n\n.focus\\:from-yellow-300:focus {\n  --gradient-from-color: #faf089;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n}\n\n.focus\\:from-yellow-400:focus {\n  --gradient-from-color: #f6e05e;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n}\n\n.focus\\:from-yellow-500:focus {\n  --gradient-from-color: #ecc94b;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n}\n\n.focus\\:from-yellow-600:focus {\n  --gradient-from-color: #d69e2e;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n}\n\n.focus\\:from-yellow-700:focus {\n  --gradient-from-color: #b7791f;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n}\n\n.focus\\:from-yellow-800:focus {\n  --gradient-from-color: #975a16;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n}\n\n.focus\\:from-yellow-900:focus {\n  --gradient-from-color: #744210;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n}\n\n.focus\\:from-green-100:focus {\n  --gradient-from-color: #f0fff4;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n}\n\n.focus\\:from-green-200:focus {\n  --gradient-from-color: #c6f6d5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n}\n\n.focus\\:from-green-300:focus {\n  --gradient-from-color: #9ae6b4;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n}\n\n.focus\\:from-green-400:focus {\n  --gradient-from-color: #68d391;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n}\n\n.focus\\:from-green-500:focus {\n  --gradient-from-color: #48bb78;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n}\n\n.focus\\:from-green-600:focus {\n  --gradient-from-color: #38a169;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n}\n\n.focus\\:from-green-700:focus {\n  --gradient-from-color: #2f855a;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n}\n\n.focus\\:from-green-800:focus {\n  --gradient-from-color: #276749;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n}\n\n.focus\\:from-green-900:focus {\n  --gradient-from-color: #22543d;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n}\n\n.focus\\:from-teal-100:focus {\n  --gradient-from-color: #e6fffa;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n}\n\n.focus\\:from-teal-200:focus {\n  --gradient-from-color: #b2f5ea;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n}\n\n.focus\\:from-teal-300:focus {\n  --gradient-from-color: #81e6d9;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n}\n\n.focus\\:from-teal-400:focus {\n  --gradient-from-color: #4fd1c5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n}\n\n.focus\\:from-teal-500:focus {\n  --gradient-from-color: #38b2ac;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n}\n\n.focus\\:from-teal-600:focus {\n  --gradient-from-color: #319795;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n}\n\n.focus\\:from-teal-700:focus {\n  --gradient-from-color: #2c7a7b;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n}\n\n.focus\\:from-teal-800:focus {\n  --gradient-from-color: #285e61;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n}\n\n.focus\\:from-teal-900:focus {\n  --gradient-from-color: #234e52;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n}\n\n.focus\\:from-blue-100:focus {\n  --gradient-from-color: #ebf8ff;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n}\n\n.focus\\:from-blue-200:focus {\n  --gradient-from-color: #bee3f8;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n}\n\n.focus\\:from-blue-300:focus {\n  --gradient-from-color: #90cdf4;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n}\n\n.focus\\:from-blue-400:focus {\n  --gradient-from-color: #63b3ed;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n}\n\n.focus\\:from-blue-500:focus {\n  --gradient-from-color: #4299e1;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n}\n\n.focus\\:from-blue-600:focus {\n  --gradient-from-color: #3182ce;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n}\n\n.focus\\:from-blue-700:focus {\n  --gradient-from-color: #2b6cb0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n}\n\n.focus\\:from-blue-800:focus {\n  --gradient-from-color: #2c5282;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n}\n\n.focus\\:from-blue-900:focus {\n  --gradient-from-color: #2a4365;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n}\n\n.focus\\:from-indigo-100:focus {\n  --gradient-from-color: #ebf4ff;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n}\n\n.focus\\:from-indigo-200:focus {\n  --gradient-from-color: #c3dafe;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n}\n\n.focus\\:from-indigo-300:focus {\n  --gradient-from-color: #a3bffa;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n}\n\n.focus\\:from-indigo-400:focus {\n  --gradient-from-color: #7f9cf5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n}\n\n.focus\\:from-indigo-500:focus {\n  --gradient-from-color: #667eea;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n}\n\n.focus\\:from-indigo-600:focus {\n  --gradient-from-color: #5a67d8;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n}\n\n.focus\\:from-indigo-700:focus {\n  --gradient-from-color: #4c51bf;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n}\n\n.focus\\:from-indigo-800:focus {\n  --gradient-from-color: #434190;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n}\n\n.focus\\:from-indigo-900:focus {\n  --gradient-from-color: #3c366b;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n}\n\n.focus\\:from-purple-100:focus {\n  --gradient-from-color: #faf5ff;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n}\n\n.focus\\:from-purple-200:focus {\n  --gradient-from-color: #e9d8fd;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n}\n\n.focus\\:from-purple-300:focus {\n  --gradient-from-color: #d6bcfa;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n}\n\n.focus\\:from-purple-400:focus {\n  --gradient-from-color: #b794f4;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n}\n\n.focus\\:from-purple-500:focus {\n  --gradient-from-color: #9f7aea;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n}\n\n.focus\\:from-purple-600:focus {\n  --gradient-from-color: #805ad5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n}\n\n.focus\\:from-purple-700:focus {\n  --gradient-from-color: #6b46c1;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n}\n\n.focus\\:from-purple-800:focus {\n  --gradient-from-color: #553c9a;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n}\n\n.focus\\:from-purple-900:focus {\n  --gradient-from-color: #44337a;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n}\n\n.focus\\:from-pink-100:focus {\n  --gradient-from-color: #fff5f7;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n}\n\n.focus\\:from-pink-200:focus {\n  --gradient-from-color: #fed7e2;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n}\n\n.focus\\:from-pink-300:focus {\n  --gradient-from-color: #fbb6ce;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n}\n\n.focus\\:from-pink-400:focus {\n  --gradient-from-color: #f687b3;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n}\n\n.focus\\:from-pink-500:focus {\n  --gradient-from-color: #ed64a6;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n}\n\n.focus\\:from-pink-600:focus {\n  --gradient-from-color: #d53f8c;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n}\n\n.focus\\:from-pink-700:focus {\n  --gradient-from-color: #b83280;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n}\n\n.focus\\:from-pink-800:focus {\n  --gradient-from-color: #97266d;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n}\n\n.focus\\:from-pink-900:focus {\n  --gradient-from-color: #702459;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n}\n\n.focus\\:from-grayscale-80:focus {\n  --gradient-from-color: hsl(0, 0%, 8%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n}\n\n.focus\\:from-grayscale-100:focus {\n  --gradient-from-color: hsl(0, 0%, 10%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n}\n\n.focus\\:from-grayscale-200:focus {\n  --gradient-from-color: hsl(0, 0%, 20%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n}\n\n.focus\\:from-grayscale-300:focus {\n  --gradient-from-color: hsl(0, 0%, 30%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n}\n\n.focus\\:from-grayscale-400:focus {\n  --gradient-from-color: hsl(0, 0%, 40%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n}\n\n.focus\\:from-grayscale-500:focus {\n  --gradient-from-color: hsl(0, 0%, 50%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n}\n\n.focus\\:from-grayscale-600:focus {\n  --gradient-from-color: hsl(0, 0%, 60%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n}\n\n.focus\\:from-grayscale-700:focus {\n  --gradient-from-color: hsl(0, 0%, 70%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n}\n\n.focus\\:from-grayscale-800:focus {\n  --gradient-from-color: hsl(0, 0%, 80%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n}\n\n.focus\\:from-grayscale-840:focus {\n  --gradient-from-color: hsl(0, 0%, 84%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n}\n\n.focus\\:from-grayscale-870:focus {\n  --gradient-from-color: hsl(0, 0%, 87%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n}\n\n.focus\\:from-grayscale-900:focus {\n  --gradient-from-color: hsl(0, 0%, 90%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n}\n\n.focus\\:from-grayscale-930:focus {\n  --gradient-from-color: hsl(0, 0%, 93%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n}\n\n.focus\\:from-primary:focus {\n  --gradient-from-color: hsl(210, 100%, 52%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n}\n\n.focus\\:from-background-main:focus {\n  --gradient-from-color: var(--main-background);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.focus\\:from-background-secondary:focus {\n  --gradient-from-color: var(--secondary-background);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.focus\\:from-foreground:focus {\n  --gradient-from-color: var(--foreground);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.focus\\:from-panels-bg:focus {\n  --gradient-from-color: var(--panels-background);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.focus\\:via-transparent:focus {\n  --gradient-via-color: transparent;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n}\n\n.focus\\:via-current:focus {\n  --gradient-via-color: currentColor;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.focus\\:via-black:focus {\n  --gradient-via-color: #000;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n}\n\n.focus\\:via-white:focus {\n  --gradient-via-color: #fff;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.focus\\:via-gray-100:focus {\n  --gradient-via-color: #f7fafc;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n}\n\n.focus\\:via-gray-200:focus {\n  --gradient-via-color: #edf2f7;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n}\n\n.focus\\:via-gray-300:focus {\n  --gradient-via-color: #e2e8f0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n}\n\n.focus\\:via-gray-400:focus {\n  --gradient-via-color: #cbd5e0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n}\n\n.focus\\:via-gray-500:focus {\n  --gradient-via-color: #a0aec0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n}\n\n.focus\\:via-gray-600:focus {\n  --gradient-via-color: #718096;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n}\n\n.focus\\:via-gray-700:focus {\n  --gradient-via-color: #4a5568;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n}\n\n.focus\\:via-gray-800:focus {\n  --gradient-via-color: #2d3748;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n}\n\n.focus\\:via-gray-900:focus {\n  --gradient-via-color: #1a202c;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n}\n\n.focus\\:via-red-100:focus {\n  --gradient-via-color: #fff5f5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n}\n\n.focus\\:via-red-200:focus {\n  --gradient-via-color: #fed7d7;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n}\n\n.focus\\:via-red-300:focus {\n  --gradient-via-color: #feb2b2;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n}\n\n.focus\\:via-red-400:focus {\n  --gradient-via-color: #fc8181;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n}\n\n.focus\\:via-red-500:focus {\n  --gradient-via-color: #f56565;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n}\n\n.focus\\:via-red-600:focus {\n  --gradient-via-color: #e53e3e;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n}\n\n.focus\\:via-red-700:focus {\n  --gradient-via-color: #c53030;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n}\n\n.focus\\:via-red-800:focus {\n  --gradient-via-color: #9b2c2c;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n}\n\n.focus\\:via-red-900:focus {\n  --gradient-via-color: #742a2a;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n}\n\n.focus\\:via-orange-100:focus {\n  --gradient-via-color: #fffaf0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n}\n\n.focus\\:via-orange-200:focus {\n  --gradient-via-color: #feebc8;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n}\n\n.focus\\:via-orange-300:focus {\n  --gradient-via-color: #fbd38d;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n}\n\n.focus\\:via-orange-400:focus {\n  --gradient-via-color: #f6ad55;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n}\n\n.focus\\:via-orange-500:focus {\n  --gradient-via-color: #ed8936;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n}\n\n.focus\\:via-orange-600:focus {\n  --gradient-via-color: #dd6b20;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n}\n\n.focus\\:via-orange-700:focus {\n  --gradient-via-color: #c05621;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n}\n\n.focus\\:via-orange-800:focus {\n  --gradient-via-color: #9c4221;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n}\n\n.focus\\:via-orange-900:focus {\n  --gradient-via-color: #7b341e;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n}\n\n.focus\\:via-yellow-100:focus {\n  --gradient-via-color: #fffff0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n}\n\n.focus\\:via-yellow-200:focus {\n  --gradient-via-color: #fefcbf;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n}\n\n.focus\\:via-yellow-300:focus {\n  --gradient-via-color: #faf089;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n}\n\n.focus\\:via-yellow-400:focus {\n  --gradient-via-color: #f6e05e;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n}\n\n.focus\\:via-yellow-500:focus {\n  --gradient-via-color: #ecc94b;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n}\n\n.focus\\:via-yellow-600:focus {\n  --gradient-via-color: #d69e2e;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n}\n\n.focus\\:via-yellow-700:focus {\n  --gradient-via-color: #b7791f;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n}\n\n.focus\\:via-yellow-800:focus {\n  --gradient-via-color: #975a16;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n}\n\n.focus\\:via-yellow-900:focus {\n  --gradient-via-color: #744210;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n}\n\n.focus\\:via-green-100:focus {\n  --gradient-via-color: #f0fff4;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n}\n\n.focus\\:via-green-200:focus {\n  --gradient-via-color: #c6f6d5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n}\n\n.focus\\:via-green-300:focus {\n  --gradient-via-color: #9ae6b4;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n}\n\n.focus\\:via-green-400:focus {\n  --gradient-via-color: #68d391;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n}\n\n.focus\\:via-green-500:focus {\n  --gradient-via-color: #48bb78;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n}\n\n.focus\\:via-green-600:focus {\n  --gradient-via-color: #38a169;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n}\n\n.focus\\:via-green-700:focus {\n  --gradient-via-color: #2f855a;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n}\n\n.focus\\:via-green-800:focus {\n  --gradient-via-color: #276749;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n}\n\n.focus\\:via-green-900:focus {\n  --gradient-via-color: #22543d;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n}\n\n.focus\\:via-teal-100:focus {\n  --gradient-via-color: #e6fffa;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n}\n\n.focus\\:via-teal-200:focus {\n  --gradient-via-color: #b2f5ea;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n}\n\n.focus\\:via-teal-300:focus {\n  --gradient-via-color: #81e6d9;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n}\n\n.focus\\:via-teal-400:focus {\n  --gradient-via-color: #4fd1c5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n}\n\n.focus\\:via-teal-500:focus {\n  --gradient-via-color: #38b2ac;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n}\n\n.focus\\:via-teal-600:focus {\n  --gradient-via-color: #319795;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n}\n\n.focus\\:via-teal-700:focus {\n  --gradient-via-color: #2c7a7b;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n}\n\n.focus\\:via-teal-800:focus {\n  --gradient-via-color: #285e61;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n}\n\n.focus\\:via-teal-900:focus {\n  --gradient-via-color: #234e52;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n}\n\n.focus\\:via-blue-100:focus {\n  --gradient-via-color: #ebf8ff;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n}\n\n.focus\\:via-blue-200:focus {\n  --gradient-via-color: #bee3f8;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n}\n\n.focus\\:via-blue-300:focus {\n  --gradient-via-color: #90cdf4;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n}\n\n.focus\\:via-blue-400:focus {\n  --gradient-via-color: #63b3ed;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n}\n\n.focus\\:via-blue-500:focus {\n  --gradient-via-color: #4299e1;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n}\n\n.focus\\:via-blue-600:focus {\n  --gradient-via-color: #3182ce;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n}\n\n.focus\\:via-blue-700:focus {\n  --gradient-via-color: #2b6cb0;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n}\n\n.focus\\:via-blue-800:focus {\n  --gradient-via-color: #2c5282;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n}\n\n.focus\\:via-blue-900:focus {\n  --gradient-via-color: #2a4365;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n}\n\n.focus\\:via-indigo-100:focus {\n  --gradient-via-color: #ebf4ff;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n}\n\n.focus\\:via-indigo-200:focus {\n  --gradient-via-color: #c3dafe;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n}\n\n.focus\\:via-indigo-300:focus {\n  --gradient-via-color: #a3bffa;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n}\n\n.focus\\:via-indigo-400:focus {\n  --gradient-via-color: #7f9cf5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n}\n\n.focus\\:via-indigo-500:focus {\n  --gradient-via-color: #667eea;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n}\n\n.focus\\:via-indigo-600:focus {\n  --gradient-via-color: #5a67d8;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n}\n\n.focus\\:via-indigo-700:focus {\n  --gradient-via-color: #4c51bf;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n}\n\n.focus\\:via-indigo-800:focus {\n  --gradient-via-color: #434190;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n}\n\n.focus\\:via-indigo-900:focus {\n  --gradient-via-color: #3c366b;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n}\n\n.focus\\:via-purple-100:focus {\n  --gradient-via-color: #faf5ff;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n}\n\n.focus\\:via-purple-200:focus {\n  --gradient-via-color: #e9d8fd;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n}\n\n.focus\\:via-purple-300:focus {\n  --gradient-via-color: #d6bcfa;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n}\n\n.focus\\:via-purple-400:focus {\n  --gradient-via-color: #b794f4;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n}\n\n.focus\\:via-purple-500:focus {\n  --gradient-via-color: #9f7aea;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n}\n\n.focus\\:via-purple-600:focus {\n  --gradient-via-color: #805ad5;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n}\n\n.focus\\:via-purple-700:focus {\n  --gradient-via-color: #6b46c1;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n}\n\n.focus\\:via-purple-800:focus {\n  --gradient-via-color: #553c9a;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n}\n\n.focus\\:via-purple-900:focus {\n  --gradient-via-color: #44337a;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n}\n\n.focus\\:via-pink-100:focus {\n  --gradient-via-color: #fff5f7;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n}\n\n.focus\\:via-pink-200:focus {\n  --gradient-via-color: #fed7e2;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n}\n\n.focus\\:via-pink-300:focus {\n  --gradient-via-color: #fbb6ce;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n}\n\n.focus\\:via-pink-400:focus {\n  --gradient-via-color: #f687b3;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n}\n\n.focus\\:via-pink-500:focus {\n  --gradient-via-color: #ed64a6;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n}\n\n.focus\\:via-pink-600:focus {\n  --gradient-via-color: #d53f8c;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n}\n\n.focus\\:via-pink-700:focus {\n  --gradient-via-color: #b83280;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n}\n\n.focus\\:via-pink-800:focus {\n  --gradient-via-color: #97266d;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n}\n\n.focus\\:via-pink-900:focus {\n  --gradient-via-color: #702459;\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n}\n\n.focus\\:via-grayscale-80:focus {\n  --gradient-via-color: hsl(0, 0%, 8%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n}\n\n.focus\\:via-grayscale-100:focus {\n  --gradient-via-color: hsl(0, 0%, 10%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n}\n\n.focus\\:via-grayscale-200:focus {\n  --gradient-via-color: hsl(0, 0%, 20%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n}\n\n.focus\\:via-grayscale-300:focus {\n  --gradient-via-color: hsl(0, 0%, 30%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n}\n\n.focus\\:via-grayscale-400:focus {\n  --gradient-via-color: hsl(0, 0%, 40%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n}\n\n.focus\\:via-grayscale-500:focus {\n  --gradient-via-color: hsl(0, 0%, 50%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n}\n\n.focus\\:via-grayscale-600:focus {\n  --gradient-via-color: hsl(0, 0%, 60%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n}\n\n.focus\\:via-grayscale-700:focus {\n  --gradient-via-color: hsl(0, 0%, 70%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n}\n\n.focus\\:via-grayscale-800:focus {\n  --gradient-via-color: hsl(0, 0%, 80%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n}\n\n.focus\\:via-grayscale-840:focus {\n  --gradient-via-color: hsl(0, 0%, 84%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n}\n\n.focus\\:via-grayscale-870:focus {\n  --gradient-via-color: hsl(0, 0%, 87%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n}\n\n.focus\\:via-grayscale-900:focus {\n  --gradient-via-color: hsl(0, 0%, 90%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n}\n\n.focus\\:via-grayscale-930:focus {\n  --gradient-via-color: hsl(0, 0%, 93%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n}\n\n.focus\\:via-primary:focus {\n  --gradient-via-color: hsl(210, 100%, 52%);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n}\n\n.focus\\:via-background-main:focus {\n  --gradient-via-color: var(--main-background);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.focus\\:via-background-secondary:focus {\n  --gradient-via-color: var(--secondary-background);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.focus\\:via-foreground:focus {\n  --gradient-via-color: var(--foreground);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.focus\\:via-panels-bg:focus {\n  --gradient-via-color: var(--panels-background);\n  --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n}\n\n.focus\\:to-transparent:focus {\n  --gradient-to-color: transparent;\n}\n\n.focus\\:to-current:focus {\n  --gradient-to-color: currentColor;\n}\n\n.focus\\:to-black:focus {\n  --gradient-to-color: #000;\n}\n\n.focus\\:to-white:focus {\n  --gradient-to-color: #fff;\n}\n\n.focus\\:to-gray-100:focus {\n  --gradient-to-color: #f7fafc;\n}\n\n.focus\\:to-gray-200:focus {\n  --gradient-to-color: #edf2f7;\n}\n\n.focus\\:to-gray-300:focus {\n  --gradient-to-color: #e2e8f0;\n}\n\n.focus\\:to-gray-400:focus {\n  --gradient-to-color: #cbd5e0;\n}\n\n.focus\\:to-gray-500:focus {\n  --gradient-to-color: #a0aec0;\n}\n\n.focus\\:to-gray-600:focus {\n  --gradient-to-color: #718096;\n}\n\n.focus\\:to-gray-700:focus {\n  --gradient-to-color: #4a5568;\n}\n\n.focus\\:to-gray-800:focus {\n  --gradient-to-color: #2d3748;\n}\n\n.focus\\:to-gray-900:focus {\n  --gradient-to-color: #1a202c;\n}\n\n.focus\\:to-red-100:focus {\n  --gradient-to-color: #fff5f5;\n}\n\n.focus\\:to-red-200:focus {\n  --gradient-to-color: #fed7d7;\n}\n\n.focus\\:to-red-300:focus {\n  --gradient-to-color: #feb2b2;\n}\n\n.focus\\:to-red-400:focus {\n  --gradient-to-color: #fc8181;\n}\n\n.focus\\:to-red-500:focus {\n  --gradient-to-color: #f56565;\n}\n\n.focus\\:to-red-600:focus {\n  --gradient-to-color: #e53e3e;\n}\n\n.focus\\:to-red-700:focus {\n  --gradient-to-color: #c53030;\n}\n\n.focus\\:to-red-800:focus {\n  --gradient-to-color: #9b2c2c;\n}\n\n.focus\\:to-red-900:focus {\n  --gradient-to-color: #742a2a;\n}\n\n.focus\\:to-orange-100:focus {\n  --gradient-to-color: #fffaf0;\n}\n\n.focus\\:to-orange-200:focus {\n  --gradient-to-color: #feebc8;\n}\n\n.focus\\:to-orange-300:focus {\n  --gradient-to-color: #fbd38d;\n}\n\n.focus\\:to-orange-400:focus {\n  --gradient-to-color: #f6ad55;\n}\n\n.focus\\:to-orange-500:focus {\n  --gradient-to-color: #ed8936;\n}\n\n.focus\\:to-orange-600:focus {\n  --gradient-to-color: #dd6b20;\n}\n\n.focus\\:to-orange-700:focus {\n  --gradient-to-color: #c05621;\n}\n\n.focus\\:to-orange-800:focus {\n  --gradient-to-color: #9c4221;\n}\n\n.focus\\:to-orange-900:focus {\n  --gradient-to-color: #7b341e;\n}\n\n.focus\\:to-yellow-100:focus {\n  --gradient-to-color: #fffff0;\n}\n\n.focus\\:to-yellow-200:focus {\n  --gradient-to-color: #fefcbf;\n}\n\n.focus\\:to-yellow-300:focus {\n  --gradient-to-color: #faf089;\n}\n\n.focus\\:to-yellow-400:focus {\n  --gradient-to-color: #f6e05e;\n}\n\n.focus\\:to-yellow-500:focus {\n  --gradient-to-color: #ecc94b;\n}\n\n.focus\\:to-yellow-600:focus {\n  --gradient-to-color: #d69e2e;\n}\n\n.focus\\:to-yellow-700:focus {\n  --gradient-to-color: #b7791f;\n}\n\n.focus\\:to-yellow-800:focus {\n  --gradient-to-color: #975a16;\n}\n\n.focus\\:to-yellow-900:focus {\n  --gradient-to-color: #744210;\n}\n\n.focus\\:to-green-100:focus {\n  --gradient-to-color: #f0fff4;\n}\n\n.focus\\:to-green-200:focus {\n  --gradient-to-color: #c6f6d5;\n}\n\n.focus\\:to-green-300:focus {\n  --gradient-to-color: #9ae6b4;\n}\n\n.focus\\:to-green-400:focus {\n  --gradient-to-color: #68d391;\n}\n\n.focus\\:to-green-500:focus {\n  --gradient-to-color: #48bb78;\n}\n\n.focus\\:to-green-600:focus {\n  --gradient-to-color: #38a169;\n}\n\n.focus\\:to-green-700:focus {\n  --gradient-to-color: #2f855a;\n}\n\n.focus\\:to-green-800:focus {\n  --gradient-to-color: #276749;\n}\n\n.focus\\:to-green-900:focus {\n  --gradient-to-color: #22543d;\n}\n\n.focus\\:to-teal-100:focus {\n  --gradient-to-color: #e6fffa;\n}\n\n.focus\\:to-teal-200:focus {\n  --gradient-to-color: #b2f5ea;\n}\n\n.focus\\:to-teal-300:focus {\n  --gradient-to-color: #81e6d9;\n}\n\n.focus\\:to-teal-400:focus {\n  --gradient-to-color: #4fd1c5;\n}\n\n.focus\\:to-teal-500:focus {\n  --gradient-to-color: #38b2ac;\n}\n\n.focus\\:to-teal-600:focus {\n  --gradient-to-color: #319795;\n}\n\n.focus\\:to-teal-700:focus {\n  --gradient-to-color: #2c7a7b;\n}\n\n.focus\\:to-teal-800:focus {\n  --gradient-to-color: #285e61;\n}\n\n.focus\\:to-teal-900:focus {\n  --gradient-to-color: #234e52;\n}\n\n.focus\\:to-blue-100:focus {\n  --gradient-to-color: #ebf8ff;\n}\n\n.focus\\:to-blue-200:focus {\n  --gradient-to-color: #bee3f8;\n}\n\n.focus\\:to-blue-300:focus {\n  --gradient-to-color: #90cdf4;\n}\n\n.focus\\:to-blue-400:focus {\n  --gradient-to-color: #63b3ed;\n}\n\n.focus\\:to-blue-500:focus {\n  --gradient-to-color: #4299e1;\n}\n\n.focus\\:to-blue-600:focus {\n  --gradient-to-color: #3182ce;\n}\n\n.focus\\:to-blue-700:focus {\n  --gradient-to-color: #2b6cb0;\n}\n\n.focus\\:to-blue-800:focus {\n  --gradient-to-color: #2c5282;\n}\n\n.focus\\:to-blue-900:focus {\n  --gradient-to-color: #2a4365;\n}\n\n.focus\\:to-indigo-100:focus {\n  --gradient-to-color: #ebf4ff;\n}\n\n.focus\\:to-indigo-200:focus {\n  --gradient-to-color: #c3dafe;\n}\n\n.focus\\:to-indigo-300:focus {\n  --gradient-to-color: #a3bffa;\n}\n\n.focus\\:to-indigo-400:focus {\n  --gradient-to-color: #7f9cf5;\n}\n\n.focus\\:to-indigo-500:focus {\n  --gradient-to-color: #667eea;\n}\n\n.focus\\:to-indigo-600:focus {\n  --gradient-to-color: #5a67d8;\n}\n\n.focus\\:to-indigo-700:focus {\n  --gradient-to-color: #4c51bf;\n}\n\n.focus\\:to-indigo-800:focus {\n  --gradient-to-color: #434190;\n}\n\n.focus\\:to-indigo-900:focus {\n  --gradient-to-color: #3c366b;\n}\n\n.focus\\:to-purple-100:focus {\n  --gradient-to-color: #faf5ff;\n}\n\n.focus\\:to-purple-200:focus {\n  --gradient-to-color: #e9d8fd;\n}\n\n.focus\\:to-purple-300:focus {\n  --gradient-to-color: #d6bcfa;\n}\n\n.focus\\:to-purple-400:focus {\n  --gradient-to-color: #b794f4;\n}\n\n.focus\\:to-purple-500:focus {\n  --gradient-to-color: #9f7aea;\n}\n\n.focus\\:to-purple-600:focus {\n  --gradient-to-color: #805ad5;\n}\n\n.focus\\:to-purple-700:focus {\n  --gradient-to-color: #6b46c1;\n}\n\n.focus\\:to-purple-800:focus {\n  --gradient-to-color: #553c9a;\n}\n\n.focus\\:to-purple-900:focus {\n  --gradient-to-color: #44337a;\n}\n\n.focus\\:to-pink-100:focus {\n  --gradient-to-color: #fff5f7;\n}\n\n.focus\\:to-pink-200:focus {\n  --gradient-to-color: #fed7e2;\n}\n\n.focus\\:to-pink-300:focus {\n  --gradient-to-color: #fbb6ce;\n}\n\n.focus\\:to-pink-400:focus {\n  --gradient-to-color: #f687b3;\n}\n\n.focus\\:to-pink-500:focus {\n  --gradient-to-color: #ed64a6;\n}\n\n.focus\\:to-pink-600:focus {\n  --gradient-to-color: #d53f8c;\n}\n\n.focus\\:to-pink-700:focus {\n  --gradient-to-color: #b83280;\n}\n\n.focus\\:to-pink-800:focus {\n  --gradient-to-color: #97266d;\n}\n\n.focus\\:to-pink-900:focus {\n  --gradient-to-color: #702459;\n}\n\n.focus\\:to-grayscale-80:focus {\n  --gradient-to-color: hsl(0, 0%, 8%);\n}\n\n.focus\\:to-grayscale-100:focus {\n  --gradient-to-color: hsl(0, 0%, 10%);\n}\n\n.focus\\:to-grayscale-200:focus {\n  --gradient-to-color: hsl(0, 0%, 20%);\n}\n\n.focus\\:to-grayscale-300:focus {\n  --gradient-to-color: hsl(0, 0%, 30%);\n}\n\n.focus\\:to-grayscale-400:focus {\n  --gradient-to-color: hsl(0, 0%, 40%);\n}\n\n.focus\\:to-grayscale-500:focus {\n  --gradient-to-color: hsl(0, 0%, 50%);\n}\n\n.focus\\:to-grayscale-600:focus {\n  --gradient-to-color: hsl(0, 0%, 60%);\n}\n\n.focus\\:to-grayscale-700:focus {\n  --gradient-to-color: hsl(0, 0%, 70%);\n}\n\n.focus\\:to-grayscale-800:focus {\n  --gradient-to-color: hsl(0, 0%, 80%);\n}\n\n.focus\\:to-grayscale-840:focus {\n  --gradient-to-color: hsl(0, 0%, 84%);\n}\n\n.focus\\:to-grayscale-870:focus {\n  --gradient-to-color: hsl(0, 0%, 87%);\n}\n\n.focus\\:to-grayscale-900:focus {\n  --gradient-to-color: hsl(0, 0%, 90%);\n}\n\n.focus\\:to-grayscale-930:focus {\n  --gradient-to-color: hsl(0, 0%, 93%);\n}\n\n.focus\\:to-primary:focus {\n  --gradient-to-color: hsl(210, 100%, 52%);\n}\n\n.focus\\:to-background-main:focus {\n  --gradient-to-color: var(--main-background);\n}\n\n.focus\\:to-background-secondary:focus {\n  --gradient-to-color: var(--secondary-background);\n}\n\n.focus\\:to-foreground:focus {\n  --gradient-to-color: var(--foreground);\n}\n\n.focus\\:to-panels-bg:focus {\n  --gradient-to-color: var(--panels-background);\n}\n\n.bg-opacity-0 {\n  --bg-opacity: 0;\n}\n\n.bg-opacity-25 {\n  --bg-opacity: 0.25;\n}\n\n.bg-opacity-50 {\n  --bg-opacity: 0.5;\n}\n\n.bg-opacity-75 {\n  --bg-opacity: 0.75;\n}\n\n.bg-opacity-100 {\n  --bg-opacity: 1;\n}\n\n.hover\\:bg-opacity-0:hover {\n  --bg-opacity: 0;\n}\n\n.hover\\:bg-opacity-25:hover {\n  --bg-opacity: 0.25;\n}\n\n.hover\\:bg-opacity-50:hover {\n  --bg-opacity: 0.5;\n}\n\n.hover\\:bg-opacity-75:hover {\n  --bg-opacity: 0.75;\n}\n\n.hover\\:bg-opacity-100:hover {\n  --bg-opacity: 1;\n}\n\n.focus\\:bg-opacity-0:focus {\n  --bg-opacity: 0;\n}\n\n.focus\\:bg-opacity-25:focus {\n  --bg-opacity: 0.25;\n}\n\n.focus\\:bg-opacity-50:focus {\n  --bg-opacity: 0.5;\n}\n\n.focus\\:bg-opacity-75:focus {\n  --bg-opacity: 0.75;\n}\n\n.focus\\:bg-opacity-100:focus {\n  --bg-opacity: 1;\n}\n\n.bg-bottom {\n  background-position: bottom;\n}\n\n.bg-center {\n  background-position: center;\n}\n\n.bg-left {\n  background-position: left;\n}\n\n.bg-left-bottom {\n  background-position: left bottom;\n}\n\n.bg-left-top {\n  background-position: left top;\n}\n\n.bg-right {\n  background-position: right;\n}\n\n.bg-right-bottom {\n  background-position: right bottom;\n}\n\n.bg-right-top {\n  background-position: right top;\n}\n\n.bg-top {\n  background-position: top;\n}\n\n.bg-repeat {\n  background-repeat: repeat;\n}\n\n.bg-no-repeat {\n  background-repeat: no-repeat;\n}\n\n.bg-repeat-x {\n  background-repeat: repeat-x;\n}\n\n.bg-repeat-y {\n  background-repeat: repeat-y;\n}\n\n.bg-repeat-round {\n  background-repeat: round;\n}\n\n.bg-repeat-space {\n  background-repeat: space;\n}\n\n.bg-auto {\n  background-size: auto;\n}\n\n.bg-cover {\n  background-size: cover;\n}\n\n.bg-contain {\n  background-size: contain;\n}\n\n.border-collapse {\n  border-collapse: collapse;\n}\n\n.border-separate {\n  border-collapse: separate;\n}\n\n.border-transparent {\n  border-color: transparent;\n}\n\n.border-current {\n  border-color: currentColor;\n}\n\n.border-black {\n  --border-opacity: 1;\n  border-color: #000;\n  border-color: rgba(0, 0, 0, var(--border-opacity));\n}\n\n.border-white {\n  --border-opacity: 1;\n  border-color: #fff;\n  border-color: rgba(255, 255, 255, var(--border-opacity));\n}\n\n.border-gray-100 {\n  --border-opacity: 1;\n  border-color: #f7fafc;\n  border-color: rgba(247, 250, 252, var(--border-opacity));\n}\n\n.border-gray-200 {\n  --border-opacity: 1;\n  border-color: #edf2f7;\n  border-color: rgba(237, 242, 247, var(--border-opacity));\n}\n\n.border-gray-300 {\n  --border-opacity: 1;\n  border-color: #e2e8f0;\n  border-color: rgba(226, 232, 240, var(--border-opacity));\n}\n\n.border-gray-400 {\n  --border-opacity: 1;\n  border-color: #cbd5e0;\n  border-color: rgba(203, 213, 224, var(--border-opacity));\n}\n\n.border-gray-500 {\n  --border-opacity: 1;\n  border-color: #a0aec0;\n  border-color: rgba(160, 174, 192, var(--border-opacity));\n}\n\n.border-gray-600 {\n  --border-opacity: 1;\n  border-color: #718096;\n  border-color: rgba(113, 128, 150, var(--border-opacity));\n}\n\n.border-gray-700 {\n  --border-opacity: 1;\n  border-color: #4a5568;\n  border-color: rgba(74, 85, 104, var(--border-opacity));\n}\n\n.border-gray-800 {\n  --border-opacity: 1;\n  border-color: #2d3748;\n  border-color: rgba(45, 55, 72, var(--border-opacity));\n}\n\n.border-gray-900 {\n  --border-opacity: 1;\n  border-color: #1a202c;\n  border-color: rgba(26, 32, 44, var(--border-opacity));\n}\n\n.border-red-100 {\n  --border-opacity: 1;\n  border-color: #fff5f5;\n  border-color: rgba(255, 245, 245, var(--border-opacity));\n}\n\n.border-red-200 {\n  --border-opacity: 1;\n  border-color: #fed7d7;\n  border-color: rgba(254, 215, 215, var(--border-opacity));\n}\n\n.border-red-300 {\n  --border-opacity: 1;\n  border-color: #feb2b2;\n  border-color: rgba(254, 178, 178, var(--border-opacity));\n}\n\n.border-red-400 {\n  --border-opacity: 1;\n  border-color: #fc8181;\n  border-color: rgba(252, 129, 129, var(--border-opacity));\n}\n\n.border-red-500 {\n  --border-opacity: 1;\n  border-color: #f56565;\n  border-color: rgba(245, 101, 101, var(--border-opacity));\n}\n\n.border-red-600 {\n  --border-opacity: 1;\n  border-color: #e53e3e;\n  border-color: rgba(229, 62, 62, var(--border-opacity));\n}\n\n.border-red-700 {\n  --border-opacity: 1;\n  border-color: #c53030;\n  border-color: rgba(197, 48, 48, var(--border-opacity));\n}\n\n.border-red-800 {\n  --border-opacity: 1;\n  border-color: #9b2c2c;\n  border-color: rgba(155, 44, 44, var(--border-opacity));\n}\n\n.border-red-900 {\n  --border-opacity: 1;\n  border-color: #742a2a;\n  border-color: rgba(116, 42, 42, var(--border-opacity));\n}\n\n.border-orange-100 {\n  --border-opacity: 1;\n  border-color: #fffaf0;\n  border-color: rgba(255, 250, 240, var(--border-opacity));\n}\n\n.border-orange-200 {\n  --border-opacity: 1;\n  border-color: #feebc8;\n  border-color: rgba(254, 235, 200, var(--border-opacity));\n}\n\n.border-orange-300 {\n  --border-opacity: 1;\n  border-color: #fbd38d;\n  border-color: rgba(251, 211, 141, var(--border-opacity));\n}\n\n.border-orange-400 {\n  --border-opacity: 1;\n  border-color: #f6ad55;\n  border-color: rgba(246, 173, 85, var(--border-opacity));\n}\n\n.border-orange-500 {\n  --border-opacity: 1;\n  border-color: #ed8936;\n  border-color: rgba(237, 137, 54, var(--border-opacity));\n}\n\n.border-orange-600 {\n  --border-opacity: 1;\n  border-color: #dd6b20;\n  border-color: rgba(221, 107, 32, var(--border-opacity));\n}\n\n.border-orange-700 {\n  --border-opacity: 1;\n  border-color: #c05621;\n  border-color: rgba(192, 86, 33, var(--border-opacity));\n}\n\n.border-orange-800 {\n  --border-opacity: 1;\n  border-color: #9c4221;\n  border-color: rgba(156, 66, 33, var(--border-opacity));\n}\n\n.border-orange-900 {\n  --border-opacity: 1;\n  border-color: #7b341e;\n  border-color: rgba(123, 52, 30, var(--border-opacity));\n}\n\n.border-yellow-100 {\n  --border-opacity: 1;\n  border-color: #fffff0;\n  border-color: rgba(255, 255, 240, var(--border-opacity));\n}\n\n.border-yellow-200 {\n  --border-opacity: 1;\n  border-color: #fefcbf;\n  border-color: rgba(254, 252, 191, var(--border-opacity));\n}\n\n.border-yellow-300 {\n  --border-opacity: 1;\n  border-color: #faf089;\n  border-color: rgba(250, 240, 137, var(--border-opacity));\n}\n\n.border-yellow-400 {\n  --border-opacity: 1;\n  border-color: #f6e05e;\n  border-color: rgba(246, 224, 94, var(--border-opacity));\n}\n\n.border-yellow-500 {\n  --border-opacity: 1;\n  border-color: #ecc94b;\n  border-color: rgba(236, 201, 75, var(--border-opacity));\n}\n\n.border-yellow-600 {\n  --border-opacity: 1;\n  border-color: #d69e2e;\n  border-color: rgba(214, 158, 46, var(--border-opacity));\n}\n\n.border-yellow-700 {\n  --border-opacity: 1;\n  border-color: #b7791f;\n  border-color: rgba(183, 121, 31, var(--border-opacity));\n}\n\n.border-yellow-800 {\n  --border-opacity: 1;\n  border-color: #975a16;\n  border-color: rgba(151, 90, 22, var(--border-opacity));\n}\n\n.border-yellow-900 {\n  --border-opacity: 1;\n  border-color: #744210;\n  border-color: rgba(116, 66, 16, var(--border-opacity));\n}\n\n.border-green-100 {\n  --border-opacity: 1;\n  border-color: #f0fff4;\n  border-color: rgba(240, 255, 244, var(--border-opacity));\n}\n\n.border-green-200 {\n  --border-opacity: 1;\n  border-color: #c6f6d5;\n  border-color: rgba(198, 246, 213, var(--border-opacity));\n}\n\n.border-green-300 {\n  --border-opacity: 1;\n  border-color: #9ae6b4;\n  border-color: rgba(154, 230, 180, var(--border-opacity));\n}\n\n.border-green-400 {\n  --border-opacity: 1;\n  border-color: #68d391;\n  border-color: rgba(104, 211, 145, var(--border-opacity));\n}\n\n.border-green-500 {\n  --border-opacity: 1;\n  border-color: #48bb78;\n  border-color: rgba(72, 187, 120, var(--border-opacity));\n}\n\n.border-green-600 {\n  --border-opacity: 1;\n  border-color: #38a169;\n  border-color: rgba(56, 161, 105, var(--border-opacity));\n}\n\n.border-green-700 {\n  --border-opacity: 1;\n  border-color: #2f855a;\n  border-color: rgba(47, 133, 90, var(--border-opacity));\n}\n\n.border-green-800 {\n  --border-opacity: 1;\n  border-color: #276749;\n  border-color: rgba(39, 103, 73, var(--border-opacity));\n}\n\n.border-green-900 {\n  --border-opacity: 1;\n  border-color: #22543d;\n  border-color: rgba(34, 84, 61, var(--border-opacity));\n}\n\n.border-teal-100 {\n  --border-opacity: 1;\n  border-color: #e6fffa;\n  border-color: rgba(230, 255, 250, var(--border-opacity));\n}\n\n.border-teal-200 {\n  --border-opacity: 1;\n  border-color: #b2f5ea;\n  border-color: rgba(178, 245, 234, var(--border-opacity));\n}\n\n.border-teal-300 {\n  --border-opacity: 1;\n  border-color: #81e6d9;\n  border-color: rgba(129, 230, 217, var(--border-opacity));\n}\n\n.border-teal-400 {\n  --border-opacity: 1;\n  border-color: #4fd1c5;\n  border-color: rgba(79, 209, 197, var(--border-opacity));\n}\n\n.border-teal-500 {\n  --border-opacity: 1;\n  border-color: #38b2ac;\n  border-color: rgba(56, 178, 172, var(--border-opacity));\n}\n\n.border-teal-600 {\n  --border-opacity: 1;\n  border-color: #319795;\n  border-color: rgba(49, 151, 149, var(--border-opacity));\n}\n\n.border-teal-700 {\n  --border-opacity: 1;\n  border-color: #2c7a7b;\n  border-color: rgba(44, 122, 123, var(--border-opacity));\n}\n\n.border-teal-800 {\n  --border-opacity: 1;\n  border-color: #285e61;\n  border-color: rgba(40, 94, 97, var(--border-opacity));\n}\n\n.border-teal-900 {\n  --border-opacity: 1;\n  border-color: #234e52;\n  border-color: rgba(35, 78, 82, var(--border-opacity));\n}\n\n.border-blue-100 {\n  --border-opacity: 1;\n  border-color: #ebf8ff;\n  border-color: rgba(235, 248, 255, var(--border-opacity));\n}\n\n.border-blue-200 {\n  --border-opacity: 1;\n  border-color: #bee3f8;\n  border-color: rgba(190, 227, 248, var(--border-opacity));\n}\n\n.border-blue-300 {\n  --border-opacity: 1;\n  border-color: #90cdf4;\n  border-color: rgba(144, 205, 244, var(--border-opacity));\n}\n\n.border-blue-400 {\n  --border-opacity: 1;\n  border-color: #63b3ed;\n  border-color: rgba(99, 179, 237, var(--border-opacity));\n}\n\n.border-blue-500 {\n  --border-opacity: 1;\n  border-color: #4299e1;\n  border-color: rgba(66, 153, 225, var(--border-opacity));\n}\n\n.border-blue-600 {\n  --border-opacity: 1;\n  border-color: #3182ce;\n  border-color: rgba(49, 130, 206, var(--border-opacity));\n}\n\n.border-blue-700 {\n  --border-opacity: 1;\n  border-color: #2b6cb0;\n  border-color: rgba(43, 108, 176, var(--border-opacity));\n}\n\n.border-blue-800 {\n  --border-opacity: 1;\n  border-color: #2c5282;\n  border-color: rgba(44, 82, 130, var(--border-opacity));\n}\n\n.border-blue-900 {\n  --border-opacity: 1;\n  border-color: #2a4365;\n  border-color: rgba(42, 67, 101, var(--border-opacity));\n}\n\n.border-indigo-100 {\n  --border-opacity: 1;\n  border-color: #ebf4ff;\n  border-color: rgba(235, 244, 255, var(--border-opacity));\n}\n\n.border-indigo-200 {\n  --border-opacity: 1;\n  border-color: #c3dafe;\n  border-color: rgba(195, 218, 254, var(--border-opacity));\n}\n\n.border-indigo-300 {\n  --border-opacity: 1;\n  border-color: #a3bffa;\n  border-color: rgba(163, 191, 250, var(--border-opacity));\n}\n\n.border-indigo-400 {\n  --border-opacity: 1;\n  border-color: #7f9cf5;\n  border-color: rgba(127, 156, 245, var(--border-opacity));\n}\n\n.border-indigo-500 {\n  --border-opacity: 1;\n  border-color: #667eea;\n  border-color: rgba(102, 126, 234, var(--border-opacity));\n}\n\n.border-indigo-600 {\n  --border-opacity: 1;\n  border-color: #5a67d8;\n  border-color: rgba(90, 103, 216, var(--border-opacity));\n}\n\n.border-indigo-700 {\n  --border-opacity: 1;\n  border-color: #4c51bf;\n  border-color: rgba(76, 81, 191, var(--border-opacity));\n}\n\n.border-indigo-800 {\n  --border-opacity: 1;\n  border-color: #434190;\n  border-color: rgba(67, 65, 144, var(--border-opacity));\n}\n\n.border-indigo-900 {\n  --border-opacity: 1;\n  border-color: #3c366b;\n  border-color: rgba(60, 54, 107, var(--border-opacity));\n}\n\n.border-purple-100 {\n  --border-opacity: 1;\n  border-color: #faf5ff;\n  border-color: rgba(250, 245, 255, var(--border-opacity));\n}\n\n.border-purple-200 {\n  --border-opacity: 1;\n  border-color: #e9d8fd;\n  border-color: rgba(233, 216, 253, var(--border-opacity));\n}\n\n.border-purple-300 {\n  --border-opacity: 1;\n  border-color: #d6bcfa;\n  border-color: rgba(214, 188, 250, var(--border-opacity));\n}\n\n.border-purple-400 {\n  --border-opacity: 1;\n  border-color: #b794f4;\n  border-color: rgba(183, 148, 244, var(--border-opacity));\n}\n\n.border-purple-500 {\n  --border-opacity: 1;\n  border-color: #9f7aea;\n  border-color: rgba(159, 122, 234, var(--border-opacity));\n}\n\n.border-purple-600 {\n  --border-opacity: 1;\n  border-color: #805ad5;\n  border-color: rgba(128, 90, 213, var(--border-opacity));\n}\n\n.border-purple-700 {\n  --border-opacity: 1;\n  border-color: #6b46c1;\n  border-color: rgba(107, 70, 193, var(--border-opacity));\n}\n\n.border-purple-800 {\n  --border-opacity: 1;\n  border-color: #553c9a;\n  border-color: rgba(85, 60, 154, var(--border-opacity));\n}\n\n.border-purple-900 {\n  --border-opacity: 1;\n  border-color: #44337a;\n  border-color: rgba(68, 51, 122, var(--border-opacity));\n}\n\n.border-pink-100 {\n  --border-opacity: 1;\n  border-color: #fff5f7;\n  border-color: rgba(255, 245, 247, var(--border-opacity));\n}\n\n.border-pink-200 {\n  --border-opacity: 1;\n  border-color: #fed7e2;\n  border-color: rgba(254, 215, 226, var(--border-opacity));\n}\n\n.border-pink-300 {\n  --border-opacity: 1;\n  border-color: #fbb6ce;\n  border-color: rgba(251, 182, 206, var(--border-opacity));\n}\n\n.border-pink-400 {\n  --border-opacity: 1;\n  border-color: #f687b3;\n  border-color: rgba(246, 135, 179, var(--border-opacity));\n}\n\n.border-pink-500 {\n  --border-opacity: 1;\n  border-color: #ed64a6;\n  border-color: rgba(237, 100, 166, var(--border-opacity));\n}\n\n.border-pink-600 {\n  --border-opacity: 1;\n  border-color: #d53f8c;\n  border-color: rgba(213, 63, 140, var(--border-opacity));\n}\n\n.border-pink-700 {\n  --border-opacity: 1;\n  border-color: #b83280;\n  border-color: rgba(184, 50, 128, var(--border-opacity));\n}\n\n.border-pink-800 {\n  --border-opacity: 1;\n  border-color: #97266d;\n  border-color: rgba(151, 38, 109, var(--border-opacity));\n}\n\n.border-pink-900 {\n  --border-opacity: 1;\n  border-color: #702459;\n  border-color: rgba(112, 36, 89, var(--border-opacity));\n}\n\n.border-grayscale-80 {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 8%);\n  border-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--border-opacity));\n}\n\n.border-grayscale-100 {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 10%);\n  border-color: rgba(25.5, 25.5, 25.5, var(--border-opacity));\n}\n\n.border-grayscale-200 {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 20%);\n  border-color: rgba(51, 51, 51, var(--border-opacity));\n}\n\n.border-grayscale-300 {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 30%);\n  border-color: rgba(76.5, 76.5, 76.5, var(--border-opacity));\n}\n\n.border-grayscale-400 {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 40%);\n  border-color: rgba(102, 102, 102, var(--border-opacity));\n}\n\n.border-grayscale-500 {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 50%);\n  border-color: rgba(127.5, 127.5, 127.5, var(--border-opacity));\n}\n\n.border-grayscale-600 {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 60%);\n  border-color: rgba(153, 153, 153, var(--border-opacity));\n}\n\n.border-grayscale-700 {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 70%);\n  border-color: rgba(178.5, 178.5, 178.5, var(--border-opacity));\n}\n\n.border-grayscale-800 {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 80%);\n  border-color: rgba(204, 204, 204, var(--border-opacity));\n}\n\n.border-grayscale-840 {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 84%);\n  border-color: rgba(214.2, 214.2, 214.2, var(--border-opacity));\n}\n\n.border-grayscale-870 {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 87%);\n  border-color: rgba(221.85, 221.85, 221.85, var(--border-opacity));\n}\n\n.border-grayscale-900 {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 90%);\n  border-color: rgba(229.5, 229.5, 229.5, var(--border-opacity));\n}\n\n.border-grayscale-930 {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 93%);\n  border-color: rgba(237.15, 237.15, 237.15, var(--border-opacity));\n}\n\n.border-primary {\n  --border-opacity: 1;\n  border-color: hsl(210, 100%, 52%);\n  border-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--border-opacity));\n}\n\n.border-background-main {\n  border-color: var(--main-background);\n}\n\n.border-background-secondary {\n  border-color: var(--secondary-background);\n}\n\n.border-foreground {\n  border-color: var(--foreground);\n}\n\n.border-panels-bg {\n  border-color: var(--panels-background);\n}\n\n.hover\\:border-transparent:hover {\n  border-color: transparent;\n}\n\n.hover\\:border-current:hover {\n  border-color: currentColor;\n}\n\n.hover\\:border-black:hover {\n  --border-opacity: 1;\n  border-color: #000;\n  border-color: rgba(0, 0, 0, var(--border-opacity));\n}\n\n.hover\\:border-white:hover {\n  --border-opacity: 1;\n  border-color: #fff;\n  border-color: rgba(255, 255, 255, var(--border-opacity));\n}\n\n.hover\\:border-gray-100:hover {\n  --border-opacity: 1;\n  border-color: #f7fafc;\n  border-color: rgba(247, 250, 252, var(--border-opacity));\n}\n\n.hover\\:border-gray-200:hover {\n  --border-opacity: 1;\n  border-color: #edf2f7;\n  border-color: rgba(237, 242, 247, var(--border-opacity));\n}\n\n.hover\\:border-gray-300:hover {\n  --border-opacity: 1;\n  border-color: #e2e8f0;\n  border-color: rgba(226, 232, 240, var(--border-opacity));\n}\n\n.hover\\:border-gray-400:hover {\n  --border-opacity: 1;\n  border-color: #cbd5e0;\n  border-color: rgba(203, 213, 224, var(--border-opacity));\n}\n\n.hover\\:border-gray-500:hover {\n  --border-opacity: 1;\n  border-color: #a0aec0;\n  border-color: rgba(160, 174, 192, var(--border-opacity));\n}\n\n.hover\\:border-gray-600:hover {\n  --border-opacity: 1;\n  border-color: #718096;\n  border-color: rgba(113, 128, 150, var(--border-opacity));\n}\n\n.hover\\:border-gray-700:hover {\n  --border-opacity: 1;\n  border-color: #4a5568;\n  border-color: rgba(74, 85, 104, var(--border-opacity));\n}\n\n.hover\\:border-gray-800:hover {\n  --border-opacity: 1;\n  border-color: #2d3748;\n  border-color: rgba(45, 55, 72, var(--border-opacity));\n}\n\n.hover\\:border-gray-900:hover {\n  --border-opacity: 1;\n  border-color: #1a202c;\n  border-color: rgba(26, 32, 44, var(--border-opacity));\n}\n\n.hover\\:border-red-100:hover {\n  --border-opacity: 1;\n  border-color: #fff5f5;\n  border-color: rgba(255, 245, 245, var(--border-opacity));\n}\n\n.hover\\:border-red-200:hover {\n  --border-opacity: 1;\n  border-color: #fed7d7;\n  border-color: rgba(254, 215, 215, var(--border-opacity));\n}\n\n.hover\\:border-red-300:hover {\n  --border-opacity: 1;\n  border-color: #feb2b2;\n  border-color: rgba(254, 178, 178, var(--border-opacity));\n}\n\n.hover\\:border-red-400:hover {\n  --border-opacity: 1;\n  border-color: #fc8181;\n  border-color: rgba(252, 129, 129, var(--border-opacity));\n}\n\n.hover\\:border-red-500:hover {\n  --border-opacity: 1;\n  border-color: #f56565;\n  border-color: rgba(245, 101, 101, var(--border-opacity));\n}\n\n.hover\\:border-red-600:hover {\n  --border-opacity: 1;\n  border-color: #e53e3e;\n  border-color: rgba(229, 62, 62, var(--border-opacity));\n}\n\n.hover\\:border-red-700:hover {\n  --border-opacity: 1;\n  border-color: #c53030;\n  border-color: rgba(197, 48, 48, var(--border-opacity));\n}\n\n.hover\\:border-red-800:hover {\n  --border-opacity: 1;\n  border-color: #9b2c2c;\n  border-color: rgba(155, 44, 44, var(--border-opacity));\n}\n\n.hover\\:border-red-900:hover {\n  --border-opacity: 1;\n  border-color: #742a2a;\n  border-color: rgba(116, 42, 42, var(--border-opacity));\n}\n\n.hover\\:border-orange-100:hover {\n  --border-opacity: 1;\n  border-color: #fffaf0;\n  border-color: rgba(255, 250, 240, var(--border-opacity));\n}\n\n.hover\\:border-orange-200:hover {\n  --border-opacity: 1;\n  border-color: #feebc8;\n  border-color: rgba(254, 235, 200, var(--border-opacity));\n}\n\n.hover\\:border-orange-300:hover {\n  --border-opacity: 1;\n  border-color: #fbd38d;\n  border-color: rgba(251, 211, 141, var(--border-opacity));\n}\n\n.hover\\:border-orange-400:hover {\n  --border-opacity: 1;\n  border-color: #f6ad55;\n  border-color: rgba(246, 173, 85, var(--border-opacity));\n}\n\n.hover\\:border-orange-500:hover {\n  --border-opacity: 1;\n  border-color: #ed8936;\n  border-color: rgba(237, 137, 54, var(--border-opacity));\n}\n\n.hover\\:border-orange-600:hover {\n  --border-opacity: 1;\n  border-color: #dd6b20;\n  border-color: rgba(221, 107, 32, var(--border-opacity));\n}\n\n.hover\\:border-orange-700:hover {\n  --border-opacity: 1;\n  border-color: #c05621;\n  border-color: rgba(192, 86, 33, var(--border-opacity));\n}\n\n.hover\\:border-orange-800:hover {\n  --border-opacity: 1;\n  border-color: #9c4221;\n  border-color: rgba(156, 66, 33, var(--border-opacity));\n}\n\n.hover\\:border-orange-900:hover {\n  --border-opacity: 1;\n  border-color: #7b341e;\n  border-color: rgba(123, 52, 30, var(--border-opacity));\n}\n\n.hover\\:border-yellow-100:hover {\n  --border-opacity: 1;\n  border-color: #fffff0;\n  border-color: rgba(255, 255, 240, var(--border-opacity));\n}\n\n.hover\\:border-yellow-200:hover {\n  --border-opacity: 1;\n  border-color: #fefcbf;\n  border-color: rgba(254, 252, 191, var(--border-opacity));\n}\n\n.hover\\:border-yellow-300:hover {\n  --border-opacity: 1;\n  border-color: #faf089;\n  border-color: rgba(250, 240, 137, var(--border-opacity));\n}\n\n.hover\\:border-yellow-400:hover {\n  --border-opacity: 1;\n  border-color: #f6e05e;\n  border-color: rgba(246, 224, 94, var(--border-opacity));\n}\n\n.hover\\:border-yellow-500:hover {\n  --border-opacity: 1;\n  border-color: #ecc94b;\n  border-color: rgba(236, 201, 75, var(--border-opacity));\n}\n\n.hover\\:border-yellow-600:hover {\n  --border-opacity: 1;\n  border-color: #d69e2e;\n  border-color: rgba(214, 158, 46, var(--border-opacity));\n}\n\n.hover\\:border-yellow-700:hover {\n  --border-opacity: 1;\n  border-color: #b7791f;\n  border-color: rgba(183, 121, 31, var(--border-opacity));\n}\n\n.hover\\:border-yellow-800:hover {\n  --border-opacity: 1;\n  border-color: #975a16;\n  border-color: rgba(151, 90, 22, var(--border-opacity));\n}\n\n.hover\\:border-yellow-900:hover {\n  --border-opacity: 1;\n  border-color: #744210;\n  border-color: rgba(116, 66, 16, var(--border-opacity));\n}\n\n.hover\\:border-green-100:hover {\n  --border-opacity: 1;\n  border-color: #f0fff4;\n  border-color: rgba(240, 255, 244, var(--border-opacity));\n}\n\n.hover\\:border-green-200:hover {\n  --border-opacity: 1;\n  border-color: #c6f6d5;\n  border-color: rgba(198, 246, 213, var(--border-opacity));\n}\n\n.hover\\:border-green-300:hover {\n  --border-opacity: 1;\n  border-color: #9ae6b4;\n  border-color: rgba(154, 230, 180, var(--border-opacity));\n}\n\n.hover\\:border-green-400:hover {\n  --border-opacity: 1;\n  border-color: #68d391;\n  border-color: rgba(104, 211, 145, var(--border-opacity));\n}\n\n.hover\\:border-green-500:hover {\n  --border-opacity: 1;\n  border-color: #48bb78;\n  border-color: rgba(72, 187, 120, var(--border-opacity));\n}\n\n.hover\\:border-green-600:hover {\n  --border-opacity: 1;\n  border-color: #38a169;\n  border-color: rgba(56, 161, 105, var(--border-opacity));\n}\n\n.hover\\:border-green-700:hover {\n  --border-opacity: 1;\n  border-color: #2f855a;\n  border-color: rgba(47, 133, 90, var(--border-opacity));\n}\n\n.hover\\:border-green-800:hover {\n  --border-opacity: 1;\n  border-color: #276749;\n  border-color: rgba(39, 103, 73, var(--border-opacity));\n}\n\n.hover\\:border-green-900:hover {\n  --border-opacity: 1;\n  border-color: #22543d;\n  border-color: rgba(34, 84, 61, var(--border-opacity));\n}\n\n.hover\\:border-teal-100:hover {\n  --border-opacity: 1;\n  border-color: #e6fffa;\n  border-color: rgba(230, 255, 250, var(--border-opacity));\n}\n\n.hover\\:border-teal-200:hover {\n  --border-opacity: 1;\n  border-color: #b2f5ea;\n  border-color: rgba(178, 245, 234, var(--border-opacity));\n}\n\n.hover\\:border-teal-300:hover {\n  --border-opacity: 1;\n  border-color: #81e6d9;\n  border-color: rgba(129, 230, 217, var(--border-opacity));\n}\n\n.hover\\:border-teal-400:hover {\n  --border-opacity: 1;\n  border-color: #4fd1c5;\n  border-color: rgba(79, 209, 197, var(--border-opacity));\n}\n\n.hover\\:border-teal-500:hover {\n  --border-opacity: 1;\n  border-color: #38b2ac;\n  border-color: rgba(56, 178, 172, var(--border-opacity));\n}\n\n.hover\\:border-teal-600:hover {\n  --border-opacity: 1;\n  border-color: #319795;\n  border-color: rgba(49, 151, 149, var(--border-opacity));\n}\n\n.hover\\:border-teal-700:hover {\n  --border-opacity: 1;\n  border-color: #2c7a7b;\n  border-color: rgba(44, 122, 123, var(--border-opacity));\n}\n\n.hover\\:border-teal-800:hover {\n  --border-opacity: 1;\n  border-color: #285e61;\n  border-color: rgba(40, 94, 97, var(--border-opacity));\n}\n\n.hover\\:border-teal-900:hover {\n  --border-opacity: 1;\n  border-color: #234e52;\n  border-color: rgba(35, 78, 82, var(--border-opacity));\n}\n\n.hover\\:border-blue-100:hover {\n  --border-opacity: 1;\n  border-color: #ebf8ff;\n  border-color: rgba(235, 248, 255, var(--border-opacity));\n}\n\n.hover\\:border-blue-200:hover {\n  --border-opacity: 1;\n  border-color: #bee3f8;\n  border-color: rgba(190, 227, 248, var(--border-opacity));\n}\n\n.hover\\:border-blue-300:hover {\n  --border-opacity: 1;\n  border-color: #90cdf4;\n  border-color: rgba(144, 205, 244, var(--border-opacity));\n}\n\n.hover\\:border-blue-400:hover {\n  --border-opacity: 1;\n  border-color: #63b3ed;\n  border-color: rgba(99, 179, 237, var(--border-opacity));\n}\n\n.hover\\:border-blue-500:hover {\n  --border-opacity: 1;\n  border-color: #4299e1;\n  border-color: rgba(66, 153, 225, var(--border-opacity));\n}\n\n.hover\\:border-blue-600:hover {\n  --border-opacity: 1;\n  border-color: #3182ce;\n  border-color: rgba(49, 130, 206, var(--border-opacity));\n}\n\n.hover\\:border-blue-700:hover {\n  --border-opacity: 1;\n  border-color: #2b6cb0;\n  border-color: rgba(43, 108, 176, var(--border-opacity));\n}\n\n.hover\\:border-blue-800:hover {\n  --border-opacity: 1;\n  border-color: #2c5282;\n  border-color: rgba(44, 82, 130, var(--border-opacity));\n}\n\n.hover\\:border-blue-900:hover {\n  --border-opacity: 1;\n  border-color: #2a4365;\n  border-color: rgba(42, 67, 101, var(--border-opacity));\n}\n\n.hover\\:border-indigo-100:hover {\n  --border-opacity: 1;\n  border-color: #ebf4ff;\n  border-color: rgba(235, 244, 255, var(--border-opacity));\n}\n\n.hover\\:border-indigo-200:hover {\n  --border-opacity: 1;\n  border-color: #c3dafe;\n  border-color: rgba(195, 218, 254, var(--border-opacity));\n}\n\n.hover\\:border-indigo-300:hover {\n  --border-opacity: 1;\n  border-color: #a3bffa;\n  border-color: rgba(163, 191, 250, var(--border-opacity));\n}\n\n.hover\\:border-indigo-400:hover {\n  --border-opacity: 1;\n  border-color: #7f9cf5;\n  border-color: rgba(127, 156, 245, var(--border-opacity));\n}\n\n.hover\\:border-indigo-500:hover {\n  --border-opacity: 1;\n  border-color: #667eea;\n  border-color: rgba(102, 126, 234, var(--border-opacity));\n}\n\n.hover\\:border-indigo-600:hover {\n  --border-opacity: 1;\n  border-color: #5a67d8;\n  border-color: rgba(90, 103, 216, var(--border-opacity));\n}\n\n.hover\\:border-indigo-700:hover {\n  --border-opacity: 1;\n  border-color: #4c51bf;\n  border-color: rgba(76, 81, 191, var(--border-opacity));\n}\n\n.hover\\:border-indigo-800:hover {\n  --border-opacity: 1;\n  border-color: #434190;\n  border-color: rgba(67, 65, 144, var(--border-opacity));\n}\n\n.hover\\:border-indigo-900:hover {\n  --border-opacity: 1;\n  border-color: #3c366b;\n  border-color: rgba(60, 54, 107, var(--border-opacity));\n}\n\n.hover\\:border-purple-100:hover {\n  --border-opacity: 1;\n  border-color: #faf5ff;\n  border-color: rgba(250, 245, 255, var(--border-opacity));\n}\n\n.hover\\:border-purple-200:hover {\n  --border-opacity: 1;\n  border-color: #e9d8fd;\n  border-color: rgba(233, 216, 253, var(--border-opacity));\n}\n\n.hover\\:border-purple-300:hover {\n  --border-opacity: 1;\n  border-color: #d6bcfa;\n  border-color: rgba(214, 188, 250, var(--border-opacity));\n}\n\n.hover\\:border-purple-400:hover {\n  --border-opacity: 1;\n  border-color: #b794f4;\n  border-color: rgba(183, 148, 244, var(--border-opacity));\n}\n\n.hover\\:border-purple-500:hover {\n  --border-opacity: 1;\n  border-color: #9f7aea;\n  border-color: rgba(159, 122, 234, var(--border-opacity));\n}\n\n.hover\\:border-purple-600:hover {\n  --border-opacity: 1;\n  border-color: #805ad5;\n  border-color: rgba(128, 90, 213, var(--border-opacity));\n}\n\n.hover\\:border-purple-700:hover {\n  --border-opacity: 1;\n  border-color: #6b46c1;\n  border-color: rgba(107, 70, 193, var(--border-opacity));\n}\n\n.hover\\:border-purple-800:hover {\n  --border-opacity: 1;\n  border-color: #553c9a;\n  border-color: rgba(85, 60, 154, var(--border-opacity));\n}\n\n.hover\\:border-purple-900:hover {\n  --border-opacity: 1;\n  border-color: #44337a;\n  border-color: rgba(68, 51, 122, var(--border-opacity));\n}\n\n.hover\\:border-pink-100:hover {\n  --border-opacity: 1;\n  border-color: #fff5f7;\n  border-color: rgba(255, 245, 247, var(--border-opacity));\n}\n\n.hover\\:border-pink-200:hover {\n  --border-opacity: 1;\n  border-color: #fed7e2;\n  border-color: rgba(254, 215, 226, var(--border-opacity));\n}\n\n.hover\\:border-pink-300:hover {\n  --border-opacity: 1;\n  border-color: #fbb6ce;\n  border-color: rgba(251, 182, 206, var(--border-opacity));\n}\n\n.hover\\:border-pink-400:hover {\n  --border-opacity: 1;\n  border-color: #f687b3;\n  border-color: rgba(246, 135, 179, var(--border-opacity));\n}\n\n.hover\\:border-pink-500:hover {\n  --border-opacity: 1;\n  border-color: #ed64a6;\n  border-color: rgba(237, 100, 166, var(--border-opacity));\n}\n\n.hover\\:border-pink-600:hover {\n  --border-opacity: 1;\n  border-color: #d53f8c;\n  border-color: rgba(213, 63, 140, var(--border-opacity));\n}\n\n.hover\\:border-pink-700:hover {\n  --border-opacity: 1;\n  border-color: #b83280;\n  border-color: rgba(184, 50, 128, var(--border-opacity));\n}\n\n.hover\\:border-pink-800:hover {\n  --border-opacity: 1;\n  border-color: #97266d;\n  border-color: rgba(151, 38, 109, var(--border-opacity));\n}\n\n.hover\\:border-pink-900:hover {\n  --border-opacity: 1;\n  border-color: #702459;\n  border-color: rgba(112, 36, 89, var(--border-opacity));\n}\n\n.hover\\:border-grayscale-80:hover {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 8%);\n  border-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--border-opacity));\n}\n\n.hover\\:border-grayscale-100:hover {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 10%);\n  border-color: rgba(25.5, 25.5, 25.5, var(--border-opacity));\n}\n\n.hover\\:border-grayscale-200:hover {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 20%);\n  border-color: rgba(51, 51, 51, var(--border-opacity));\n}\n\n.hover\\:border-grayscale-300:hover {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 30%);\n  border-color: rgba(76.5, 76.5, 76.5, var(--border-opacity));\n}\n\n.hover\\:border-grayscale-400:hover {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 40%);\n  border-color: rgba(102, 102, 102, var(--border-opacity));\n}\n\n.hover\\:border-grayscale-500:hover {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 50%);\n  border-color: rgba(127.5, 127.5, 127.5, var(--border-opacity));\n}\n\n.hover\\:border-grayscale-600:hover {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 60%);\n  border-color: rgba(153, 153, 153, var(--border-opacity));\n}\n\n.hover\\:border-grayscale-700:hover {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 70%);\n  border-color: rgba(178.5, 178.5, 178.5, var(--border-opacity));\n}\n\n.hover\\:border-grayscale-800:hover {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 80%);\n  border-color: rgba(204, 204, 204, var(--border-opacity));\n}\n\n.hover\\:border-grayscale-840:hover {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 84%);\n  border-color: rgba(214.2, 214.2, 214.2, var(--border-opacity));\n}\n\n.hover\\:border-grayscale-870:hover {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 87%);\n  border-color: rgba(221.85, 221.85, 221.85, var(--border-opacity));\n}\n\n.hover\\:border-grayscale-900:hover {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 90%);\n  border-color: rgba(229.5, 229.5, 229.5, var(--border-opacity));\n}\n\n.hover\\:border-grayscale-930:hover {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 93%);\n  border-color: rgba(237.15, 237.15, 237.15, var(--border-opacity));\n}\n\n.hover\\:border-primary:hover {\n  --border-opacity: 1;\n  border-color: hsl(210, 100%, 52%);\n  border-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--border-opacity));\n}\n\n.hover\\:border-background-main:hover {\n  border-color: var(--main-background);\n}\n\n.hover\\:border-background-secondary:hover {\n  border-color: var(--secondary-background);\n}\n\n.hover\\:border-foreground:hover {\n  border-color: var(--foreground);\n}\n\n.hover\\:border-panels-bg:hover {\n  border-color: var(--panels-background);\n}\n\n.focus\\:border-transparent:focus {\n  border-color: transparent;\n}\n\n.focus\\:border-current:focus {\n  border-color: currentColor;\n}\n\n.focus\\:border-black:focus {\n  --border-opacity: 1;\n  border-color: #000;\n  border-color: rgba(0, 0, 0, var(--border-opacity));\n}\n\n.focus\\:border-white:focus {\n  --border-opacity: 1;\n  border-color: #fff;\n  border-color: rgba(255, 255, 255, var(--border-opacity));\n}\n\n.focus\\:border-gray-100:focus {\n  --border-opacity: 1;\n  border-color: #f7fafc;\n  border-color: rgba(247, 250, 252, var(--border-opacity));\n}\n\n.focus\\:border-gray-200:focus {\n  --border-opacity: 1;\n  border-color: #edf2f7;\n  border-color: rgba(237, 242, 247, var(--border-opacity));\n}\n\n.focus\\:border-gray-300:focus {\n  --border-opacity: 1;\n  border-color: #e2e8f0;\n  border-color: rgba(226, 232, 240, var(--border-opacity));\n}\n\n.focus\\:border-gray-400:focus {\n  --border-opacity: 1;\n  border-color: #cbd5e0;\n  border-color: rgba(203, 213, 224, var(--border-opacity));\n}\n\n.focus\\:border-gray-500:focus {\n  --border-opacity: 1;\n  border-color: #a0aec0;\n  border-color: rgba(160, 174, 192, var(--border-opacity));\n}\n\n.focus\\:border-gray-600:focus {\n  --border-opacity: 1;\n  border-color: #718096;\n  border-color: rgba(113, 128, 150, var(--border-opacity));\n}\n\n.focus\\:border-gray-700:focus {\n  --border-opacity: 1;\n  border-color: #4a5568;\n  border-color: rgba(74, 85, 104, var(--border-opacity));\n}\n\n.focus\\:border-gray-800:focus {\n  --border-opacity: 1;\n  border-color: #2d3748;\n  border-color: rgba(45, 55, 72, var(--border-opacity));\n}\n\n.focus\\:border-gray-900:focus {\n  --border-opacity: 1;\n  border-color: #1a202c;\n  border-color: rgba(26, 32, 44, var(--border-opacity));\n}\n\n.focus\\:border-red-100:focus {\n  --border-opacity: 1;\n  border-color: #fff5f5;\n  border-color: rgba(255, 245, 245, var(--border-opacity));\n}\n\n.focus\\:border-red-200:focus {\n  --border-opacity: 1;\n  border-color: #fed7d7;\n  border-color: rgba(254, 215, 215, var(--border-opacity));\n}\n\n.focus\\:border-red-300:focus {\n  --border-opacity: 1;\n  border-color: #feb2b2;\n  border-color: rgba(254, 178, 178, var(--border-opacity));\n}\n\n.focus\\:border-red-400:focus {\n  --border-opacity: 1;\n  border-color: #fc8181;\n  border-color: rgba(252, 129, 129, var(--border-opacity));\n}\n\n.focus\\:border-red-500:focus {\n  --border-opacity: 1;\n  border-color: #f56565;\n  border-color: rgba(245, 101, 101, var(--border-opacity));\n}\n\n.focus\\:border-red-600:focus {\n  --border-opacity: 1;\n  border-color: #e53e3e;\n  border-color: rgba(229, 62, 62, var(--border-opacity));\n}\n\n.focus\\:border-red-700:focus {\n  --border-opacity: 1;\n  border-color: #c53030;\n  border-color: rgba(197, 48, 48, var(--border-opacity));\n}\n\n.focus\\:border-red-800:focus {\n  --border-opacity: 1;\n  border-color: #9b2c2c;\n  border-color: rgba(155, 44, 44, var(--border-opacity));\n}\n\n.focus\\:border-red-900:focus {\n  --border-opacity: 1;\n  border-color: #742a2a;\n  border-color: rgba(116, 42, 42, var(--border-opacity));\n}\n\n.focus\\:border-orange-100:focus {\n  --border-opacity: 1;\n  border-color: #fffaf0;\n  border-color: rgba(255, 250, 240, var(--border-opacity));\n}\n\n.focus\\:border-orange-200:focus {\n  --border-opacity: 1;\n  border-color: #feebc8;\n  border-color: rgba(254, 235, 200, var(--border-opacity));\n}\n\n.focus\\:border-orange-300:focus {\n  --border-opacity: 1;\n  border-color: #fbd38d;\n  border-color: rgba(251, 211, 141, var(--border-opacity));\n}\n\n.focus\\:border-orange-400:focus {\n  --border-opacity: 1;\n  border-color: #f6ad55;\n  border-color: rgba(246, 173, 85, var(--border-opacity));\n}\n\n.focus\\:border-orange-500:focus {\n  --border-opacity: 1;\n  border-color: #ed8936;\n  border-color: rgba(237, 137, 54, var(--border-opacity));\n}\n\n.focus\\:border-orange-600:focus {\n  --border-opacity: 1;\n  border-color: #dd6b20;\n  border-color: rgba(221, 107, 32, var(--border-opacity));\n}\n\n.focus\\:border-orange-700:focus {\n  --border-opacity: 1;\n  border-color: #c05621;\n  border-color: rgba(192, 86, 33, var(--border-opacity));\n}\n\n.focus\\:border-orange-800:focus {\n  --border-opacity: 1;\n  border-color: #9c4221;\n  border-color: rgba(156, 66, 33, var(--border-opacity));\n}\n\n.focus\\:border-orange-900:focus {\n  --border-opacity: 1;\n  border-color: #7b341e;\n  border-color: rgba(123, 52, 30, var(--border-opacity));\n}\n\n.focus\\:border-yellow-100:focus {\n  --border-opacity: 1;\n  border-color: #fffff0;\n  border-color: rgba(255, 255, 240, var(--border-opacity));\n}\n\n.focus\\:border-yellow-200:focus {\n  --border-opacity: 1;\n  border-color: #fefcbf;\n  border-color: rgba(254, 252, 191, var(--border-opacity));\n}\n\n.focus\\:border-yellow-300:focus {\n  --border-opacity: 1;\n  border-color: #faf089;\n  border-color: rgba(250, 240, 137, var(--border-opacity));\n}\n\n.focus\\:border-yellow-400:focus {\n  --border-opacity: 1;\n  border-color: #f6e05e;\n  border-color: rgba(246, 224, 94, var(--border-opacity));\n}\n\n.focus\\:border-yellow-500:focus {\n  --border-opacity: 1;\n  border-color: #ecc94b;\n  border-color: rgba(236, 201, 75, var(--border-opacity));\n}\n\n.focus\\:border-yellow-600:focus {\n  --border-opacity: 1;\n  border-color: #d69e2e;\n  border-color: rgba(214, 158, 46, var(--border-opacity));\n}\n\n.focus\\:border-yellow-700:focus {\n  --border-opacity: 1;\n  border-color: #b7791f;\n  border-color: rgba(183, 121, 31, var(--border-opacity));\n}\n\n.focus\\:border-yellow-800:focus {\n  --border-opacity: 1;\n  border-color: #975a16;\n  border-color: rgba(151, 90, 22, var(--border-opacity));\n}\n\n.focus\\:border-yellow-900:focus {\n  --border-opacity: 1;\n  border-color: #744210;\n  border-color: rgba(116, 66, 16, var(--border-opacity));\n}\n\n.focus\\:border-green-100:focus {\n  --border-opacity: 1;\n  border-color: #f0fff4;\n  border-color: rgba(240, 255, 244, var(--border-opacity));\n}\n\n.focus\\:border-green-200:focus {\n  --border-opacity: 1;\n  border-color: #c6f6d5;\n  border-color: rgba(198, 246, 213, var(--border-opacity));\n}\n\n.focus\\:border-green-300:focus {\n  --border-opacity: 1;\n  border-color: #9ae6b4;\n  border-color: rgba(154, 230, 180, var(--border-opacity));\n}\n\n.focus\\:border-green-400:focus {\n  --border-opacity: 1;\n  border-color: #68d391;\n  border-color: rgba(104, 211, 145, var(--border-opacity));\n}\n\n.focus\\:border-green-500:focus {\n  --border-opacity: 1;\n  border-color: #48bb78;\n  border-color: rgba(72, 187, 120, var(--border-opacity));\n}\n\n.focus\\:border-green-600:focus {\n  --border-opacity: 1;\n  border-color: #38a169;\n  border-color: rgba(56, 161, 105, var(--border-opacity));\n}\n\n.focus\\:border-green-700:focus {\n  --border-opacity: 1;\n  border-color: #2f855a;\n  border-color: rgba(47, 133, 90, var(--border-opacity));\n}\n\n.focus\\:border-green-800:focus {\n  --border-opacity: 1;\n  border-color: #276749;\n  border-color: rgba(39, 103, 73, var(--border-opacity));\n}\n\n.focus\\:border-green-900:focus {\n  --border-opacity: 1;\n  border-color: #22543d;\n  border-color: rgba(34, 84, 61, var(--border-opacity));\n}\n\n.focus\\:border-teal-100:focus {\n  --border-opacity: 1;\n  border-color: #e6fffa;\n  border-color: rgba(230, 255, 250, var(--border-opacity));\n}\n\n.focus\\:border-teal-200:focus {\n  --border-opacity: 1;\n  border-color: #b2f5ea;\n  border-color: rgba(178, 245, 234, var(--border-opacity));\n}\n\n.focus\\:border-teal-300:focus {\n  --border-opacity: 1;\n  border-color: #81e6d9;\n  border-color: rgba(129, 230, 217, var(--border-opacity));\n}\n\n.focus\\:border-teal-400:focus {\n  --border-opacity: 1;\n  border-color: #4fd1c5;\n  border-color: rgba(79, 209, 197, var(--border-opacity));\n}\n\n.focus\\:border-teal-500:focus {\n  --border-opacity: 1;\n  border-color: #38b2ac;\n  border-color: rgba(56, 178, 172, var(--border-opacity));\n}\n\n.focus\\:border-teal-600:focus {\n  --border-opacity: 1;\n  border-color: #319795;\n  border-color: rgba(49, 151, 149, var(--border-opacity));\n}\n\n.focus\\:border-teal-700:focus {\n  --border-opacity: 1;\n  border-color: #2c7a7b;\n  border-color: rgba(44, 122, 123, var(--border-opacity));\n}\n\n.focus\\:border-teal-800:focus {\n  --border-opacity: 1;\n  border-color: #285e61;\n  border-color: rgba(40, 94, 97, var(--border-opacity));\n}\n\n.focus\\:border-teal-900:focus {\n  --border-opacity: 1;\n  border-color: #234e52;\n  border-color: rgba(35, 78, 82, var(--border-opacity));\n}\n\n.focus\\:border-blue-100:focus {\n  --border-opacity: 1;\n  border-color: #ebf8ff;\n  border-color: rgba(235, 248, 255, var(--border-opacity));\n}\n\n.focus\\:border-blue-200:focus {\n  --border-opacity: 1;\n  border-color: #bee3f8;\n  border-color: rgba(190, 227, 248, var(--border-opacity));\n}\n\n.focus\\:border-blue-300:focus {\n  --border-opacity: 1;\n  border-color: #90cdf4;\n  border-color: rgba(144, 205, 244, var(--border-opacity));\n}\n\n.focus\\:border-blue-400:focus {\n  --border-opacity: 1;\n  border-color: #63b3ed;\n  border-color: rgba(99, 179, 237, var(--border-opacity));\n}\n\n.focus\\:border-blue-500:focus {\n  --border-opacity: 1;\n  border-color: #4299e1;\n  border-color: rgba(66, 153, 225, var(--border-opacity));\n}\n\n.focus\\:border-blue-600:focus {\n  --border-opacity: 1;\n  border-color: #3182ce;\n  border-color: rgba(49, 130, 206, var(--border-opacity));\n}\n\n.focus\\:border-blue-700:focus {\n  --border-opacity: 1;\n  border-color: #2b6cb0;\n  border-color: rgba(43, 108, 176, var(--border-opacity));\n}\n\n.focus\\:border-blue-800:focus {\n  --border-opacity: 1;\n  border-color: #2c5282;\n  border-color: rgba(44, 82, 130, var(--border-opacity));\n}\n\n.focus\\:border-blue-900:focus {\n  --border-opacity: 1;\n  border-color: #2a4365;\n  border-color: rgba(42, 67, 101, var(--border-opacity));\n}\n\n.focus\\:border-indigo-100:focus {\n  --border-opacity: 1;\n  border-color: #ebf4ff;\n  border-color: rgba(235, 244, 255, var(--border-opacity));\n}\n\n.focus\\:border-indigo-200:focus {\n  --border-opacity: 1;\n  border-color: #c3dafe;\n  border-color: rgba(195, 218, 254, var(--border-opacity));\n}\n\n.focus\\:border-indigo-300:focus {\n  --border-opacity: 1;\n  border-color: #a3bffa;\n  border-color: rgba(163, 191, 250, var(--border-opacity));\n}\n\n.focus\\:border-indigo-400:focus {\n  --border-opacity: 1;\n  border-color: #7f9cf5;\n  border-color: rgba(127, 156, 245, var(--border-opacity));\n}\n\n.focus\\:border-indigo-500:focus {\n  --border-opacity: 1;\n  border-color: #667eea;\n  border-color: rgba(102, 126, 234, var(--border-opacity));\n}\n\n.focus\\:border-indigo-600:focus {\n  --border-opacity: 1;\n  border-color: #5a67d8;\n  border-color: rgba(90, 103, 216, var(--border-opacity));\n}\n\n.focus\\:border-indigo-700:focus {\n  --border-opacity: 1;\n  border-color: #4c51bf;\n  border-color: rgba(76, 81, 191, var(--border-opacity));\n}\n\n.focus\\:border-indigo-800:focus {\n  --border-opacity: 1;\n  border-color: #434190;\n  border-color: rgba(67, 65, 144, var(--border-opacity));\n}\n\n.focus\\:border-indigo-900:focus {\n  --border-opacity: 1;\n  border-color: #3c366b;\n  border-color: rgba(60, 54, 107, var(--border-opacity));\n}\n\n.focus\\:border-purple-100:focus {\n  --border-opacity: 1;\n  border-color: #faf5ff;\n  border-color: rgba(250, 245, 255, var(--border-opacity));\n}\n\n.focus\\:border-purple-200:focus {\n  --border-opacity: 1;\n  border-color: #e9d8fd;\n  border-color: rgba(233, 216, 253, var(--border-opacity));\n}\n\n.focus\\:border-purple-300:focus {\n  --border-opacity: 1;\n  border-color: #d6bcfa;\n  border-color: rgba(214, 188, 250, var(--border-opacity));\n}\n\n.focus\\:border-purple-400:focus {\n  --border-opacity: 1;\n  border-color: #b794f4;\n  border-color: rgba(183, 148, 244, var(--border-opacity));\n}\n\n.focus\\:border-purple-500:focus {\n  --border-opacity: 1;\n  border-color: #9f7aea;\n  border-color: rgba(159, 122, 234, var(--border-opacity));\n}\n\n.focus\\:border-purple-600:focus {\n  --border-opacity: 1;\n  border-color: #805ad5;\n  border-color: rgba(128, 90, 213, var(--border-opacity));\n}\n\n.focus\\:border-purple-700:focus {\n  --border-opacity: 1;\n  border-color: #6b46c1;\n  border-color: rgba(107, 70, 193, var(--border-opacity));\n}\n\n.focus\\:border-purple-800:focus {\n  --border-opacity: 1;\n  border-color: #553c9a;\n  border-color: rgba(85, 60, 154, var(--border-opacity));\n}\n\n.focus\\:border-purple-900:focus {\n  --border-opacity: 1;\n  border-color: #44337a;\n  border-color: rgba(68, 51, 122, var(--border-opacity));\n}\n\n.focus\\:border-pink-100:focus {\n  --border-opacity: 1;\n  border-color: #fff5f7;\n  border-color: rgba(255, 245, 247, var(--border-opacity));\n}\n\n.focus\\:border-pink-200:focus {\n  --border-opacity: 1;\n  border-color: #fed7e2;\n  border-color: rgba(254, 215, 226, var(--border-opacity));\n}\n\n.focus\\:border-pink-300:focus {\n  --border-opacity: 1;\n  border-color: #fbb6ce;\n  border-color: rgba(251, 182, 206, var(--border-opacity));\n}\n\n.focus\\:border-pink-400:focus {\n  --border-opacity: 1;\n  border-color: #f687b3;\n  border-color: rgba(246, 135, 179, var(--border-opacity));\n}\n\n.focus\\:border-pink-500:focus {\n  --border-opacity: 1;\n  border-color: #ed64a6;\n  border-color: rgba(237, 100, 166, var(--border-opacity));\n}\n\n.focus\\:border-pink-600:focus {\n  --border-opacity: 1;\n  border-color: #d53f8c;\n  border-color: rgba(213, 63, 140, var(--border-opacity));\n}\n\n.focus\\:border-pink-700:focus {\n  --border-opacity: 1;\n  border-color: #b83280;\n  border-color: rgba(184, 50, 128, var(--border-opacity));\n}\n\n.focus\\:border-pink-800:focus {\n  --border-opacity: 1;\n  border-color: #97266d;\n  border-color: rgba(151, 38, 109, var(--border-opacity));\n}\n\n.focus\\:border-pink-900:focus {\n  --border-opacity: 1;\n  border-color: #702459;\n  border-color: rgba(112, 36, 89, var(--border-opacity));\n}\n\n.focus\\:border-grayscale-80:focus {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 8%);\n  border-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--border-opacity));\n}\n\n.focus\\:border-grayscale-100:focus {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 10%);\n  border-color: rgba(25.5, 25.5, 25.5, var(--border-opacity));\n}\n\n.focus\\:border-grayscale-200:focus {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 20%);\n  border-color: rgba(51, 51, 51, var(--border-opacity));\n}\n\n.focus\\:border-grayscale-300:focus {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 30%);\n  border-color: rgba(76.5, 76.5, 76.5, var(--border-opacity));\n}\n\n.focus\\:border-grayscale-400:focus {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 40%);\n  border-color: rgba(102, 102, 102, var(--border-opacity));\n}\n\n.focus\\:border-grayscale-500:focus {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 50%);\n  border-color: rgba(127.5, 127.5, 127.5, var(--border-opacity));\n}\n\n.focus\\:border-grayscale-600:focus {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 60%);\n  border-color: rgba(153, 153, 153, var(--border-opacity));\n}\n\n.focus\\:border-grayscale-700:focus {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 70%);\n  border-color: rgba(178.5, 178.5, 178.5, var(--border-opacity));\n}\n\n.focus\\:border-grayscale-800:focus {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 80%);\n  border-color: rgba(204, 204, 204, var(--border-opacity));\n}\n\n.focus\\:border-grayscale-840:focus {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 84%);\n  border-color: rgba(214.2, 214.2, 214.2, var(--border-opacity));\n}\n\n.focus\\:border-grayscale-870:focus {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 87%);\n  border-color: rgba(221.85, 221.85, 221.85, var(--border-opacity));\n}\n\n.focus\\:border-grayscale-900:focus {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 90%);\n  border-color: rgba(229.5, 229.5, 229.5, var(--border-opacity));\n}\n\n.focus\\:border-grayscale-930:focus {\n  --border-opacity: 1;\n  border-color: hsl(0, 0%, 93%);\n  border-color: rgba(237.15, 237.15, 237.15, var(--border-opacity));\n}\n\n.focus\\:border-primary:focus {\n  --border-opacity: 1;\n  border-color: hsl(210, 100%, 52%);\n  border-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--border-opacity));\n}\n\n.focus\\:border-background-main:focus {\n  border-color: var(--main-background);\n}\n\n.focus\\:border-background-secondary:focus {\n  border-color: var(--secondary-background);\n}\n\n.focus\\:border-foreground:focus {\n  border-color: var(--foreground);\n}\n\n.focus\\:border-panels-bg:focus {\n  border-color: var(--panels-background);\n}\n\n.border-opacity-0 {\n  --border-opacity: 0;\n}\n\n.border-opacity-25 {\n  --border-opacity: 0.25;\n}\n\n.border-opacity-50 {\n  --border-opacity: 0.5;\n}\n\n.border-opacity-75 {\n  --border-opacity: 0.75;\n}\n\n.border-opacity-100 {\n  --border-opacity: 1;\n}\n\n.hover\\:border-opacity-0:hover {\n  --border-opacity: 0;\n}\n\n.hover\\:border-opacity-25:hover {\n  --border-opacity: 0.25;\n}\n\n.hover\\:border-opacity-50:hover {\n  --border-opacity: 0.5;\n}\n\n.hover\\:border-opacity-75:hover {\n  --border-opacity: 0.75;\n}\n\n.hover\\:border-opacity-100:hover {\n  --border-opacity: 1;\n}\n\n.focus\\:border-opacity-0:focus {\n  --border-opacity: 0;\n}\n\n.focus\\:border-opacity-25:focus {\n  --border-opacity: 0.25;\n}\n\n.focus\\:border-opacity-50:focus {\n  --border-opacity: 0.5;\n}\n\n.focus\\:border-opacity-75:focus {\n  --border-opacity: 0.75;\n}\n\n.focus\\:border-opacity-100:focus {\n  --border-opacity: 1;\n}\n\n.rounded-none {\n  border-radius: 0;\n}\n\n.rounded-sm {\n  border-radius: 0.125rem;\n}\n\n.rounded {\n  border-radius: 0.25rem;\n}\n\n.rounded-md {\n  border-radius: 0.375rem;\n}\n\n.rounded-lg {\n  border-radius: 0.5rem;\n}\n\n.rounded-xl {\n  border-radius: 0.75rem;\n}\n\n.rounded-2xl {\n  border-radius: 1rem;\n}\n\n.rounded-3xl {\n  border-radius: 1.5rem;\n}\n\n.rounded-full {\n  border-radius: 9999px;\n}\n\n.rounded-t-none {\n  border-top-left-radius: 0;\n  border-top-right-radius: 0;\n}\n\n.rounded-r-none {\n  border-top-right-radius: 0;\n  border-bottom-right-radius: 0;\n}\n\n.rounded-b-none {\n  border-bottom-right-radius: 0;\n  border-bottom-left-radius: 0;\n}\n\n.rounded-l-none {\n  border-top-left-radius: 0;\n  border-bottom-left-radius: 0;\n}\n\n.rounded-t-sm {\n  border-top-left-radius: 0.125rem;\n  border-top-right-radius: 0.125rem;\n}\n\n.rounded-r-sm {\n  border-top-right-radius: 0.125rem;\n  border-bottom-right-radius: 0.125rem;\n}\n\n.rounded-b-sm {\n  border-bottom-right-radius: 0.125rem;\n  border-bottom-left-radius: 0.125rem;\n}\n\n.rounded-l-sm {\n  border-top-left-radius: 0.125rem;\n  border-bottom-left-radius: 0.125rem;\n}\n\n.rounded-t {\n  border-top-left-radius: 0.25rem;\n  border-top-right-radius: 0.25rem;\n}\n\n.rounded-r {\n  border-top-right-radius: 0.25rem;\n  border-bottom-right-radius: 0.25rem;\n}\n\n.rounded-b {\n  border-bottom-right-radius: 0.25rem;\n  border-bottom-left-radius: 0.25rem;\n}\n\n.rounded-l {\n  border-top-left-radius: 0.25rem;\n  border-bottom-left-radius: 0.25rem;\n}\n\n.rounded-t-md {\n  border-top-left-radius: 0.375rem;\n  border-top-right-radius: 0.375rem;\n}\n\n.rounded-r-md {\n  border-top-right-radius: 0.375rem;\n  border-bottom-right-radius: 0.375rem;\n}\n\n.rounded-b-md {\n  border-bottom-right-radius: 0.375rem;\n  border-bottom-left-radius: 0.375rem;\n}\n\n.rounded-l-md {\n  border-top-left-radius: 0.375rem;\n  border-bottom-left-radius: 0.375rem;\n}\n\n.rounded-t-lg {\n  border-top-left-radius: 0.5rem;\n  border-top-right-radius: 0.5rem;\n}\n\n.rounded-r-lg {\n  border-top-right-radius: 0.5rem;\n  border-bottom-right-radius: 0.5rem;\n}\n\n.rounded-b-lg {\n  border-bottom-right-radius: 0.5rem;\n  border-bottom-left-radius: 0.5rem;\n}\n\n.rounded-l-lg {\n  border-top-left-radius: 0.5rem;\n  border-bottom-left-radius: 0.5rem;\n}\n\n.rounded-t-xl {\n  border-top-left-radius: 0.75rem;\n  border-top-right-radius: 0.75rem;\n}\n\n.rounded-r-xl {\n  border-top-right-radius: 0.75rem;\n  border-bottom-right-radius: 0.75rem;\n}\n\n.rounded-b-xl {\n  border-bottom-right-radius: 0.75rem;\n  border-bottom-left-radius: 0.75rem;\n}\n\n.rounded-l-xl {\n  border-top-left-radius: 0.75rem;\n  border-bottom-left-radius: 0.75rem;\n}\n\n.rounded-t-2xl {\n  border-top-left-radius: 1rem;\n  border-top-right-radius: 1rem;\n}\n\n.rounded-r-2xl {\n  border-top-right-radius: 1rem;\n  border-bottom-right-radius: 1rem;\n}\n\n.rounded-b-2xl {\n  border-bottom-right-radius: 1rem;\n  border-bottom-left-radius: 1rem;\n}\n\n.rounded-l-2xl {\n  border-top-left-radius: 1rem;\n  border-bottom-left-radius: 1rem;\n}\n\n.rounded-t-3xl {\n  border-top-left-radius: 1.5rem;\n  border-top-right-radius: 1.5rem;\n}\n\n.rounded-r-3xl {\n  border-top-right-radius: 1.5rem;\n  border-bottom-right-radius: 1.5rem;\n}\n\n.rounded-b-3xl {\n  border-bottom-right-radius: 1.5rem;\n  border-bottom-left-radius: 1.5rem;\n}\n\n.rounded-l-3xl {\n  border-top-left-radius: 1.5rem;\n  border-bottom-left-radius: 1.5rem;\n}\n\n.rounded-t-full {\n  border-top-left-radius: 9999px;\n  border-top-right-radius: 9999px;\n}\n\n.rounded-r-full {\n  border-top-right-radius: 9999px;\n  border-bottom-right-radius: 9999px;\n}\n\n.rounded-b-full {\n  border-bottom-right-radius: 9999px;\n  border-bottom-left-radius: 9999px;\n}\n\n.rounded-l-full {\n  border-top-left-radius: 9999px;\n  border-bottom-left-radius: 9999px;\n}\n\n.rounded-tl-none {\n  border-top-left-radius: 0;\n}\n\n.rounded-tr-none {\n  border-top-right-radius: 0;\n}\n\n.rounded-br-none {\n  border-bottom-right-radius: 0;\n}\n\n.rounded-bl-none {\n  border-bottom-left-radius: 0;\n}\n\n.rounded-tl-sm {\n  border-top-left-radius: 0.125rem;\n}\n\n.rounded-tr-sm {\n  border-top-right-radius: 0.125rem;\n}\n\n.rounded-br-sm {\n  border-bottom-right-radius: 0.125rem;\n}\n\n.rounded-bl-sm {\n  border-bottom-left-radius: 0.125rem;\n}\n\n.rounded-tl {\n  border-top-left-radius: 0.25rem;\n}\n\n.rounded-tr {\n  border-top-right-radius: 0.25rem;\n}\n\n.rounded-br {\n  border-bottom-right-radius: 0.25rem;\n}\n\n.rounded-bl {\n  border-bottom-left-radius: 0.25rem;\n}\n\n.rounded-tl-md {\n  border-top-left-radius: 0.375rem;\n}\n\n.rounded-tr-md {\n  border-top-right-radius: 0.375rem;\n}\n\n.rounded-br-md {\n  border-bottom-right-radius: 0.375rem;\n}\n\n.rounded-bl-md {\n  border-bottom-left-radius: 0.375rem;\n}\n\n.rounded-tl-lg {\n  border-top-left-radius: 0.5rem;\n}\n\n.rounded-tr-lg {\n  border-top-right-radius: 0.5rem;\n}\n\n.rounded-br-lg {\n  border-bottom-right-radius: 0.5rem;\n}\n\n.rounded-bl-lg {\n  border-bottom-left-radius: 0.5rem;\n}\n\n.rounded-tl-xl {\n  border-top-left-radius: 0.75rem;\n}\n\n.rounded-tr-xl {\n  border-top-right-radius: 0.75rem;\n}\n\n.rounded-br-xl {\n  border-bottom-right-radius: 0.75rem;\n}\n\n.rounded-bl-xl {\n  border-bottom-left-radius: 0.75rem;\n}\n\n.rounded-tl-2xl {\n  border-top-left-radius: 1rem;\n}\n\n.rounded-tr-2xl {\n  border-top-right-radius: 1rem;\n}\n\n.rounded-br-2xl {\n  border-bottom-right-radius: 1rem;\n}\n\n.rounded-bl-2xl {\n  border-bottom-left-radius: 1rem;\n}\n\n.rounded-tl-3xl {\n  border-top-left-radius: 1.5rem;\n}\n\n.rounded-tr-3xl {\n  border-top-right-radius: 1.5rem;\n}\n\n.rounded-br-3xl {\n  border-bottom-right-radius: 1.5rem;\n}\n\n.rounded-bl-3xl {\n  border-bottom-left-radius: 1.5rem;\n}\n\n.rounded-tl-full {\n  border-top-left-radius: 9999px;\n}\n\n.rounded-tr-full {\n  border-top-right-radius: 9999px;\n}\n\n.rounded-br-full {\n  border-bottom-right-radius: 9999px;\n}\n\n.rounded-bl-full {\n  border-bottom-left-radius: 9999px;\n}\n\n.border-solid {\n  border-style: solid;\n}\n\n.border-dashed {\n  border-style: dashed;\n}\n\n.border-dotted {\n  border-style: dotted;\n}\n\n.border-double {\n  border-style: double;\n}\n\n.border-none {\n  border-style: none;\n}\n\n.border-0 {\n  border-width: 0;\n}\n\n.border-2 {\n  border-width: 2px;\n}\n\n.border-4 {\n  border-width: 4px;\n}\n\n.border-8 {\n  border-width: 8px;\n}\n\n.border {\n  border-width: 1px;\n}\n\n.border-t-0 {\n  border-top-width: 0;\n}\n\n.border-r-0 {\n  border-right-width: 0;\n}\n\n.border-b-0 {\n  border-bottom-width: 0;\n}\n\n.border-l-0 {\n  border-left-width: 0;\n}\n\n.border-t-2 {\n  border-top-width: 2px;\n}\n\n.border-r-2 {\n  border-right-width: 2px;\n}\n\n.border-b-2 {\n  border-bottom-width: 2px;\n}\n\n.border-l-2 {\n  border-left-width: 2px;\n}\n\n.border-t-4 {\n  border-top-width: 4px;\n}\n\n.border-r-4 {\n  border-right-width: 4px;\n}\n\n.border-b-4 {\n  border-bottom-width: 4px;\n}\n\n.border-l-4 {\n  border-left-width: 4px;\n}\n\n.border-t-8 {\n  border-top-width: 8px;\n}\n\n.border-r-8 {\n  border-right-width: 8px;\n}\n\n.border-b-8 {\n  border-bottom-width: 8px;\n}\n\n.border-l-8 {\n  border-left-width: 8px;\n}\n\n.border-t {\n  border-top-width: 1px;\n}\n\n.border-r {\n  border-right-width: 1px;\n}\n\n.border-b {\n  border-bottom-width: 1px;\n}\n\n.border-l {\n  border-left-width: 1px;\n}\n\n.box-border {\n  box-sizing: border-box;\n}\n\n.box-content {\n  box-sizing: content-box;\n}\n\n.cursor-auto {\n  cursor: auto;\n}\n\n.cursor-default {\n  cursor: default;\n}\n\n.cursor-pointer {\n  cursor: pointer;\n}\n\n.cursor-wait {\n  cursor: wait;\n}\n\n.cursor-text {\n  cursor: text;\n}\n\n.cursor-move {\n  cursor: move;\n}\n\n.cursor-not-allowed {\n  cursor: not-allowed;\n}\n\n.block {\n  display: block;\n}\n\n.inline-block {\n  display: inline-block;\n}\n\n.inline {\n  display: inline;\n}\n\n.flex {\n  display: flex;\n}\n\n.inline-flex {\n  display: inline-flex;\n}\n\n.table {\n  display: table;\n}\n\n.table-caption {\n  display: table-caption;\n}\n\n.table-cell {\n  display: table-cell;\n}\n\n.table-column {\n  display: table-column;\n}\n\n.table-column-group {\n  display: table-column-group;\n}\n\n.table-footer-group {\n  display: table-footer-group;\n}\n\n.table-header-group {\n  display: table-header-group;\n}\n\n.table-row-group {\n  display: table-row-group;\n}\n\n.table-row {\n  display: table-row;\n}\n\n.flow-root {\n  display: flow-root;\n}\n\n.grid {\n  display: grid;\n}\n\n.inline-grid {\n  display: inline-grid;\n}\n\n.contents {\n  display: contents;\n}\n\n.hidden {\n  display: none;\n}\n\n.flex-row {\n  flex-direction: row;\n}\n\n.flex-row-reverse {\n  flex-direction: row-reverse;\n}\n\n.flex-col {\n  flex-direction: column;\n}\n\n.flex-col-reverse {\n  flex-direction: column-reverse;\n}\n\n.flex-wrap {\n  flex-wrap: wrap;\n}\n\n.flex-wrap-reverse {\n  flex-wrap: wrap-reverse;\n}\n\n.flex-no-wrap {\n  flex-wrap: nowrap;\n}\n\n.place-items-auto {\n  place-items: auto;\n}\n\n.place-items-start {\n  place-items: start;\n}\n\n.place-items-end {\n  place-items: end;\n}\n\n.place-items-center {\n  place-items: center;\n}\n\n.place-items-stretch {\n  place-items: stretch;\n}\n\n.place-content-center {\n  place-content: center;\n}\n\n.place-content-start {\n  place-content: start;\n}\n\n.place-content-end {\n  place-content: end;\n}\n\n.place-content-between {\n  place-content: space-between;\n}\n\n.place-content-around {\n  place-content: space-around;\n}\n\n.place-content-evenly {\n  place-content: space-evenly;\n}\n\n.place-content-stretch {\n  place-content: stretch;\n}\n\n.place-self-auto {\n  place-self: auto;\n}\n\n.place-self-start {\n  place-self: start;\n}\n\n.place-self-end {\n  place-self: end;\n}\n\n.place-self-center {\n  place-self: center;\n}\n\n.place-self-stretch {\n  place-self: stretch;\n}\n\n.items-start {\n  align-items: flex-start;\n}\n\n.items-end {\n  align-items: flex-end;\n}\n\n.items-center {\n  align-items: center;\n}\n\n.items-baseline {\n  align-items: baseline;\n}\n\n.items-stretch {\n  align-items: stretch;\n}\n\n.content-center {\n  align-content: center;\n}\n\n.content-start {\n  align-content: flex-start;\n}\n\n.content-end {\n  align-content: flex-end;\n}\n\n.content-between {\n  align-content: space-between;\n}\n\n.content-around {\n  align-content: space-around;\n}\n\n.content-evenly {\n  align-content: space-evenly;\n}\n\n.self-auto {\n  align-self: auto;\n}\n\n.self-start {\n  align-self: flex-start;\n}\n\n.self-end {\n  align-self: flex-end;\n}\n\n.self-center {\n  align-self: center;\n}\n\n.self-stretch {\n  align-self: stretch;\n}\n\n.justify-items-auto {\n  justify-items: auto;\n}\n\n.justify-items-start {\n  justify-items: start;\n}\n\n.justify-items-end {\n  justify-items: end;\n}\n\n.justify-items-center {\n  justify-items: center;\n}\n\n.justify-items-stretch {\n  justify-items: stretch;\n}\n\n.justify-start {\n  justify-content: flex-start;\n}\n\n.justify-end {\n  justify-content: flex-end;\n}\n\n.justify-center {\n  justify-content: center;\n}\n\n.justify-between {\n  justify-content: space-between;\n}\n\n.justify-around {\n  justify-content: space-around;\n}\n\n.justify-evenly {\n  justify-content: space-evenly;\n}\n\n.justify-self-auto {\n  justify-self: auto;\n}\n\n.justify-self-start {\n  justify-self: start;\n}\n\n.justify-self-end {\n  justify-self: end;\n}\n\n.justify-self-center {\n  justify-self: center;\n}\n\n.justify-self-stretch {\n  justify-self: stretch;\n}\n\n.flex-1 {\n  flex: 1 1 0%;\n}\n\n.flex-auto {\n  flex: 1 1 auto;\n}\n\n.flex-initial {\n  flex: 0 1 auto;\n}\n\n.flex-none {\n  flex: none;\n}\n\n.flex-grow-0 {\n  flex-grow: 0;\n}\n\n.flex-grow {\n  flex-grow: 1;\n}\n\n.flex-shrink-0 {\n  flex-shrink: 0;\n}\n\n.flex-shrink {\n  flex-shrink: 1;\n}\n\n.order-1 {\n  order: 1;\n}\n\n.order-2 {\n  order: 2;\n}\n\n.order-3 {\n  order: 3;\n}\n\n.order-4 {\n  order: 4;\n}\n\n.order-5 {\n  order: 5;\n}\n\n.order-6 {\n  order: 6;\n}\n\n.order-7 {\n  order: 7;\n}\n\n.order-8 {\n  order: 8;\n}\n\n.order-9 {\n  order: 9;\n}\n\n.order-10 {\n  order: 10;\n}\n\n.order-11 {\n  order: 11;\n}\n\n.order-12 {\n  order: 12;\n}\n\n.order-first {\n  order: -9999;\n}\n\n.order-last {\n  order: 9999;\n}\n\n.order-none {\n  order: 0;\n}\n\n.float-right {\n  float: right;\n}\n\n.float-left {\n  float: left;\n}\n\n.float-none {\n  float: none;\n}\n\n.clearfix:after {\n  content: \"\";\n  display: table;\n  clear: both;\n}\n\n.clear-left {\n  clear: left;\n}\n\n.clear-right {\n  clear: right;\n}\n\n.clear-both {\n  clear: both;\n}\n\n.clear-none {\n  clear: none;\n}\n\n.font-sans {\n  font-family: system-ui, -apple-system, BlinkMacSystemFont, \"Segoe UI\", Roboto, \"Helvetica Neue\", Arial, \"Noto Sans\", sans-serif, \"Apple Color Emoji\", \"Segoe UI Emoji\", \"Segoe UI Symbol\", \"Noto Color Emoji\";\n}\n\n.font-serif {\n  font-family: Georgia, Cambria, \"Times New Roman\", Times, serif;\n}\n\n.font-mono {\n  font-family: Menlo, Monaco, Consolas, \"Liberation Mono\", \"Courier New\", monospace;\n}\n\n.font-hairline {\n  font-weight: 100;\n}\n\n.font-thin {\n  font-weight: 200;\n}\n\n.font-light {\n  font-weight: 300;\n}\n\n.font-normal {\n  font-weight: 400;\n}\n\n.font-medium {\n  font-weight: 500;\n}\n\n.font-semibold {\n  font-weight: 600;\n}\n\n.font-bold {\n  font-weight: 700;\n}\n\n.font-extrabold {\n  font-weight: 800;\n}\n\n.font-black {\n  font-weight: 900;\n}\n\n.hover\\:font-hairline:hover {\n  font-weight: 100;\n}\n\n.hover\\:font-thin:hover {\n  font-weight: 200;\n}\n\n.hover\\:font-light:hover {\n  font-weight: 300;\n}\n\n.hover\\:font-normal:hover {\n  font-weight: 400;\n}\n\n.hover\\:font-medium:hover {\n  font-weight: 500;\n}\n\n.hover\\:font-semibold:hover {\n  font-weight: 600;\n}\n\n.hover\\:font-bold:hover {\n  font-weight: 700;\n}\n\n.hover\\:font-extrabold:hover {\n  font-weight: 800;\n}\n\n.hover\\:font-black:hover {\n  font-weight: 900;\n}\n\n.focus\\:font-hairline:focus {\n  font-weight: 100;\n}\n\n.focus\\:font-thin:focus {\n  font-weight: 200;\n}\n\n.focus\\:font-light:focus {\n  font-weight: 300;\n}\n\n.focus\\:font-normal:focus {\n  font-weight: 400;\n}\n\n.focus\\:font-medium:focus {\n  font-weight: 500;\n}\n\n.focus\\:font-semibold:focus {\n  font-weight: 600;\n}\n\n.focus\\:font-bold:focus {\n  font-weight: 700;\n}\n\n.focus\\:font-extrabold:focus {\n  font-weight: 800;\n}\n\n.focus\\:font-black:focus {\n  font-weight: 900;\n}\n\n.h-0 {\n  height: 0;\n}\n\n.h-1 {\n  height: 0.25rem;\n}\n\n.h-2 {\n  height: 0.5rem;\n}\n\n.h-3 {\n  height: 0.75rem;\n}\n\n.h-4 {\n  height: 1rem;\n}\n\n.h-5 {\n  height: 1.25rem;\n}\n\n.h-6 {\n  height: 1.5rem;\n}\n\n.h-8 {\n  height: 2rem;\n}\n\n.h-10 {\n  height: 2.5rem;\n}\n\n.h-12 {\n  height: 3rem;\n}\n\n.h-16 {\n  height: 4rem;\n}\n\n.h-20 {\n  height: 5rem;\n}\n\n.h-24 {\n  height: 6rem;\n}\n\n.h-32 {\n  height: 8rem;\n}\n\n.h-40 {\n  height: 10rem;\n}\n\n.h-48 {\n  height: 12rem;\n}\n\n.h-56 {\n  height: 14rem;\n}\n\n.h-64 {\n  height: 16rem;\n}\n\n.h-auto {\n  height: auto;\n}\n\n.h-px {\n  height: 1px;\n}\n\n.h-full {\n  height: 100%;\n}\n\n.h-screen {\n  height: 100vh;\n}\n\n.text-xs {\n  font-size: 0.75rem;\n}\n\n.text-sm {\n  font-size: 0.875rem;\n}\n\n.text-base {\n  font-size: 1rem;\n}\n\n.text-lg {\n  font-size: 1.125rem;\n}\n\n.text-xl {\n  font-size: 1.25rem;\n}\n\n.text-2xl {\n  font-size: 1.5rem;\n}\n\n.text-3xl {\n  font-size: 1.875rem;\n}\n\n.text-4xl {\n  font-size: 2.25rem;\n}\n\n.text-5xl {\n  font-size: 3rem;\n}\n\n.text-6xl {\n  font-size: 4rem;\n}\n\n.leading-3 {\n  line-height: .75rem;\n}\n\n.leading-4 {\n  line-height: 1rem;\n}\n\n.leading-5 {\n  line-height: 1.25rem;\n}\n\n.leading-6 {\n  line-height: 1.5rem;\n}\n\n.leading-7 {\n  line-height: 1.75rem;\n}\n\n.leading-8 {\n  line-height: 2rem;\n}\n\n.leading-9 {\n  line-height: 2.25rem;\n}\n\n.leading-10 {\n  line-height: 2.5rem;\n}\n\n.leading-none {\n  line-height: 1;\n}\n\n.leading-tight {\n  line-height: 1.25;\n}\n\n.leading-snug {\n  line-height: 1.375;\n}\n\n.leading-normal {\n  line-height: 1.5;\n}\n\n.leading-relaxed {\n  line-height: 1.625;\n}\n\n.leading-loose {\n  line-height: 2;\n}\n\n.list-inside {\n  list-style-position: inside;\n}\n\n.list-outside {\n  list-style-position: outside;\n}\n\n.list-none {\n  list-style-type: none;\n}\n\n.list-disc {\n  list-style-type: disc;\n}\n\n.list-decimal {\n  list-style-type: decimal;\n}\n\n.m-0 {\n  margin: 0;\n}\n\n.m-1 {\n  margin: 0.25rem;\n}\n\n.m-2 {\n  margin: 0.5rem;\n}\n\n.m-3 {\n  margin: 0.75rem;\n}\n\n.m-4 {\n  margin: 1rem;\n}\n\n.m-5 {\n  margin: 1.25rem;\n}\n\n.m-6 {\n  margin: 1.5rem;\n}\n\n.m-8 {\n  margin: 2rem;\n}\n\n.m-10 {\n  margin: 2.5rem;\n}\n\n.m-12 {\n  margin: 3rem;\n}\n\n.m-16 {\n  margin: 4rem;\n}\n\n.m-20 {\n  margin: 5rem;\n}\n\n.m-24 {\n  margin: 6rem;\n}\n\n.m-32 {\n  margin: 8rem;\n}\n\n.m-40 {\n  margin: 10rem;\n}\n\n.m-48 {\n  margin: 12rem;\n}\n\n.m-56 {\n  margin: 14rem;\n}\n\n.m-64 {\n  margin: 16rem;\n}\n\n.m-auto {\n  margin: auto;\n}\n\n.m-px {\n  margin: 1px;\n}\n\n.-m-1 {\n  margin: -0.25rem;\n}\n\n.-m-2 {\n  margin: -0.5rem;\n}\n\n.-m-3 {\n  margin: -0.75rem;\n}\n\n.-m-4 {\n  margin: -1rem;\n}\n\n.-m-5 {\n  margin: -1.25rem;\n}\n\n.-m-6 {\n  margin: -1.5rem;\n}\n\n.-m-8 {\n  margin: -2rem;\n}\n\n.-m-10 {\n  margin: -2.5rem;\n}\n\n.-m-12 {\n  margin: -3rem;\n}\n\n.-m-16 {\n  margin: -4rem;\n}\n\n.-m-20 {\n  margin: -5rem;\n}\n\n.-m-24 {\n  margin: -6rem;\n}\n\n.-m-32 {\n  margin: -8rem;\n}\n\n.-m-40 {\n  margin: -10rem;\n}\n\n.-m-48 {\n  margin: -12rem;\n}\n\n.-m-56 {\n  margin: -14rem;\n}\n\n.-m-64 {\n  margin: -16rem;\n}\n\n.-m-px {\n  margin: -1px;\n}\n\n.my-0 {\n  margin-top: 0;\n  margin-bottom: 0;\n}\n\n.mx-0 {\n  margin-left: 0;\n  margin-right: 0;\n}\n\n.my-1 {\n  margin-top: 0.25rem;\n  margin-bottom: 0.25rem;\n}\n\n.mx-1 {\n  margin-left: 0.25rem;\n  margin-right: 0.25rem;\n}\n\n.my-2 {\n  margin-top: 0.5rem;\n  margin-bottom: 0.5rem;\n}\n\n.mx-2 {\n  margin-left: 0.5rem;\n  margin-right: 0.5rem;\n}\n\n.my-3 {\n  margin-top: 0.75rem;\n  margin-bottom: 0.75rem;\n}\n\n.mx-3 {\n  margin-left: 0.75rem;\n  margin-right: 0.75rem;\n}\n\n.my-4 {\n  margin-top: 1rem;\n  margin-bottom: 1rem;\n}\n\n.mx-4 {\n  margin-left: 1rem;\n  margin-right: 1rem;\n}\n\n.my-5 {\n  margin-top: 1.25rem;\n  margin-bottom: 1.25rem;\n}\n\n.mx-5 {\n  margin-left: 1.25rem;\n  margin-right: 1.25rem;\n}\n\n.my-6 {\n  margin-top: 1.5rem;\n  margin-bottom: 1.5rem;\n}\n\n.mx-6 {\n  margin-left: 1.5rem;\n  margin-right: 1.5rem;\n}\n\n.my-8 {\n  margin-top: 2rem;\n  margin-bottom: 2rem;\n}\n\n.mx-8 {\n  margin-left: 2rem;\n  margin-right: 2rem;\n}\n\n.my-10 {\n  margin-top: 2.5rem;\n  margin-bottom: 2.5rem;\n}\n\n.mx-10 {\n  margin-left: 2.5rem;\n  margin-right: 2.5rem;\n}\n\n.my-12 {\n  margin-top: 3rem;\n  margin-bottom: 3rem;\n}\n\n.mx-12 {\n  margin-left: 3rem;\n  margin-right: 3rem;\n}\n\n.my-16 {\n  margin-top: 4rem;\n  margin-bottom: 4rem;\n}\n\n.mx-16 {\n  margin-left: 4rem;\n  margin-right: 4rem;\n}\n\n.my-20 {\n  margin-top: 5rem;\n  margin-bottom: 5rem;\n}\n\n.mx-20 {\n  margin-left: 5rem;\n  margin-right: 5rem;\n}\n\n.my-24 {\n  margin-top: 6rem;\n  margin-bottom: 6rem;\n}\n\n.mx-24 {\n  margin-left: 6rem;\n  margin-right: 6rem;\n}\n\n.my-32 {\n  margin-top: 8rem;\n  margin-bottom: 8rem;\n}\n\n.mx-32 {\n  margin-left: 8rem;\n  margin-right: 8rem;\n}\n\n.my-40 {\n  margin-top: 10rem;\n  margin-bottom: 10rem;\n}\n\n.mx-40 {\n  margin-left: 10rem;\n  margin-right: 10rem;\n}\n\n.my-48 {\n  margin-top: 12rem;\n  margin-bottom: 12rem;\n}\n\n.mx-48 {\n  margin-left: 12rem;\n  margin-right: 12rem;\n}\n\n.my-56 {\n  margin-top: 14rem;\n  margin-bottom: 14rem;\n}\n\n.mx-56 {\n  margin-left: 14rem;\n  margin-right: 14rem;\n}\n\n.my-64 {\n  margin-top: 16rem;\n  margin-bottom: 16rem;\n}\n\n.mx-64 {\n  margin-left: 16rem;\n  margin-right: 16rem;\n}\n\n.my-auto {\n  margin-top: auto;\n  margin-bottom: auto;\n}\n\n.mx-auto {\n  margin-left: auto;\n  margin-right: auto;\n}\n\n.my-px {\n  margin-top: 1px;\n  margin-bottom: 1px;\n}\n\n.mx-px {\n  margin-left: 1px;\n  margin-right: 1px;\n}\n\n.-my-1 {\n  margin-top: -0.25rem;\n  margin-bottom: -0.25rem;\n}\n\n.-mx-1 {\n  margin-left: -0.25rem;\n  margin-right: -0.25rem;\n}\n\n.-my-2 {\n  margin-top: -0.5rem;\n  margin-bottom: -0.5rem;\n}\n\n.-mx-2 {\n  margin-left: -0.5rem;\n  margin-right: -0.5rem;\n}\n\n.-my-3 {\n  margin-top: -0.75rem;\n  margin-bottom: -0.75rem;\n}\n\n.-mx-3 {\n  margin-left: -0.75rem;\n  margin-right: -0.75rem;\n}\n\n.-my-4 {\n  margin-top: -1rem;\n  margin-bottom: -1rem;\n}\n\n.-mx-4 {\n  margin-left: -1rem;\n  margin-right: -1rem;\n}\n\n.-my-5 {\n  margin-top: -1.25rem;\n  margin-bottom: -1.25rem;\n}\n\n.-mx-5 {\n  margin-left: -1.25rem;\n  margin-right: -1.25rem;\n}\n\n.-my-6 {\n  margin-top: -1.5rem;\n  margin-bottom: -1.5rem;\n}\n\n.-mx-6 {\n  margin-left: -1.5rem;\n  margin-right: -1.5rem;\n}\n\n.-my-8 {\n  margin-top: -2rem;\n  margin-bottom: -2rem;\n}\n\n.-mx-8 {\n  margin-left: -2rem;\n  margin-right: -2rem;\n}\n\n.-my-10 {\n  margin-top: -2.5rem;\n  margin-bottom: -2.5rem;\n}\n\n.-mx-10 {\n  margin-left: -2.5rem;\n  margin-right: -2.5rem;\n}\n\n.-my-12 {\n  margin-top: -3rem;\n  margin-bottom: -3rem;\n}\n\n.-mx-12 {\n  margin-left: -3rem;\n  margin-right: -3rem;\n}\n\n.-my-16 {\n  margin-top: -4rem;\n  margin-bottom: -4rem;\n}\n\n.-mx-16 {\n  margin-left: -4rem;\n  margin-right: -4rem;\n}\n\n.-my-20 {\n  margin-top: -5rem;\n  margin-bottom: -5rem;\n}\n\n.-mx-20 {\n  margin-left: -5rem;\n  margin-right: -5rem;\n}\n\n.-my-24 {\n  margin-top: -6rem;\n  margin-bottom: -6rem;\n}\n\n.-mx-24 {\n  margin-left: -6rem;\n  margin-right: -6rem;\n}\n\n.-my-32 {\n  margin-top: -8rem;\n  margin-bottom: -8rem;\n}\n\n.-mx-32 {\n  margin-left: -8rem;\n  margin-right: -8rem;\n}\n\n.-my-40 {\n  margin-top: -10rem;\n  margin-bottom: -10rem;\n}\n\n.-mx-40 {\n  margin-left: -10rem;\n  margin-right: -10rem;\n}\n\n.-my-48 {\n  margin-top: -12rem;\n  margin-bottom: -12rem;\n}\n\n.-mx-48 {\n  margin-left: -12rem;\n  margin-right: -12rem;\n}\n\n.-my-56 {\n  margin-top: -14rem;\n  margin-bottom: -14rem;\n}\n\n.-mx-56 {\n  margin-left: -14rem;\n  margin-right: -14rem;\n}\n\n.-my-64 {\n  margin-top: -16rem;\n  margin-bottom: -16rem;\n}\n\n.-mx-64 {\n  margin-left: -16rem;\n  margin-right: -16rem;\n}\n\n.-my-px {\n  margin-top: -1px;\n  margin-bottom: -1px;\n}\n\n.-mx-px {\n  margin-left: -1px;\n  margin-right: -1px;\n}\n\n.mt-0 {\n  margin-top: 0;\n}\n\n.mr-0 {\n  margin-right: 0;\n}\n\n.mb-0 {\n  margin-bottom: 0;\n}\n\n.ml-0 {\n  margin-left: 0;\n}\n\n.mt-1 {\n  margin-top: 0.25rem;\n}\n\n.mr-1 {\n  margin-right: 0.25rem;\n}\n\n.mb-1 {\n  margin-bottom: 0.25rem;\n}\n\n.ml-1 {\n  margin-left: 0.25rem;\n}\n\n.mt-2 {\n  margin-top: 0.5rem;\n}\n\n.mr-2 {\n  margin-right: 0.5rem;\n}\n\n.mb-2 {\n  margin-bottom: 0.5rem;\n}\n\n.ml-2 {\n  margin-left: 0.5rem;\n}\n\n.mt-3 {\n  margin-top: 0.75rem;\n}\n\n.mr-3 {\n  margin-right: 0.75rem;\n}\n\n.mb-3 {\n  margin-bottom: 0.75rem;\n}\n\n.ml-3 {\n  margin-left: 0.75rem;\n}\n\n.mt-4 {\n  margin-top: 1rem;\n}\n\n.mr-4 {\n  margin-right: 1rem;\n}\n\n.mb-4 {\n  margin-bottom: 1rem;\n}\n\n.ml-4 {\n  margin-left: 1rem;\n}\n\n.mt-5 {\n  margin-top: 1.25rem;\n}\n\n.mr-5 {\n  margin-right: 1.25rem;\n}\n\n.mb-5 {\n  margin-bottom: 1.25rem;\n}\n\n.ml-5 {\n  margin-left: 1.25rem;\n}\n\n.mt-6 {\n  margin-top: 1.5rem;\n}\n\n.mr-6 {\n  margin-right: 1.5rem;\n}\n\n.mb-6 {\n  margin-bottom: 1.5rem;\n}\n\n.ml-6 {\n  margin-left: 1.5rem;\n}\n\n.mt-8 {\n  margin-top: 2rem;\n}\n\n.mr-8 {\n  margin-right: 2rem;\n}\n\n.mb-8 {\n  margin-bottom: 2rem;\n}\n\n.ml-8 {\n  margin-left: 2rem;\n}\n\n.mt-10 {\n  margin-top: 2.5rem;\n}\n\n.mr-10 {\n  margin-right: 2.5rem;\n}\n\n.mb-10 {\n  margin-bottom: 2.5rem;\n}\n\n.ml-10 {\n  margin-left: 2.5rem;\n}\n\n.mt-12 {\n  margin-top: 3rem;\n}\n\n.mr-12 {\n  margin-right: 3rem;\n}\n\n.mb-12 {\n  margin-bottom: 3rem;\n}\n\n.ml-12 {\n  margin-left: 3rem;\n}\n\n.mt-16 {\n  margin-top: 4rem;\n}\n\n.mr-16 {\n  margin-right: 4rem;\n}\n\n.mb-16 {\n  margin-bottom: 4rem;\n}\n\n.ml-16 {\n  margin-left: 4rem;\n}\n\n.mt-20 {\n  margin-top: 5rem;\n}\n\n.mr-20 {\n  margin-right: 5rem;\n}\n\n.mb-20 {\n  margin-bottom: 5rem;\n}\n\n.ml-20 {\n  margin-left: 5rem;\n}\n\n.mt-24 {\n  margin-top: 6rem;\n}\n\n.mr-24 {\n  margin-right: 6rem;\n}\n\n.mb-24 {\n  margin-bottom: 6rem;\n}\n\n.ml-24 {\n  margin-left: 6rem;\n}\n\n.mt-32 {\n  margin-top: 8rem;\n}\n\n.mr-32 {\n  margin-right: 8rem;\n}\n\n.mb-32 {\n  margin-bottom: 8rem;\n}\n\n.ml-32 {\n  margin-left: 8rem;\n}\n\n.mt-40 {\n  margin-top: 10rem;\n}\n\n.mr-40 {\n  margin-right: 10rem;\n}\n\n.mb-40 {\n  margin-bottom: 10rem;\n}\n\n.ml-40 {\n  margin-left: 10rem;\n}\n\n.mt-48 {\n  margin-top: 12rem;\n}\n\n.mr-48 {\n  margin-right: 12rem;\n}\n\n.mb-48 {\n  margin-bottom: 12rem;\n}\n\n.ml-48 {\n  margin-left: 12rem;\n}\n\n.mt-56 {\n  margin-top: 14rem;\n}\n\n.mr-56 {\n  margin-right: 14rem;\n}\n\n.mb-56 {\n  margin-bottom: 14rem;\n}\n\n.ml-56 {\n  margin-left: 14rem;\n}\n\n.mt-64 {\n  margin-top: 16rem;\n}\n\n.mr-64 {\n  margin-right: 16rem;\n}\n\n.mb-64 {\n  margin-bottom: 16rem;\n}\n\n.ml-64 {\n  margin-left: 16rem;\n}\n\n.mt-auto {\n  margin-top: auto;\n}\n\n.mr-auto {\n  margin-right: auto;\n}\n\n.mb-auto {\n  margin-bottom: auto;\n}\n\n.ml-auto {\n  margin-left: auto;\n}\n\n.mt-px {\n  margin-top: 1px;\n}\n\n.mr-px {\n  margin-right: 1px;\n}\n\n.mb-px {\n  margin-bottom: 1px;\n}\n\n.ml-px {\n  margin-left: 1px;\n}\n\n.-mt-1 {\n  margin-top: -0.25rem;\n}\n\n.-mr-1 {\n  margin-right: -0.25rem;\n}\n\n.-mb-1 {\n  margin-bottom: -0.25rem;\n}\n\n.-ml-1 {\n  margin-left: -0.25rem;\n}\n\n.-mt-2 {\n  margin-top: -0.5rem;\n}\n\n.-mr-2 {\n  margin-right: -0.5rem;\n}\n\n.-mb-2 {\n  margin-bottom: -0.5rem;\n}\n\n.-ml-2 {\n  margin-left: -0.5rem;\n}\n\n.-mt-3 {\n  margin-top: -0.75rem;\n}\n\n.-mr-3 {\n  margin-right: -0.75rem;\n}\n\n.-mb-3 {\n  margin-bottom: -0.75rem;\n}\n\n.-ml-3 {\n  margin-left: -0.75rem;\n}\n\n.-mt-4 {\n  margin-top: -1rem;\n}\n\n.-mr-4 {\n  margin-right: -1rem;\n}\n\n.-mb-4 {\n  margin-bottom: -1rem;\n}\n\n.-ml-4 {\n  margin-left: -1rem;\n}\n\n.-mt-5 {\n  margin-top: -1.25rem;\n}\n\n.-mr-5 {\n  margin-right: -1.25rem;\n}\n\n.-mb-5 {\n  margin-bottom: -1.25rem;\n}\n\n.-ml-5 {\n  margin-left: -1.25rem;\n}\n\n.-mt-6 {\n  margin-top: -1.5rem;\n}\n\n.-mr-6 {\n  margin-right: -1.5rem;\n}\n\n.-mb-6 {\n  margin-bottom: -1.5rem;\n}\n\n.-ml-6 {\n  margin-left: -1.5rem;\n}\n\n.-mt-8 {\n  margin-top: -2rem;\n}\n\n.-mr-8 {\n  margin-right: -2rem;\n}\n\n.-mb-8 {\n  margin-bottom: -2rem;\n}\n\n.-ml-8 {\n  margin-left: -2rem;\n}\n\n.-mt-10 {\n  margin-top: -2.5rem;\n}\n\n.-mr-10 {\n  margin-right: -2.5rem;\n}\n\n.-mb-10 {\n  margin-bottom: -2.5rem;\n}\n\n.-ml-10 {\n  margin-left: -2.5rem;\n}\n\n.-mt-12 {\n  margin-top: -3rem;\n}\n\n.-mr-12 {\n  margin-right: -3rem;\n}\n\n.-mb-12 {\n  margin-bottom: -3rem;\n}\n\n.-ml-12 {\n  margin-left: -3rem;\n}\n\n.-mt-16 {\n  margin-top: -4rem;\n}\n\n.-mr-16 {\n  margin-right: -4rem;\n}\n\n.-mb-16 {\n  margin-bottom: -4rem;\n}\n\n.-ml-16 {\n  margin-left: -4rem;\n}\n\n.-mt-20 {\n  margin-top: -5rem;\n}\n\n.-mr-20 {\n  margin-right: -5rem;\n}\n\n.-mb-20 {\n  margin-bottom: -5rem;\n}\n\n.-ml-20 {\n  margin-left: -5rem;\n}\n\n.-mt-24 {\n  margin-top: -6rem;\n}\n\n.-mr-24 {\n  margin-right: -6rem;\n}\n\n.-mb-24 {\n  margin-bottom: -6rem;\n}\n\n.-ml-24 {\n  margin-left: -6rem;\n}\n\n.-mt-32 {\n  margin-top: -8rem;\n}\n\n.-mr-32 {\n  margin-right: -8rem;\n}\n\n.-mb-32 {\n  margin-bottom: -8rem;\n}\n\n.-ml-32 {\n  margin-left: -8rem;\n}\n\n.-mt-40 {\n  margin-top: -10rem;\n}\n\n.-mr-40 {\n  margin-right: -10rem;\n}\n\n.-mb-40 {\n  margin-bottom: -10rem;\n}\n\n.-ml-40 {\n  margin-left: -10rem;\n}\n\n.-mt-48 {\n  margin-top: -12rem;\n}\n\n.-mr-48 {\n  margin-right: -12rem;\n}\n\n.-mb-48 {\n  margin-bottom: -12rem;\n}\n\n.-ml-48 {\n  margin-left: -12rem;\n}\n\n.-mt-56 {\n  margin-top: -14rem;\n}\n\n.-mr-56 {\n  margin-right: -14rem;\n}\n\n.-mb-56 {\n  margin-bottom: -14rem;\n}\n\n.-ml-56 {\n  margin-left: -14rem;\n}\n\n.-mt-64 {\n  margin-top: -16rem;\n}\n\n.-mr-64 {\n  margin-right: -16rem;\n}\n\n.-mb-64 {\n  margin-bottom: -16rem;\n}\n\n.-ml-64 {\n  margin-left: -16rem;\n}\n\n.-mt-px {\n  margin-top: -1px;\n}\n\n.-mr-px {\n  margin-right: -1px;\n}\n\n.-mb-px {\n  margin-bottom: -1px;\n}\n\n.-ml-px {\n  margin-left: -1px;\n}\n\n.max-h-full {\n  max-height: 100%;\n}\n\n.max-h-screen {\n  max-height: 100vh;\n}\n\n.max-w-none {\n  max-width: none;\n}\n\n.max-w-xs {\n  max-width: 20rem;\n}\n\n.max-w-sm {\n  max-width: 24rem;\n}\n\n.max-w-md {\n  max-width: 28rem;\n}\n\n.max-w-lg {\n  max-width: 32rem;\n}\n\n.max-w-xl {\n  max-width: 36rem;\n}\n\n.max-w-2xl {\n  max-width: 42rem;\n}\n\n.max-w-3xl {\n  max-width: 48rem;\n}\n\n.max-w-4xl {\n  max-width: 56rem;\n}\n\n.max-w-5xl {\n  max-width: 64rem;\n}\n\n.max-w-6xl {\n  max-width: 72rem;\n}\n\n.max-w-full {\n  max-width: 100%;\n}\n\n.max-w-screen-sm {\n  max-width: 640px;\n}\n\n.max-w-screen-md {\n  max-width: 768px;\n}\n\n.max-w-screen-lg {\n  max-width: 1024px;\n}\n\n.max-w-screen-xl {\n  max-width: 1280px;\n}\n\n.min-h-0 {\n  min-height: 0;\n}\n\n.min-h-full {\n  min-height: 100%;\n}\n\n.min-h-screen {\n  min-height: 100vh;\n}\n\n.min-w-0 {\n  min-width: 0;\n}\n\n.min-w-full {\n  min-width: 100%;\n}\n\n.object-contain {\n  -o-object-fit: contain;\n     object-fit: contain;\n}\n\n.object-cover {\n  -o-object-fit: cover;\n     object-fit: cover;\n}\n\n.object-fill {\n  -o-object-fit: fill;\n     object-fit: fill;\n}\n\n.object-none {\n  -o-object-fit: none;\n     object-fit: none;\n}\n\n.object-scale-down {\n  -o-object-fit: scale-down;\n     object-fit: scale-down;\n}\n\n.object-bottom {\n  -o-object-position: bottom;\n     object-position: bottom;\n}\n\n.object-center {\n  -o-object-position: center;\n     object-position: center;\n}\n\n.object-left {\n  -o-object-position: left;\n     object-position: left;\n}\n\n.object-left-bottom {\n  -o-object-position: left bottom;\n     object-position: left bottom;\n}\n\n.object-left-top {\n  -o-object-position: left top;\n     object-position: left top;\n}\n\n.object-right {\n  -o-object-position: right;\n     object-position: right;\n}\n\n.object-right-bottom {\n  -o-object-position: right bottom;\n     object-position: right bottom;\n}\n\n.object-right-top {\n  -o-object-position: right top;\n     object-position: right top;\n}\n\n.object-top {\n  -o-object-position: top;\n     object-position: top;\n}\n\n.opacity-0 {\n  opacity: 0;\n}\n\n.opacity-25 {\n  opacity: 0.25;\n}\n\n.opacity-50 {\n  opacity: 0.5;\n}\n\n.opacity-75 {\n  opacity: 0.75;\n}\n\n.opacity-100 {\n  opacity: 1;\n}\n\n.hover\\:opacity-0:hover {\n  opacity: 0;\n}\n\n.hover\\:opacity-25:hover {\n  opacity: 0.25;\n}\n\n.hover\\:opacity-50:hover {\n  opacity: 0.5;\n}\n\n.hover\\:opacity-75:hover {\n  opacity: 0.75;\n}\n\n.hover\\:opacity-100:hover {\n  opacity: 1;\n}\n\n.focus\\:opacity-0:focus {\n  opacity: 0;\n}\n\n.focus\\:opacity-25:focus {\n  opacity: 0.25;\n}\n\n.focus\\:opacity-50:focus {\n  opacity: 0.5;\n}\n\n.focus\\:opacity-75:focus {\n  opacity: 0.75;\n}\n\n.focus\\:opacity-100:focus {\n  opacity: 1;\n}\n\n.outline-none {\n  outline: 2px solid transparent;\n  outline-offset: 2px;\n}\n\n.outline-white {\n  outline: 2px dotted white;\n  outline-offset: 2px;\n}\n\n.outline-black {\n  outline: 2px dotted black;\n  outline-offset: 2px;\n}\n\n.focus\\:outline-none:focus {\n  outline: 2px solid transparent;\n  outline-offset: 2px;\n}\n\n.focus\\:outline-white:focus {\n  outline: 2px dotted white;\n  outline-offset: 2px;\n}\n\n.focus\\:outline-black:focus {\n  outline: 2px dotted black;\n  outline-offset: 2px;\n}\n\n.overflow-auto {\n  overflow: auto;\n}\n\n.overflow-hidden {\n  overflow: hidden;\n}\n\n.overflow-visible {\n  overflow: visible;\n}\n\n.overflow-scroll {\n  overflow: scroll;\n}\n\n.overflow-x-auto {\n  overflow-x: auto;\n}\n\n.overflow-y-auto {\n  overflow-y: auto;\n}\n\n.overflow-x-hidden {\n  overflow-x: hidden;\n}\n\n.overflow-y-hidden {\n  overflow-y: hidden;\n}\n\n.overflow-x-visible {\n  overflow-x: visible;\n}\n\n.overflow-y-visible {\n  overflow-y: visible;\n}\n\n.overflow-x-scroll {\n  overflow-x: scroll;\n}\n\n.overflow-y-scroll {\n  overflow-y: scroll;\n}\n\n.scrolling-touch {\n  -webkit-overflow-scrolling: touch;\n}\n\n.scrolling-auto {\n  -webkit-overflow-scrolling: auto;\n}\n\n.overscroll-auto {\n  -ms-scroll-chaining: chained;\n      overscroll-behavior: auto;\n}\n\n.overscroll-contain {\n  -ms-scroll-chaining: none;\n      overscroll-behavior: contain;\n}\n\n.overscroll-none {\n  -ms-scroll-chaining: none;\n      overscroll-behavior: none;\n}\n\n.overscroll-y-auto {\n  overscroll-behavior-y: auto;\n}\n\n.overscroll-y-contain {\n  overscroll-behavior-y: contain;\n}\n\n.overscroll-y-none {\n  overscroll-behavior-y: none;\n}\n\n.overscroll-x-auto {\n  overscroll-behavior-x: auto;\n}\n\n.overscroll-x-contain {\n  overscroll-behavior-x: contain;\n}\n\n.overscroll-x-none {\n  overscroll-behavior-x: none;\n}\n\n.p-0 {\n  padding: 0;\n}\n\n.p-1 {\n  padding: 0.25rem;\n}\n\n.p-2 {\n  padding: 0.5rem;\n}\n\n.p-3 {\n  padding: 0.75rem;\n}\n\n.p-4 {\n  padding: 1rem;\n}\n\n.p-5 {\n  padding: 1.25rem;\n}\n\n.p-6 {\n  padding: 1.5rem;\n}\n\n.p-8 {\n  padding: 2rem;\n}\n\n.p-10 {\n  padding: 2.5rem;\n}\n\n.p-12 {\n  padding: 3rem;\n}\n\n.p-16 {\n  padding: 4rem;\n}\n\n.p-20 {\n  padding: 5rem;\n}\n\n.p-24 {\n  padding: 6rem;\n}\n\n.p-32 {\n  padding: 8rem;\n}\n\n.p-40 {\n  padding: 10rem;\n}\n\n.p-48 {\n  padding: 12rem;\n}\n\n.p-56 {\n  padding: 14rem;\n}\n\n.p-64 {\n  padding: 16rem;\n}\n\n.p-px {\n  padding: 1px;\n}\n\n.py-0 {\n  padding-top: 0;\n  padding-bottom: 0;\n}\n\n.px-0 {\n  padding-left: 0;\n  padding-right: 0;\n}\n\n.py-1 {\n  padding-top: 0.25rem;\n  padding-bottom: 0.25rem;\n}\n\n.px-1 {\n  padding-left: 0.25rem;\n  padding-right: 0.25rem;\n}\n\n.py-2 {\n  padding-top: 0.5rem;\n  padding-bottom: 0.5rem;\n}\n\n.px-2 {\n  padding-left: 0.5rem;\n  padding-right: 0.5rem;\n}\n\n.py-3 {\n  padding-top: 0.75rem;\n  padding-bottom: 0.75rem;\n}\n\n.px-3 {\n  padding-left: 0.75rem;\n  padding-right: 0.75rem;\n}\n\n.py-4 {\n  padding-top: 1rem;\n  padding-bottom: 1rem;\n}\n\n.px-4 {\n  padding-left: 1rem;\n  padding-right: 1rem;\n}\n\n.py-5 {\n  padding-top: 1.25rem;\n  padding-bottom: 1.25rem;\n}\n\n.px-5 {\n  padding-left: 1.25rem;\n  padding-right: 1.25rem;\n}\n\n.py-6 {\n  padding-top: 1.5rem;\n  padding-bottom: 1.5rem;\n}\n\n.px-6 {\n  padding-left: 1.5rem;\n  padding-right: 1.5rem;\n}\n\n.py-8 {\n  padding-top: 2rem;\n  padding-bottom: 2rem;\n}\n\n.px-8 {\n  padding-left: 2rem;\n  padding-right: 2rem;\n}\n\n.py-10 {\n  padding-top: 2.5rem;\n  padding-bottom: 2.5rem;\n}\n\n.px-10 {\n  padding-left: 2.5rem;\n  padding-right: 2.5rem;\n}\n\n.py-12 {\n  padding-top: 3rem;\n  padding-bottom: 3rem;\n}\n\n.px-12 {\n  padding-left: 3rem;\n  padding-right: 3rem;\n}\n\n.py-16 {\n  padding-top: 4rem;\n  padding-bottom: 4rem;\n}\n\n.px-16 {\n  padding-left: 4rem;\n  padding-right: 4rem;\n}\n\n.py-20 {\n  padding-top: 5rem;\n  padding-bottom: 5rem;\n}\n\n.px-20 {\n  padding-left: 5rem;\n  padding-right: 5rem;\n}\n\n.py-24 {\n  padding-top: 6rem;\n  padding-bottom: 6rem;\n}\n\n.px-24 {\n  padding-left: 6rem;\n  padding-right: 6rem;\n}\n\n.py-32 {\n  padding-top: 8rem;\n  padding-bottom: 8rem;\n}\n\n.px-32 {\n  padding-left: 8rem;\n  padding-right: 8rem;\n}\n\n.py-40 {\n  padding-top: 10rem;\n  padding-bottom: 10rem;\n}\n\n.px-40 {\n  padding-left: 10rem;\n  padding-right: 10rem;\n}\n\n.py-48 {\n  padding-top: 12rem;\n  padding-bottom: 12rem;\n}\n\n.px-48 {\n  padding-left: 12rem;\n  padding-right: 12rem;\n}\n\n.py-56 {\n  padding-top: 14rem;\n  padding-bottom: 14rem;\n}\n\n.px-56 {\n  padding-left: 14rem;\n  padding-right: 14rem;\n}\n\n.py-64 {\n  padding-top: 16rem;\n  padding-bottom: 16rem;\n}\n\n.px-64 {\n  padding-left: 16rem;\n  padding-right: 16rem;\n}\n\n.py-px {\n  padding-top: 1px;\n  padding-bottom: 1px;\n}\n\n.px-px {\n  padding-left: 1px;\n  padding-right: 1px;\n}\n\n.pt-0 {\n  padding-top: 0;\n}\n\n.pr-0 {\n  padding-right: 0;\n}\n\n.pb-0 {\n  padding-bottom: 0;\n}\n\n.pl-0 {\n  padding-left: 0;\n}\n\n.pt-1 {\n  padding-top: 0.25rem;\n}\n\n.pr-1 {\n  padding-right: 0.25rem;\n}\n\n.pb-1 {\n  padding-bottom: 0.25rem;\n}\n\n.pl-1 {\n  padding-left: 0.25rem;\n}\n\n.pt-2 {\n  padding-top: 0.5rem;\n}\n\n.pr-2 {\n  padding-right: 0.5rem;\n}\n\n.pb-2 {\n  padding-bottom: 0.5rem;\n}\n\n.pl-2 {\n  padding-left: 0.5rem;\n}\n\n.pt-3 {\n  padding-top: 0.75rem;\n}\n\n.pr-3 {\n  padding-right: 0.75rem;\n}\n\n.pb-3 {\n  padding-bottom: 0.75rem;\n}\n\n.pl-3 {\n  padding-left: 0.75rem;\n}\n\n.pt-4 {\n  padding-top: 1rem;\n}\n\n.pr-4 {\n  padding-right: 1rem;\n}\n\n.pb-4 {\n  padding-bottom: 1rem;\n}\n\n.pl-4 {\n  padding-left: 1rem;\n}\n\n.pt-5 {\n  padding-top: 1.25rem;\n}\n\n.pr-5 {\n  padding-right: 1.25rem;\n}\n\n.pb-5 {\n  padding-bottom: 1.25rem;\n}\n\n.pl-5 {\n  padding-left: 1.25rem;\n}\n\n.pt-6 {\n  padding-top: 1.5rem;\n}\n\n.pr-6 {\n  padding-right: 1.5rem;\n}\n\n.pb-6 {\n  padding-bottom: 1.5rem;\n}\n\n.pl-6 {\n  padding-left: 1.5rem;\n}\n\n.pt-8 {\n  padding-top: 2rem;\n}\n\n.pr-8 {\n  padding-right: 2rem;\n}\n\n.pb-8 {\n  padding-bottom: 2rem;\n}\n\n.pl-8 {\n  padding-left: 2rem;\n}\n\n.pt-10 {\n  padding-top: 2.5rem;\n}\n\n.pr-10 {\n  padding-right: 2.5rem;\n}\n\n.pb-10 {\n  padding-bottom: 2.5rem;\n}\n\n.pl-10 {\n  padding-left: 2.5rem;\n}\n\n.pt-12 {\n  padding-top: 3rem;\n}\n\n.pr-12 {\n  padding-right: 3rem;\n}\n\n.pb-12 {\n  padding-bottom: 3rem;\n}\n\n.pl-12 {\n  padding-left: 3rem;\n}\n\n.pt-16 {\n  padding-top: 4rem;\n}\n\n.pr-16 {\n  padding-right: 4rem;\n}\n\n.pb-16 {\n  padding-bottom: 4rem;\n}\n\n.pl-16 {\n  padding-left: 4rem;\n}\n\n.pt-20 {\n  padding-top: 5rem;\n}\n\n.pr-20 {\n  padding-right: 5rem;\n}\n\n.pb-20 {\n  padding-bottom: 5rem;\n}\n\n.pl-20 {\n  padding-left: 5rem;\n}\n\n.pt-24 {\n  padding-top: 6rem;\n}\n\n.pr-24 {\n  padding-right: 6rem;\n}\n\n.pb-24 {\n  padding-bottom: 6rem;\n}\n\n.pl-24 {\n  padding-left: 6rem;\n}\n\n.pt-32 {\n  padding-top: 8rem;\n}\n\n.pr-32 {\n  padding-right: 8rem;\n}\n\n.pb-32 {\n  padding-bottom: 8rem;\n}\n\n.pl-32 {\n  padding-left: 8rem;\n}\n\n.pt-40 {\n  padding-top: 10rem;\n}\n\n.pr-40 {\n  padding-right: 10rem;\n}\n\n.pb-40 {\n  padding-bottom: 10rem;\n}\n\n.pl-40 {\n  padding-left: 10rem;\n}\n\n.pt-48 {\n  padding-top: 12rem;\n}\n\n.pr-48 {\n  padding-right: 12rem;\n}\n\n.pb-48 {\n  padding-bottom: 12rem;\n}\n\n.pl-48 {\n  padding-left: 12rem;\n}\n\n.pt-56 {\n  padding-top: 14rem;\n}\n\n.pr-56 {\n  padding-right: 14rem;\n}\n\n.pb-56 {\n  padding-bottom: 14rem;\n}\n\n.pl-56 {\n  padding-left: 14rem;\n}\n\n.pt-64 {\n  padding-top: 16rem;\n}\n\n.pr-64 {\n  padding-right: 16rem;\n}\n\n.pb-64 {\n  padding-bottom: 16rem;\n}\n\n.pl-64 {\n  padding-left: 16rem;\n}\n\n.pt-px {\n  padding-top: 1px;\n}\n\n.pr-px {\n  padding-right: 1px;\n}\n\n.pb-px {\n  padding-bottom: 1px;\n}\n\n.pl-px {\n  padding-left: 1px;\n}\n\n.placeholder-transparent::-moz-placeholder {\n  color: transparent;\n}\n\n.placeholder-transparent:-ms-input-placeholder {\n  color: transparent;\n}\n\n.placeholder-transparent::placeholder {\n  color: transparent;\n}\n\n.placeholder-current::-moz-placeholder {\n  color: currentColor;\n}\n\n.placeholder-current:-ms-input-placeholder {\n  color: currentColor;\n}\n\n.placeholder-current::placeholder {\n  color: currentColor;\n}\n\n.placeholder-black::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #000;\n  color: rgba(0, 0, 0, var(--placeholder-opacity));\n}\n\n.placeholder-black:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #000;\n  color: rgba(0, 0, 0, var(--placeholder-opacity));\n}\n\n.placeholder-black::placeholder {\n  --placeholder-opacity: 1;\n  color: #000;\n  color: rgba(0, 0, 0, var(--placeholder-opacity));\n}\n\n.placeholder-white::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #fff;\n  color: rgba(255, 255, 255, var(--placeholder-opacity));\n}\n\n.placeholder-white:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #fff;\n  color: rgba(255, 255, 255, var(--placeholder-opacity));\n}\n\n.placeholder-white::placeholder {\n  --placeholder-opacity: 1;\n  color: #fff;\n  color: rgba(255, 255, 255, var(--placeholder-opacity));\n}\n\n.placeholder-gray-100::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #f7fafc;\n  color: rgba(247, 250, 252, var(--placeholder-opacity));\n}\n\n.placeholder-gray-100:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #f7fafc;\n  color: rgba(247, 250, 252, var(--placeholder-opacity));\n}\n\n.placeholder-gray-100::placeholder {\n  --placeholder-opacity: 1;\n  color: #f7fafc;\n  color: rgba(247, 250, 252, var(--placeholder-opacity));\n}\n\n.placeholder-gray-200::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #edf2f7;\n  color: rgba(237, 242, 247, var(--placeholder-opacity));\n}\n\n.placeholder-gray-200:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #edf2f7;\n  color: rgba(237, 242, 247, var(--placeholder-opacity));\n}\n\n.placeholder-gray-200::placeholder {\n  --placeholder-opacity: 1;\n  color: #edf2f7;\n  color: rgba(237, 242, 247, var(--placeholder-opacity));\n}\n\n.placeholder-gray-300::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #e2e8f0;\n  color: rgba(226, 232, 240, var(--placeholder-opacity));\n}\n\n.placeholder-gray-300:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #e2e8f0;\n  color: rgba(226, 232, 240, var(--placeholder-opacity));\n}\n\n.placeholder-gray-300::placeholder {\n  --placeholder-opacity: 1;\n  color: #e2e8f0;\n  color: rgba(226, 232, 240, var(--placeholder-opacity));\n}\n\n.placeholder-gray-400::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #cbd5e0;\n  color: rgba(203, 213, 224, var(--placeholder-opacity));\n}\n\n.placeholder-gray-400:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #cbd5e0;\n  color: rgba(203, 213, 224, var(--placeholder-opacity));\n}\n\n.placeholder-gray-400::placeholder {\n  --placeholder-opacity: 1;\n  color: #cbd5e0;\n  color: rgba(203, 213, 224, var(--placeholder-opacity));\n}\n\n.placeholder-gray-500::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #a0aec0;\n  color: rgba(160, 174, 192, var(--placeholder-opacity));\n}\n\n.placeholder-gray-500:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #a0aec0;\n  color: rgba(160, 174, 192, var(--placeholder-opacity));\n}\n\n.placeholder-gray-500::placeholder {\n  --placeholder-opacity: 1;\n  color: #a0aec0;\n  color: rgba(160, 174, 192, var(--placeholder-opacity));\n}\n\n.placeholder-gray-600::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #718096;\n  color: rgba(113, 128, 150, var(--placeholder-opacity));\n}\n\n.placeholder-gray-600:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #718096;\n  color: rgba(113, 128, 150, var(--placeholder-opacity));\n}\n\n.placeholder-gray-600::placeholder {\n  --placeholder-opacity: 1;\n  color: #718096;\n  color: rgba(113, 128, 150, var(--placeholder-opacity));\n}\n\n.placeholder-gray-700::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #4a5568;\n  color: rgba(74, 85, 104, var(--placeholder-opacity));\n}\n\n.placeholder-gray-700:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #4a5568;\n  color: rgba(74, 85, 104, var(--placeholder-opacity));\n}\n\n.placeholder-gray-700::placeholder {\n  --placeholder-opacity: 1;\n  color: #4a5568;\n  color: rgba(74, 85, 104, var(--placeholder-opacity));\n}\n\n.placeholder-gray-800::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #2d3748;\n  color: rgba(45, 55, 72, var(--placeholder-opacity));\n}\n\n.placeholder-gray-800:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #2d3748;\n  color: rgba(45, 55, 72, var(--placeholder-opacity));\n}\n\n.placeholder-gray-800::placeholder {\n  --placeholder-opacity: 1;\n  color: #2d3748;\n  color: rgba(45, 55, 72, var(--placeholder-opacity));\n}\n\n.placeholder-gray-900::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #1a202c;\n  color: rgba(26, 32, 44, var(--placeholder-opacity));\n}\n\n.placeholder-gray-900:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #1a202c;\n  color: rgba(26, 32, 44, var(--placeholder-opacity));\n}\n\n.placeholder-gray-900::placeholder {\n  --placeholder-opacity: 1;\n  color: #1a202c;\n  color: rgba(26, 32, 44, var(--placeholder-opacity));\n}\n\n.placeholder-red-100::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #fff5f5;\n  color: rgba(255, 245, 245, var(--placeholder-opacity));\n}\n\n.placeholder-red-100:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #fff5f5;\n  color: rgba(255, 245, 245, var(--placeholder-opacity));\n}\n\n.placeholder-red-100::placeholder {\n  --placeholder-opacity: 1;\n  color: #fff5f5;\n  color: rgba(255, 245, 245, var(--placeholder-opacity));\n}\n\n.placeholder-red-200::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #fed7d7;\n  color: rgba(254, 215, 215, var(--placeholder-opacity));\n}\n\n.placeholder-red-200:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #fed7d7;\n  color: rgba(254, 215, 215, var(--placeholder-opacity));\n}\n\n.placeholder-red-200::placeholder {\n  --placeholder-opacity: 1;\n  color: #fed7d7;\n  color: rgba(254, 215, 215, var(--placeholder-opacity));\n}\n\n.placeholder-red-300::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #feb2b2;\n  color: rgba(254, 178, 178, var(--placeholder-opacity));\n}\n\n.placeholder-red-300:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #feb2b2;\n  color: rgba(254, 178, 178, var(--placeholder-opacity));\n}\n\n.placeholder-red-300::placeholder {\n  --placeholder-opacity: 1;\n  color: #feb2b2;\n  color: rgba(254, 178, 178, var(--placeholder-opacity));\n}\n\n.placeholder-red-400::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #fc8181;\n  color: rgba(252, 129, 129, var(--placeholder-opacity));\n}\n\n.placeholder-red-400:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #fc8181;\n  color: rgba(252, 129, 129, var(--placeholder-opacity));\n}\n\n.placeholder-red-400::placeholder {\n  --placeholder-opacity: 1;\n  color: #fc8181;\n  color: rgba(252, 129, 129, var(--placeholder-opacity));\n}\n\n.placeholder-red-500::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #f56565;\n  color: rgba(245, 101, 101, var(--placeholder-opacity));\n}\n\n.placeholder-red-500:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #f56565;\n  color: rgba(245, 101, 101, var(--placeholder-opacity));\n}\n\n.placeholder-red-500::placeholder {\n  --placeholder-opacity: 1;\n  color: #f56565;\n  color: rgba(245, 101, 101, var(--placeholder-opacity));\n}\n\n.placeholder-red-600::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #e53e3e;\n  color: rgba(229, 62, 62, var(--placeholder-opacity));\n}\n\n.placeholder-red-600:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #e53e3e;\n  color: rgba(229, 62, 62, var(--placeholder-opacity));\n}\n\n.placeholder-red-600::placeholder {\n  --placeholder-opacity: 1;\n  color: #e53e3e;\n  color: rgba(229, 62, 62, var(--placeholder-opacity));\n}\n\n.placeholder-red-700::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #c53030;\n  color: rgba(197, 48, 48, var(--placeholder-opacity));\n}\n\n.placeholder-red-700:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #c53030;\n  color: rgba(197, 48, 48, var(--placeholder-opacity));\n}\n\n.placeholder-red-700::placeholder {\n  --placeholder-opacity: 1;\n  color: #c53030;\n  color: rgba(197, 48, 48, var(--placeholder-opacity));\n}\n\n.placeholder-red-800::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #9b2c2c;\n  color: rgba(155, 44, 44, var(--placeholder-opacity));\n}\n\n.placeholder-red-800:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #9b2c2c;\n  color: rgba(155, 44, 44, var(--placeholder-opacity));\n}\n\n.placeholder-red-800::placeholder {\n  --placeholder-opacity: 1;\n  color: #9b2c2c;\n  color: rgba(155, 44, 44, var(--placeholder-opacity));\n}\n\n.placeholder-red-900::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #742a2a;\n  color: rgba(116, 42, 42, var(--placeholder-opacity));\n}\n\n.placeholder-red-900:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #742a2a;\n  color: rgba(116, 42, 42, var(--placeholder-opacity));\n}\n\n.placeholder-red-900::placeholder {\n  --placeholder-opacity: 1;\n  color: #742a2a;\n  color: rgba(116, 42, 42, var(--placeholder-opacity));\n}\n\n.placeholder-orange-100::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #fffaf0;\n  color: rgba(255, 250, 240, var(--placeholder-opacity));\n}\n\n.placeholder-orange-100:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #fffaf0;\n  color: rgba(255, 250, 240, var(--placeholder-opacity));\n}\n\n.placeholder-orange-100::placeholder {\n  --placeholder-opacity: 1;\n  color: #fffaf0;\n  color: rgba(255, 250, 240, var(--placeholder-opacity));\n}\n\n.placeholder-orange-200::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #feebc8;\n  color: rgba(254, 235, 200, var(--placeholder-opacity));\n}\n\n.placeholder-orange-200:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #feebc8;\n  color: rgba(254, 235, 200, var(--placeholder-opacity));\n}\n\n.placeholder-orange-200::placeholder {\n  --placeholder-opacity: 1;\n  color: #feebc8;\n  color: rgba(254, 235, 200, var(--placeholder-opacity));\n}\n\n.placeholder-orange-300::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #fbd38d;\n  color: rgba(251, 211, 141, var(--placeholder-opacity));\n}\n\n.placeholder-orange-300:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #fbd38d;\n  color: rgba(251, 211, 141, var(--placeholder-opacity));\n}\n\n.placeholder-orange-300::placeholder {\n  --placeholder-opacity: 1;\n  color: #fbd38d;\n  color: rgba(251, 211, 141, var(--placeholder-opacity));\n}\n\n.placeholder-orange-400::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #f6ad55;\n  color: rgba(246, 173, 85, var(--placeholder-opacity));\n}\n\n.placeholder-orange-400:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #f6ad55;\n  color: rgba(246, 173, 85, var(--placeholder-opacity));\n}\n\n.placeholder-orange-400::placeholder {\n  --placeholder-opacity: 1;\n  color: #f6ad55;\n  color: rgba(246, 173, 85, var(--placeholder-opacity));\n}\n\n.placeholder-orange-500::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #ed8936;\n  color: rgba(237, 137, 54, var(--placeholder-opacity));\n}\n\n.placeholder-orange-500:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #ed8936;\n  color: rgba(237, 137, 54, var(--placeholder-opacity));\n}\n\n.placeholder-orange-500::placeholder {\n  --placeholder-opacity: 1;\n  color: #ed8936;\n  color: rgba(237, 137, 54, var(--placeholder-opacity));\n}\n\n.placeholder-orange-600::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #dd6b20;\n  color: rgba(221, 107, 32, var(--placeholder-opacity));\n}\n\n.placeholder-orange-600:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #dd6b20;\n  color: rgba(221, 107, 32, var(--placeholder-opacity));\n}\n\n.placeholder-orange-600::placeholder {\n  --placeholder-opacity: 1;\n  color: #dd6b20;\n  color: rgba(221, 107, 32, var(--placeholder-opacity));\n}\n\n.placeholder-orange-700::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #c05621;\n  color: rgba(192, 86, 33, var(--placeholder-opacity));\n}\n\n.placeholder-orange-700:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #c05621;\n  color: rgba(192, 86, 33, var(--placeholder-opacity));\n}\n\n.placeholder-orange-700::placeholder {\n  --placeholder-opacity: 1;\n  color: #c05621;\n  color: rgba(192, 86, 33, var(--placeholder-opacity));\n}\n\n.placeholder-orange-800::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #9c4221;\n  color: rgba(156, 66, 33, var(--placeholder-opacity));\n}\n\n.placeholder-orange-800:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #9c4221;\n  color: rgba(156, 66, 33, var(--placeholder-opacity));\n}\n\n.placeholder-orange-800::placeholder {\n  --placeholder-opacity: 1;\n  color: #9c4221;\n  color: rgba(156, 66, 33, var(--placeholder-opacity));\n}\n\n.placeholder-orange-900::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #7b341e;\n  color: rgba(123, 52, 30, var(--placeholder-opacity));\n}\n\n.placeholder-orange-900:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #7b341e;\n  color: rgba(123, 52, 30, var(--placeholder-opacity));\n}\n\n.placeholder-orange-900::placeholder {\n  --placeholder-opacity: 1;\n  color: #7b341e;\n  color: rgba(123, 52, 30, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-100::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #fffff0;\n  color: rgba(255, 255, 240, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-100:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #fffff0;\n  color: rgba(255, 255, 240, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-100::placeholder {\n  --placeholder-opacity: 1;\n  color: #fffff0;\n  color: rgba(255, 255, 240, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-200::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #fefcbf;\n  color: rgba(254, 252, 191, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-200:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #fefcbf;\n  color: rgba(254, 252, 191, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-200::placeholder {\n  --placeholder-opacity: 1;\n  color: #fefcbf;\n  color: rgba(254, 252, 191, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-300::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #faf089;\n  color: rgba(250, 240, 137, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-300:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #faf089;\n  color: rgba(250, 240, 137, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-300::placeholder {\n  --placeholder-opacity: 1;\n  color: #faf089;\n  color: rgba(250, 240, 137, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-400::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #f6e05e;\n  color: rgba(246, 224, 94, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-400:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #f6e05e;\n  color: rgba(246, 224, 94, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-400::placeholder {\n  --placeholder-opacity: 1;\n  color: #f6e05e;\n  color: rgba(246, 224, 94, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-500::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #ecc94b;\n  color: rgba(236, 201, 75, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-500:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #ecc94b;\n  color: rgba(236, 201, 75, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-500::placeholder {\n  --placeholder-opacity: 1;\n  color: #ecc94b;\n  color: rgba(236, 201, 75, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-600::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #d69e2e;\n  color: rgba(214, 158, 46, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-600:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #d69e2e;\n  color: rgba(214, 158, 46, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-600::placeholder {\n  --placeholder-opacity: 1;\n  color: #d69e2e;\n  color: rgba(214, 158, 46, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-700::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #b7791f;\n  color: rgba(183, 121, 31, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-700:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #b7791f;\n  color: rgba(183, 121, 31, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-700::placeholder {\n  --placeholder-opacity: 1;\n  color: #b7791f;\n  color: rgba(183, 121, 31, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-800::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #975a16;\n  color: rgba(151, 90, 22, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-800:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #975a16;\n  color: rgba(151, 90, 22, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-800::placeholder {\n  --placeholder-opacity: 1;\n  color: #975a16;\n  color: rgba(151, 90, 22, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-900::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #744210;\n  color: rgba(116, 66, 16, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-900:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #744210;\n  color: rgba(116, 66, 16, var(--placeholder-opacity));\n}\n\n.placeholder-yellow-900::placeholder {\n  --placeholder-opacity: 1;\n  color: #744210;\n  color: rgba(116, 66, 16, var(--placeholder-opacity));\n}\n\n.placeholder-green-100::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #f0fff4;\n  color: rgba(240, 255, 244, var(--placeholder-opacity));\n}\n\n.placeholder-green-100:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #f0fff4;\n  color: rgba(240, 255, 244, var(--placeholder-opacity));\n}\n\n.placeholder-green-100::placeholder {\n  --placeholder-opacity: 1;\n  color: #f0fff4;\n  color: rgba(240, 255, 244, var(--placeholder-opacity));\n}\n\n.placeholder-green-200::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #c6f6d5;\n  color: rgba(198, 246, 213, var(--placeholder-opacity));\n}\n\n.placeholder-green-200:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #c6f6d5;\n  color: rgba(198, 246, 213, var(--placeholder-opacity));\n}\n\n.placeholder-green-200::placeholder {\n  --placeholder-opacity: 1;\n  color: #c6f6d5;\n  color: rgba(198, 246, 213, var(--placeholder-opacity));\n}\n\n.placeholder-green-300::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #9ae6b4;\n  color: rgba(154, 230, 180, var(--placeholder-opacity));\n}\n\n.placeholder-green-300:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #9ae6b4;\n  color: rgba(154, 230, 180, var(--placeholder-opacity));\n}\n\n.placeholder-green-300::placeholder {\n  --placeholder-opacity: 1;\n  color: #9ae6b4;\n  color: rgba(154, 230, 180, var(--placeholder-opacity));\n}\n\n.placeholder-green-400::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #68d391;\n  color: rgba(104, 211, 145, var(--placeholder-opacity));\n}\n\n.placeholder-green-400:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #68d391;\n  color: rgba(104, 211, 145, var(--placeholder-opacity));\n}\n\n.placeholder-green-400::placeholder {\n  --placeholder-opacity: 1;\n  color: #68d391;\n  color: rgba(104, 211, 145, var(--placeholder-opacity));\n}\n\n.placeholder-green-500::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #48bb78;\n  color: rgba(72, 187, 120, var(--placeholder-opacity));\n}\n\n.placeholder-green-500:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #48bb78;\n  color: rgba(72, 187, 120, var(--placeholder-opacity));\n}\n\n.placeholder-green-500::placeholder {\n  --placeholder-opacity: 1;\n  color: #48bb78;\n  color: rgba(72, 187, 120, var(--placeholder-opacity));\n}\n\n.placeholder-green-600::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #38a169;\n  color: rgba(56, 161, 105, var(--placeholder-opacity));\n}\n\n.placeholder-green-600:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #38a169;\n  color: rgba(56, 161, 105, var(--placeholder-opacity));\n}\n\n.placeholder-green-600::placeholder {\n  --placeholder-opacity: 1;\n  color: #38a169;\n  color: rgba(56, 161, 105, var(--placeholder-opacity));\n}\n\n.placeholder-green-700::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #2f855a;\n  color: rgba(47, 133, 90, var(--placeholder-opacity));\n}\n\n.placeholder-green-700:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #2f855a;\n  color: rgba(47, 133, 90, var(--placeholder-opacity));\n}\n\n.placeholder-green-700::placeholder {\n  --placeholder-opacity: 1;\n  color: #2f855a;\n  color: rgba(47, 133, 90, var(--placeholder-opacity));\n}\n\n.placeholder-green-800::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #276749;\n  color: rgba(39, 103, 73, var(--placeholder-opacity));\n}\n\n.placeholder-green-800:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #276749;\n  color: rgba(39, 103, 73, var(--placeholder-opacity));\n}\n\n.placeholder-green-800::placeholder {\n  --placeholder-opacity: 1;\n  color: #276749;\n  color: rgba(39, 103, 73, var(--placeholder-opacity));\n}\n\n.placeholder-green-900::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #22543d;\n  color: rgba(34, 84, 61, var(--placeholder-opacity));\n}\n\n.placeholder-green-900:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #22543d;\n  color: rgba(34, 84, 61, var(--placeholder-opacity));\n}\n\n.placeholder-green-900::placeholder {\n  --placeholder-opacity: 1;\n  color: #22543d;\n  color: rgba(34, 84, 61, var(--placeholder-opacity));\n}\n\n.placeholder-teal-100::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #e6fffa;\n  color: rgba(230, 255, 250, var(--placeholder-opacity));\n}\n\n.placeholder-teal-100:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #e6fffa;\n  color: rgba(230, 255, 250, var(--placeholder-opacity));\n}\n\n.placeholder-teal-100::placeholder {\n  --placeholder-opacity: 1;\n  color: #e6fffa;\n  color: rgba(230, 255, 250, var(--placeholder-opacity));\n}\n\n.placeholder-teal-200::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #b2f5ea;\n  color: rgba(178, 245, 234, var(--placeholder-opacity));\n}\n\n.placeholder-teal-200:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #b2f5ea;\n  color: rgba(178, 245, 234, var(--placeholder-opacity));\n}\n\n.placeholder-teal-200::placeholder {\n  --placeholder-opacity: 1;\n  color: #b2f5ea;\n  color: rgba(178, 245, 234, var(--placeholder-opacity));\n}\n\n.placeholder-teal-300::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #81e6d9;\n  color: rgba(129, 230, 217, var(--placeholder-opacity));\n}\n\n.placeholder-teal-300:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #81e6d9;\n  color: rgba(129, 230, 217, var(--placeholder-opacity));\n}\n\n.placeholder-teal-300::placeholder {\n  --placeholder-opacity: 1;\n  color: #81e6d9;\n  color: rgba(129, 230, 217, var(--placeholder-opacity));\n}\n\n.placeholder-teal-400::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #4fd1c5;\n  color: rgba(79, 209, 197, var(--placeholder-opacity));\n}\n\n.placeholder-teal-400:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #4fd1c5;\n  color: rgba(79, 209, 197, var(--placeholder-opacity));\n}\n\n.placeholder-teal-400::placeholder {\n  --placeholder-opacity: 1;\n  color: #4fd1c5;\n  color: rgba(79, 209, 197, var(--placeholder-opacity));\n}\n\n.placeholder-teal-500::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #38b2ac;\n  color: rgba(56, 178, 172, var(--placeholder-opacity));\n}\n\n.placeholder-teal-500:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #38b2ac;\n  color: rgba(56, 178, 172, var(--placeholder-opacity));\n}\n\n.placeholder-teal-500::placeholder {\n  --placeholder-opacity: 1;\n  color: #38b2ac;\n  color: rgba(56, 178, 172, var(--placeholder-opacity));\n}\n\n.placeholder-teal-600::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #319795;\n  color: rgba(49, 151, 149, var(--placeholder-opacity));\n}\n\n.placeholder-teal-600:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #319795;\n  color: rgba(49, 151, 149, var(--placeholder-opacity));\n}\n\n.placeholder-teal-600::placeholder {\n  --placeholder-opacity: 1;\n  color: #319795;\n  color: rgba(49, 151, 149, var(--placeholder-opacity));\n}\n\n.placeholder-teal-700::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #2c7a7b;\n  color: rgba(44, 122, 123, var(--placeholder-opacity));\n}\n\n.placeholder-teal-700:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #2c7a7b;\n  color: rgba(44, 122, 123, var(--placeholder-opacity));\n}\n\n.placeholder-teal-700::placeholder {\n  --placeholder-opacity: 1;\n  color: #2c7a7b;\n  color: rgba(44, 122, 123, var(--placeholder-opacity));\n}\n\n.placeholder-teal-800::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #285e61;\n  color: rgba(40, 94, 97, var(--placeholder-opacity));\n}\n\n.placeholder-teal-800:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #285e61;\n  color: rgba(40, 94, 97, var(--placeholder-opacity));\n}\n\n.placeholder-teal-800::placeholder {\n  --placeholder-opacity: 1;\n  color: #285e61;\n  color: rgba(40, 94, 97, var(--placeholder-opacity));\n}\n\n.placeholder-teal-900::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #234e52;\n  color: rgba(35, 78, 82, var(--placeholder-opacity));\n}\n\n.placeholder-teal-900:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #234e52;\n  color: rgba(35, 78, 82, var(--placeholder-opacity));\n}\n\n.placeholder-teal-900::placeholder {\n  --placeholder-opacity: 1;\n  color: #234e52;\n  color: rgba(35, 78, 82, var(--placeholder-opacity));\n}\n\n.placeholder-blue-100::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #ebf8ff;\n  color: rgba(235, 248, 255, var(--placeholder-opacity));\n}\n\n.placeholder-blue-100:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #ebf8ff;\n  color: rgba(235, 248, 255, var(--placeholder-opacity));\n}\n\n.placeholder-blue-100::placeholder {\n  --placeholder-opacity: 1;\n  color: #ebf8ff;\n  color: rgba(235, 248, 255, var(--placeholder-opacity));\n}\n\n.placeholder-blue-200::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #bee3f8;\n  color: rgba(190, 227, 248, var(--placeholder-opacity));\n}\n\n.placeholder-blue-200:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #bee3f8;\n  color: rgba(190, 227, 248, var(--placeholder-opacity));\n}\n\n.placeholder-blue-200::placeholder {\n  --placeholder-opacity: 1;\n  color: #bee3f8;\n  color: rgba(190, 227, 248, var(--placeholder-opacity));\n}\n\n.placeholder-blue-300::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #90cdf4;\n  color: rgba(144, 205, 244, var(--placeholder-opacity));\n}\n\n.placeholder-blue-300:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #90cdf4;\n  color: rgba(144, 205, 244, var(--placeholder-opacity));\n}\n\n.placeholder-blue-300::placeholder {\n  --placeholder-opacity: 1;\n  color: #90cdf4;\n  color: rgba(144, 205, 244, var(--placeholder-opacity));\n}\n\n.placeholder-blue-400::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #63b3ed;\n  color: rgba(99, 179, 237, var(--placeholder-opacity));\n}\n\n.placeholder-blue-400:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #63b3ed;\n  color: rgba(99, 179, 237, var(--placeholder-opacity));\n}\n\n.placeholder-blue-400::placeholder {\n  --placeholder-opacity: 1;\n  color: #63b3ed;\n  color: rgba(99, 179, 237, var(--placeholder-opacity));\n}\n\n.placeholder-blue-500::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #4299e1;\n  color: rgba(66, 153, 225, var(--placeholder-opacity));\n}\n\n.placeholder-blue-500:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #4299e1;\n  color: rgba(66, 153, 225, var(--placeholder-opacity));\n}\n\n.placeholder-blue-500::placeholder {\n  --placeholder-opacity: 1;\n  color: #4299e1;\n  color: rgba(66, 153, 225, var(--placeholder-opacity));\n}\n\n.placeholder-blue-600::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #3182ce;\n  color: rgba(49, 130, 206, var(--placeholder-opacity));\n}\n\n.placeholder-blue-600:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #3182ce;\n  color: rgba(49, 130, 206, var(--placeholder-opacity));\n}\n\n.placeholder-blue-600::placeholder {\n  --placeholder-opacity: 1;\n  color: #3182ce;\n  color: rgba(49, 130, 206, var(--placeholder-opacity));\n}\n\n.placeholder-blue-700::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #2b6cb0;\n  color: rgba(43, 108, 176, var(--placeholder-opacity));\n}\n\n.placeholder-blue-700:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #2b6cb0;\n  color: rgba(43, 108, 176, var(--placeholder-opacity));\n}\n\n.placeholder-blue-700::placeholder {\n  --placeholder-opacity: 1;\n  color: #2b6cb0;\n  color: rgba(43, 108, 176, var(--placeholder-opacity));\n}\n\n.placeholder-blue-800::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #2c5282;\n  color: rgba(44, 82, 130, var(--placeholder-opacity));\n}\n\n.placeholder-blue-800:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #2c5282;\n  color: rgba(44, 82, 130, var(--placeholder-opacity));\n}\n\n.placeholder-blue-800::placeholder {\n  --placeholder-opacity: 1;\n  color: #2c5282;\n  color: rgba(44, 82, 130, var(--placeholder-opacity));\n}\n\n.placeholder-blue-900::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #2a4365;\n  color: rgba(42, 67, 101, var(--placeholder-opacity));\n}\n\n.placeholder-blue-900:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #2a4365;\n  color: rgba(42, 67, 101, var(--placeholder-opacity));\n}\n\n.placeholder-blue-900::placeholder {\n  --placeholder-opacity: 1;\n  color: #2a4365;\n  color: rgba(42, 67, 101, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-100::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #ebf4ff;\n  color: rgba(235, 244, 255, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-100:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #ebf4ff;\n  color: rgba(235, 244, 255, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-100::placeholder {\n  --placeholder-opacity: 1;\n  color: #ebf4ff;\n  color: rgba(235, 244, 255, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-200::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #c3dafe;\n  color: rgba(195, 218, 254, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-200:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #c3dafe;\n  color: rgba(195, 218, 254, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-200::placeholder {\n  --placeholder-opacity: 1;\n  color: #c3dafe;\n  color: rgba(195, 218, 254, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-300::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #a3bffa;\n  color: rgba(163, 191, 250, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-300:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #a3bffa;\n  color: rgba(163, 191, 250, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-300::placeholder {\n  --placeholder-opacity: 1;\n  color: #a3bffa;\n  color: rgba(163, 191, 250, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-400::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #7f9cf5;\n  color: rgba(127, 156, 245, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-400:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #7f9cf5;\n  color: rgba(127, 156, 245, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-400::placeholder {\n  --placeholder-opacity: 1;\n  color: #7f9cf5;\n  color: rgba(127, 156, 245, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-500::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #667eea;\n  color: rgba(102, 126, 234, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-500:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #667eea;\n  color: rgba(102, 126, 234, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-500::placeholder {\n  --placeholder-opacity: 1;\n  color: #667eea;\n  color: rgba(102, 126, 234, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-600::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #5a67d8;\n  color: rgba(90, 103, 216, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-600:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #5a67d8;\n  color: rgba(90, 103, 216, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-600::placeholder {\n  --placeholder-opacity: 1;\n  color: #5a67d8;\n  color: rgba(90, 103, 216, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-700::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #4c51bf;\n  color: rgba(76, 81, 191, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-700:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #4c51bf;\n  color: rgba(76, 81, 191, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-700::placeholder {\n  --placeholder-opacity: 1;\n  color: #4c51bf;\n  color: rgba(76, 81, 191, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-800::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #434190;\n  color: rgba(67, 65, 144, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-800:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #434190;\n  color: rgba(67, 65, 144, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-800::placeholder {\n  --placeholder-opacity: 1;\n  color: #434190;\n  color: rgba(67, 65, 144, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-900::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #3c366b;\n  color: rgba(60, 54, 107, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-900:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #3c366b;\n  color: rgba(60, 54, 107, var(--placeholder-opacity));\n}\n\n.placeholder-indigo-900::placeholder {\n  --placeholder-opacity: 1;\n  color: #3c366b;\n  color: rgba(60, 54, 107, var(--placeholder-opacity));\n}\n\n.placeholder-purple-100::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #faf5ff;\n  color: rgba(250, 245, 255, var(--placeholder-opacity));\n}\n\n.placeholder-purple-100:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #faf5ff;\n  color: rgba(250, 245, 255, var(--placeholder-opacity));\n}\n\n.placeholder-purple-100::placeholder {\n  --placeholder-opacity: 1;\n  color: #faf5ff;\n  color: rgba(250, 245, 255, var(--placeholder-opacity));\n}\n\n.placeholder-purple-200::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #e9d8fd;\n  color: rgba(233, 216, 253, var(--placeholder-opacity));\n}\n\n.placeholder-purple-200:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #e9d8fd;\n  color: rgba(233, 216, 253, var(--placeholder-opacity));\n}\n\n.placeholder-purple-200::placeholder {\n  --placeholder-opacity: 1;\n  color: #e9d8fd;\n  color: rgba(233, 216, 253, var(--placeholder-opacity));\n}\n\n.placeholder-purple-300::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #d6bcfa;\n  color: rgba(214, 188, 250, var(--placeholder-opacity));\n}\n\n.placeholder-purple-300:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #d6bcfa;\n  color: rgba(214, 188, 250, var(--placeholder-opacity));\n}\n\n.placeholder-purple-300::placeholder {\n  --placeholder-opacity: 1;\n  color: #d6bcfa;\n  color: rgba(214, 188, 250, var(--placeholder-opacity));\n}\n\n.placeholder-purple-400::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #b794f4;\n  color: rgba(183, 148, 244, var(--placeholder-opacity));\n}\n\n.placeholder-purple-400:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #b794f4;\n  color: rgba(183, 148, 244, var(--placeholder-opacity));\n}\n\n.placeholder-purple-400::placeholder {\n  --placeholder-opacity: 1;\n  color: #b794f4;\n  color: rgba(183, 148, 244, var(--placeholder-opacity));\n}\n\n.placeholder-purple-500::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #9f7aea;\n  color: rgba(159, 122, 234, var(--placeholder-opacity));\n}\n\n.placeholder-purple-500:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #9f7aea;\n  color: rgba(159, 122, 234, var(--placeholder-opacity));\n}\n\n.placeholder-purple-500::placeholder {\n  --placeholder-opacity: 1;\n  color: #9f7aea;\n  color: rgba(159, 122, 234, var(--placeholder-opacity));\n}\n\n.placeholder-purple-600::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #805ad5;\n  color: rgba(128, 90, 213, var(--placeholder-opacity));\n}\n\n.placeholder-purple-600:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #805ad5;\n  color: rgba(128, 90, 213, var(--placeholder-opacity));\n}\n\n.placeholder-purple-600::placeholder {\n  --placeholder-opacity: 1;\n  color: #805ad5;\n  color: rgba(128, 90, 213, var(--placeholder-opacity));\n}\n\n.placeholder-purple-700::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #6b46c1;\n  color: rgba(107, 70, 193, var(--placeholder-opacity));\n}\n\n.placeholder-purple-700:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #6b46c1;\n  color: rgba(107, 70, 193, var(--placeholder-opacity));\n}\n\n.placeholder-purple-700::placeholder {\n  --placeholder-opacity: 1;\n  color: #6b46c1;\n  color: rgba(107, 70, 193, var(--placeholder-opacity));\n}\n\n.placeholder-purple-800::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #553c9a;\n  color: rgba(85, 60, 154, var(--placeholder-opacity));\n}\n\n.placeholder-purple-800:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #553c9a;\n  color: rgba(85, 60, 154, var(--placeholder-opacity));\n}\n\n.placeholder-purple-800::placeholder {\n  --placeholder-opacity: 1;\n  color: #553c9a;\n  color: rgba(85, 60, 154, var(--placeholder-opacity));\n}\n\n.placeholder-purple-900::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #44337a;\n  color: rgba(68, 51, 122, var(--placeholder-opacity));\n}\n\n.placeholder-purple-900:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #44337a;\n  color: rgba(68, 51, 122, var(--placeholder-opacity));\n}\n\n.placeholder-purple-900::placeholder {\n  --placeholder-opacity: 1;\n  color: #44337a;\n  color: rgba(68, 51, 122, var(--placeholder-opacity));\n}\n\n.placeholder-pink-100::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #fff5f7;\n  color: rgba(255, 245, 247, var(--placeholder-opacity));\n}\n\n.placeholder-pink-100:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #fff5f7;\n  color: rgba(255, 245, 247, var(--placeholder-opacity));\n}\n\n.placeholder-pink-100::placeholder {\n  --placeholder-opacity: 1;\n  color: #fff5f7;\n  color: rgba(255, 245, 247, var(--placeholder-opacity));\n}\n\n.placeholder-pink-200::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #fed7e2;\n  color: rgba(254, 215, 226, var(--placeholder-opacity));\n}\n\n.placeholder-pink-200:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #fed7e2;\n  color: rgba(254, 215, 226, var(--placeholder-opacity));\n}\n\n.placeholder-pink-200::placeholder {\n  --placeholder-opacity: 1;\n  color: #fed7e2;\n  color: rgba(254, 215, 226, var(--placeholder-opacity));\n}\n\n.placeholder-pink-300::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #fbb6ce;\n  color: rgba(251, 182, 206, var(--placeholder-opacity));\n}\n\n.placeholder-pink-300:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #fbb6ce;\n  color: rgba(251, 182, 206, var(--placeholder-opacity));\n}\n\n.placeholder-pink-300::placeholder {\n  --placeholder-opacity: 1;\n  color: #fbb6ce;\n  color: rgba(251, 182, 206, var(--placeholder-opacity));\n}\n\n.placeholder-pink-400::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #f687b3;\n  color: rgba(246, 135, 179, var(--placeholder-opacity));\n}\n\n.placeholder-pink-400:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #f687b3;\n  color: rgba(246, 135, 179, var(--placeholder-opacity));\n}\n\n.placeholder-pink-400::placeholder {\n  --placeholder-opacity: 1;\n  color: #f687b3;\n  color: rgba(246, 135, 179, var(--placeholder-opacity));\n}\n\n.placeholder-pink-500::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #ed64a6;\n  color: rgba(237, 100, 166, var(--placeholder-opacity));\n}\n\n.placeholder-pink-500:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #ed64a6;\n  color: rgba(237, 100, 166, var(--placeholder-opacity));\n}\n\n.placeholder-pink-500::placeholder {\n  --placeholder-opacity: 1;\n  color: #ed64a6;\n  color: rgba(237, 100, 166, var(--placeholder-opacity));\n}\n\n.placeholder-pink-600::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #d53f8c;\n  color: rgba(213, 63, 140, var(--placeholder-opacity));\n}\n\n.placeholder-pink-600:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #d53f8c;\n  color: rgba(213, 63, 140, var(--placeholder-opacity));\n}\n\n.placeholder-pink-600::placeholder {\n  --placeholder-opacity: 1;\n  color: #d53f8c;\n  color: rgba(213, 63, 140, var(--placeholder-opacity));\n}\n\n.placeholder-pink-700::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #b83280;\n  color: rgba(184, 50, 128, var(--placeholder-opacity));\n}\n\n.placeholder-pink-700:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #b83280;\n  color: rgba(184, 50, 128, var(--placeholder-opacity));\n}\n\n.placeholder-pink-700::placeholder {\n  --placeholder-opacity: 1;\n  color: #b83280;\n  color: rgba(184, 50, 128, var(--placeholder-opacity));\n}\n\n.placeholder-pink-800::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #97266d;\n  color: rgba(151, 38, 109, var(--placeholder-opacity));\n}\n\n.placeholder-pink-800:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #97266d;\n  color: rgba(151, 38, 109, var(--placeholder-opacity));\n}\n\n.placeholder-pink-800::placeholder {\n  --placeholder-opacity: 1;\n  color: #97266d;\n  color: rgba(151, 38, 109, var(--placeholder-opacity));\n}\n\n.placeholder-pink-900::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #702459;\n  color: rgba(112, 36, 89, var(--placeholder-opacity));\n}\n\n.placeholder-pink-900:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #702459;\n  color: rgba(112, 36, 89, var(--placeholder-opacity));\n}\n\n.placeholder-pink-900::placeholder {\n  --placeholder-opacity: 1;\n  color: #702459;\n  color: rgba(112, 36, 89, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-80::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 8%);\n  color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-80:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 8%);\n  color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-80::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 8%);\n  color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-100::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 10%);\n  color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-100:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 10%);\n  color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-100::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 10%);\n  color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-200::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 20%);\n  color: rgba(51, 51, 51, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-200:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 20%);\n  color: rgba(51, 51, 51, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-200::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 20%);\n  color: rgba(51, 51, 51, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-300::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 30%);\n  color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-300:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 30%);\n  color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-300::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 30%);\n  color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-400::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 40%);\n  color: rgba(102, 102, 102, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-400:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 40%);\n  color: rgba(102, 102, 102, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-400::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 40%);\n  color: rgba(102, 102, 102, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-500::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 50%);\n  color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-500:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 50%);\n  color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-500::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 50%);\n  color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-600::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 60%);\n  color: rgba(153, 153, 153, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-600:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 60%);\n  color: rgba(153, 153, 153, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-600::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 60%);\n  color: rgba(153, 153, 153, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-700::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 70%);\n  color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-700:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 70%);\n  color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-700::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 70%);\n  color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-800::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 80%);\n  color: rgba(204, 204, 204, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-800:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 80%);\n  color: rgba(204, 204, 204, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-800::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 80%);\n  color: rgba(204, 204, 204, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-840::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 84%);\n  color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-840:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 84%);\n  color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-840::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 84%);\n  color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-870::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 87%);\n  color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-870:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 87%);\n  color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-870::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 87%);\n  color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-900::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 90%);\n  color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-900:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 90%);\n  color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-900::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 90%);\n  color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-930::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 93%);\n  color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-930:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 93%);\n  color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n}\n\n.placeholder-grayscale-930::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 93%);\n  color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n}\n\n.placeholder-primary::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(210, 100%, 52%);\n  color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n}\n\n.placeholder-primary:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(210, 100%, 52%);\n  color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n}\n\n.placeholder-primary::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(210, 100%, 52%);\n  color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n}\n\n.placeholder-background-main::-moz-placeholder {\n  color: var(--main-background);\n}\n\n.placeholder-background-main:-ms-input-placeholder {\n  color: var(--main-background);\n}\n\n.placeholder-background-main::placeholder {\n  color: var(--main-background);\n}\n\n.placeholder-background-secondary::-moz-placeholder {\n  color: var(--secondary-background);\n}\n\n.placeholder-background-secondary:-ms-input-placeholder {\n  color: var(--secondary-background);\n}\n\n.placeholder-background-secondary::placeholder {\n  color: var(--secondary-background);\n}\n\n.placeholder-foreground::-moz-placeholder {\n  color: var(--foreground);\n}\n\n.placeholder-foreground:-ms-input-placeholder {\n  color: var(--foreground);\n}\n\n.placeholder-foreground::placeholder {\n  color: var(--foreground);\n}\n\n.placeholder-panels-bg::-moz-placeholder {\n  color: var(--panels-background);\n}\n\n.placeholder-panels-bg:-ms-input-placeholder {\n  color: var(--panels-background);\n}\n\n.placeholder-panels-bg::placeholder {\n  color: var(--panels-background);\n}\n\n.focus\\:placeholder-transparent:focus::-moz-placeholder {\n  color: transparent;\n}\n\n.focus\\:placeholder-transparent:focus:-ms-input-placeholder {\n  color: transparent;\n}\n\n.focus\\:placeholder-transparent:focus::placeholder {\n  color: transparent;\n}\n\n.focus\\:placeholder-current:focus::-moz-placeholder {\n  color: currentColor;\n}\n\n.focus\\:placeholder-current:focus:-ms-input-placeholder {\n  color: currentColor;\n}\n\n.focus\\:placeholder-current:focus::placeholder {\n  color: currentColor;\n}\n\n.focus\\:placeholder-black:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #000;\n  color: rgba(0, 0, 0, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-black:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #000;\n  color: rgba(0, 0, 0, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-black:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #000;\n  color: rgba(0, 0, 0, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-white:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #fff;\n  color: rgba(255, 255, 255, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-white:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #fff;\n  color: rgba(255, 255, 255, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-white:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #fff;\n  color: rgba(255, 255, 255, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-100:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #f7fafc;\n  color: rgba(247, 250, 252, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-100:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #f7fafc;\n  color: rgba(247, 250, 252, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-100:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #f7fafc;\n  color: rgba(247, 250, 252, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-200:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #edf2f7;\n  color: rgba(237, 242, 247, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-200:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #edf2f7;\n  color: rgba(237, 242, 247, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-200:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #edf2f7;\n  color: rgba(237, 242, 247, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-300:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #e2e8f0;\n  color: rgba(226, 232, 240, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-300:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #e2e8f0;\n  color: rgba(226, 232, 240, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-300:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #e2e8f0;\n  color: rgba(226, 232, 240, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-400:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #cbd5e0;\n  color: rgba(203, 213, 224, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-400:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #cbd5e0;\n  color: rgba(203, 213, 224, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-400:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #cbd5e0;\n  color: rgba(203, 213, 224, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-500:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #a0aec0;\n  color: rgba(160, 174, 192, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-500:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #a0aec0;\n  color: rgba(160, 174, 192, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-500:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #a0aec0;\n  color: rgba(160, 174, 192, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-600:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #718096;\n  color: rgba(113, 128, 150, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-600:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #718096;\n  color: rgba(113, 128, 150, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-600:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #718096;\n  color: rgba(113, 128, 150, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-700:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #4a5568;\n  color: rgba(74, 85, 104, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-700:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #4a5568;\n  color: rgba(74, 85, 104, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-700:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #4a5568;\n  color: rgba(74, 85, 104, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-800:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #2d3748;\n  color: rgba(45, 55, 72, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-800:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #2d3748;\n  color: rgba(45, 55, 72, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-800:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #2d3748;\n  color: rgba(45, 55, 72, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-900:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #1a202c;\n  color: rgba(26, 32, 44, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-900:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #1a202c;\n  color: rgba(26, 32, 44, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-gray-900:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #1a202c;\n  color: rgba(26, 32, 44, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-100:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #fff5f5;\n  color: rgba(255, 245, 245, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-100:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #fff5f5;\n  color: rgba(255, 245, 245, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-100:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #fff5f5;\n  color: rgba(255, 245, 245, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-200:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #fed7d7;\n  color: rgba(254, 215, 215, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-200:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #fed7d7;\n  color: rgba(254, 215, 215, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-200:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #fed7d7;\n  color: rgba(254, 215, 215, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-300:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #feb2b2;\n  color: rgba(254, 178, 178, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-300:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #feb2b2;\n  color: rgba(254, 178, 178, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-300:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #feb2b2;\n  color: rgba(254, 178, 178, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-400:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #fc8181;\n  color: rgba(252, 129, 129, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-400:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #fc8181;\n  color: rgba(252, 129, 129, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-400:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #fc8181;\n  color: rgba(252, 129, 129, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-500:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #f56565;\n  color: rgba(245, 101, 101, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-500:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #f56565;\n  color: rgba(245, 101, 101, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-500:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #f56565;\n  color: rgba(245, 101, 101, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-600:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #e53e3e;\n  color: rgba(229, 62, 62, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-600:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #e53e3e;\n  color: rgba(229, 62, 62, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-600:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #e53e3e;\n  color: rgba(229, 62, 62, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-700:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #c53030;\n  color: rgba(197, 48, 48, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-700:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #c53030;\n  color: rgba(197, 48, 48, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-700:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #c53030;\n  color: rgba(197, 48, 48, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-800:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #9b2c2c;\n  color: rgba(155, 44, 44, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-800:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #9b2c2c;\n  color: rgba(155, 44, 44, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-800:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #9b2c2c;\n  color: rgba(155, 44, 44, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-900:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #742a2a;\n  color: rgba(116, 42, 42, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-900:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #742a2a;\n  color: rgba(116, 42, 42, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-red-900:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #742a2a;\n  color: rgba(116, 42, 42, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-100:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #fffaf0;\n  color: rgba(255, 250, 240, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-100:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #fffaf0;\n  color: rgba(255, 250, 240, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-100:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #fffaf0;\n  color: rgba(255, 250, 240, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-200:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #feebc8;\n  color: rgba(254, 235, 200, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-200:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #feebc8;\n  color: rgba(254, 235, 200, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-200:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #feebc8;\n  color: rgba(254, 235, 200, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-300:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #fbd38d;\n  color: rgba(251, 211, 141, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-300:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #fbd38d;\n  color: rgba(251, 211, 141, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-300:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #fbd38d;\n  color: rgba(251, 211, 141, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-400:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #f6ad55;\n  color: rgba(246, 173, 85, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-400:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #f6ad55;\n  color: rgba(246, 173, 85, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-400:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #f6ad55;\n  color: rgba(246, 173, 85, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-500:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #ed8936;\n  color: rgba(237, 137, 54, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-500:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #ed8936;\n  color: rgba(237, 137, 54, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-500:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #ed8936;\n  color: rgba(237, 137, 54, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-600:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #dd6b20;\n  color: rgba(221, 107, 32, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-600:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #dd6b20;\n  color: rgba(221, 107, 32, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-600:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #dd6b20;\n  color: rgba(221, 107, 32, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-700:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #c05621;\n  color: rgba(192, 86, 33, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-700:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #c05621;\n  color: rgba(192, 86, 33, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-700:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #c05621;\n  color: rgba(192, 86, 33, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-800:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #9c4221;\n  color: rgba(156, 66, 33, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-800:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #9c4221;\n  color: rgba(156, 66, 33, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-800:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #9c4221;\n  color: rgba(156, 66, 33, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-900:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #7b341e;\n  color: rgba(123, 52, 30, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-900:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #7b341e;\n  color: rgba(123, 52, 30, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-orange-900:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #7b341e;\n  color: rgba(123, 52, 30, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-100:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #fffff0;\n  color: rgba(255, 255, 240, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-100:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #fffff0;\n  color: rgba(255, 255, 240, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-100:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #fffff0;\n  color: rgba(255, 255, 240, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-200:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #fefcbf;\n  color: rgba(254, 252, 191, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-200:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #fefcbf;\n  color: rgba(254, 252, 191, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-200:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #fefcbf;\n  color: rgba(254, 252, 191, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-300:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #faf089;\n  color: rgba(250, 240, 137, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-300:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #faf089;\n  color: rgba(250, 240, 137, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-300:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #faf089;\n  color: rgba(250, 240, 137, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-400:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #f6e05e;\n  color: rgba(246, 224, 94, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-400:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #f6e05e;\n  color: rgba(246, 224, 94, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-400:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #f6e05e;\n  color: rgba(246, 224, 94, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-500:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #ecc94b;\n  color: rgba(236, 201, 75, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-500:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #ecc94b;\n  color: rgba(236, 201, 75, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-500:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #ecc94b;\n  color: rgba(236, 201, 75, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-600:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #d69e2e;\n  color: rgba(214, 158, 46, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-600:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #d69e2e;\n  color: rgba(214, 158, 46, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-600:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #d69e2e;\n  color: rgba(214, 158, 46, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-700:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #b7791f;\n  color: rgba(183, 121, 31, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-700:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #b7791f;\n  color: rgba(183, 121, 31, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-700:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #b7791f;\n  color: rgba(183, 121, 31, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-800:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #975a16;\n  color: rgba(151, 90, 22, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-800:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #975a16;\n  color: rgba(151, 90, 22, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-800:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #975a16;\n  color: rgba(151, 90, 22, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-900:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #744210;\n  color: rgba(116, 66, 16, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-900:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #744210;\n  color: rgba(116, 66, 16, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-yellow-900:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #744210;\n  color: rgba(116, 66, 16, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-100:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #f0fff4;\n  color: rgba(240, 255, 244, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-100:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #f0fff4;\n  color: rgba(240, 255, 244, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-100:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #f0fff4;\n  color: rgba(240, 255, 244, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-200:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #c6f6d5;\n  color: rgba(198, 246, 213, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-200:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #c6f6d5;\n  color: rgba(198, 246, 213, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-200:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #c6f6d5;\n  color: rgba(198, 246, 213, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-300:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #9ae6b4;\n  color: rgba(154, 230, 180, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-300:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #9ae6b4;\n  color: rgba(154, 230, 180, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-300:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #9ae6b4;\n  color: rgba(154, 230, 180, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-400:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #68d391;\n  color: rgba(104, 211, 145, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-400:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #68d391;\n  color: rgba(104, 211, 145, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-400:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #68d391;\n  color: rgba(104, 211, 145, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-500:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #48bb78;\n  color: rgba(72, 187, 120, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-500:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #48bb78;\n  color: rgba(72, 187, 120, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-500:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #48bb78;\n  color: rgba(72, 187, 120, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-600:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #38a169;\n  color: rgba(56, 161, 105, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-600:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #38a169;\n  color: rgba(56, 161, 105, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-600:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #38a169;\n  color: rgba(56, 161, 105, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-700:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #2f855a;\n  color: rgba(47, 133, 90, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-700:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #2f855a;\n  color: rgba(47, 133, 90, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-700:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #2f855a;\n  color: rgba(47, 133, 90, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-800:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #276749;\n  color: rgba(39, 103, 73, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-800:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #276749;\n  color: rgba(39, 103, 73, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-800:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #276749;\n  color: rgba(39, 103, 73, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-900:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #22543d;\n  color: rgba(34, 84, 61, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-900:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #22543d;\n  color: rgba(34, 84, 61, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-green-900:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #22543d;\n  color: rgba(34, 84, 61, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-100:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #e6fffa;\n  color: rgba(230, 255, 250, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-100:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #e6fffa;\n  color: rgba(230, 255, 250, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-100:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #e6fffa;\n  color: rgba(230, 255, 250, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-200:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #b2f5ea;\n  color: rgba(178, 245, 234, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-200:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #b2f5ea;\n  color: rgba(178, 245, 234, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-200:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #b2f5ea;\n  color: rgba(178, 245, 234, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-300:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #81e6d9;\n  color: rgba(129, 230, 217, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-300:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #81e6d9;\n  color: rgba(129, 230, 217, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-300:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #81e6d9;\n  color: rgba(129, 230, 217, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-400:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #4fd1c5;\n  color: rgba(79, 209, 197, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-400:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #4fd1c5;\n  color: rgba(79, 209, 197, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-400:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #4fd1c5;\n  color: rgba(79, 209, 197, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-500:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #38b2ac;\n  color: rgba(56, 178, 172, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-500:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #38b2ac;\n  color: rgba(56, 178, 172, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-500:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #38b2ac;\n  color: rgba(56, 178, 172, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-600:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #319795;\n  color: rgba(49, 151, 149, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-600:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #319795;\n  color: rgba(49, 151, 149, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-600:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #319795;\n  color: rgba(49, 151, 149, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-700:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #2c7a7b;\n  color: rgba(44, 122, 123, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-700:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #2c7a7b;\n  color: rgba(44, 122, 123, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-700:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #2c7a7b;\n  color: rgba(44, 122, 123, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-800:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #285e61;\n  color: rgba(40, 94, 97, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-800:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #285e61;\n  color: rgba(40, 94, 97, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-800:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #285e61;\n  color: rgba(40, 94, 97, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-900:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #234e52;\n  color: rgba(35, 78, 82, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-900:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #234e52;\n  color: rgba(35, 78, 82, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-teal-900:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #234e52;\n  color: rgba(35, 78, 82, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-100:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #ebf8ff;\n  color: rgba(235, 248, 255, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-100:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #ebf8ff;\n  color: rgba(235, 248, 255, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-100:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #ebf8ff;\n  color: rgba(235, 248, 255, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-200:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #bee3f8;\n  color: rgba(190, 227, 248, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-200:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #bee3f8;\n  color: rgba(190, 227, 248, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-200:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #bee3f8;\n  color: rgba(190, 227, 248, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-300:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #90cdf4;\n  color: rgba(144, 205, 244, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-300:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #90cdf4;\n  color: rgba(144, 205, 244, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-300:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #90cdf4;\n  color: rgba(144, 205, 244, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-400:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #63b3ed;\n  color: rgba(99, 179, 237, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-400:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #63b3ed;\n  color: rgba(99, 179, 237, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-400:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #63b3ed;\n  color: rgba(99, 179, 237, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-500:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #4299e1;\n  color: rgba(66, 153, 225, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-500:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #4299e1;\n  color: rgba(66, 153, 225, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-500:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #4299e1;\n  color: rgba(66, 153, 225, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-600:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #3182ce;\n  color: rgba(49, 130, 206, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-600:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #3182ce;\n  color: rgba(49, 130, 206, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-600:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #3182ce;\n  color: rgba(49, 130, 206, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-700:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #2b6cb0;\n  color: rgba(43, 108, 176, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-700:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #2b6cb0;\n  color: rgba(43, 108, 176, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-700:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #2b6cb0;\n  color: rgba(43, 108, 176, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-800:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #2c5282;\n  color: rgba(44, 82, 130, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-800:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #2c5282;\n  color: rgba(44, 82, 130, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-800:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #2c5282;\n  color: rgba(44, 82, 130, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-900:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #2a4365;\n  color: rgba(42, 67, 101, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-900:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #2a4365;\n  color: rgba(42, 67, 101, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-blue-900:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #2a4365;\n  color: rgba(42, 67, 101, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-100:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #ebf4ff;\n  color: rgba(235, 244, 255, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-100:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #ebf4ff;\n  color: rgba(235, 244, 255, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-100:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #ebf4ff;\n  color: rgba(235, 244, 255, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-200:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #c3dafe;\n  color: rgba(195, 218, 254, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-200:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #c3dafe;\n  color: rgba(195, 218, 254, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-200:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #c3dafe;\n  color: rgba(195, 218, 254, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-300:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #a3bffa;\n  color: rgba(163, 191, 250, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-300:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #a3bffa;\n  color: rgba(163, 191, 250, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-300:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #a3bffa;\n  color: rgba(163, 191, 250, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-400:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #7f9cf5;\n  color: rgba(127, 156, 245, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-400:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #7f9cf5;\n  color: rgba(127, 156, 245, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-400:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #7f9cf5;\n  color: rgba(127, 156, 245, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-500:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #667eea;\n  color: rgba(102, 126, 234, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-500:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #667eea;\n  color: rgba(102, 126, 234, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-500:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #667eea;\n  color: rgba(102, 126, 234, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-600:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #5a67d8;\n  color: rgba(90, 103, 216, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-600:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #5a67d8;\n  color: rgba(90, 103, 216, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-600:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #5a67d8;\n  color: rgba(90, 103, 216, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-700:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #4c51bf;\n  color: rgba(76, 81, 191, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-700:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #4c51bf;\n  color: rgba(76, 81, 191, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-700:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #4c51bf;\n  color: rgba(76, 81, 191, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-800:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #434190;\n  color: rgba(67, 65, 144, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-800:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #434190;\n  color: rgba(67, 65, 144, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-800:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #434190;\n  color: rgba(67, 65, 144, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-900:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #3c366b;\n  color: rgba(60, 54, 107, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-900:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #3c366b;\n  color: rgba(60, 54, 107, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-indigo-900:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #3c366b;\n  color: rgba(60, 54, 107, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-100:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #faf5ff;\n  color: rgba(250, 245, 255, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-100:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #faf5ff;\n  color: rgba(250, 245, 255, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-100:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #faf5ff;\n  color: rgba(250, 245, 255, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-200:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #e9d8fd;\n  color: rgba(233, 216, 253, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-200:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #e9d8fd;\n  color: rgba(233, 216, 253, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-200:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #e9d8fd;\n  color: rgba(233, 216, 253, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-300:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #d6bcfa;\n  color: rgba(214, 188, 250, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-300:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #d6bcfa;\n  color: rgba(214, 188, 250, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-300:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #d6bcfa;\n  color: rgba(214, 188, 250, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-400:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #b794f4;\n  color: rgba(183, 148, 244, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-400:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #b794f4;\n  color: rgba(183, 148, 244, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-400:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #b794f4;\n  color: rgba(183, 148, 244, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-500:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #9f7aea;\n  color: rgba(159, 122, 234, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-500:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #9f7aea;\n  color: rgba(159, 122, 234, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-500:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #9f7aea;\n  color: rgba(159, 122, 234, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-600:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #805ad5;\n  color: rgba(128, 90, 213, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-600:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #805ad5;\n  color: rgba(128, 90, 213, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-600:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #805ad5;\n  color: rgba(128, 90, 213, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-700:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #6b46c1;\n  color: rgba(107, 70, 193, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-700:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #6b46c1;\n  color: rgba(107, 70, 193, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-700:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #6b46c1;\n  color: rgba(107, 70, 193, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-800:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #553c9a;\n  color: rgba(85, 60, 154, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-800:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #553c9a;\n  color: rgba(85, 60, 154, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-800:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #553c9a;\n  color: rgba(85, 60, 154, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-900:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #44337a;\n  color: rgba(68, 51, 122, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-900:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #44337a;\n  color: rgba(68, 51, 122, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-purple-900:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #44337a;\n  color: rgba(68, 51, 122, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-100:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #fff5f7;\n  color: rgba(255, 245, 247, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-100:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #fff5f7;\n  color: rgba(255, 245, 247, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-100:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #fff5f7;\n  color: rgba(255, 245, 247, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-200:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #fed7e2;\n  color: rgba(254, 215, 226, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-200:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #fed7e2;\n  color: rgba(254, 215, 226, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-200:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #fed7e2;\n  color: rgba(254, 215, 226, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-300:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #fbb6ce;\n  color: rgba(251, 182, 206, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-300:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #fbb6ce;\n  color: rgba(251, 182, 206, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-300:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #fbb6ce;\n  color: rgba(251, 182, 206, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-400:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #f687b3;\n  color: rgba(246, 135, 179, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-400:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #f687b3;\n  color: rgba(246, 135, 179, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-400:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #f687b3;\n  color: rgba(246, 135, 179, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-500:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #ed64a6;\n  color: rgba(237, 100, 166, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-500:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #ed64a6;\n  color: rgba(237, 100, 166, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-500:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #ed64a6;\n  color: rgba(237, 100, 166, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-600:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #d53f8c;\n  color: rgba(213, 63, 140, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-600:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #d53f8c;\n  color: rgba(213, 63, 140, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-600:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #d53f8c;\n  color: rgba(213, 63, 140, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-700:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #b83280;\n  color: rgba(184, 50, 128, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-700:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #b83280;\n  color: rgba(184, 50, 128, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-700:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #b83280;\n  color: rgba(184, 50, 128, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-800:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #97266d;\n  color: rgba(151, 38, 109, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-800:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #97266d;\n  color: rgba(151, 38, 109, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-800:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #97266d;\n  color: rgba(151, 38, 109, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-900:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: #702459;\n  color: rgba(112, 36, 89, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-900:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: #702459;\n  color: rgba(112, 36, 89, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-pink-900:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: #702459;\n  color: rgba(112, 36, 89, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-80:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 8%);\n  color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-80:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 8%);\n  color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-80:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 8%);\n  color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-100:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 10%);\n  color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-100:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 10%);\n  color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-100:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 10%);\n  color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-200:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 20%);\n  color: rgba(51, 51, 51, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-200:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 20%);\n  color: rgba(51, 51, 51, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-200:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 20%);\n  color: rgba(51, 51, 51, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-300:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 30%);\n  color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-300:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 30%);\n  color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-300:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 30%);\n  color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-400:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 40%);\n  color: rgba(102, 102, 102, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-400:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 40%);\n  color: rgba(102, 102, 102, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-400:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 40%);\n  color: rgba(102, 102, 102, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-500:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 50%);\n  color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-500:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 50%);\n  color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-500:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 50%);\n  color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-600:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 60%);\n  color: rgba(153, 153, 153, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-600:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 60%);\n  color: rgba(153, 153, 153, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-600:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 60%);\n  color: rgba(153, 153, 153, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-700:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 70%);\n  color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-700:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 70%);\n  color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-700:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 70%);\n  color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-800:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 80%);\n  color: rgba(204, 204, 204, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-800:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 80%);\n  color: rgba(204, 204, 204, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-800:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 80%);\n  color: rgba(204, 204, 204, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-840:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 84%);\n  color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-840:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 84%);\n  color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-840:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 84%);\n  color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-870:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 87%);\n  color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-870:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 87%);\n  color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-870:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 87%);\n  color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-900:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 90%);\n  color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-900:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 90%);\n  color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-900:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 90%);\n  color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-930:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 93%);\n  color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-930:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 93%);\n  color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-grayscale-930:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(0, 0%, 93%);\n  color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-primary:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(210, 100%, 52%);\n  color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-primary:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(210, 100%, 52%);\n  color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-primary:focus::placeholder {\n  --placeholder-opacity: 1;\n  color: hsl(210, 100%, 52%);\n  color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n}\n\n.focus\\:placeholder-background-main:focus::-moz-placeholder {\n  color: var(--main-background);\n}\n\n.focus\\:placeholder-background-main:focus:-ms-input-placeholder {\n  color: var(--main-background);\n}\n\n.focus\\:placeholder-background-main:focus::placeholder {\n  color: var(--main-background);\n}\n\n.focus\\:placeholder-background-secondary:focus::-moz-placeholder {\n  color: var(--secondary-background);\n}\n\n.focus\\:placeholder-background-secondary:focus:-ms-input-placeholder {\n  color: var(--secondary-background);\n}\n\n.focus\\:placeholder-background-secondary:focus::placeholder {\n  color: var(--secondary-background);\n}\n\n.focus\\:placeholder-foreground:focus::-moz-placeholder {\n  color: var(--foreground);\n}\n\n.focus\\:placeholder-foreground:focus:-ms-input-placeholder {\n  color: var(--foreground);\n}\n\n.focus\\:placeholder-foreground:focus::placeholder {\n  color: var(--foreground);\n}\n\n.focus\\:placeholder-panels-bg:focus::-moz-placeholder {\n  color: var(--panels-background);\n}\n\n.focus\\:placeholder-panels-bg:focus:-ms-input-placeholder {\n  color: var(--panels-background);\n}\n\n.focus\\:placeholder-panels-bg:focus::placeholder {\n  color: var(--panels-background);\n}\n\n.placeholder-opacity-0::-moz-placeholder {\n  --placeholder-opacity: 0;\n}\n\n.placeholder-opacity-0:-ms-input-placeholder {\n  --placeholder-opacity: 0;\n}\n\n.placeholder-opacity-0::placeholder {\n  --placeholder-opacity: 0;\n}\n\n.placeholder-opacity-25::-moz-placeholder {\n  --placeholder-opacity: 0.25;\n}\n\n.placeholder-opacity-25:-ms-input-placeholder {\n  --placeholder-opacity: 0.25;\n}\n\n.placeholder-opacity-25::placeholder {\n  --placeholder-opacity: 0.25;\n}\n\n.placeholder-opacity-50::-moz-placeholder {\n  --placeholder-opacity: 0.5;\n}\n\n.placeholder-opacity-50:-ms-input-placeholder {\n  --placeholder-opacity: 0.5;\n}\n\n.placeholder-opacity-50::placeholder {\n  --placeholder-opacity: 0.5;\n}\n\n.placeholder-opacity-75::-moz-placeholder {\n  --placeholder-opacity: 0.75;\n}\n\n.placeholder-opacity-75:-ms-input-placeholder {\n  --placeholder-opacity: 0.75;\n}\n\n.placeholder-opacity-75::placeholder {\n  --placeholder-opacity: 0.75;\n}\n\n.placeholder-opacity-100::-moz-placeholder {\n  --placeholder-opacity: 1;\n}\n\n.placeholder-opacity-100:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n}\n\n.placeholder-opacity-100::placeholder {\n  --placeholder-opacity: 1;\n}\n\n.focus\\:placeholder-opacity-0:focus::-moz-placeholder {\n  --placeholder-opacity: 0;\n}\n\n.focus\\:placeholder-opacity-0:focus:-ms-input-placeholder {\n  --placeholder-opacity: 0;\n}\n\n.focus\\:placeholder-opacity-0:focus::placeholder {\n  --placeholder-opacity: 0;\n}\n\n.focus\\:placeholder-opacity-25:focus::-moz-placeholder {\n  --placeholder-opacity: 0.25;\n}\n\n.focus\\:placeholder-opacity-25:focus:-ms-input-placeholder {\n  --placeholder-opacity: 0.25;\n}\n\n.focus\\:placeholder-opacity-25:focus::placeholder {\n  --placeholder-opacity: 0.25;\n}\n\n.focus\\:placeholder-opacity-50:focus::-moz-placeholder {\n  --placeholder-opacity: 0.5;\n}\n\n.focus\\:placeholder-opacity-50:focus:-ms-input-placeholder {\n  --placeholder-opacity: 0.5;\n}\n\n.focus\\:placeholder-opacity-50:focus::placeholder {\n  --placeholder-opacity: 0.5;\n}\n\n.focus\\:placeholder-opacity-75:focus::-moz-placeholder {\n  --placeholder-opacity: 0.75;\n}\n\n.focus\\:placeholder-opacity-75:focus:-ms-input-placeholder {\n  --placeholder-opacity: 0.75;\n}\n\n.focus\\:placeholder-opacity-75:focus::placeholder {\n  --placeholder-opacity: 0.75;\n}\n\n.focus\\:placeholder-opacity-100:focus::-moz-placeholder {\n  --placeholder-opacity: 1;\n}\n\n.focus\\:placeholder-opacity-100:focus:-ms-input-placeholder {\n  --placeholder-opacity: 1;\n}\n\n.focus\\:placeholder-opacity-100:focus::placeholder {\n  --placeholder-opacity: 1;\n}\n\n.pointer-events-none {\n  pointer-events: none;\n}\n\n.pointer-events-auto {\n  pointer-events: auto;\n}\n\n.static {\n  position: static;\n}\n\n.fixed {\n  position: fixed;\n}\n\n.absolute {\n  position: absolute;\n}\n\n.relative {\n  position: relative;\n}\n\n.sticky {\n  position: -webkit-sticky;\n  position: sticky;\n}\n\n.inset-0 {\n  top: 0;\n  right: 0;\n  bottom: 0;\n  left: 0;\n}\n\n.inset-auto {\n  top: auto;\n  right: auto;\n  bottom: auto;\n  left: auto;\n}\n\n.inset-y-0 {\n  top: 0;\n  bottom: 0;\n}\n\n.inset-x-0 {\n  right: 0;\n  left: 0;\n}\n\n.inset-y-auto {\n  top: auto;\n  bottom: auto;\n}\n\n.inset-x-auto {\n  right: auto;\n  left: auto;\n}\n\n.top-0 {\n  top: 0;\n}\n\n.right-0 {\n  right: 0;\n}\n\n.bottom-0 {\n  bottom: 0;\n}\n\n.left-0 {\n  left: 0;\n}\n\n.top-auto {\n  top: auto;\n}\n\n.right-auto {\n  right: auto;\n}\n\n.bottom-auto {\n  bottom: auto;\n}\n\n.left-auto {\n  left: auto;\n}\n\n.resize-none {\n  resize: none;\n}\n\n.resize-y {\n  resize: vertical;\n}\n\n.resize-x {\n  resize: horizontal;\n}\n\n.resize {\n  resize: both;\n}\n\n.shadow-xs {\n  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.05);\n}\n\n.shadow-sm {\n  box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);\n}\n\n.shadow {\n  box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);\n}\n\n.shadow-md {\n  box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);\n}\n\n.shadow-lg {\n  box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);\n}\n\n.shadow-xl {\n  box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04);\n}\n\n.shadow-2xl {\n  box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);\n}\n\n.shadow-inner {\n  box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);\n}\n\n.shadow-outline {\n  box-shadow: 0 0 0 3px rgba(66, 153, 225, 0.5);\n}\n\n.shadow-none {\n  box-shadow: none;\n}\n\n.hover\\:shadow-xs:hover {\n  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.05);\n}\n\n.hover\\:shadow-sm:hover {\n  box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);\n}\n\n.hover\\:shadow:hover {\n  box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);\n}\n\n.hover\\:shadow-md:hover {\n  box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);\n}\n\n.hover\\:shadow-lg:hover {\n  box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);\n}\n\n.hover\\:shadow-xl:hover {\n  box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04);\n}\n\n.hover\\:shadow-2xl:hover {\n  box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);\n}\n\n.hover\\:shadow-inner:hover {\n  box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);\n}\n\n.hover\\:shadow-outline:hover {\n  box-shadow: 0 0 0 3px rgba(66, 153, 225, 0.5);\n}\n\n.hover\\:shadow-none:hover {\n  box-shadow: none;\n}\n\n.focus\\:shadow-xs:focus {\n  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.05);\n}\n\n.focus\\:shadow-sm:focus {\n  box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);\n}\n\n.focus\\:shadow:focus {\n  box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);\n}\n\n.focus\\:shadow-md:focus {\n  box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);\n}\n\n.focus\\:shadow-lg:focus {\n  box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);\n}\n\n.focus\\:shadow-xl:focus {\n  box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04);\n}\n\n.focus\\:shadow-2xl:focus {\n  box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);\n}\n\n.focus\\:shadow-inner:focus {\n  box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);\n}\n\n.focus\\:shadow-outline:focus {\n  box-shadow: 0 0 0 3px rgba(66, 153, 225, 0.5);\n}\n\n.focus\\:shadow-none:focus {\n  box-shadow: none;\n}\n\n.fill-current {\n  fill: currentColor;\n}\n\n.stroke-current {\n  stroke: currentColor;\n}\n\n.stroke-0 {\n  stroke-width: 0;\n}\n\n.stroke-1 {\n  stroke-width: 1;\n}\n\n.stroke-2 {\n  stroke-width: 2;\n}\n\n.table-auto {\n  table-layout: auto;\n}\n\n.table-fixed {\n  table-layout: fixed;\n}\n\n.text-left {\n  text-align: left;\n}\n\n.text-center {\n  text-align: center;\n}\n\n.text-right {\n  text-align: right;\n}\n\n.text-justify {\n  text-align: justify;\n}\n\n.text-transparent {\n  color: transparent;\n}\n\n.text-current {\n  color: currentColor;\n}\n\n.text-black {\n  --text-opacity: 1;\n  color: #000;\n  color: rgba(0, 0, 0, var(--text-opacity));\n}\n\n.text-white {\n  --text-opacity: 1;\n  color: #fff;\n  color: rgba(255, 255, 255, var(--text-opacity));\n}\n\n.text-gray-100 {\n  --text-opacity: 1;\n  color: #f7fafc;\n  color: rgba(247, 250, 252, var(--text-opacity));\n}\n\n.text-gray-200 {\n  --text-opacity: 1;\n  color: #edf2f7;\n  color: rgba(237, 242, 247, var(--text-opacity));\n}\n\n.text-gray-300 {\n  --text-opacity: 1;\n  color: #e2e8f0;\n  color: rgba(226, 232, 240, var(--text-opacity));\n}\n\n.text-gray-400 {\n  --text-opacity: 1;\n  color: #cbd5e0;\n  color: rgba(203, 213, 224, var(--text-opacity));\n}\n\n.text-gray-500 {\n  --text-opacity: 1;\n  color: #a0aec0;\n  color: rgba(160, 174, 192, var(--text-opacity));\n}\n\n.text-gray-600 {\n  --text-opacity: 1;\n  color: #718096;\n  color: rgba(113, 128, 150, var(--text-opacity));\n}\n\n.text-gray-700 {\n  --text-opacity: 1;\n  color: #4a5568;\n  color: rgba(74, 85, 104, var(--text-opacity));\n}\n\n.text-gray-800 {\n  --text-opacity: 1;\n  color: #2d3748;\n  color: rgba(45, 55, 72, var(--text-opacity));\n}\n\n.text-gray-900 {\n  --text-opacity: 1;\n  color: #1a202c;\n  color: rgba(26, 32, 44, var(--text-opacity));\n}\n\n.text-red-100 {\n  --text-opacity: 1;\n  color: #fff5f5;\n  color: rgba(255, 245, 245, var(--text-opacity));\n}\n\n.text-red-200 {\n  --text-opacity: 1;\n  color: #fed7d7;\n  color: rgba(254, 215, 215, var(--text-opacity));\n}\n\n.text-red-300 {\n  --text-opacity: 1;\n  color: #feb2b2;\n  color: rgba(254, 178, 178, var(--text-opacity));\n}\n\n.text-red-400 {\n  --text-opacity: 1;\n  color: #fc8181;\n  color: rgba(252, 129, 129, var(--text-opacity));\n}\n\n.text-red-500 {\n  --text-opacity: 1;\n  color: #f56565;\n  color: rgba(245, 101, 101, var(--text-opacity));\n}\n\n.text-red-600 {\n  --text-opacity: 1;\n  color: #e53e3e;\n  color: rgba(229, 62, 62, var(--text-opacity));\n}\n\n.text-red-700 {\n  --text-opacity: 1;\n  color: #c53030;\n  color: rgba(197, 48, 48, var(--text-opacity));\n}\n\n.text-red-800 {\n  --text-opacity: 1;\n  color: #9b2c2c;\n  color: rgba(155, 44, 44, var(--text-opacity));\n}\n\n.text-red-900 {\n  --text-opacity: 1;\n  color: #742a2a;\n  color: rgba(116, 42, 42, var(--text-opacity));\n}\n\n.text-orange-100 {\n  --text-opacity: 1;\n  color: #fffaf0;\n  color: rgba(255, 250, 240, var(--text-opacity));\n}\n\n.text-orange-200 {\n  --text-opacity: 1;\n  color: #feebc8;\n  color: rgba(254, 235, 200, var(--text-opacity));\n}\n\n.text-orange-300 {\n  --text-opacity: 1;\n  color: #fbd38d;\n  color: rgba(251, 211, 141, var(--text-opacity));\n}\n\n.text-orange-400 {\n  --text-opacity: 1;\n  color: #f6ad55;\n  color: rgba(246, 173, 85, var(--text-opacity));\n}\n\n.text-orange-500 {\n  --text-opacity: 1;\n  color: #ed8936;\n  color: rgba(237, 137, 54, var(--text-opacity));\n}\n\n.text-orange-600 {\n  --text-opacity: 1;\n  color: #dd6b20;\n  color: rgba(221, 107, 32, var(--text-opacity));\n}\n\n.text-orange-700 {\n  --text-opacity: 1;\n  color: #c05621;\n  color: rgba(192, 86, 33, var(--text-opacity));\n}\n\n.text-orange-800 {\n  --text-opacity: 1;\n  color: #9c4221;\n  color: rgba(156, 66, 33, var(--text-opacity));\n}\n\n.text-orange-900 {\n  --text-opacity: 1;\n  color: #7b341e;\n  color: rgba(123, 52, 30, var(--text-opacity));\n}\n\n.text-yellow-100 {\n  --text-opacity: 1;\n  color: #fffff0;\n  color: rgba(255, 255, 240, var(--text-opacity));\n}\n\n.text-yellow-200 {\n  --text-opacity: 1;\n  color: #fefcbf;\n  color: rgba(254, 252, 191, var(--text-opacity));\n}\n\n.text-yellow-300 {\n  --text-opacity: 1;\n  color: #faf089;\n  color: rgba(250, 240, 137, var(--text-opacity));\n}\n\n.text-yellow-400 {\n  --text-opacity: 1;\n  color: #f6e05e;\n  color: rgba(246, 224, 94, var(--text-opacity));\n}\n\n.text-yellow-500 {\n  --text-opacity: 1;\n  color: #ecc94b;\n  color: rgba(236, 201, 75, var(--text-opacity));\n}\n\n.text-yellow-600 {\n  --text-opacity: 1;\n  color: #d69e2e;\n  color: rgba(214, 158, 46, var(--text-opacity));\n}\n\n.text-yellow-700 {\n  --text-opacity: 1;\n  color: #b7791f;\n  color: rgba(183, 121, 31, var(--text-opacity));\n}\n\n.text-yellow-800 {\n  --text-opacity: 1;\n  color: #975a16;\n  color: rgba(151, 90, 22, var(--text-opacity));\n}\n\n.text-yellow-900 {\n  --text-opacity: 1;\n  color: #744210;\n  color: rgba(116, 66, 16, var(--text-opacity));\n}\n\n.text-green-100 {\n  --text-opacity: 1;\n  color: #f0fff4;\n  color: rgba(240, 255, 244, var(--text-opacity));\n}\n\n.text-green-200 {\n  --text-opacity: 1;\n  color: #c6f6d5;\n  color: rgba(198, 246, 213, var(--text-opacity));\n}\n\n.text-green-300 {\n  --text-opacity: 1;\n  color: #9ae6b4;\n  color: rgba(154, 230, 180, var(--text-opacity));\n}\n\n.text-green-400 {\n  --text-opacity: 1;\n  color: #68d391;\n  color: rgba(104, 211, 145, var(--text-opacity));\n}\n\n.text-green-500 {\n  --text-opacity: 1;\n  color: #48bb78;\n  color: rgba(72, 187, 120, var(--text-opacity));\n}\n\n.text-green-600 {\n  --text-opacity: 1;\n  color: #38a169;\n  color: rgba(56, 161, 105, var(--text-opacity));\n}\n\n.text-green-700 {\n  --text-opacity: 1;\n  color: #2f855a;\n  color: rgba(47, 133, 90, var(--text-opacity));\n}\n\n.text-green-800 {\n  --text-opacity: 1;\n  color: #276749;\n  color: rgba(39, 103, 73, var(--text-opacity));\n}\n\n.text-green-900 {\n  --text-opacity: 1;\n  color: #22543d;\n  color: rgba(34, 84, 61, var(--text-opacity));\n}\n\n.text-teal-100 {\n  --text-opacity: 1;\n  color: #e6fffa;\n  color: rgba(230, 255, 250, var(--text-opacity));\n}\n\n.text-teal-200 {\n  --text-opacity: 1;\n  color: #b2f5ea;\n  color: rgba(178, 245, 234, var(--text-opacity));\n}\n\n.text-teal-300 {\n  --text-opacity: 1;\n  color: #81e6d9;\n  color: rgba(129, 230, 217, var(--text-opacity));\n}\n\n.text-teal-400 {\n  --text-opacity: 1;\n  color: #4fd1c5;\n  color: rgba(79, 209, 197, var(--text-opacity));\n}\n\n.text-teal-500 {\n  --text-opacity: 1;\n  color: #38b2ac;\n  color: rgba(56, 178, 172, var(--text-opacity));\n}\n\n.text-teal-600 {\n  --text-opacity: 1;\n  color: #319795;\n  color: rgba(49, 151, 149, var(--text-opacity));\n}\n\n.text-teal-700 {\n  --text-opacity: 1;\n  color: #2c7a7b;\n  color: rgba(44, 122, 123, var(--text-opacity));\n}\n\n.text-teal-800 {\n  --text-opacity: 1;\n  color: #285e61;\n  color: rgba(40, 94, 97, var(--text-opacity));\n}\n\n.text-teal-900 {\n  --text-opacity: 1;\n  color: #234e52;\n  color: rgba(35, 78, 82, var(--text-opacity));\n}\n\n.text-blue-100 {\n  --text-opacity: 1;\n  color: #ebf8ff;\n  color: rgba(235, 248, 255, var(--text-opacity));\n}\n\n.text-blue-200 {\n  --text-opacity: 1;\n  color: #bee3f8;\n  color: rgba(190, 227, 248, var(--text-opacity));\n}\n\n.text-blue-300 {\n  --text-opacity: 1;\n  color: #90cdf4;\n  color: rgba(144, 205, 244, var(--text-opacity));\n}\n\n.text-blue-400 {\n  --text-opacity: 1;\n  color: #63b3ed;\n  color: rgba(99, 179, 237, var(--text-opacity));\n}\n\n.text-blue-500 {\n  --text-opacity: 1;\n  color: #4299e1;\n  color: rgba(66, 153, 225, var(--text-opacity));\n}\n\n.text-blue-600 {\n  --text-opacity: 1;\n  color: #3182ce;\n  color: rgba(49, 130, 206, var(--text-opacity));\n}\n\n.text-blue-700 {\n  --text-opacity: 1;\n  color: #2b6cb0;\n  color: rgba(43, 108, 176, var(--text-opacity));\n}\n\n.text-blue-800 {\n  --text-opacity: 1;\n  color: #2c5282;\n  color: rgba(44, 82, 130, var(--text-opacity));\n}\n\n.text-blue-900 {\n  --text-opacity: 1;\n  color: #2a4365;\n  color: rgba(42, 67, 101, var(--text-opacity));\n}\n\n.text-indigo-100 {\n  --text-opacity: 1;\n  color: #ebf4ff;\n  color: rgba(235, 244, 255, var(--text-opacity));\n}\n\n.text-indigo-200 {\n  --text-opacity: 1;\n  color: #c3dafe;\n  color: rgba(195, 218, 254, var(--text-opacity));\n}\n\n.text-indigo-300 {\n  --text-opacity: 1;\n  color: #a3bffa;\n  color: rgba(163, 191, 250, var(--text-opacity));\n}\n\n.text-indigo-400 {\n  --text-opacity: 1;\n  color: #7f9cf5;\n  color: rgba(127, 156, 245, var(--text-opacity));\n}\n\n.text-indigo-500 {\n  --text-opacity: 1;\n  color: #667eea;\n  color: rgba(102, 126, 234, var(--text-opacity));\n}\n\n.text-indigo-600 {\n  --text-opacity: 1;\n  color: #5a67d8;\n  color: rgba(90, 103, 216, var(--text-opacity));\n}\n\n.text-indigo-700 {\n  --text-opacity: 1;\n  color: #4c51bf;\n  color: rgba(76, 81, 191, var(--text-opacity));\n}\n\n.text-indigo-800 {\n  --text-opacity: 1;\n  color: #434190;\n  color: rgba(67, 65, 144, var(--text-opacity));\n}\n\n.text-indigo-900 {\n  --text-opacity: 1;\n  color: #3c366b;\n  color: rgba(60, 54, 107, var(--text-opacity));\n}\n\n.text-purple-100 {\n  --text-opacity: 1;\n  color: #faf5ff;\n  color: rgba(250, 245, 255, var(--text-opacity));\n}\n\n.text-purple-200 {\n  --text-opacity: 1;\n  color: #e9d8fd;\n  color: rgba(233, 216, 253, var(--text-opacity));\n}\n\n.text-purple-300 {\n  --text-opacity: 1;\n  color: #d6bcfa;\n  color: rgba(214, 188, 250, var(--text-opacity));\n}\n\n.text-purple-400 {\n  --text-opacity: 1;\n  color: #b794f4;\n  color: rgba(183, 148, 244, var(--text-opacity));\n}\n\n.text-purple-500 {\n  --text-opacity: 1;\n  color: #9f7aea;\n  color: rgba(159, 122, 234, var(--text-opacity));\n}\n\n.text-purple-600 {\n  --text-opacity: 1;\n  color: #805ad5;\n  color: rgba(128, 90, 213, var(--text-opacity));\n}\n\n.text-purple-700 {\n  --text-opacity: 1;\n  color: #6b46c1;\n  color: rgba(107, 70, 193, var(--text-opacity));\n}\n\n.text-purple-800 {\n  --text-opacity: 1;\n  color: #553c9a;\n  color: rgba(85, 60, 154, var(--text-opacity));\n}\n\n.text-purple-900 {\n  --text-opacity: 1;\n  color: #44337a;\n  color: rgba(68, 51, 122, var(--text-opacity));\n}\n\n.text-pink-100 {\n  --text-opacity: 1;\n  color: #fff5f7;\n  color: rgba(255, 245, 247, var(--text-opacity));\n}\n\n.text-pink-200 {\n  --text-opacity: 1;\n  color: #fed7e2;\n  color: rgba(254, 215, 226, var(--text-opacity));\n}\n\n.text-pink-300 {\n  --text-opacity: 1;\n  color: #fbb6ce;\n  color: rgba(251, 182, 206, var(--text-opacity));\n}\n\n.text-pink-400 {\n  --text-opacity: 1;\n  color: #f687b3;\n  color: rgba(246, 135, 179, var(--text-opacity));\n}\n\n.text-pink-500 {\n  --text-opacity: 1;\n  color: #ed64a6;\n  color: rgba(237, 100, 166, var(--text-opacity));\n}\n\n.text-pink-600 {\n  --text-opacity: 1;\n  color: #d53f8c;\n  color: rgba(213, 63, 140, var(--text-opacity));\n}\n\n.text-pink-700 {\n  --text-opacity: 1;\n  color: #b83280;\n  color: rgba(184, 50, 128, var(--text-opacity));\n}\n\n.text-pink-800 {\n  --text-opacity: 1;\n  color: #97266d;\n  color: rgba(151, 38, 109, var(--text-opacity));\n}\n\n.text-pink-900 {\n  --text-opacity: 1;\n  color: #702459;\n  color: rgba(112, 36, 89, var(--text-opacity));\n}\n\n.text-grayscale-80 {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 8%);\n  color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--text-opacity));\n}\n\n.text-grayscale-100 {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 10%);\n  color: rgba(25.5, 25.5, 25.5, var(--text-opacity));\n}\n\n.text-grayscale-200 {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 20%);\n  color: rgba(51, 51, 51, var(--text-opacity));\n}\n\n.text-grayscale-300 {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 30%);\n  color: rgba(76.5, 76.5, 76.5, var(--text-opacity));\n}\n\n.text-grayscale-400 {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 40%);\n  color: rgba(102, 102, 102, var(--text-opacity));\n}\n\n.text-grayscale-500 {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 50%);\n  color: rgba(127.5, 127.5, 127.5, var(--text-opacity));\n}\n\n.text-grayscale-600 {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 60%);\n  color: rgba(153, 153, 153, var(--text-opacity));\n}\n\n.text-grayscale-700 {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 70%);\n  color: rgba(178.5, 178.5, 178.5, var(--text-opacity));\n}\n\n.text-grayscale-800 {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 80%);\n  color: rgba(204, 204, 204, var(--text-opacity));\n}\n\n.text-grayscale-840 {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 84%);\n  color: rgba(214.2, 214.2, 214.2, var(--text-opacity));\n}\n\n.text-grayscale-870 {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 87%);\n  color: rgba(221.85, 221.85, 221.85, var(--text-opacity));\n}\n\n.text-grayscale-900 {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 90%);\n  color: rgba(229.5, 229.5, 229.5, var(--text-opacity));\n}\n\n.text-grayscale-930 {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 93%);\n  color: rgba(237.15, 237.15, 237.15, var(--text-opacity));\n}\n\n.text-primary {\n  --text-opacity: 1;\n  color: hsl(210, 100%, 52%);\n  color: rgba(10.20000000000001, 132.59999999999988, 255, var(--text-opacity));\n}\n\n.text-background-main {\n  color: var(--main-background);\n}\n\n.text-background-secondary {\n  color: var(--secondary-background);\n}\n\n.text-foreground {\n  color: var(--foreground);\n}\n\n.text-panels-bg {\n  color: var(--panels-background);\n}\n\n.hover\\:text-transparent:hover {\n  color: transparent;\n}\n\n.hover\\:text-current:hover {\n  color: currentColor;\n}\n\n.hover\\:text-black:hover {\n  --text-opacity: 1;\n  color: #000;\n  color: rgba(0, 0, 0, var(--text-opacity));\n}\n\n.hover\\:text-white:hover {\n  --text-opacity: 1;\n  color: #fff;\n  color: rgba(255, 255, 255, var(--text-opacity));\n}\n\n.hover\\:text-gray-100:hover {\n  --text-opacity: 1;\n  color: #f7fafc;\n  color: rgba(247, 250, 252, var(--text-opacity));\n}\n\n.hover\\:text-gray-200:hover {\n  --text-opacity: 1;\n  color: #edf2f7;\n  color: rgba(237, 242, 247, var(--text-opacity));\n}\n\n.hover\\:text-gray-300:hover {\n  --text-opacity: 1;\n  color: #e2e8f0;\n  color: rgba(226, 232, 240, var(--text-opacity));\n}\n\n.hover\\:text-gray-400:hover {\n  --text-opacity: 1;\n  color: #cbd5e0;\n  color: rgba(203, 213, 224, var(--text-opacity));\n}\n\n.hover\\:text-gray-500:hover {\n  --text-opacity: 1;\n  color: #a0aec0;\n  color: rgba(160, 174, 192, var(--text-opacity));\n}\n\n.hover\\:text-gray-600:hover {\n  --text-opacity: 1;\n  color: #718096;\n  color: rgba(113, 128, 150, var(--text-opacity));\n}\n\n.hover\\:text-gray-700:hover {\n  --text-opacity: 1;\n  color: #4a5568;\n  color: rgba(74, 85, 104, var(--text-opacity));\n}\n\n.hover\\:text-gray-800:hover {\n  --text-opacity: 1;\n  color: #2d3748;\n  color: rgba(45, 55, 72, var(--text-opacity));\n}\n\n.hover\\:text-gray-900:hover {\n  --text-opacity: 1;\n  color: #1a202c;\n  color: rgba(26, 32, 44, var(--text-opacity));\n}\n\n.hover\\:text-red-100:hover {\n  --text-opacity: 1;\n  color: #fff5f5;\n  color: rgba(255, 245, 245, var(--text-opacity));\n}\n\n.hover\\:text-red-200:hover {\n  --text-opacity: 1;\n  color: #fed7d7;\n  color: rgba(254, 215, 215, var(--text-opacity));\n}\n\n.hover\\:text-red-300:hover {\n  --text-opacity: 1;\n  color: #feb2b2;\n  color: rgba(254, 178, 178, var(--text-opacity));\n}\n\n.hover\\:text-red-400:hover {\n  --text-opacity: 1;\n  color: #fc8181;\n  color: rgba(252, 129, 129, var(--text-opacity));\n}\n\n.hover\\:text-red-500:hover {\n  --text-opacity: 1;\n  color: #f56565;\n  color: rgba(245, 101, 101, var(--text-opacity));\n}\n\n.hover\\:text-red-600:hover {\n  --text-opacity: 1;\n  color: #e53e3e;\n  color: rgba(229, 62, 62, var(--text-opacity));\n}\n\n.hover\\:text-red-700:hover {\n  --text-opacity: 1;\n  color: #c53030;\n  color: rgba(197, 48, 48, var(--text-opacity));\n}\n\n.hover\\:text-red-800:hover {\n  --text-opacity: 1;\n  color: #9b2c2c;\n  color: rgba(155, 44, 44, var(--text-opacity));\n}\n\n.hover\\:text-red-900:hover {\n  --text-opacity: 1;\n  color: #742a2a;\n  color: rgba(116, 42, 42, var(--text-opacity));\n}\n\n.hover\\:text-orange-100:hover {\n  --text-opacity: 1;\n  color: #fffaf0;\n  color: rgba(255, 250, 240, var(--text-opacity));\n}\n\n.hover\\:text-orange-200:hover {\n  --text-opacity: 1;\n  color: #feebc8;\n  color: rgba(254, 235, 200, var(--text-opacity));\n}\n\n.hover\\:text-orange-300:hover {\n  --text-opacity: 1;\n  color: #fbd38d;\n  color: rgba(251, 211, 141, var(--text-opacity));\n}\n\n.hover\\:text-orange-400:hover {\n  --text-opacity: 1;\n  color: #f6ad55;\n  color: rgba(246, 173, 85, var(--text-opacity));\n}\n\n.hover\\:text-orange-500:hover {\n  --text-opacity: 1;\n  color: #ed8936;\n  color: rgba(237, 137, 54, var(--text-opacity));\n}\n\n.hover\\:text-orange-600:hover {\n  --text-opacity: 1;\n  color: #dd6b20;\n  color: rgba(221, 107, 32, var(--text-opacity));\n}\n\n.hover\\:text-orange-700:hover {\n  --text-opacity: 1;\n  color: #c05621;\n  color: rgba(192, 86, 33, var(--text-opacity));\n}\n\n.hover\\:text-orange-800:hover {\n  --text-opacity: 1;\n  color: #9c4221;\n  color: rgba(156, 66, 33, var(--text-opacity));\n}\n\n.hover\\:text-orange-900:hover {\n  --text-opacity: 1;\n  color: #7b341e;\n  color: rgba(123, 52, 30, var(--text-opacity));\n}\n\n.hover\\:text-yellow-100:hover {\n  --text-opacity: 1;\n  color: #fffff0;\n  color: rgba(255, 255, 240, var(--text-opacity));\n}\n\n.hover\\:text-yellow-200:hover {\n  --text-opacity: 1;\n  color: #fefcbf;\n  color: rgba(254, 252, 191, var(--text-opacity));\n}\n\n.hover\\:text-yellow-300:hover {\n  --text-opacity: 1;\n  color: #faf089;\n  color: rgba(250, 240, 137, var(--text-opacity));\n}\n\n.hover\\:text-yellow-400:hover {\n  --text-opacity: 1;\n  color: #f6e05e;\n  color: rgba(246, 224, 94, var(--text-opacity));\n}\n\n.hover\\:text-yellow-500:hover {\n  --text-opacity: 1;\n  color: #ecc94b;\n  color: rgba(236, 201, 75, var(--text-opacity));\n}\n\n.hover\\:text-yellow-600:hover {\n  --text-opacity: 1;\n  color: #d69e2e;\n  color: rgba(214, 158, 46, var(--text-opacity));\n}\n\n.hover\\:text-yellow-700:hover {\n  --text-opacity: 1;\n  color: #b7791f;\n  color: rgba(183, 121, 31, var(--text-opacity));\n}\n\n.hover\\:text-yellow-800:hover {\n  --text-opacity: 1;\n  color: #975a16;\n  color: rgba(151, 90, 22, var(--text-opacity));\n}\n\n.hover\\:text-yellow-900:hover {\n  --text-opacity: 1;\n  color: #744210;\n  color: rgba(116, 66, 16, var(--text-opacity));\n}\n\n.hover\\:text-green-100:hover {\n  --text-opacity: 1;\n  color: #f0fff4;\n  color: rgba(240, 255, 244, var(--text-opacity));\n}\n\n.hover\\:text-green-200:hover {\n  --text-opacity: 1;\n  color: #c6f6d5;\n  color: rgba(198, 246, 213, var(--text-opacity));\n}\n\n.hover\\:text-green-300:hover {\n  --text-opacity: 1;\n  color: #9ae6b4;\n  color: rgba(154, 230, 180, var(--text-opacity));\n}\n\n.hover\\:text-green-400:hover {\n  --text-opacity: 1;\n  color: #68d391;\n  color: rgba(104, 211, 145, var(--text-opacity));\n}\n\n.hover\\:text-green-500:hover {\n  --text-opacity: 1;\n  color: #48bb78;\n  color: rgba(72, 187, 120, var(--text-opacity));\n}\n\n.hover\\:text-green-600:hover {\n  --text-opacity: 1;\n  color: #38a169;\n  color: rgba(56, 161, 105, var(--text-opacity));\n}\n\n.hover\\:text-green-700:hover {\n  --text-opacity: 1;\n  color: #2f855a;\n  color: rgba(47, 133, 90, var(--text-opacity));\n}\n\n.hover\\:text-green-800:hover {\n  --text-opacity: 1;\n  color: #276749;\n  color: rgba(39, 103, 73, var(--text-opacity));\n}\n\n.hover\\:text-green-900:hover {\n  --text-opacity: 1;\n  color: #22543d;\n  color: rgba(34, 84, 61, var(--text-opacity));\n}\n\n.hover\\:text-teal-100:hover {\n  --text-opacity: 1;\n  color: #e6fffa;\n  color: rgba(230, 255, 250, var(--text-opacity));\n}\n\n.hover\\:text-teal-200:hover {\n  --text-opacity: 1;\n  color: #b2f5ea;\n  color: rgba(178, 245, 234, var(--text-opacity));\n}\n\n.hover\\:text-teal-300:hover {\n  --text-opacity: 1;\n  color: #81e6d9;\n  color: rgba(129, 230, 217, var(--text-opacity));\n}\n\n.hover\\:text-teal-400:hover {\n  --text-opacity: 1;\n  color: #4fd1c5;\n  color: rgba(79, 209, 197, var(--text-opacity));\n}\n\n.hover\\:text-teal-500:hover {\n  --text-opacity: 1;\n  color: #38b2ac;\n  color: rgba(56, 178, 172, var(--text-opacity));\n}\n\n.hover\\:text-teal-600:hover {\n  --text-opacity: 1;\n  color: #319795;\n  color: rgba(49, 151, 149, var(--text-opacity));\n}\n\n.hover\\:text-teal-700:hover {\n  --text-opacity: 1;\n  color: #2c7a7b;\n  color: rgba(44, 122, 123, var(--text-opacity));\n}\n\n.hover\\:text-teal-800:hover {\n  --text-opacity: 1;\n  color: #285e61;\n  color: rgba(40, 94, 97, var(--text-opacity));\n}\n\n.hover\\:text-teal-900:hover {\n  --text-opacity: 1;\n  color: #234e52;\n  color: rgba(35, 78, 82, var(--text-opacity));\n}\n\n.hover\\:text-blue-100:hover {\n  --text-opacity: 1;\n  color: #ebf8ff;\n  color: rgba(235, 248, 255, var(--text-opacity));\n}\n\n.hover\\:text-blue-200:hover {\n  --text-opacity: 1;\n  color: #bee3f8;\n  color: rgba(190, 227, 248, var(--text-opacity));\n}\n\n.hover\\:text-blue-300:hover {\n  --text-opacity: 1;\n  color: #90cdf4;\n  color: rgba(144, 205, 244, var(--text-opacity));\n}\n\n.hover\\:text-blue-400:hover {\n  --text-opacity: 1;\n  color: #63b3ed;\n  color: rgba(99, 179, 237, var(--text-opacity));\n}\n\n.hover\\:text-blue-500:hover {\n  --text-opacity: 1;\n  color: #4299e1;\n  color: rgba(66, 153, 225, var(--text-opacity));\n}\n\n.hover\\:text-blue-600:hover {\n  --text-opacity: 1;\n  color: #3182ce;\n  color: rgba(49, 130, 206, var(--text-opacity));\n}\n\n.hover\\:text-blue-700:hover {\n  --text-opacity: 1;\n  color: #2b6cb0;\n  color: rgba(43, 108, 176, var(--text-opacity));\n}\n\n.hover\\:text-blue-800:hover {\n  --text-opacity: 1;\n  color: #2c5282;\n  color: rgba(44, 82, 130, var(--text-opacity));\n}\n\n.hover\\:text-blue-900:hover {\n  --text-opacity: 1;\n  color: #2a4365;\n  color: rgba(42, 67, 101, var(--text-opacity));\n}\n\n.hover\\:text-indigo-100:hover {\n  --text-opacity: 1;\n  color: #ebf4ff;\n  color: rgba(235, 244, 255, var(--text-opacity));\n}\n\n.hover\\:text-indigo-200:hover {\n  --text-opacity: 1;\n  color: #c3dafe;\n  color: rgba(195, 218, 254, var(--text-opacity));\n}\n\n.hover\\:text-indigo-300:hover {\n  --text-opacity: 1;\n  color: #a3bffa;\n  color: rgba(163, 191, 250, var(--text-opacity));\n}\n\n.hover\\:text-indigo-400:hover {\n  --text-opacity: 1;\n  color: #7f9cf5;\n  color: rgba(127, 156, 245, var(--text-opacity));\n}\n\n.hover\\:text-indigo-500:hover {\n  --text-opacity: 1;\n  color: #667eea;\n  color: rgba(102, 126, 234, var(--text-opacity));\n}\n\n.hover\\:text-indigo-600:hover {\n  --text-opacity: 1;\n  color: #5a67d8;\n  color: rgba(90, 103, 216, var(--text-opacity));\n}\n\n.hover\\:text-indigo-700:hover {\n  --text-opacity: 1;\n  color: #4c51bf;\n  color: rgba(76, 81, 191, var(--text-opacity));\n}\n\n.hover\\:text-indigo-800:hover {\n  --text-opacity: 1;\n  color: #434190;\n  color: rgba(67, 65, 144, var(--text-opacity));\n}\n\n.hover\\:text-indigo-900:hover {\n  --text-opacity: 1;\n  color: #3c366b;\n  color: rgba(60, 54, 107, var(--text-opacity));\n}\n\n.hover\\:text-purple-100:hover {\n  --text-opacity: 1;\n  color: #faf5ff;\n  color: rgba(250, 245, 255, var(--text-opacity));\n}\n\n.hover\\:text-purple-200:hover {\n  --text-opacity: 1;\n  color: #e9d8fd;\n  color: rgba(233, 216, 253, var(--text-opacity));\n}\n\n.hover\\:text-purple-300:hover {\n  --text-opacity: 1;\n  color: #d6bcfa;\n  color: rgba(214, 188, 250, var(--text-opacity));\n}\n\n.hover\\:text-purple-400:hover {\n  --text-opacity: 1;\n  color: #b794f4;\n  color: rgba(183, 148, 244, var(--text-opacity));\n}\n\n.hover\\:text-purple-500:hover {\n  --text-opacity: 1;\n  color: #9f7aea;\n  color: rgba(159, 122, 234, var(--text-opacity));\n}\n\n.hover\\:text-purple-600:hover {\n  --text-opacity: 1;\n  color: #805ad5;\n  color: rgba(128, 90, 213, var(--text-opacity));\n}\n\n.hover\\:text-purple-700:hover {\n  --text-opacity: 1;\n  color: #6b46c1;\n  color: rgba(107, 70, 193, var(--text-opacity));\n}\n\n.hover\\:text-purple-800:hover {\n  --text-opacity: 1;\n  color: #553c9a;\n  color: rgba(85, 60, 154, var(--text-opacity));\n}\n\n.hover\\:text-purple-900:hover {\n  --text-opacity: 1;\n  color: #44337a;\n  color: rgba(68, 51, 122, var(--text-opacity));\n}\n\n.hover\\:text-pink-100:hover {\n  --text-opacity: 1;\n  color: #fff5f7;\n  color: rgba(255, 245, 247, var(--text-opacity));\n}\n\n.hover\\:text-pink-200:hover {\n  --text-opacity: 1;\n  color: #fed7e2;\n  color: rgba(254, 215, 226, var(--text-opacity));\n}\n\n.hover\\:text-pink-300:hover {\n  --text-opacity: 1;\n  color: #fbb6ce;\n  color: rgba(251, 182, 206, var(--text-opacity));\n}\n\n.hover\\:text-pink-400:hover {\n  --text-opacity: 1;\n  color: #f687b3;\n  color: rgba(246, 135, 179, var(--text-opacity));\n}\n\n.hover\\:text-pink-500:hover {\n  --text-opacity: 1;\n  color: #ed64a6;\n  color: rgba(237, 100, 166, var(--text-opacity));\n}\n\n.hover\\:text-pink-600:hover {\n  --text-opacity: 1;\n  color: #d53f8c;\n  color: rgba(213, 63, 140, var(--text-opacity));\n}\n\n.hover\\:text-pink-700:hover {\n  --text-opacity: 1;\n  color: #b83280;\n  color: rgba(184, 50, 128, var(--text-opacity));\n}\n\n.hover\\:text-pink-800:hover {\n  --text-opacity: 1;\n  color: #97266d;\n  color: rgba(151, 38, 109, var(--text-opacity));\n}\n\n.hover\\:text-pink-900:hover {\n  --text-opacity: 1;\n  color: #702459;\n  color: rgba(112, 36, 89, var(--text-opacity));\n}\n\n.hover\\:text-grayscale-80:hover {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 8%);\n  color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--text-opacity));\n}\n\n.hover\\:text-grayscale-100:hover {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 10%);\n  color: rgba(25.5, 25.5, 25.5, var(--text-opacity));\n}\n\n.hover\\:text-grayscale-200:hover {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 20%);\n  color: rgba(51, 51, 51, var(--text-opacity));\n}\n\n.hover\\:text-grayscale-300:hover {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 30%);\n  color: rgba(76.5, 76.5, 76.5, var(--text-opacity));\n}\n\n.hover\\:text-grayscale-400:hover {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 40%);\n  color: rgba(102, 102, 102, var(--text-opacity));\n}\n\n.hover\\:text-grayscale-500:hover {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 50%);\n  color: rgba(127.5, 127.5, 127.5, var(--text-opacity));\n}\n\n.hover\\:text-grayscale-600:hover {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 60%);\n  color: rgba(153, 153, 153, var(--text-opacity));\n}\n\n.hover\\:text-grayscale-700:hover {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 70%);\n  color: rgba(178.5, 178.5, 178.5, var(--text-opacity));\n}\n\n.hover\\:text-grayscale-800:hover {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 80%);\n  color: rgba(204, 204, 204, var(--text-opacity));\n}\n\n.hover\\:text-grayscale-840:hover {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 84%);\n  color: rgba(214.2, 214.2, 214.2, var(--text-opacity));\n}\n\n.hover\\:text-grayscale-870:hover {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 87%);\n  color: rgba(221.85, 221.85, 221.85, var(--text-opacity));\n}\n\n.hover\\:text-grayscale-900:hover {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 90%);\n  color: rgba(229.5, 229.5, 229.5, var(--text-opacity));\n}\n\n.hover\\:text-grayscale-930:hover {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 93%);\n  color: rgba(237.15, 237.15, 237.15, var(--text-opacity));\n}\n\n.hover\\:text-primary:hover {\n  --text-opacity: 1;\n  color: hsl(210, 100%, 52%);\n  color: rgba(10.20000000000001, 132.59999999999988, 255, var(--text-opacity));\n}\n\n.hover\\:text-background-main:hover {\n  color: var(--main-background);\n}\n\n.hover\\:text-background-secondary:hover {\n  color: var(--secondary-background);\n}\n\n.hover\\:text-foreground:hover {\n  color: var(--foreground);\n}\n\n.hover\\:text-panels-bg:hover {\n  color: var(--panels-background);\n}\n\n.focus\\:text-transparent:focus {\n  color: transparent;\n}\n\n.focus\\:text-current:focus {\n  color: currentColor;\n}\n\n.focus\\:text-black:focus {\n  --text-opacity: 1;\n  color: #000;\n  color: rgba(0, 0, 0, var(--text-opacity));\n}\n\n.focus\\:text-white:focus {\n  --text-opacity: 1;\n  color: #fff;\n  color: rgba(255, 255, 255, var(--text-opacity));\n}\n\n.focus\\:text-gray-100:focus {\n  --text-opacity: 1;\n  color: #f7fafc;\n  color: rgba(247, 250, 252, var(--text-opacity));\n}\n\n.focus\\:text-gray-200:focus {\n  --text-opacity: 1;\n  color: #edf2f7;\n  color: rgba(237, 242, 247, var(--text-opacity));\n}\n\n.focus\\:text-gray-300:focus {\n  --text-opacity: 1;\n  color: #e2e8f0;\n  color: rgba(226, 232, 240, var(--text-opacity));\n}\n\n.focus\\:text-gray-400:focus {\n  --text-opacity: 1;\n  color: #cbd5e0;\n  color: rgba(203, 213, 224, var(--text-opacity));\n}\n\n.focus\\:text-gray-500:focus {\n  --text-opacity: 1;\n  color: #a0aec0;\n  color: rgba(160, 174, 192, var(--text-opacity));\n}\n\n.focus\\:text-gray-600:focus {\n  --text-opacity: 1;\n  color: #718096;\n  color: rgba(113, 128, 150, var(--text-opacity));\n}\n\n.focus\\:text-gray-700:focus {\n  --text-opacity: 1;\n  color: #4a5568;\n  color: rgba(74, 85, 104, var(--text-opacity));\n}\n\n.focus\\:text-gray-800:focus {\n  --text-opacity: 1;\n  color: #2d3748;\n  color: rgba(45, 55, 72, var(--text-opacity));\n}\n\n.focus\\:text-gray-900:focus {\n  --text-opacity: 1;\n  color: #1a202c;\n  color: rgba(26, 32, 44, var(--text-opacity));\n}\n\n.focus\\:text-red-100:focus {\n  --text-opacity: 1;\n  color: #fff5f5;\n  color: rgba(255, 245, 245, var(--text-opacity));\n}\n\n.focus\\:text-red-200:focus {\n  --text-opacity: 1;\n  color: #fed7d7;\n  color: rgba(254, 215, 215, var(--text-opacity));\n}\n\n.focus\\:text-red-300:focus {\n  --text-opacity: 1;\n  color: #feb2b2;\n  color: rgba(254, 178, 178, var(--text-opacity));\n}\n\n.focus\\:text-red-400:focus {\n  --text-opacity: 1;\n  color: #fc8181;\n  color: rgba(252, 129, 129, var(--text-opacity));\n}\n\n.focus\\:text-red-500:focus {\n  --text-opacity: 1;\n  color: #f56565;\n  color: rgba(245, 101, 101, var(--text-opacity));\n}\n\n.focus\\:text-red-600:focus {\n  --text-opacity: 1;\n  color: #e53e3e;\n  color: rgba(229, 62, 62, var(--text-opacity));\n}\n\n.focus\\:text-red-700:focus {\n  --text-opacity: 1;\n  color: #c53030;\n  color: rgba(197, 48, 48, var(--text-opacity));\n}\n\n.focus\\:text-red-800:focus {\n  --text-opacity: 1;\n  color: #9b2c2c;\n  color: rgba(155, 44, 44, var(--text-opacity));\n}\n\n.focus\\:text-red-900:focus {\n  --text-opacity: 1;\n  color: #742a2a;\n  color: rgba(116, 42, 42, var(--text-opacity));\n}\n\n.focus\\:text-orange-100:focus {\n  --text-opacity: 1;\n  color: #fffaf0;\n  color: rgba(255, 250, 240, var(--text-opacity));\n}\n\n.focus\\:text-orange-200:focus {\n  --text-opacity: 1;\n  color: #feebc8;\n  color: rgba(254, 235, 200, var(--text-opacity));\n}\n\n.focus\\:text-orange-300:focus {\n  --text-opacity: 1;\n  color: #fbd38d;\n  color: rgba(251, 211, 141, var(--text-opacity));\n}\n\n.focus\\:text-orange-400:focus {\n  --text-opacity: 1;\n  color: #f6ad55;\n  color: rgba(246, 173, 85, var(--text-opacity));\n}\n\n.focus\\:text-orange-500:focus {\n  --text-opacity: 1;\n  color: #ed8936;\n  color: rgba(237, 137, 54, var(--text-opacity));\n}\n\n.focus\\:text-orange-600:focus {\n  --text-opacity: 1;\n  color: #dd6b20;\n  color: rgba(221, 107, 32, var(--text-opacity));\n}\n\n.focus\\:text-orange-700:focus {\n  --text-opacity: 1;\n  color: #c05621;\n  color: rgba(192, 86, 33, var(--text-opacity));\n}\n\n.focus\\:text-orange-800:focus {\n  --text-opacity: 1;\n  color: #9c4221;\n  color: rgba(156, 66, 33, var(--text-opacity));\n}\n\n.focus\\:text-orange-900:focus {\n  --text-opacity: 1;\n  color: #7b341e;\n  color: rgba(123, 52, 30, var(--text-opacity));\n}\n\n.focus\\:text-yellow-100:focus {\n  --text-opacity: 1;\n  color: #fffff0;\n  color: rgba(255, 255, 240, var(--text-opacity));\n}\n\n.focus\\:text-yellow-200:focus {\n  --text-opacity: 1;\n  color: #fefcbf;\n  color: rgba(254, 252, 191, var(--text-opacity));\n}\n\n.focus\\:text-yellow-300:focus {\n  --text-opacity: 1;\n  color: #faf089;\n  color: rgba(250, 240, 137, var(--text-opacity));\n}\n\n.focus\\:text-yellow-400:focus {\n  --text-opacity: 1;\n  color: #f6e05e;\n  color: rgba(246, 224, 94, var(--text-opacity));\n}\n\n.focus\\:text-yellow-500:focus {\n  --text-opacity: 1;\n  color: #ecc94b;\n  color: rgba(236, 201, 75, var(--text-opacity));\n}\n\n.focus\\:text-yellow-600:focus {\n  --text-opacity: 1;\n  color: #d69e2e;\n  color: rgba(214, 158, 46, var(--text-opacity));\n}\n\n.focus\\:text-yellow-700:focus {\n  --text-opacity: 1;\n  color: #b7791f;\n  color: rgba(183, 121, 31, var(--text-opacity));\n}\n\n.focus\\:text-yellow-800:focus {\n  --text-opacity: 1;\n  color: #975a16;\n  color: rgba(151, 90, 22, var(--text-opacity));\n}\n\n.focus\\:text-yellow-900:focus {\n  --text-opacity: 1;\n  color: #744210;\n  color: rgba(116, 66, 16, var(--text-opacity));\n}\n\n.focus\\:text-green-100:focus {\n  --text-opacity: 1;\n  color: #f0fff4;\n  color: rgba(240, 255, 244, var(--text-opacity));\n}\n\n.focus\\:text-green-200:focus {\n  --text-opacity: 1;\n  color: #c6f6d5;\n  color: rgba(198, 246, 213, var(--text-opacity));\n}\n\n.focus\\:text-green-300:focus {\n  --text-opacity: 1;\n  color: #9ae6b4;\n  color: rgba(154, 230, 180, var(--text-opacity));\n}\n\n.focus\\:text-green-400:focus {\n  --text-opacity: 1;\n  color: #68d391;\n  color: rgba(104, 211, 145, var(--text-opacity));\n}\n\n.focus\\:text-green-500:focus {\n  --text-opacity: 1;\n  color: #48bb78;\n  color: rgba(72, 187, 120, var(--text-opacity));\n}\n\n.focus\\:text-green-600:focus {\n  --text-opacity: 1;\n  color: #38a169;\n  color: rgba(56, 161, 105, var(--text-opacity));\n}\n\n.focus\\:text-green-700:focus {\n  --text-opacity: 1;\n  color: #2f855a;\n  color: rgba(47, 133, 90, var(--text-opacity));\n}\n\n.focus\\:text-green-800:focus {\n  --text-opacity: 1;\n  color: #276749;\n  color: rgba(39, 103, 73, var(--text-opacity));\n}\n\n.focus\\:text-green-900:focus {\n  --text-opacity: 1;\n  color: #22543d;\n  color: rgba(34, 84, 61, var(--text-opacity));\n}\n\n.focus\\:text-teal-100:focus {\n  --text-opacity: 1;\n  color: #e6fffa;\n  color: rgba(230, 255, 250, var(--text-opacity));\n}\n\n.focus\\:text-teal-200:focus {\n  --text-opacity: 1;\n  color: #b2f5ea;\n  color: rgba(178, 245, 234, var(--text-opacity));\n}\n\n.focus\\:text-teal-300:focus {\n  --text-opacity: 1;\n  color: #81e6d9;\n  color: rgba(129, 230, 217, var(--text-opacity));\n}\n\n.focus\\:text-teal-400:focus {\n  --text-opacity: 1;\n  color: #4fd1c5;\n  color: rgba(79, 209, 197, var(--text-opacity));\n}\n\n.focus\\:text-teal-500:focus {\n  --text-opacity: 1;\n  color: #38b2ac;\n  color: rgba(56, 178, 172, var(--text-opacity));\n}\n\n.focus\\:text-teal-600:focus {\n  --text-opacity: 1;\n  color: #319795;\n  color: rgba(49, 151, 149, var(--text-opacity));\n}\n\n.focus\\:text-teal-700:focus {\n  --text-opacity: 1;\n  color: #2c7a7b;\n  color: rgba(44, 122, 123, var(--text-opacity));\n}\n\n.focus\\:text-teal-800:focus {\n  --text-opacity: 1;\n  color: #285e61;\n  color: rgba(40, 94, 97, var(--text-opacity));\n}\n\n.focus\\:text-teal-900:focus {\n  --text-opacity: 1;\n  color: #234e52;\n  color: rgba(35, 78, 82, var(--text-opacity));\n}\n\n.focus\\:text-blue-100:focus {\n  --text-opacity: 1;\n  color: #ebf8ff;\n  color: rgba(235, 248, 255, var(--text-opacity));\n}\n\n.focus\\:text-blue-200:focus {\n  --text-opacity: 1;\n  color: #bee3f8;\n  color: rgba(190, 227, 248, var(--text-opacity));\n}\n\n.focus\\:text-blue-300:focus {\n  --text-opacity: 1;\n  color: #90cdf4;\n  color: rgba(144, 205, 244, var(--text-opacity));\n}\n\n.focus\\:text-blue-400:focus {\n  --text-opacity: 1;\n  color: #63b3ed;\n  color: rgba(99, 179, 237, var(--text-opacity));\n}\n\n.focus\\:text-blue-500:focus {\n  --text-opacity: 1;\n  color: #4299e1;\n  color: rgba(66, 153, 225, var(--text-opacity));\n}\n\n.focus\\:text-blue-600:focus {\n  --text-opacity: 1;\n  color: #3182ce;\n  color: rgba(49, 130, 206, var(--text-opacity));\n}\n\n.focus\\:text-blue-700:focus {\n  --text-opacity: 1;\n  color: #2b6cb0;\n  color: rgba(43, 108, 176, var(--text-opacity));\n}\n\n.focus\\:text-blue-800:focus {\n  --text-opacity: 1;\n  color: #2c5282;\n  color: rgba(44, 82, 130, var(--text-opacity));\n}\n\n.focus\\:text-blue-900:focus {\n  --text-opacity: 1;\n  color: #2a4365;\n  color: rgba(42, 67, 101, var(--text-opacity));\n}\n\n.focus\\:text-indigo-100:focus {\n  --text-opacity: 1;\n  color: #ebf4ff;\n  color: rgba(235, 244, 255, var(--text-opacity));\n}\n\n.focus\\:text-indigo-200:focus {\n  --text-opacity: 1;\n  color: #c3dafe;\n  color: rgba(195, 218, 254, var(--text-opacity));\n}\n\n.focus\\:text-indigo-300:focus {\n  --text-opacity: 1;\n  color: #a3bffa;\n  color: rgba(163, 191, 250, var(--text-opacity));\n}\n\n.focus\\:text-indigo-400:focus {\n  --text-opacity: 1;\n  color: #7f9cf5;\n  color: rgba(127, 156, 245, var(--text-opacity));\n}\n\n.focus\\:text-indigo-500:focus {\n  --text-opacity: 1;\n  color: #667eea;\n  color: rgba(102, 126, 234, var(--text-opacity));\n}\n\n.focus\\:text-indigo-600:focus {\n  --text-opacity: 1;\n  color: #5a67d8;\n  color: rgba(90, 103, 216, var(--text-opacity));\n}\n\n.focus\\:text-indigo-700:focus {\n  --text-opacity: 1;\n  color: #4c51bf;\n  color: rgba(76, 81, 191, var(--text-opacity));\n}\n\n.focus\\:text-indigo-800:focus {\n  --text-opacity: 1;\n  color: #434190;\n  color: rgba(67, 65, 144, var(--text-opacity));\n}\n\n.focus\\:text-indigo-900:focus {\n  --text-opacity: 1;\n  color: #3c366b;\n  color: rgba(60, 54, 107, var(--text-opacity));\n}\n\n.focus\\:text-purple-100:focus {\n  --text-opacity: 1;\n  color: #faf5ff;\n  color: rgba(250, 245, 255, var(--text-opacity));\n}\n\n.focus\\:text-purple-200:focus {\n  --text-opacity: 1;\n  color: #e9d8fd;\n  color: rgba(233, 216, 253, var(--text-opacity));\n}\n\n.focus\\:text-purple-300:focus {\n  --text-opacity: 1;\n  color: #d6bcfa;\n  color: rgba(214, 188, 250, var(--text-opacity));\n}\n\n.focus\\:text-purple-400:focus {\n  --text-opacity: 1;\n  color: #b794f4;\n  color: rgba(183, 148, 244, var(--text-opacity));\n}\n\n.focus\\:text-purple-500:focus {\n  --text-opacity: 1;\n  color: #9f7aea;\n  color: rgba(159, 122, 234, var(--text-opacity));\n}\n\n.focus\\:text-purple-600:focus {\n  --text-opacity: 1;\n  color: #805ad5;\n  color: rgba(128, 90, 213, var(--text-opacity));\n}\n\n.focus\\:text-purple-700:focus {\n  --text-opacity: 1;\n  color: #6b46c1;\n  color: rgba(107, 70, 193, var(--text-opacity));\n}\n\n.focus\\:text-purple-800:focus {\n  --text-opacity: 1;\n  color: #553c9a;\n  color: rgba(85, 60, 154, var(--text-opacity));\n}\n\n.focus\\:text-purple-900:focus {\n  --text-opacity: 1;\n  color: #44337a;\n  color: rgba(68, 51, 122, var(--text-opacity));\n}\n\n.focus\\:text-pink-100:focus {\n  --text-opacity: 1;\n  color: #fff5f7;\n  color: rgba(255, 245, 247, var(--text-opacity));\n}\n\n.focus\\:text-pink-200:focus {\n  --text-opacity: 1;\n  color: #fed7e2;\n  color: rgba(254, 215, 226, var(--text-opacity));\n}\n\n.focus\\:text-pink-300:focus {\n  --text-opacity: 1;\n  color: #fbb6ce;\n  color: rgba(251, 182, 206, var(--text-opacity));\n}\n\n.focus\\:text-pink-400:focus {\n  --text-opacity: 1;\n  color: #f687b3;\n  color: rgba(246, 135, 179, var(--text-opacity));\n}\n\n.focus\\:text-pink-500:focus {\n  --text-opacity: 1;\n  color: #ed64a6;\n  color: rgba(237, 100, 166, var(--text-opacity));\n}\n\n.focus\\:text-pink-600:focus {\n  --text-opacity: 1;\n  color: #d53f8c;\n  color: rgba(213, 63, 140, var(--text-opacity));\n}\n\n.focus\\:text-pink-700:focus {\n  --text-opacity: 1;\n  color: #b83280;\n  color: rgba(184, 50, 128, var(--text-opacity));\n}\n\n.focus\\:text-pink-800:focus {\n  --text-opacity: 1;\n  color: #97266d;\n  color: rgba(151, 38, 109, var(--text-opacity));\n}\n\n.focus\\:text-pink-900:focus {\n  --text-opacity: 1;\n  color: #702459;\n  color: rgba(112, 36, 89, var(--text-opacity));\n}\n\n.focus\\:text-grayscale-80:focus {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 8%);\n  color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--text-opacity));\n}\n\n.focus\\:text-grayscale-100:focus {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 10%);\n  color: rgba(25.5, 25.5, 25.5, var(--text-opacity));\n}\n\n.focus\\:text-grayscale-200:focus {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 20%);\n  color: rgba(51, 51, 51, var(--text-opacity));\n}\n\n.focus\\:text-grayscale-300:focus {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 30%);\n  color: rgba(76.5, 76.5, 76.5, var(--text-opacity));\n}\n\n.focus\\:text-grayscale-400:focus {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 40%);\n  color: rgba(102, 102, 102, var(--text-opacity));\n}\n\n.focus\\:text-grayscale-500:focus {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 50%);\n  color: rgba(127.5, 127.5, 127.5, var(--text-opacity));\n}\n\n.focus\\:text-grayscale-600:focus {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 60%);\n  color: rgba(153, 153, 153, var(--text-opacity));\n}\n\n.focus\\:text-grayscale-700:focus {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 70%);\n  color: rgba(178.5, 178.5, 178.5, var(--text-opacity));\n}\n\n.focus\\:text-grayscale-800:focus {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 80%);\n  color: rgba(204, 204, 204, var(--text-opacity));\n}\n\n.focus\\:text-grayscale-840:focus {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 84%);\n  color: rgba(214.2, 214.2, 214.2, var(--text-opacity));\n}\n\n.focus\\:text-grayscale-870:focus {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 87%);\n  color: rgba(221.85, 221.85, 221.85, var(--text-opacity));\n}\n\n.focus\\:text-grayscale-900:focus {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 90%);\n  color: rgba(229.5, 229.5, 229.5, var(--text-opacity));\n}\n\n.focus\\:text-grayscale-930:focus {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 93%);\n  color: rgba(237.15, 237.15, 237.15, var(--text-opacity));\n}\n\n.focus\\:text-primary:focus {\n  --text-opacity: 1;\n  color: hsl(210, 100%, 52%);\n  color: rgba(10.20000000000001, 132.59999999999988, 255, var(--text-opacity));\n}\n\n.focus\\:text-background-main:focus {\n  color: var(--main-background);\n}\n\n.focus\\:text-background-secondary:focus {\n  color: var(--secondary-background);\n}\n\n.focus\\:text-foreground:focus {\n  color: var(--foreground);\n}\n\n.focus\\:text-panels-bg:focus {\n  color: var(--panels-background);\n}\n\n.group:hover .group-hover\\:text-transparent {\n  color: transparent;\n}\n\n.group:hover .group-hover\\:text-current {\n  color: currentColor;\n}\n\n.group:hover .group-hover\\:text-black {\n  --text-opacity: 1;\n  color: #000;\n  color: rgba(0, 0, 0, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-white {\n  --text-opacity: 1;\n  color: #fff;\n  color: rgba(255, 255, 255, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-gray-100 {\n  --text-opacity: 1;\n  color: #f7fafc;\n  color: rgba(247, 250, 252, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-gray-200 {\n  --text-opacity: 1;\n  color: #edf2f7;\n  color: rgba(237, 242, 247, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-gray-300 {\n  --text-opacity: 1;\n  color: #e2e8f0;\n  color: rgba(226, 232, 240, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-gray-400 {\n  --text-opacity: 1;\n  color: #cbd5e0;\n  color: rgba(203, 213, 224, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-gray-500 {\n  --text-opacity: 1;\n  color: #a0aec0;\n  color: rgba(160, 174, 192, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-gray-600 {\n  --text-opacity: 1;\n  color: #718096;\n  color: rgba(113, 128, 150, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-gray-700 {\n  --text-opacity: 1;\n  color: #4a5568;\n  color: rgba(74, 85, 104, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-gray-800 {\n  --text-opacity: 1;\n  color: #2d3748;\n  color: rgba(45, 55, 72, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-gray-900 {\n  --text-opacity: 1;\n  color: #1a202c;\n  color: rgba(26, 32, 44, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-red-100 {\n  --text-opacity: 1;\n  color: #fff5f5;\n  color: rgba(255, 245, 245, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-red-200 {\n  --text-opacity: 1;\n  color: #fed7d7;\n  color: rgba(254, 215, 215, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-red-300 {\n  --text-opacity: 1;\n  color: #feb2b2;\n  color: rgba(254, 178, 178, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-red-400 {\n  --text-opacity: 1;\n  color: #fc8181;\n  color: rgba(252, 129, 129, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-red-500 {\n  --text-opacity: 1;\n  color: #f56565;\n  color: rgba(245, 101, 101, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-red-600 {\n  --text-opacity: 1;\n  color: #e53e3e;\n  color: rgba(229, 62, 62, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-red-700 {\n  --text-opacity: 1;\n  color: #c53030;\n  color: rgba(197, 48, 48, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-red-800 {\n  --text-opacity: 1;\n  color: #9b2c2c;\n  color: rgba(155, 44, 44, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-red-900 {\n  --text-opacity: 1;\n  color: #742a2a;\n  color: rgba(116, 42, 42, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-orange-100 {\n  --text-opacity: 1;\n  color: #fffaf0;\n  color: rgba(255, 250, 240, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-orange-200 {\n  --text-opacity: 1;\n  color: #feebc8;\n  color: rgba(254, 235, 200, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-orange-300 {\n  --text-opacity: 1;\n  color: #fbd38d;\n  color: rgba(251, 211, 141, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-orange-400 {\n  --text-opacity: 1;\n  color: #f6ad55;\n  color: rgba(246, 173, 85, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-orange-500 {\n  --text-opacity: 1;\n  color: #ed8936;\n  color: rgba(237, 137, 54, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-orange-600 {\n  --text-opacity: 1;\n  color: #dd6b20;\n  color: rgba(221, 107, 32, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-orange-700 {\n  --text-opacity: 1;\n  color: #c05621;\n  color: rgba(192, 86, 33, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-orange-800 {\n  --text-opacity: 1;\n  color: #9c4221;\n  color: rgba(156, 66, 33, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-orange-900 {\n  --text-opacity: 1;\n  color: #7b341e;\n  color: rgba(123, 52, 30, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-yellow-100 {\n  --text-opacity: 1;\n  color: #fffff0;\n  color: rgba(255, 255, 240, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-yellow-200 {\n  --text-opacity: 1;\n  color: #fefcbf;\n  color: rgba(254, 252, 191, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-yellow-300 {\n  --text-opacity: 1;\n  color: #faf089;\n  color: rgba(250, 240, 137, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-yellow-400 {\n  --text-opacity: 1;\n  color: #f6e05e;\n  color: rgba(246, 224, 94, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-yellow-500 {\n  --text-opacity: 1;\n  color: #ecc94b;\n  color: rgba(236, 201, 75, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-yellow-600 {\n  --text-opacity: 1;\n  color: #d69e2e;\n  color: rgba(214, 158, 46, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-yellow-700 {\n  --text-opacity: 1;\n  color: #b7791f;\n  color: rgba(183, 121, 31, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-yellow-800 {\n  --text-opacity: 1;\n  color: #975a16;\n  color: rgba(151, 90, 22, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-yellow-900 {\n  --text-opacity: 1;\n  color: #744210;\n  color: rgba(116, 66, 16, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-green-100 {\n  --text-opacity: 1;\n  color: #f0fff4;\n  color: rgba(240, 255, 244, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-green-200 {\n  --text-opacity: 1;\n  color: #c6f6d5;\n  color: rgba(198, 246, 213, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-green-300 {\n  --text-opacity: 1;\n  color: #9ae6b4;\n  color: rgba(154, 230, 180, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-green-400 {\n  --text-opacity: 1;\n  color: #68d391;\n  color: rgba(104, 211, 145, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-green-500 {\n  --text-opacity: 1;\n  color: #48bb78;\n  color: rgba(72, 187, 120, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-green-600 {\n  --text-opacity: 1;\n  color: #38a169;\n  color: rgba(56, 161, 105, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-green-700 {\n  --text-opacity: 1;\n  color: #2f855a;\n  color: rgba(47, 133, 90, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-green-800 {\n  --text-opacity: 1;\n  color: #276749;\n  color: rgba(39, 103, 73, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-green-900 {\n  --text-opacity: 1;\n  color: #22543d;\n  color: rgba(34, 84, 61, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-teal-100 {\n  --text-opacity: 1;\n  color: #e6fffa;\n  color: rgba(230, 255, 250, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-teal-200 {\n  --text-opacity: 1;\n  color: #b2f5ea;\n  color: rgba(178, 245, 234, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-teal-300 {\n  --text-opacity: 1;\n  color: #81e6d9;\n  color: rgba(129, 230, 217, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-teal-400 {\n  --text-opacity: 1;\n  color: #4fd1c5;\n  color: rgba(79, 209, 197, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-teal-500 {\n  --text-opacity: 1;\n  color: #38b2ac;\n  color: rgba(56, 178, 172, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-teal-600 {\n  --text-opacity: 1;\n  color: #319795;\n  color: rgba(49, 151, 149, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-teal-700 {\n  --text-opacity: 1;\n  color: #2c7a7b;\n  color: rgba(44, 122, 123, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-teal-800 {\n  --text-opacity: 1;\n  color: #285e61;\n  color: rgba(40, 94, 97, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-teal-900 {\n  --text-opacity: 1;\n  color: #234e52;\n  color: rgba(35, 78, 82, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-blue-100 {\n  --text-opacity: 1;\n  color: #ebf8ff;\n  color: rgba(235, 248, 255, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-blue-200 {\n  --text-opacity: 1;\n  color: #bee3f8;\n  color: rgba(190, 227, 248, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-blue-300 {\n  --text-opacity: 1;\n  color: #90cdf4;\n  color: rgba(144, 205, 244, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-blue-400 {\n  --text-opacity: 1;\n  color: #63b3ed;\n  color: rgba(99, 179, 237, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-blue-500 {\n  --text-opacity: 1;\n  color: #4299e1;\n  color: rgba(66, 153, 225, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-blue-600 {\n  --text-opacity: 1;\n  color: #3182ce;\n  color: rgba(49, 130, 206, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-blue-700 {\n  --text-opacity: 1;\n  color: #2b6cb0;\n  color: rgba(43, 108, 176, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-blue-800 {\n  --text-opacity: 1;\n  color: #2c5282;\n  color: rgba(44, 82, 130, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-blue-900 {\n  --text-opacity: 1;\n  color: #2a4365;\n  color: rgba(42, 67, 101, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-indigo-100 {\n  --text-opacity: 1;\n  color: #ebf4ff;\n  color: rgba(235, 244, 255, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-indigo-200 {\n  --text-opacity: 1;\n  color: #c3dafe;\n  color: rgba(195, 218, 254, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-indigo-300 {\n  --text-opacity: 1;\n  color: #a3bffa;\n  color: rgba(163, 191, 250, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-indigo-400 {\n  --text-opacity: 1;\n  color: #7f9cf5;\n  color: rgba(127, 156, 245, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-indigo-500 {\n  --text-opacity: 1;\n  color: #667eea;\n  color: rgba(102, 126, 234, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-indigo-600 {\n  --text-opacity: 1;\n  color: #5a67d8;\n  color: rgba(90, 103, 216, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-indigo-700 {\n  --text-opacity: 1;\n  color: #4c51bf;\n  color: rgba(76, 81, 191, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-indigo-800 {\n  --text-opacity: 1;\n  color: #434190;\n  color: rgba(67, 65, 144, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-indigo-900 {\n  --text-opacity: 1;\n  color: #3c366b;\n  color: rgba(60, 54, 107, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-purple-100 {\n  --text-opacity: 1;\n  color: #faf5ff;\n  color: rgba(250, 245, 255, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-purple-200 {\n  --text-opacity: 1;\n  color: #e9d8fd;\n  color: rgba(233, 216, 253, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-purple-300 {\n  --text-opacity: 1;\n  color: #d6bcfa;\n  color: rgba(214, 188, 250, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-purple-400 {\n  --text-opacity: 1;\n  color: #b794f4;\n  color: rgba(183, 148, 244, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-purple-500 {\n  --text-opacity: 1;\n  color: #9f7aea;\n  color: rgba(159, 122, 234, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-purple-600 {\n  --text-opacity: 1;\n  color: #805ad5;\n  color: rgba(128, 90, 213, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-purple-700 {\n  --text-opacity: 1;\n  color: #6b46c1;\n  color: rgba(107, 70, 193, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-purple-800 {\n  --text-opacity: 1;\n  color: #553c9a;\n  color: rgba(85, 60, 154, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-purple-900 {\n  --text-opacity: 1;\n  color: #44337a;\n  color: rgba(68, 51, 122, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-pink-100 {\n  --text-opacity: 1;\n  color: #fff5f7;\n  color: rgba(255, 245, 247, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-pink-200 {\n  --text-opacity: 1;\n  color: #fed7e2;\n  color: rgba(254, 215, 226, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-pink-300 {\n  --text-opacity: 1;\n  color: #fbb6ce;\n  color: rgba(251, 182, 206, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-pink-400 {\n  --text-opacity: 1;\n  color: #f687b3;\n  color: rgba(246, 135, 179, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-pink-500 {\n  --text-opacity: 1;\n  color: #ed64a6;\n  color: rgba(237, 100, 166, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-pink-600 {\n  --text-opacity: 1;\n  color: #d53f8c;\n  color: rgba(213, 63, 140, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-pink-700 {\n  --text-opacity: 1;\n  color: #b83280;\n  color: rgba(184, 50, 128, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-pink-800 {\n  --text-opacity: 1;\n  color: #97266d;\n  color: rgba(151, 38, 109, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-pink-900 {\n  --text-opacity: 1;\n  color: #702459;\n  color: rgba(112, 36, 89, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-grayscale-80 {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 8%);\n  color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-grayscale-100 {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 10%);\n  color: rgba(25.5, 25.5, 25.5, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-grayscale-200 {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 20%);\n  color: rgba(51, 51, 51, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-grayscale-300 {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 30%);\n  color: rgba(76.5, 76.5, 76.5, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-grayscale-400 {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 40%);\n  color: rgba(102, 102, 102, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-grayscale-500 {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 50%);\n  color: rgba(127.5, 127.5, 127.5, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-grayscale-600 {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 60%);\n  color: rgba(153, 153, 153, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-grayscale-700 {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 70%);\n  color: rgba(178.5, 178.5, 178.5, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-grayscale-800 {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 80%);\n  color: rgba(204, 204, 204, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-grayscale-840 {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 84%);\n  color: rgba(214.2, 214.2, 214.2, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-grayscale-870 {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 87%);\n  color: rgba(221.85, 221.85, 221.85, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-grayscale-900 {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 90%);\n  color: rgba(229.5, 229.5, 229.5, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-grayscale-930 {\n  --text-opacity: 1;\n  color: hsl(0, 0%, 93%);\n  color: rgba(237.15, 237.15, 237.15, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-primary {\n  --text-opacity: 1;\n  color: hsl(210, 100%, 52%);\n  color: rgba(10.20000000000001, 132.59999999999988, 255, var(--text-opacity));\n}\n\n.group:hover .group-hover\\:text-background-main {\n  color: var(--main-background);\n}\n\n.group:hover .group-hover\\:text-background-secondary {\n  color: var(--secondary-background);\n}\n\n.group:hover .group-hover\\:text-foreground {\n  color: var(--foreground);\n}\n\n.group:hover .group-hover\\:text-panels-bg {\n  color: var(--panels-background);\n}\n\n.text-opacity-0 {\n  --text-opacity: 0;\n}\n\n.text-opacity-25 {\n  --text-opacity: 0.25;\n}\n\n.text-opacity-50 {\n  --text-opacity: 0.5;\n}\n\n.text-opacity-75 {\n  --text-opacity: 0.75;\n}\n\n.text-opacity-100 {\n  --text-opacity: 1;\n}\n\n.hover\\:text-opacity-0:hover {\n  --text-opacity: 0;\n}\n\n.hover\\:text-opacity-25:hover {\n  --text-opacity: 0.25;\n}\n\n.hover\\:text-opacity-50:hover {\n  --text-opacity: 0.5;\n}\n\n.hover\\:text-opacity-75:hover {\n  --text-opacity: 0.75;\n}\n\n.hover\\:text-opacity-100:hover {\n  --text-opacity: 1;\n}\n\n.focus\\:text-opacity-0:focus {\n  --text-opacity: 0;\n}\n\n.focus\\:text-opacity-25:focus {\n  --text-opacity: 0.25;\n}\n\n.focus\\:text-opacity-50:focus {\n  --text-opacity: 0.5;\n}\n\n.focus\\:text-opacity-75:focus {\n  --text-opacity: 0.75;\n}\n\n.focus\\:text-opacity-100:focus {\n  --text-opacity: 1;\n}\n\n.italic {\n  font-style: italic;\n}\n\n.not-italic {\n  font-style: normal;\n}\n\n.uppercase {\n  text-transform: uppercase;\n}\n\n.lowercase {\n  text-transform: lowercase;\n}\n\n.capitalize {\n  text-transform: capitalize;\n}\n\n.normal-case {\n  text-transform: none;\n}\n\n.underline {\n  text-decoration: underline;\n}\n\n.line-through {\n  text-decoration: line-through;\n}\n\n.no-underline {\n  text-decoration: none;\n}\n\n.hover\\:underline:hover {\n  text-decoration: underline;\n}\n\n.hover\\:line-through:hover {\n  text-decoration: line-through;\n}\n\n.hover\\:no-underline:hover {\n  text-decoration: none;\n}\n\n.focus\\:underline:focus {\n  text-decoration: underline;\n}\n\n.focus\\:line-through:focus {\n  text-decoration: line-through;\n}\n\n.focus\\:no-underline:focus {\n  text-decoration: none;\n}\n\n.antialiased {\n  -webkit-font-smoothing: antialiased;\n  -moz-osx-font-smoothing: grayscale;\n}\n\n.subpixel-antialiased {\n  -webkit-font-smoothing: auto;\n  -moz-osx-font-smoothing: auto;\n}\n\n.ordinal, .slashed-zero, .lining-nums, .oldstyle-nums, .proportional-nums, .tabular-nums, .diagonal-fractions, .stacked-fractions {\n  --font-variant-numeric-ordinal: var(--tailwind-empty,/*!*/ /*!*/);\n  --font-variant-numeric-slashed-zero: var(--tailwind-empty,/*!*/ /*!*/);\n  --font-variant-numeric-figure: var(--tailwind-empty,/*!*/ /*!*/);\n  --font-variant-numeric-spacing: var(--tailwind-empty,/*!*/ /*!*/);\n  --font-variant-numeric-fraction: var(--tailwind-empty,/*!*/ /*!*/);\n  font-variant-numeric: var(--font-variant-numeric-ordinal) var(--font-variant-numeric-slashed-zero) var(--font-variant-numeric-figure) var(--font-variant-numeric-spacing) var(--font-variant-numeric-fraction);\n}\n\n.normal-nums {\n  font-variant-numeric: normal;\n}\n\n.ordinal {\n  --font-variant-numeric-ordinal: ordinal;\n}\n\n.slashed-zero {\n  --font-variant-numeric-slashed-zero: slashed-zero;\n}\n\n.lining-nums {\n  --font-variant-numeric-figure: lining-nums;\n}\n\n.oldstyle-nums {\n  --font-variant-numeric-figure: oldstyle-nums;\n}\n\n.proportional-nums {\n  --font-variant-numeric-spacing: proportional-nums;\n}\n\n.tabular-nums {\n  --font-variant-numeric-spacing: tabular-nums;\n}\n\n.diagonal-fractions {\n  --font-variant-numeric-fraction: diagonal-fractions;\n}\n\n.stacked-fractions {\n  --font-variant-numeric-fraction: stacked-fractions;\n}\n\n.tracking-tighter {\n  letter-spacing: -0.05em;\n}\n\n.tracking-tight {\n  letter-spacing: -0.025em;\n}\n\n.tracking-normal {\n  letter-spacing: 0;\n}\n\n.tracking-wide {\n  letter-spacing: 0.025em;\n}\n\n.tracking-wider {\n  letter-spacing: 0.05em;\n}\n\n.tracking-widest {\n  letter-spacing: 0.1em;\n}\n\n.select-none {\n  -webkit-user-select: none;\n     -moz-user-select: none;\n      -ms-user-select: none;\n          user-select: none;\n}\n\n.select-text {\n  -webkit-user-select: text;\n     -moz-user-select: text;\n      -ms-user-select: text;\n          user-select: text;\n}\n\n.select-all {\n  -webkit-user-select: all;\n     -moz-user-select: all;\n      -ms-user-select: all;\n          user-select: all;\n}\n\n.select-auto {\n  -webkit-user-select: auto;\n     -moz-user-select: auto;\n      -ms-user-select: auto;\n          user-select: auto;\n}\n\n.align-baseline {\n  vertical-align: baseline;\n}\n\n.align-top {\n  vertical-align: top;\n}\n\n.align-middle {\n  vertical-align: middle;\n}\n\n.align-bottom {\n  vertical-align: bottom;\n}\n\n.align-text-top {\n  vertical-align: text-top;\n}\n\n.align-text-bottom {\n  vertical-align: text-bottom;\n}\n\n.visible {\n  visibility: visible;\n}\n\n.invisible {\n  visibility: hidden;\n}\n\n.whitespace-normal {\n  white-space: normal;\n}\n\n.whitespace-no-wrap {\n  white-space: nowrap;\n}\n\n.whitespace-pre {\n  white-space: pre;\n}\n\n.whitespace-pre-line {\n  white-space: pre-line;\n}\n\n.whitespace-pre-wrap {\n  white-space: pre-wrap;\n}\n\n.break-normal {\n  word-wrap: normal;\n  overflow-wrap: normal;\n  word-break: normal;\n}\n\n.break-words {\n  word-wrap: break-word;\n  overflow-wrap: break-word;\n}\n\n.break-all {\n  word-break: break-all;\n}\n\n.truncate {\n  overflow: hidden;\n  text-overflow: ellipsis;\n  white-space: nowrap;\n}\n\n.w-0 {\n  width: 0;\n}\n\n.w-1 {\n  width: 0.25rem;\n}\n\n.w-2 {\n  width: 0.5rem;\n}\n\n.w-3 {\n  width: 0.75rem;\n}\n\n.w-4 {\n  width: 1rem;\n}\n\n.w-5 {\n  width: 1.25rem;\n}\n\n.w-6 {\n  width: 1.5rem;\n}\n\n.w-8 {\n  width: 2rem;\n}\n\n.w-10 {\n  width: 2.5rem;\n}\n\n.w-12 {\n  width: 3rem;\n}\n\n.w-16 {\n  width: 4rem;\n}\n\n.w-20 {\n  width: 5rem;\n}\n\n.w-24 {\n  width: 6rem;\n}\n\n.w-32 {\n  width: 8rem;\n}\n\n.w-40 {\n  width: 10rem;\n}\n\n.w-48 {\n  width: 12rem;\n}\n\n.w-56 {\n  width: 14rem;\n}\n\n.w-64 {\n  width: 16rem;\n}\n\n.w-auto {\n  width: auto;\n}\n\n.w-px {\n  width: 1px;\n}\n\n.w-1\\/2 {\n  width: 50%;\n}\n\n.w-1\\/3 {\n  width: 33.333333%;\n}\n\n.w-2\\/3 {\n  width: 66.666667%;\n}\n\n.w-1\\/4 {\n  width: 25%;\n}\n\n.w-2\\/4 {\n  width: 50%;\n}\n\n.w-3\\/4 {\n  width: 75%;\n}\n\n.w-1\\/5 {\n  width: 20%;\n}\n\n.w-2\\/5 {\n  width: 40%;\n}\n\n.w-3\\/5 {\n  width: 60%;\n}\n\n.w-4\\/5 {\n  width: 80%;\n}\n\n.w-1\\/6 {\n  width: 16.666667%;\n}\n\n.w-2\\/6 {\n  width: 33.333333%;\n}\n\n.w-3\\/6 {\n  width: 50%;\n}\n\n.w-4\\/6 {\n  width: 66.666667%;\n}\n\n.w-5\\/6 {\n  width: 83.333333%;\n}\n\n.w-1\\/12 {\n  width: 8.333333%;\n}\n\n.w-2\\/12 {\n  width: 16.666667%;\n}\n\n.w-3\\/12 {\n  width: 25%;\n}\n\n.w-4\\/12 {\n  width: 33.333333%;\n}\n\n.w-5\\/12 {\n  width: 41.666667%;\n}\n\n.w-6\\/12 {\n  width: 50%;\n}\n\n.w-7\\/12 {\n  width: 58.333333%;\n}\n\n.w-8\\/12 {\n  width: 66.666667%;\n}\n\n.w-9\\/12 {\n  width: 75%;\n}\n\n.w-10\\/12 {\n  width: 83.333333%;\n}\n\n.w-11\\/12 {\n  width: 91.666667%;\n}\n\n.w-full {\n  width: 100%;\n}\n\n.w-screen {\n  width: 100vw;\n}\n\n.z-0 {\n  z-index: 0;\n}\n\n.z-10 {\n  z-index: 10;\n}\n\n.z-20 {\n  z-index: 20;\n}\n\n.z-30 {\n  z-index: 30;\n}\n\n.z-40 {\n  z-index: 40;\n}\n\n.z-50 {\n  z-index: 50;\n}\n\n.z-auto {\n  z-index: auto;\n}\n\n.gap-0 {\n  grid-gap: 0;\n  gap: 0;\n}\n\n.gap-1 {\n  grid-gap: 0.25rem;\n  gap: 0.25rem;\n}\n\n.gap-2 {\n  grid-gap: 0.5rem;\n  gap: 0.5rem;\n}\n\n.gap-3 {\n  grid-gap: 0.75rem;\n  gap: 0.75rem;\n}\n\n.gap-4 {\n  grid-gap: 1rem;\n  gap: 1rem;\n}\n\n.gap-5 {\n  grid-gap: 1.25rem;\n  gap: 1.25rem;\n}\n\n.gap-6 {\n  grid-gap: 1.5rem;\n  gap: 1.5rem;\n}\n\n.gap-8 {\n  grid-gap: 2rem;\n  gap: 2rem;\n}\n\n.gap-10 {\n  grid-gap: 2.5rem;\n  gap: 2.5rem;\n}\n\n.gap-12 {\n  grid-gap: 3rem;\n  gap: 3rem;\n}\n\n.gap-16 {\n  grid-gap: 4rem;\n  gap: 4rem;\n}\n\n.gap-20 {\n  grid-gap: 5rem;\n  gap: 5rem;\n}\n\n.gap-24 {\n  grid-gap: 6rem;\n  gap: 6rem;\n}\n\n.gap-32 {\n  grid-gap: 8rem;\n  gap: 8rem;\n}\n\n.gap-40 {\n  grid-gap: 10rem;\n  gap: 10rem;\n}\n\n.gap-48 {\n  grid-gap: 12rem;\n  gap: 12rem;\n}\n\n.gap-56 {\n  grid-gap: 14rem;\n  gap: 14rem;\n}\n\n.gap-64 {\n  grid-gap: 16rem;\n  gap: 16rem;\n}\n\n.gap-px {\n  grid-gap: 1px;\n  gap: 1px;\n}\n\n.gap-x-0 {\n  grid-column-gap: 0;\n  -moz-column-gap: 0;\n       column-gap: 0;\n}\n\n.gap-x-1 {\n  grid-column-gap: 0.25rem;\n  -moz-column-gap: 0.25rem;\n       column-gap: 0.25rem;\n}\n\n.gap-x-2 {\n  grid-column-gap: 0.5rem;\n  -moz-column-gap: 0.5rem;\n       column-gap: 0.5rem;\n}\n\n.gap-x-3 {\n  grid-column-gap: 0.75rem;\n  -moz-column-gap: 0.75rem;\n       column-gap: 0.75rem;\n}\n\n.gap-x-4 {\n  grid-column-gap: 1rem;\n  -moz-column-gap: 1rem;\n       column-gap: 1rem;\n}\n\n.gap-x-5 {\n  grid-column-gap: 1.25rem;\n  -moz-column-gap: 1.25rem;\n       column-gap: 1.25rem;\n}\n\n.gap-x-6 {\n  grid-column-gap: 1.5rem;\n  -moz-column-gap: 1.5rem;\n       column-gap: 1.5rem;\n}\n\n.gap-x-8 {\n  grid-column-gap: 2rem;\n  -moz-column-gap: 2rem;\n       column-gap: 2rem;\n}\n\n.gap-x-10 {\n  grid-column-gap: 2.5rem;\n  -moz-column-gap: 2.5rem;\n       column-gap: 2.5rem;\n}\n\n.gap-x-12 {\n  grid-column-gap: 3rem;\n  -moz-column-gap: 3rem;\n       column-gap: 3rem;\n}\n\n.gap-x-16 {\n  grid-column-gap: 4rem;\n  -moz-column-gap: 4rem;\n       column-gap: 4rem;\n}\n\n.gap-x-20 {\n  grid-column-gap: 5rem;\n  -moz-column-gap: 5rem;\n       column-gap: 5rem;\n}\n\n.gap-x-24 {\n  grid-column-gap: 6rem;\n  -moz-column-gap: 6rem;\n       column-gap: 6rem;\n}\n\n.gap-x-32 {\n  grid-column-gap: 8rem;\n  -moz-column-gap: 8rem;\n       column-gap: 8rem;\n}\n\n.gap-x-40 {\n  grid-column-gap: 10rem;\n  -moz-column-gap: 10rem;\n       column-gap: 10rem;\n}\n\n.gap-x-48 {\n  grid-column-gap: 12rem;\n  -moz-column-gap: 12rem;\n       column-gap: 12rem;\n}\n\n.gap-x-56 {\n  grid-column-gap: 14rem;\n  -moz-column-gap: 14rem;\n       column-gap: 14rem;\n}\n\n.gap-x-64 {\n  grid-column-gap: 16rem;\n  -moz-column-gap: 16rem;\n       column-gap: 16rem;\n}\n\n.gap-x-px {\n  grid-column-gap: 1px;\n  -moz-column-gap: 1px;\n       column-gap: 1px;\n}\n\n.gap-y-0 {\n  grid-row-gap: 0;\n  row-gap: 0;\n}\n\n.gap-y-1 {\n  grid-row-gap: 0.25rem;\n  row-gap: 0.25rem;\n}\n\n.gap-y-2 {\n  grid-row-gap: 0.5rem;\n  row-gap: 0.5rem;\n}\n\n.gap-y-3 {\n  grid-row-gap: 0.75rem;\n  row-gap: 0.75rem;\n}\n\n.gap-y-4 {\n  grid-row-gap: 1rem;\n  row-gap: 1rem;\n}\n\n.gap-y-5 {\n  grid-row-gap: 1.25rem;\n  row-gap: 1.25rem;\n}\n\n.gap-y-6 {\n  grid-row-gap: 1.5rem;\n  row-gap: 1.5rem;\n}\n\n.gap-y-8 {\n  grid-row-gap: 2rem;\n  row-gap: 2rem;\n}\n\n.gap-y-10 {\n  grid-row-gap: 2.5rem;\n  row-gap: 2.5rem;\n}\n\n.gap-y-12 {\n  grid-row-gap: 3rem;\n  row-gap: 3rem;\n}\n\n.gap-y-16 {\n  grid-row-gap: 4rem;\n  row-gap: 4rem;\n}\n\n.gap-y-20 {\n  grid-row-gap: 5rem;\n  row-gap: 5rem;\n}\n\n.gap-y-24 {\n  grid-row-gap: 6rem;\n  row-gap: 6rem;\n}\n\n.gap-y-32 {\n  grid-row-gap: 8rem;\n  row-gap: 8rem;\n}\n\n.gap-y-40 {\n  grid-row-gap: 10rem;\n  row-gap: 10rem;\n}\n\n.gap-y-48 {\n  grid-row-gap: 12rem;\n  row-gap: 12rem;\n}\n\n.gap-y-56 {\n  grid-row-gap: 14rem;\n  row-gap: 14rem;\n}\n\n.gap-y-64 {\n  grid-row-gap: 16rem;\n  row-gap: 16rem;\n}\n\n.gap-y-px {\n  grid-row-gap: 1px;\n  row-gap: 1px;\n}\n\n.grid-flow-row {\n  grid-auto-flow: row;\n}\n\n.grid-flow-col {\n  grid-auto-flow: column;\n}\n\n.grid-flow-row-dense {\n  grid-auto-flow: row dense;\n}\n\n.grid-flow-col-dense {\n  grid-auto-flow: column dense;\n}\n\n.grid-cols-1 {\n  grid-template-columns: repeat(1, minmax(0, 1fr));\n}\n\n.grid-cols-2 {\n  grid-template-columns: repeat(2, minmax(0, 1fr));\n}\n\n.grid-cols-3 {\n  grid-template-columns: repeat(3, minmax(0, 1fr));\n}\n\n.grid-cols-4 {\n  grid-template-columns: repeat(4, minmax(0, 1fr));\n}\n\n.grid-cols-5 {\n  grid-template-columns: repeat(5, minmax(0, 1fr));\n}\n\n.grid-cols-6 {\n  grid-template-columns: repeat(6, minmax(0, 1fr));\n}\n\n.grid-cols-7 {\n  grid-template-columns: repeat(7, minmax(0, 1fr));\n}\n\n.grid-cols-8 {\n  grid-template-columns: repeat(8, minmax(0, 1fr));\n}\n\n.grid-cols-9 {\n  grid-template-columns: repeat(9, minmax(0, 1fr));\n}\n\n.grid-cols-10 {\n  grid-template-columns: repeat(10, minmax(0, 1fr));\n}\n\n.grid-cols-11 {\n  grid-template-columns: repeat(11, minmax(0, 1fr));\n}\n\n.grid-cols-12 {\n  grid-template-columns: repeat(12, minmax(0, 1fr));\n}\n\n.grid-cols-none {\n  grid-template-columns: none;\n}\n\n.auto-cols-auto {\n  grid-auto-columns: auto;\n}\n\n.auto-cols-min {\n  grid-auto-columns: -webkit-min-content;\n  grid-auto-columns: min-content;\n}\n\n.auto-cols-max {\n  grid-auto-columns: -webkit-max-content;\n  grid-auto-columns: max-content;\n}\n\n.auto-cols-fr {\n  grid-auto-columns: minmax(0, 1fr);\n}\n\n.col-auto {\n  grid-column: auto;\n}\n\n.col-span-1 {\n  grid-column: span 1 / span 1;\n}\n\n.col-span-2 {\n  grid-column: span 2 / span 2;\n}\n\n.col-span-3 {\n  grid-column: span 3 / span 3;\n}\n\n.col-span-4 {\n  grid-column: span 4 / span 4;\n}\n\n.col-span-5 {\n  grid-column: span 5 / span 5;\n}\n\n.col-span-6 {\n  grid-column: span 6 / span 6;\n}\n\n.col-span-7 {\n  grid-column: span 7 / span 7;\n}\n\n.col-span-8 {\n  grid-column: span 8 / span 8;\n}\n\n.col-span-9 {\n  grid-column: span 9 / span 9;\n}\n\n.col-span-10 {\n  grid-column: span 10 / span 10;\n}\n\n.col-span-11 {\n  grid-column: span 11 / span 11;\n}\n\n.col-span-12 {\n  grid-column: span 12 / span 12;\n}\n\n.col-span-full {\n  grid-column: 1 / -1;\n}\n\n.col-start-1 {\n  grid-column-start: 1;\n}\n\n.col-start-2 {\n  grid-column-start: 2;\n}\n\n.col-start-3 {\n  grid-column-start: 3;\n}\n\n.col-start-4 {\n  grid-column-start: 4;\n}\n\n.col-start-5 {\n  grid-column-start: 5;\n}\n\n.col-start-6 {\n  grid-column-start: 6;\n}\n\n.col-start-7 {\n  grid-column-start: 7;\n}\n\n.col-start-8 {\n  grid-column-start: 8;\n}\n\n.col-start-9 {\n  grid-column-start: 9;\n}\n\n.col-start-10 {\n  grid-column-start: 10;\n}\n\n.col-start-11 {\n  grid-column-start: 11;\n}\n\n.col-start-12 {\n  grid-column-start: 12;\n}\n\n.col-start-13 {\n  grid-column-start: 13;\n}\n\n.col-start-auto {\n  grid-column-start: auto;\n}\n\n.col-end-1 {\n  grid-column-end: 1;\n}\n\n.col-end-2 {\n  grid-column-end: 2;\n}\n\n.col-end-3 {\n  grid-column-end: 3;\n}\n\n.col-end-4 {\n  grid-column-end: 4;\n}\n\n.col-end-5 {\n  grid-column-end: 5;\n}\n\n.col-end-6 {\n  grid-column-end: 6;\n}\n\n.col-end-7 {\n  grid-column-end: 7;\n}\n\n.col-end-8 {\n  grid-column-end: 8;\n}\n\n.col-end-9 {\n  grid-column-end: 9;\n}\n\n.col-end-10 {\n  grid-column-end: 10;\n}\n\n.col-end-11 {\n  grid-column-end: 11;\n}\n\n.col-end-12 {\n  grid-column-end: 12;\n}\n\n.col-end-13 {\n  grid-column-end: 13;\n}\n\n.col-end-auto {\n  grid-column-end: auto;\n}\n\n.grid-rows-1 {\n  grid-template-rows: repeat(1, minmax(0, 1fr));\n}\n\n.grid-rows-2 {\n  grid-template-rows: repeat(2, minmax(0, 1fr));\n}\n\n.grid-rows-3 {\n  grid-template-rows: repeat(3, minmax(0, 1fr));\n}\n\n.grid-rows-4 {\n  grid-template-rows: repeat(4, minmax(0, 1fr));\n}\n\n.grid-rows-5 {\n  grid-template-rows: repeat(5, minmax(0, 1fr));\n}\n\n.grid-rows-6 {\n  grid-template-rows: repeat(6, minmax(0, 1fr));\n}\n\n.grid-rows-none {\n  grid-template-rows: none;\n}\n\n.auto-rows-auto {\n  grid-auto-rows: auto;\n}\n\n.auto-rows-min {\n  grid-auto-rows: -webkit-min-content;\n  grid-auto-rows: min-content;\n}\n\n.auto-rows-max {\n  grid-auto-rows: -webkit-max-content;\n  grid-auto-rows: max-content;\n}\n\n.auto-rows-fr {\n  grid-auto-rows: minmax(0, 1fr);\n}\n\n.row-auto {\n  grid-row: auto;\n}\n\n.row-span-1 {\n  grid-row: span 1 / span 1;\n}\n\n.row-span-2 {\n  grid-row: span 2 / span 2;\n}\n\n.row-span-3 {\n  grid-row: span 3 / span 3;\n}\n\n.row-span-4 {\n  grid-row: span 4 / span 4;\n}\n\n.row-span-5 {\n  grid-row: span 5 / span 5;\n}\n\n.row-span-6 {\n  grid-row: span 6 / span 6;\n}\n\n.row-span-full {\n  grid-row: 1 / -1;\n}\n\n.row-start-1 {\n  grid-row-start: 1;\n}\n\n.row-start-2 {\n  grid-row-start: 2;\n}\n\n.row-start-3 {\n  grid-row-start: 3;\n}\n\n.row-start-4 {\n  grid-row-start: 4;\n}\n\n.row-start-5 {\n  grid-row-start: 5;\n}\n\n.row-start-6 {\n  grid-row-start: 6;\n}\n\n.row-start-7 {\n  grid-row-start: 7;\n}\n\n.row-start-auto {\n  grid-row-start: auto;\n}\n\n.row-end-1 {\n  grid-row-end: 1;\n}\n\n.row-end-2 {\n  grid-row-end: 2;\n}\n\n.row-end-3 {\n  grid-row-end: 3;\n}\n\n.row-end-4 {\n  grid-row-end: 4;\n}\n\n.row-end-5 {\n  grid-row-end: 5;\n}\n\n.row-end-6 {\n  grid-row-end: 6;\n}\n\n.row-end-7 {\n  grid-row-end: 7;\n}\n\n.row-end-auto {\n  grid-row-end: auto;\n}\n\n.transform {\n  --transform-translate-x: 0;\n  --transform-translate-y: 0;\n  --transform-rotate: 0;\n  --transform-skew-x: 0;\n  --transform-skew-y: 0;\n  --transform-scale-x: 1;\n  --transform-scale-y: 1;\n  transform: translateX(var(--transform-translate-x)) translateY(var(--transform-translate-y)) rotate(var(--transform-rotate)) skewX(var(--transform-skew-x)) skewY(var(--transform-skew-y)) scaleX(var(--transform-scale-x)) scaleY(var(--transform-scale-y));\n}\n\n.transform-none {\n  transform: none;\n}\n\n.origin-center {\n  transform-origin: center;\n}\n\n.origin-top {\n  transform-origin: top;\n}\n\n.origin-top-right {\n  transform-origin: top right;\n}\n\n.origin-right {\n  transform-origin: right;\n}\n\n.origin-bottom-right {\n  transform-origin: bottom right;\n}\n\n.origin-bottom {\n  transform-origin: bottom;\n}\n\n.origin-bottom-left {\n  transform-origin: bottom left;\n}\n\n.origin-left {\n  transform-origin: left;\n}\n\n.origin-top-left {\n  transform-origin: top left;\n}\n\n.scale-0 {\n  --transform-scale-x: 0;\n  --transform-scale-y: 0;\n}\n\n.scale-50 {\n  --transform-scale-x: .5;\n  --transform-scale-y: .5;\n}\n\n.scale-75 {\n  --transform-scale-x: .75;\n  --transform-scale-y: .75;\n}\n\n.scale-90 {\n  --transform-scale-x: .9;\n  --transform-scale-y: .9;\n}\n\n.scale-95 {\n  --transform-scale-x: .95;\n  --transform-scale-y: .95;\n}\n\n.scale-100 {\n  --transform-scale-x: 1;\n  --transform-scale-y: 1;\n}\n\n.scale-105 {\n  --transform-scale-x: 1.05;\n  --transform-scale-y: 1.05;\n}\n\n.scale-110 {\n  --transform-scale-x: 1.1;\n  --transform-scale-y: 1.1;\n}\n\n.scale-125 {\n  --transform-scale-x: 1.25;\n  --transform-scale-y: 1.25;\n}\n\n.scale-150 {\n  --transform-scale-x: 1.5;\n  --transform-scale-y: 1.5;\n}\n\n.scale-x-0 {\n  --transform-scale-x: 0;\n}\n\n.scale-x-50 {\n  --transform-scale-x: .5;\n}\n\n.scale-x-75 {\n  --transform-scale-x: .75;\n}\n\n.scale-x-90 {\n  --transform-scale-x: .9;\n}\n\n.scale-x-95 {\n  --transform-scale-x: .95;\n}\n\n.scale-x-100 {\n  --transform-scale-x: 1;\n}\n\n.scale-x-105 {\n  --transform-scale-x: 1.05;\n}\n\n.scale-x-110 {\n  --transform-scale-x: 1.1;\n}\n\n.scale-x-125 {\n  --transform-scale-x: 1.25;\n}\n\n.scale-x-150 {\n  --transform-scale-x: 1.5;\n}\n\n.scale-y-0 {\n  --transform-scale-y: 0;\n}\n\n.scale-y-50 {\n  --transform-scale-y: .5;\n}\n\n.scale-y-75 {\n  --transform-scale-y: .75;\n}\n\n.scale-y-90 {\n  --transform-scale-y: .9;\n}\n\n.scale-y-95 {\n  --transform-scale-y: .95;\n}\n\n.scale-y-100 {\n  --transform-scale-y: 1;\n}\n\n.scale-y-105 {\n  --transform-scale-y: 1.05;\n}\n\n.scale-y-110 {\n  --transform-scale-y: 1.1;\n}\n\n.scale-y-125 {\n  --transform-scale-y: 1.25;\n}\n\n.scale-y-150 {\n  --transform-scale-y: 1.5;\n}\n\n.hover\\:scale-0:hover {\n  --transform-scale-x: 0;\n  --transform-scale-y: 0;\n}\n\n.hover\\:scale-50:hover {\n  --transform-scale-x: .5;\n  --transform-scale-y: .5;\n}\n\n.hover\\:scale-75:hover {\n  --transform-scale-x: .75;\n  --transform-scale-y: .75;\n}\n\n.hover\\:scale-90:hover {\n  --transform-scale-x: .9;\n  --transform-scale-y: .9;\n}\n\n.hover\\:scale-95:hover {\n  --transform-scale-x: .95;\n  --transform-scale-y: .95;\n}\n\n.hover\\:scale-100:hover {\n  --transform-scale-x: 1;\n  --transform-scale-y: 1;\n}\n\n.hover\\:scale-105:hover {\n  --transform-scale-x: 1.05;\n  --transform-scale-y: 1.05;\n}\n\n.hover\\:scale-110:hover {\n  --transform-scale-x: 1.1;\n  --transform-scale-y: 1.1;\n}\n\n.hover\\:scale-125:hover {\n  --transform-scale-x: 1.25;\n  --transform-scale-y: 1.25;\n}\n\n.hover\\:scale-150:hover {\n  --transform-scale-x: 1.5;\n  --transform-scale-y: 1.5;\n}\n\n.hover\\:scale-x-0:hover {\n  --transform-scale-x: 0;\n}\n\n.hover\\:scale-x-50:hover {\n  --transform-scale-x: .5;\n}\n\n.hover\\:scale-x-75:hover {\n  --transform-scale-x: .75;\n}\n\n.hover\\:scale-x-90:hover {\n  --transform-scale-x: .9;\n}\n\n.hover\\:scale-x-95:hover {\n  --transform-scale-x: .95;\n}\n\n.hover\\:scale-x-100:hover {\n  --transform-scale-x: 1;\n}\n\n.hover\\:scale-x-105:hover {\n  --transform-scale-x: 1.05;\n}\n\n.hover\\:scale-x-110:hover {\n  --transform-scale-x: 1.1;\n}\n\n.hover\\:scale-x-125:hover {\n  --transform-scale-x: 1.25;\n}\n\n.hover\\:scale-x-150:hover {\n  --transform-scale-x: 1.5;\n}\n\n.hover\\:scale-y-0:hover {\n  --transform-scale-y: 0;\n}\n\n.hover\\:scale-y-50:hover {\n  --transform-scale-y: .5;\n}\n\n.hover\\:scale-y-75:hover {\n  --transform-scale-y: .75;\n}\n\n.hover\\:scale-y-90:hover {\n  --transform-scale-y: .9;\n}\n\n.hover\\:scale-y-95:hover {\n  --transform-scale-y: .95;\n}\n\n.hover\\:scale-y-100:hover {\n  --transform-scale-y: 1;\n}\n\n.hover\\:scale-y-105:hover {\n  --transform-scale-y: 1.05;\n}\n\n.hover\\:scale-y-110:hover {\n  --transform-scale-y: 1.1;\n}\n\n.hover\\:scale-y-125:hover {\n  --transform-scale-y: 1.25;\n}\n\n.hover\\:scale-y-150:hover {\n  --transform-scale-y: 1.5;\n}\n\n.focus\\:scale-0:focus {\n  --transform-scale-x: 0;\n  --transform-scale-y: 0;\n}\n\n.focus\\:scale-50:focus {\n  --transform-scale-x: .5;\n  --transform-scale-y: .5;\n}\n\n.focus\\:scale-75:focus {\n  --transform-scale-x: .75;\n  --transform-scale-y: .75;\n}\n\n.focus\\:scale-90:focus {\n  --transform-scale-x: .9;\n  --transform-scale-y: .9;\n}\n\n.focus\\:scale-95:focus {\n  --transform-scale-x: .95;\n  --transform-scale-y: .95;\n}\n\n.focus\\:scale-100:focus {\n  --transform-scale-x: 1;\n  --transform-scale-y: 1;\n}\n\n.focus\\:scale-105:focus {\n  --transform-scale-x: 1.05;\n  --transform-scale-y: 1.05;\n}\n\n.focus\\:scale-110:focus {\n  --transform-scale-x: 1.1;\n  --transform-scale-y: 1.1;\n}\n\n.focus\\:scale-125:focus {\n  --transform-scale-x: 1.25;\n  --transform-scale-y: 1.25;\n}\n\n.focus\\:scale-150:focus {\n  --transform-scale-x: 1.5;\n  --transform-scale-y: 1.5;\n}\n\n.focus\\:scale-x-0:focus {\n  --transform-scale-x: 0;\n}\n\n.focus\\:scale-x-50:focus {\n  --transform-scale-x: .5;\n}\n\n.focus\\:scale-x-75:focus {\n  --transform-scale-x: .75;\n}\n\n.focus\\:scale-x-90:focus {\n  --transform-scale-x: .9;\n}\n\n.focus\\:scale-x-95:focus {\n  --transform-scale-x: .95;\n}\n\n.focus\\:scale-x-100:focus {\n  --transform-scale-x: 1;\n}\n\n.focus\\:scale-x-105:focus {\n  --transform-scale-x: 1.05;\n}\n\n.focus\\:scale-x-110:focus {\n  --transform-scale-x: 1.1;\n}\n\n.focus\\:scale-x-125:focus {\n  --transform-scale-x: 1.25;\n}\n\n.focus\\:scale-x-150:focus {\n  --transform-scale-x: 1.5;\n}\n\n.focus\\:scale-y-0:focus {\n  --transform-scale-y: 0;\n}\n\n.focus\\:scale-y-50:focus {\n  --transform-scale-y: .5;\n}\n\n.focus\\:scale-y-75:focus {\n  --transform-scale-y: .75;\n}\n\n.focus\\:scale-y-90:focus {\n  --transform-scale-y: .9;\n}\n\n.focus\\:scale-y-95:focus {\n  --transform-scale-y: .95;\n}\n\n.focus\\:scale-y-100:focus {\n  --transform-scale-y: 1;\n}\n\n.focus\\:scale-y-105:focus {\n  --transform-scale-y: 1.05;\n}\n\n.focus\\:scale-y-110:focus {\n  --transform-scale-y: 1.1;\n}\n\n.focus\\:scale-y-125:focus {\n  --transform-scale-y: 1.25;\n}\n\n.focus\\:scale-y-150:focus {\n  --transform-scale-y: 1.5;\n}\n\n.rotate-0 {\n  --transform-rotate: 0;\n}\n\n.rotate-1 {\n  --transform-rotate: 1deg;\n}\n\n.rotate-2 {\n  --transform-rotate: 2deg;\n}\n\n.rotate-3 {\n  --transform-rotate: 3deg;\n}\n\n.rotate-6 {\n  --transform-rotate: 6deg;\n}\n\n.rotate-12 {\n  --transform-rotate: 12deg;\n}\n\n.rotate-45 {\n  --transform-rotate: 45deg;\n}\n\n.rotate-90 {\n  --transform-rotate: 90deg;\n}\n\n.rotate-180 {\n  --transform-rotate: 180deg;\n}\n\n.-rotate-180 {\n  --transform-rotate: -180deg;\n}\n\n.-rotate-90 {\n  --transform-rotate: -90deg;\n}\n\n.-rotate-45 {\n  --transform-rotate: -45deg;\n}\n\n.-rotate-12 {\n  --transform-rotate: -12deg;\n}\n\n.-rotate-6 {\n  --transform-rotate: -6deg;\n}\n\n.-rotate-3 {\n  --transform-rotate: -3deg;\n}\n\n.-rotate-2 {\n  --transform-rotate: -2deg;\n}\n\n.-rotate-1 {\n  --transform-rotate: -1deg;\n}\n\n.hover\\:rotate-0:hover {\n  --transform-rotate: 0;\n}\n\n.hover\\:rotate-1:hover {\n  --transform-rotate: 1deg;\n}\n\n.hover\\:rotate-2:hover {\n  --transform-rotate: 2deg;\n}\n\n.hover\\:rotate-3:hover {\n  --transform-rotate: 3deg;\n}\n\n.hover\\:rotate-6:hover {\n  --transform-rotate: 6deg;\n}\n\n.hover\\:rotate-12:hover {\n  --transform-rotate: 12deg;\n}\n\n.hover\\:rotate-45:hover {\n  --transform-rotate: 45deg;\n}\n\n.hover\\:rotate-90:hover {\n  --transform-rotate: 90deg;\n}\n\n.hover\\:rotate-180:hover {\n  --transform-rotate: 180deg;\n}\n\n.hover\\:-rotate-180:hover {\n  --transform-rotate: -180deg;\n}\n\n.hover\\:-rotate-90:hover {\n  --transform-rotate: -90deg;\n}\n\n.hover\\:-rotate-45:hover {\n  --transform-rotate: -45deg;\n}\n\n.hover\\:-rotate-12:hover {\n  --transform-rotate: -12deg;\n}\n\n.hover\\:-rotate-6:hover {\n  --transform-rotate: -6deg;\n}\n\n.hover\\:-rotate-3:hover {\n  --transform-rotate: -3deg;\n}\n\n.hover\\:-rotate-2:hover {\n  --transform-rotate: -2deg;\n}\n\n.hover\\:-rotate-1:hover {\n  --transform-rotate: -1deg;\n}\n\n.focus\\:rotate-0:focus {\n  --transform-rotate: 0;\n}\n\n.focus\\:rotate-1:focus {\n  --transform-rotate: 1deg;\n}\n\n.focus\\:rotate-2:focus {\n  --transform-rotate: 2deg;\n}\n\n.focus\\:rotate-3:focus {\n  --transform-rotate: 3deg;\n}\n\n.focus\\:rotate-6:focus {\n  --transform-rotate: 6deg;\n}\n\n.focus\\:rotate-12:focus {\n  --transform-rotate: 12deg;\n}\n\n.focus\\:rotate-45:focus {\n  --transform-rotate: 45deg;\n}\n\n.focus\\:rotate-90:focus {\n  --transform-rotate: 90deg;\n}\n\n.focus\\:rotate-180:focus {\n  --transform-rotate: 180deg;\n}\n\n.focus\\:-rotate-180:focus {\n  --transform-rotate: -180deg;\n}\n\n.focus\\:-rotate-90:focus {\n  --transform-rotate: -90deg;\n}\n\n.focus\\:-rotate-45:focus {\n  --transform-rotate: -45deg;\n}\n\n.focus\\:-rotate-12:focus {\n  --transform-rotate: -12deg;\n}\n\n.focus\\:-rotate-6:focus {\n  --transform-rotate: -6deg;\n}\n\n.focus\\:-rotate-3:focus {\n  --transform-rotate: -3deg;\n}\n\n.focus\\:-rotate-2:focus {\n  --transform-rotate: -2deg;\n}\n\n.focus\\:-rotate-1:focus {\n  --transform-rotate: -1deg;\n}\n\n.translate-x-0 {\n  --transform-translate-x: 0;\n}\n\n.translate-x-1 {\n  --transform-translate-x: 0.25rem;\n}\n\n.translate-x-2 {\n  --transform-translate-x: 0.5rem;\n}\n\n.translate-x-3 {\n  --transform-translate-x: 0.75rem;\n}\n\n.translate-x-4 {\n  --transform-translate-x: 1rem;\n}\n\n.translate-x-5 {\n  --transform-translate-x: 1.25rem;\n}\n\n.translate-x-6 {\n  --transform-translate-x: 1.5rem;\n}\n\n.translate-x-8 {\n  --transform-translate-x: 2rem;\n}\n\n.translate-x-10 {\n  --transform-translate-x: 2.5rem;\n}\n\n.translate-x-12 {\n  --transform-translate-x: 3rem;\n}\n\n.translate-x-16 {\n  --transform-translate-x: 4rem;\n}\n\n.translate-x-20 {\n  --transform-translate-x: 5rem;\n}\n\n.translate-x-24 {\n  --transform-translate-x: 6rem;\n}\n\n.translate-x-32 {\n  --transform-translate-x: 8rem;\n}\n\n.translate-x-40 {\n  --transform-translate-x: 10rem;\n}\n\n.translate-x-48 {\n  --transform-translate-x: 12rem;\n}\n\n.translate-x-56 {\n  --transform-translate-x: 14rem;\n}\n\n.translate-x-64 {\n  --transform-translate-x: 16rem;\n}\n\n.translate-x-px {\n  --transform-translate-x: 1px;\n}\n\n.-translate-x-1 {\n  --transform-translate-x: -0.25rem;\n}\n\n.-translate-x-2 {\n  --transform-translate-x: -0.5rem;\n}\n\n.-translate-x-3 {\n  --transform-translate-x: -0.75rem;\n}\n\n.-translate-x-4 {\n  --transform-translate-x: -1rem;\n}\n\n.-translate-x-5 {\n  --transform-translate-x: -1.25rem;\n}\n\n.-translate-x-6 {\n  --transform-translate-x: -1.5rem;\n}\n\n.-translate-x-8 {\n  --transform-translate-x: -2rem;\n}\n\n.-translate-x-10 {\n  --transform-translate-x: -2.5rem;\n}\n\n.-translate-x-12 {\n  --transform-translate-x: -3rem;\n}\n\n.-translate-x-16 {\n  --transform-translate-x: -4rem;\n}\n\n.-translate-x-20 {\n  --transform-translate-x: -5rem;\n}\n\n.-translate-x-24 {\n  --transform-translate-x: -6rem;\n}\n\n.-translate-x-32 {\n  --transform-translate-x: -8rem;\n}\n\n.-translate-x-40 {\n  --transform-translate-x: -10rem;\n}\n\n.-translate-x-48 {\n  --transform-translate-x: -12rem;\n}\n\n.-translate-x-56 {\n  --transform-translate-x: -14rem;\n}\n\n.-translate-x-64 {\n  --transform-translate-x: -16rem;\n}\n\n.-translate-x-px {\n  --transform-translate-x: -1px;\n}\n\n.-translate-x-full {\n  --transform-translate-x: -100%;\n}\n\n.-translate-x-1\\/2 {\n  --transform-translate-x: -50%;\n}\n\n.translate-x-1\\/2 {\n  --transform-translate-x: 50%;\n}\n\n.translate-x-full {\n  --transform-translate-x: 100%;\n}\n\n.translate-y-0 {\n  --transform-translate-y: 0;\n}\n\n.translate-y-1 {\n  --transform-translate-y: 0.25rem;\n}\n\n.translate-y-2 {\n  --transform-translate-y: 0.5rem;\n}\n\n.translate-y-3 {\n  --transform-translate-y: 0.75rem;\n}\n\n.translate-y-4 {\n  --transform-translate-y: 1rem;\n}\n\n.translate-y-5 {\n  --transform-translate-y: 1.25rem;\n}\n\n.translate-y-6 {\n  --transform-translate-y: 1.5rem;\n}\n\n.translate-y-8 {\n  --transform-translate-y: 2rem;\n}\n\n.translate-y-10 {\n  --transform-translate-y: 2.5rem;\n}\n\n.translate-y-12 {\n  --transform-translate-y: 3rem;\n}\n\n.translate-y-16 {\n  --transform-translate-y: 4rem;\n}\n\n.translate-y-20 {\n  --transform-translate-y: 5rem;\n}\n\n.translate-y-24 {\n  --transform-translate-y: 6rem;\n}\n\n.translate-y-32 {\n  --transform-translate-y: 8rem;\n}\n\n.translate-y-40 {\n  --transform-translate-y: 10rem;\n}\n\n.translate-y-48 {\n  --transform-translate-y: 12rem;\n}\n\n.translate-y-56 {\n  --transform-translate-y: 14rem;\n}\n\n.translate-y-64 {\n  --transform-translate-y: 16rem;\n}\n\n.translate-y-px {\n  --transform-translate-y: 1px;\n}\n\n.-translate-y-1 {\n  --transform-translate-y: -0.25rem;\n}\n\n.-translate-y-2 {\n  --transform-translate-y: -0.5rem;\n}\n\n.-translate-y-3 {\n  --transform-translate-y: -0.75rem;\n}\n\n.-translate-y-4 {\n  --transform-translate-y: -1rem;\n}\n\n.-translate-y-5 {\n  --transform-translate-y: -1.25rem;\n}\n\n.-translate-y-6 {\n  --transform-translate-y: -1.5rem;\n}\n\n.-translate-y-8 {\n  --transform-translate-y: -2rem;\n}\n\n.-translate-y-10 {\n  --transform-translate-y: -2.5rem;\n}\n\n.-translate-y-12 {\n  --transform-translate-y: -3rem;\n}\n\n.-translate-y-16 {\n  --transform-translate-y: -4rem;\n}\n\n.-translate-y-20 {\n  --transform-translate-y: -5rem;\n}\n\n.-translate-y-24 {\n  --transform-translate-y: -6rem;\n}\n\n.-translate-y-32 {\n  --transform-translate-y: -8rem;\n}\n\n.-translate-y-40 {\n  --transform-translate-y: -10rem;\n}\n\n.-translate-y-48 {\n  --transform-translate-y: -12rem;\n}\n\n.-translate-y-56 {\n  --transform-translate-y: -14rem;\n}\n\n.-translate-y-64 {\n  --transform-translate-y: -16rem;\n}\n\n.-translate-y-px {\n  --transform-translate-y: -1px;\n}\n\n.-translate-y-full {\n  --transform-translate-y: -100%;\n}\n\n.-translate-y-1\\/2 {\n  --transform-translate-y: -50%;\n}\n\n.translate-y-1\\/2 {\n  --transform-translate-y: 50%;\n}\n\n.translate-y-full {\n  --transform-translate-y: 100%;\n}\n\n.hover\\:translate-x-0:hover {\n  --transform-translate-x: 0;\n}\n\n.hover\\:translate-x-1:hover {\n  --transform-translate-x: 0.25rem;\n}\n\n.hover\\:translate-x-2:hover {\n  --transform-translate-x: 0.5rem;\n}\n\n.hover\\:translate-x-3:hover {\n  --transform-translate-x: 0.75rem;\n}\n\n.hover\\:translate-x-4:hover {\n  --transform-translate-x: 1rem;\n}\n\n.hover\\:translate-x-5:hover {\n  --transform-translate-x: 1.25rem;\n}\n\n.hover\\:translate-x-6:hover {\n  --transform-translate-x: 1.5rem;\n}\n\n.hover\\:translate-x-8:hover {\n  --transform-translate-x: 2rem;\n}\n\n.hover\\:translate-x-10:hover {\n  --transform-translate-x: 2.5rem;\n}\n\n.hover\\:translate-x-12:hover {\n  --transform-translate-x: 3rem;\n}\n\n.hover\\:translate-x-16:hover {\n  --transform-translate-x: 4rem;\n}\n\n.hover\\:translate-x-20:hover {\n  --transform-translate-x: 5rem;\n}\n\n.hover\\:translate-x-24:hover {\n  --transform-translate-x: 6rem;\n}\n\n.hover\\:translate-x-32:hover {\n  --transform-translate-x: 8rem;\n}\n\n.hover\\:translate-x-40:hover {\n  --transform-translate-x: 10rem;\n}\n\n.hover\\:translate-x-48:hover {\n  --transform-translate-x: 12rem;\n}\n\n.hover\\:translate-x-56:hover {\n  --transform-translate-x: 14rem;\n}\n\n.hover\\:translate-x-64:hover {\n  --transform-translate-x: 16rem;\n}\n\n.hover\\:translate-x-px:hover {\n  --transform-translate-x: 1px;\n}\n\n.hover\\:-translate-x-1:hover {\n  --transform-translate-x: -0.25rem;\n}\n\n.hover\\:-translate-x-2:hover {\n  --transform-translate-x: -0.5rem;\n}\n\n.hover\\:-translate-x-3:hover {\n  --transform-translate-x: -0.75rem;\n}\n\n.hover\\:-translate-x-4:hover {\n  --transform-translate-x: -1rem;\n}\n\n.hover\\:-translate-x-5:hover {\n  --transform-translate-x: -1.25rem;\n}\n\n.hover\\:-translate-x-6:hover {\n  --transform-translate-x: -1.5rem;\n}\n\n.hover\\:-translate-x-8:hover {\n  --transform-translate-x: -2rem;\n}\n\n.hover\\:-translate-x-10:hover {\n  --transform-translate-x: -2.5rem;\n}\n\n.hover\\:-translate-x-12:hover {\n  --transform-translate-x: -3rem;\n}\n\n.hover\\:-translate-x-16:hover {\n  --transform-translate-x: -4rem;\n}\n\n.hover\\:-translate-x-20:hover {\n  --transform-translate-x: -5rem;\n}\n\n.hover\\:-translate-x-24:hover {\n  --transform-translate-x: -6rem;\n}\n\n.hover\\:-translate-x-32:hover {\n  --transform-translate-x: -8rem;\n}\n\n.hover\\:-translate-x-40:hover {\n  --transform-translate-x: -10rem;\n}\n\n.hover\\:-translate-x-48:hover {\n  --transform-translate-x: -12rem;\n}\n\n.hover\\:-translate-x-56:hover {\n  --transform-translate-x: -14rem;\n}\n\n.hover\\:-translate-x-64:hover {\n  --transform-translate-x: -16rem;\n}\n\n.hover\\:-translate-x-px:hover {\n  --transform-translate-x: -1px;\n}\n\n.hover\\:-translate-x-full:hover {\n  --transform-translate-x: -100%;\n}\n\n.hover\\:-translate-x-1\\/2:hover {\n  --transform-translate-x: -50%;\n}\n\n.hover\\:translate-x-1\\/2:hover {\n  --transform-translate-x: 50%;\n}\n\n.hover\\:translate-x-full:hover {\n  --transform-translate-x: 100%;\n}\n\n.hover\\:translate-y-0:hover {\n  --transform-translate-y: 0;\n}\n\n.hover\\:translate-y-1:hover {\n  --transform-translate-y: 0.25rem;\n}\n\n.hover\\:translate-y-2:hover {\n  --transform-translate-y: 0.5rem;\n}\n\n.hover\\:translate-y-3:hover {\n  --transform-translate-y: 0.75rem;\n}\n\n.hover\\:translate-y-4:hover {\n  --transform-translate-y: 1rem;\n}\n\n.hover\\:translate-y-5:hover {\n  --transform-translate-y: 1.25rem;\n}\n\n.hover\\:translate-y-6:hover {\n  --transform-translate-y: 1.5rem;\n}\n\n.hover\\:translate-y-8:hover {\n  --transform-translate-y: 2rem;\n}\n\n.hover\\:translate-y-10:hover {\n  --transform-translate-y: 2.5rem;\n}\n\n.hover\\:translate-y-12:hover {\n  --transform-translate-y: 3rem;\n}\n\n.hover\\:translate-y-16:hover {\n  --transform-translate-y: 4rem;\n}\n\n.hover\\:translate-y-20:hover {\n  --transform-translate-y: 5rem;\n}\n\n.hover\\:translate-y-24:hover {\n  --transform-translate-y: 6rem;\n}\n\n.hover\\:translate-y-32:hover {\n  --transform-translate-y: 8rem;\n}\n\n.hover\\:translate-y-40:hover {\n  --transform-translate-y: 10rem;\n}\n\n.hover\\:translate-y-48:hover {\n  --transform-translate-y: 12rem;\n}\n\n.hover\\:translate-y-56:hover {\n  --transform-translate-y: 14rem;\n}\n\n.hover\\:translate-y-64:hover {\n  --transform-translate-y: 16rem;\n}\n\n.hover\\:translate-y-px:hover {\n  --transform-translate-y: 1px;\n}\n\n.hover\\:-translate-y-1:hover {\n  --transform-translate-y: -0.25rem;\n}\n\n.hover\\:-translate-y-2:hover {\n  --transform-translate-y: -0.5rem;\n}\n\n.hover\\:-translate-y-3:hover {\n  --transform-translate-y: -0.75rem;\n}\n\n.hover\\:-translate-y-4:hover {\n  --transform-translate-y: -1rem;\n}\n\n.hover\\:-translate-y-5:hover {\n  --transform-translate-y: -1.25rem;\n}\n\n.hover\\:-translate-y-6:hover {\n  --transform-translate-y: -1.5rem;\n}\n\n.hover\\:-translate-y-8:hover {\n  --transform-translate-y: -2rem;\n}\n\n.hover\\:-translate-y-10:hover {\n  --transform-translate-y: -2.5rem;\n}\n\n.hover\\:-translate-y-12:hover {\n  --transform-translate-y: -3rem;\n}\n\n.hover\\:-translate-y-16:hover {\n  --transform-translate-y: -4rem;\n}\n\n.hover\\:-translate-y-20:hover {\n  --transform-translate-y: -5rem;\n}\n\n.hover\\:-translate-y-24:hover {\n  --transform-translate-y: -6rem;\n}\n\n.hover\\:-translate-y-32:hover {\n  --transform-translate-y: -8rem;\n}\n\n.hover\\:-translate-y-40:hover {\n  --transform-translate-y: -10rem;\n}\n\n.hover\\:-translate-y-48:hover {\n  --transform-translate-y: -12rem;\n}\n\n.hover\\:-translate-y-56:hover {\n  --transform-translate-y: -14rem;\n}\n\n.hover\\:-translate-y-64:hover {\n  --transform-translate-y: -16rem;\n}\n\n.hover\\:-translate-y-px:hover {\n  --transform-translate-y: -1px;\n}\n\n.hover\\:-translate-y-full:hover {\n  --transform-translate-y: -100%;\n}\n\n.hover\\:-translate-y-1\\/2:hover {\n  --transform-translate-y: -50%;\n}\n\n.hover\\:translate-y-1\\/2:hover {\n  --transform-translate-y: 50%;\n}\n\n.hover\\:translate-y-full:hover {\n  --transform-translate-y: 100%;\n}\n\n.focus\\:translate-x-0:focus {\n  --transform-translate-x: 0;\n}\n\n.focus\\:translate-x-1:focus {\n  --transform-translate-x: 0.25rem;\n}\n\n.focus\\:translate-x-2:focus {\n  --transform-translate-x: 0.5rem;\n}\n\n.focus\\:translate-x-3:focus {\n  --transform-translate-x: 0.75rem;\n}\n\n.focus\\:translate-x-4:focus {\n  --transform-translate-x: 1rem;\n}\n\n.focus\\:translate-x-5:focus {\n  --transform-translate-x: 1.25rem;\n}\n\n.focus\\:translate-x-6:focus {\n  --transform-translate-x: 1.5rem;\n}\n\n.focus\\:translate-x-8:focus {\n  --transform-translate-x: 2rem;\n}\n\n.focus\\:translate-x-10:focus {\n  --transform-translate-x: 2.5rem;\n}\n\n.focus\\:translate-x-12:focus {\n  --transform-translate-x: 3rem;\n}\n\n.focus\\:translate-x-16:focus {\n  --transform-translate-x: 4rem;\n}\n\n.focus\\:translate-x-20:focus {\n  --transform-translate-x: 5rem;\n}\n\n.focus\\:translate-x-24:focus {\n  --transform-translate-x: 6rem;\n}\n\n.focus\\:translate-x-32:focus {\n  --transform-translate-x: 8rem;\n}\n\n.focus\\:translate-x-40:focus {\n  --transform-translate-x: 10rem;\n}\n\n.focus\\:translate-x-48:focus {\n  --transform-translate-x: 12rem;\n}\n\n.focus\\:translate-x-56:focus {\n  --transform-translate-x: 14rem;\n}\n\n.focus\\:translate-x-64:focus {\n  --transform-translate-x: 16rem;\n}\n\n.focus\\:translate-x-px:focus {\n  --transform-translate-x: 1px;\n}\n\n.focus\\:-translate-x-1:focus {\n  --transform-translate-x: -0.25rem;\n}\n\n.focus\\:-translate-x-2:focus {\n  --transform-translate-x: -0.5rem;\n}\n\n.focus\\:-translate-x-3:focus {\n  --transform-translate-x: -0.75rem;\n}\n\n.focus\\:-translate-x-4:focus {\n  --transform-translate-x: -1rem;\n}\n\n.focus\\:-translate-x-5:focus {\n  --transform-translate-x: -1.25rem;\n}\n\n.focus\\:-translate-x-6:focus {\n  --transform-translate-x: -1.5rem;\n}\n\n.focus\\:-translate-x-8:focus {\n  --transform-translate-x: -2rem;\n}\n\n.focus\\:-translate-x-10:focus {\n  --transform-translate-x: -2.5rem;\n}\n\n.focus\\:-translate-x-12:focus {\n  --transform-translate-x: -3rem;\n}\n\n.focus\\:-translate-x-16:focus {\n  --transform-translate-x: -4rem;\n}\n\n.focus\\:-translate-x-20:focus {\n  --transform-translate-x: -5rem;\n}\n\n.focus\\:-translate-x-24:focus {\n  --transform-translate-x: -6rem;\n}\n\n.focus\\:-translate-x-32:focus {\n  --transform-translate-x: -8rem;\n}\n\n.focus\\:-translate-x-40:focus {\n  --transform-translate-x: -10rem;\n}\n\n.focus\\:-translate-x-48:focus {\n  --transform-translate-x: -12rem;\n}\n\n.focus\\:-translate-x-56:focus {\n  --transform-translate-x: -14rem;\n}\n\n.focus\\:-translate-x-64:focus {\n  --transform-translate-x: -16rem;\n}\n\n.focus\\:-translate-x-px:focus {\n  --transform-translate-x: -1px;\n}\n\n.focus\\:-translate-x-full:focus {\n  --transform-translate-x: -100%;\n}\n\n.focus\\:-translate-x-1\\/2:focus {\n  --transform-translate-x: -50%;\n}\n\n.focus\\:translate-x-1\\/2:focus {\n  --transform-translate-x: 50%;\n}\n\n.focus\\:translate-x-full:focus {\n  --transform-translate-x: 100%;\n}\n\n.focus\\:translate-y-0:focus {\n  --transform-translate-y: 0;\n}\n\n.focus\\:translate-y-1:focus {\n  --transform-translate-y: 0.25rem;\n}\n\n.focus\\:translate-y-2:focus {\n  --transform-translate-y: 0.5rem;\n}\n\n.focus\\:translate-y-3:focus {\n  --transform-translate-y: 0.75rem;\n}\n\n.focus\\:translate-y-4:focus {\n  --transform-translate-y: 1rem;\n}\n\n.focus\\:translate-y-5:focus {\n  --transform-translate-y: 1.25rem;\n}\n\n.focus\\:translate-y-6:focus {\n  --transform-translate-y: 1.5rem;\n}\n\n.focus\\:translate-y-8:focus {\n  --transform-translate-y: 2rem;\n}\n\n.focus\\:translate-y-10:focus {\n  --transform-translate-y: 2.5rem;\n}\n\n.focus\\:translate-y-12:focus {\n  --transform-translate-y: 3rem;\n}\n\n.focus\\:translate-y-16:focus {\n  --transform-translate-y: 4rem;\n}\n\n.focus\\:translate-y-20:focus {\n  --transform-translate-y: 5rem;\n}\n\n.focus\\:translate-y-24:focus {\n  --transform-translate-y: 6rem;\n}\n\n.focus\\:translate-y-32:focus {\n  --transform-translate-y: 8rem;\n}\n\n.focus\\:translate-y-40:focus {\n  --transform-translate-y: 10rem;\n}\n\n.focus\\:translate-y-48:focus {\n  --transform-translate-y: 12rem;\n}\n\n.focus\\:translate-y-56:focus {\n  --transform-translate-y: 14rem;\n}\n\n.focus\\:translate-y-64:focus {\n  --transform-translate-y: 16rem;\n}\n\n.focus\\:translate-y-px:focus {\n  --transform-translate-y: 1px;\n}\n\n.focus\\:-translate-y-1:focus {\n  --transform-translate-y: -0.25rem;\n}\n\n.focus\\:-translate-y-2:focus {\n  --transform-translate-y: -0.5rem;\n}\n\n.focus\\:-translate-y-3:focus {\n  --transform-translate-y: -0.75rem;\n}\n\n.focus\\:-translate-y-4:focus {\n  --transform-translate-y: -1rem;\n}\n\n.focus\\:-translate-y-5:focus {\n  --transform-translate-y: -1.25rem;\n}\n\n.focus\\:-translate-y-6:focus {\n  --transform-translate-y: -1.5rem;\n}\n\n.focus\\:-translate-y-8:focus {\n  --transform-translate-y: -2rem;\n}\n\n.focus\\:-translate-y-10:focus {\n  --transform-translate-y: -2.5rem;\n}\n\n.focus\\:-translate-y-12:focus {\n  --transform-translate-y: -3rem;\n}\n\n.focus\\:-translate-y-16:focus {\n  --transform-translate-y: -4rem;\n}\n\n.focus\\:-translate-y-20:focus {\n  --transform-translate-y: -5rem;\n}\n\n.focus\\:-translate-y-24:focus {\n  --transform-translate-y: -6rem;\n}\n\n.focus\\:-translate-y-32:focus {\n  --transform-translate-y: -8rem;\n}\n\n.focus\\:-translate-y-40:focus {\n  --transform-translate-y: -10rem;\n}\n\n.focus\\:-translate-y-48:focus {\n  --transform-translate-y: -12rem;\n}\n\n.focus\\:-translate-y-56:focus {\n  --transform-translate-y: -14rem;\n}\n\n.focus\\:-translate-y-64:focus {\n  --transform-translate-y: -16rem;\n}\n\n.focus\\:-translate-y-px:focus {\n  --transform-translate-y: -1px;\n}\n\n.focus\\:-translate-y-full:focus {\n  --transform-translate-y: -100%;\n}\n\n.focus\\:-translate-y-1\\/2:focus {\n  --transform-translate-y: -50%;\n}\n\n.focus\\:translate-y-1\\/2:focus {\n  --transform-translate-y: 50%;\n}\n\n.focus\\:translate-y-full:focus {\n  --transform-translate-y: 100%;\n}\n\n.skew-x-0 {\n  --transform-skew-x: 0;\n}\n\n.skew-x-1 {\n  --transform-skew-x: 1deg;\n}\n\n.skew-x-2 {\n  --transform-skew-x: 2deg;\n}\n\n.skew-x-3 {\n  --transform-skew-x: 3deg;\n}\n\n.skew-x-6 {\n  --transform-skew-x: 6deg;\n}\n\n.skew-x-12 {\n  --transform-skew-x: 12deg;\n}\n\n.-skew-x-12 {\n  --transform-skew-x: -12deg;\n}\n\n.-skew-x-6 {\n  --transform-skew-x: -6deg;\n}\n\n.-skew-x-3 {\n  --transform-skew-x: -3deg;\n}\n\n.-skew-x-2 {\n  --transform-skew-x: -2deg;\n}\n\n.-skew-x-1 {\n  --transform-skew-x: -1deg;\n}\n\n.skew-y-0 {\n  --transform-skew-y: 0;\n}\n\n.skew-y-1 {\n  --transform-skew-y: 1deg;\n}\n\n.skew-y-2 {\n  --transform-skew-y: 2deg;\n}\n\n.skew-y-3 {\n  --transform-skew-y: 3deg;\n}\n\n.skew-y-6 {\n  --transform-skew-y: 6deg;\n}\n\n.skew-y-12 {\n  --transform-skew-y: 12deg;\n}\n\n.-skew-y-12 {\n  --transform-skew-y: -12deg;\n}\n\n.-skew-y-6 {\n  --transform-skew-y: -6deg;\n}\n\n.-skew-y-3 {\n  --transform-skew-y: -3deg;\n}\n\n.-skew-y-2 {\n  --transform-skew-y: -2deg;\n}\n\n.-skew-y-1 {\n  --transform-skew-y: -1deg;\n}\n\n.hover\\:skew-x-0:hover {\n  --transform-skew-x: 0;\n}\n\n.hover\\:skew-x-1:hover {\n  --transform-skew-x: 1deg;\n}\n\n.hover\\:skew-x-2:hover {\n  --transform-skew-x: 2deg;\n}\n\n.hover\\:skew-x-3:hover {\n  --transform-skew-x: 3deg;\n}\n\n.hover\\:skew-x-6:hover {\n  --transform-skew-x: 6deg;\n}\n\n.hover\\:skew-x-12:hover {\n  --transform-skew-x: 12deg;\n}\n\n.hover\\:-skew-x-12:hover {\n  --transform-skew-x: -12deg;\n}\n\n.hover\\:-skew-x-6:hover {\n  --transform-skew-x: -6deg;\n}\n\n.hover\\:-skew-x-3:hover {\n  --transform-skew-x: -3deg;\n}\n\n.hover\\:-skew-x-2:hover {\n  --transform-skew-x: -2deg;\n}\n\n.hover\\:-skew-x-1:hover {\n  --transform-skew-x: -1deg;\n}\n\n.hover\\:skew-y-0:hover {\n  --transform-skew-y: 0;\n}\n\n.hover\\:skew-y-1:hover {\n  --transform-skew-y: 1deg;\n}\n\n.hover\\:skew-y-2:hover {\n  --transform-skew-y: 2deg;\n}\n\n.hover\\:skew-y-3:hover {\n  --transform-skew-y: 3deg;\n}\n\n.hover\\:skew-y-6:hover {\n  --transform-skew-y: 6deg;\n}\n\n.hover\\:skew-y-12:hover {\n  --transform-skew-y: 12deg;\n}\n\n.hover\\:-skew-y-12:hover {\n  --transform-skew-y: -12deg;\n}\n\n.hover\\:-skew-y-6:hover {\n  --transform-skew-y: -6deg;\n}\n\n.hover\\:-skew-y-3:hover {\n  --transform-skew-y: -3deg;\n}\n\n.hover\\:-skew-y-2:hover {\n  --transform-skew-y: -2deg;\n}\n\n.hover\\:-skew-y-1:hover {\n  --transform-skew-y: -1deg;\n}\n\n.focus\\:skew-x-0:focus {\n  --transform-skew-x: 0;\n}\n\n.focus\\:skew-x-1:focus {\n  --transform-skew-x: 1deg;\n}\n\n.focus\\:skew-x-2:focus {\n  --transform-skew-x: 2deg;\n}\n\n.focus\\:skew-x-3:focus {\n  --transform-skew-x: 3deg;\n}\n\n.focus\\:skew-x-6:focus {\n  --transform-skew-x: 6deg;\n}\n\n.focus\\:skew-x-12:focus {\n  --transform-skew-x: 12deg;\n}\n\n.focus\\:-skew-x-12:focus {\n  --transform-skew-x: -12deg;\n}\n\n.focus\\:-skew-x-6:focus {\n  --transform-skew-x: -6deg;\n}\n\n.focus\\:-skew-x-3:focus {\n  --transform-skew-x: -3deg;\n}\n\n.focus\\:-skew-x-2:focus {\n  --transform-skew-x: -2deg;\n}\n\n.focus\\:-skew-x-1:focus {\n  --transform-skew-x: -1deg;\n}\n\n.focus\\:skew-y-0:focus {\n  --transform-skew-y: 0;\n}\n\n.focus\\:skew-y-1:focus {\n  --transform-skew-y: 1deg;\n}\n\n.focus\\:skew-y-2:focus {\n  --transform-skew-y: 2deg;\n}\n\n.focus\\:skew-y-3:focus {\n  --transform-skew-y: 3deg;\n}\n\n.focus\\:skew-y-6:focus {\n  --transform-skew-y: 6deg;\n}\n\n.focus\\:skew-y-12:focus {\n  --transform-skew-y: 12deg;\n}\n\n.focus\\:-skew-y-12:focus {\n  --transform-skew-y: -12deg;\n}\n\n.focus\\:-skew-y-6:focus {\n  --transform-skew-y: -6deg;\n}\n\n.focus\\:-skew-y-3:focus {\n  --transform-skew-y: -3deg;\n}\n\n.focus\\:-skew-y-2:focus {\n  --transform-skew-y: -2deg;\n}\n\n.focus\\:-skew-y-1:focus {\n  --transform-skew-y: -1deg;\n}\n\n.transition-none {\n  transition-property: none;\n}\n\n.transition-all {\n  transition-property: all;\n}\n\n.transition {\n  transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform;\n}\n\n.transition-colors {\n  transition-property: background-color, border-color, color, fill, stroke;\n}\n\n.transition-opacity {\n  transition-property: opacity;\n}\n\n.transition-shadow {\n  transition-property: box-shadow;\n}\n\n.transition-transform {\n  transition-property: transform;\n}\n\n.ease-linear {\n  transition-timing-function: linear;\n}\n\n.ease-in {\n  transition-timing-function: cubic-bezier(0.4, 0, 1, 1);\n}\n\n.ease-out {\n  transition-timing-function: cubic-bezier(0, 0, 0.2, 1);\n}\n\n.ease-in-out {\n  transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);\n}\n\n.duration-75 {\n  transition-duration: 75ms;\n}\n\n.duration-100 {\n  transition-duration: 100ms;\n}\n\n.duration-150 {\n  transition-duration: 150ms;\n}\n\n.duration-200 {\n  transition-duration: 200ms;\n}\n\n.duration-300 {\n  transition-duration: 300ms;\n}\n\n.duration-500 {\n  transition-duration: 500ms;\n}\n\n.duration-700 {\n  transition-duration: 700ms;\n}\n\n.duration-1000 {\n  transition-duration: 1000ms;\n}\n\n.delay-75 {\n  transition-delay: 75ms;\n}\n\n.delay-100 {\n  transition-delay: 100ms;\n}\n\n.delay-150 {\n  transition-delay: 150ms;\n}\n\n.delay-200 {\n  transition-delay: 200ms;\n}\n\n.delay-300 {\n  transition-delay: 300ms;\n}\n\n.delay-500 {\n  transition-delay: 500ms;\n}\n\n.delay-700 {\n  transition-delay: 700ms;\n}\n\n.delay-1000 {\n  transition-delay: 1000ms;\n}\n\n@-webkit-keyframes spin {\n  to {\n    transform: rotate(360deg);\n  }\n}\n\n@keyframes spin {\n  to {\n    transform: rotate(360deg);\n  }\n}\n\n@-webkit-keyframes ping {\n  75%, 100% {\n    transform: scale(2);\n    opacity: 0;\n  }\n}\n\n@keyframes ping {\n  75%, 100% {\n    transform: scale(2);\n    opacity: 0;\n  }\n}\n\n@-webkit-keyframes pulse {\n  50% {\n    opacity: .5;\n  }\n}\n\n@keyframes pulse {\n  50% {\n    opacity: .5;\n  }\n}\n\n@-webkit-keyframes bounce {\n  0%, 100% {\n    transform: translateY(-25%);\n    -webkit-animation-timing-function: cubic-bezier(0.8,0,1,1);\n            animation-timing-function: cubic-bezier(0.8,0,1,1);\n  }\n\n  50% {\n    transform: none;\n    -webkit-animation-timing-function: cubic-bezier(0,0,0.2,1);\n            animation-timing-function: cubic-bezier(0,0,0.2,1);\n  }\n}\n\n@keyframes bounce {\n  0%, 100% {\n    transform: translateY(-25%);\n    -webkit-animation-timing-function: cubic-bezier(0.8,0,1,1);\n            animation-timing-function: cubic-bezier(0.8,0,1,1);\n  }\n\n  50% {\n    transform: none;\n    -webkit-animation-timing-function: cubic-bezier(0,0,0.2,1);\n            animation-timing-function: cubic-bezier(0,0,0.2,1);\n  }\n}\n\n.animate-none {\n  -webkit-animation: none;\n          animation: none;\n}\n\n.animate-spin {\n  -webkit-animation: spin 1s linear infinite;\n          animation: spin 1s linear infinite;\n}\n\n.animate-ping {\n  -webkit-animation: ping 1s cubic-bezier(0, 0, 0.2, 1) infinite;\n          animation: ping 1s cubic-bezier(0, 0, 0.2, 1) infinite;\n}\n\n.animate-pulse {\n  -webkit-animation: pulse 2s cubic-bezier(0.4, 0, 0.6, 1) infinite;\n          animation: pulse 2s cubic-bezier(0.4, 0, 0.6, 1) infinite;\n}\n\n.animate-bounce {\n  -webkit-animation: bounce 1s infinite;\n          animation: bounce 1s infinite;\n}\n\n.outline-transparent {\n  box-shadow: 0 0 0 3px transparent;\n}\n\n.outline-current {\n  box-shadow: 0 0 0 3px currentColor;\n}\n\n.outline-black {\n  box-shadow: 0 0 0 3px #000;\n}\n\n.outline-white {\n  box-shadow: 0 0 0 3px #fff;\n}\n\n.outline-gray-100 {\n  box-shadow: 0 0 0 3px #f7fafc;\n}\n\n.outline-gray-200 {\n  box-shadow: 0 0 0 3px #edf2f7;\n}\n\n.outline-gray-300 {\n  box-shadow: 0 0 0 3px #e2e8f0;\n}\n\n.outline-gray-400 {\n  box-shadow: 0 0 0 3px #cbd5e0;\n}\n\n.outline-gray-500 {\n  box-shadow: 0 0 0 3px #a0aec0;\n}\n\n.outline-gray-600 {\n  box-shadow: 0 0 0 3px #718096;\n}\n\n.outline-gray-700 {\n  box-shadow: 0 0 0 3px #4a5568;\n}\n\n.outline-gray-800 {\n  box-shadow: 0 0 0 3px #2d3748;\n}\n\n.outline-gray-900 {\n  box-shadow: 0 0 0 3px #1a202c;\n}\n\n.outline-red-100 {\n  box-shadow: 0 0 0 3px #fff5f5;\n}\n\n.outline-red-200 {\n  box-shadow: 0 0 0 3px #fed7d7;\n}\n\n.outline-red-300 {\n  box-shadow: 0 0 0 3px #feb2b2;\n}\n\n.outline-red-400 {\n  box-shadow: 0 0 0 3px #fc8181;\n}\n\n.outline-red-500 {\n  box-shadow: 0 0 0 3px #f56565;\n}\n\n.outline-red-600 {\n  box-shadow: 0 0 0 3px #e53e3e;\n}\n\n.outline-red-700 {\n  box-shadow: 0 0 0 3px #c53030;\n}\n\n.outline-red-800 {\n  box-shadow: 0 0 0 3px #9b2c2c;\n}\n\n.outline-red-900 {\n  box-shadow: 0 0 0 3px #742a2a;\n}\n\n.outline-orange-100 {\n  box-shadow: 0 0 0 3px #fffaf0;\n}\n\n.outline-orange-200 {\n  box-shadow: 0 0 0 3px #feebc8;\n}\n\n.outline-orange-300 {\n  box-shadow: 0 0 0 3px #fbd38d;\n}\n\n.outline-orange-400 {\n  box-shadow: 0 0 0 3px #f6ad55;\n}\n\n.outline-orange-500 {\n  box-shadow: 0 0 0 3px #ed8936;\n}\n\n.outline-orange-600 {\n  box-shadow: 0 0 0 3px #dd6b20;\n}\n\n.outline-orange-700 {\n  box-shadow: 0 0 0 3px #c05621;\n}\n\n.outline-orange-800 {\n  box-shadow: 0 0 0 3px #9c4221;\n}\n\n.outline-orange-900 {\n  box-shadow: 0 0 0 3px #7b341e;\n}\n\n.outline-yellow-100 {\n  box-shadow: 0 0 0 3px #fffff0;\n}\n\n.outline-yellow-200 {\n  box-shadow: 0 0 0 3px #fefcbf;\n}\n\n.outline-yellow-300 {\n  box-shadow: 0 0 0 3px #faf089;\n}\n\n.outline-yellow-400 {\n  box-shadow: 0 0 0 3px #f6e05e;\n}\n\n.outline-yellow-500 {\n  box-shadow: 0 0 0 3px #ecc94b;\n}\n\n.outline-yellow-600 {\n  box-shadow: 0 0 0 3px #d69e2e;\n}\n\n.outline-yellow-700 {\n  box-shadow: 0 0 0 3px #b7791f;\n}\n\n.outline-yellow-800 {\n  box-shadow: 0 0 0 3px #975a16;\n}\n\n.outline-yellow-900 {\n  box-shadow: 0 0 0 3px #744210;\n}\n\n.outline-green-100 {\n  box-shadow: 0 0 0 3px #f0fff4;\n}\n\n.outline-green-200 {\n  box-shadow: 0 0 0 3px #c6f6d5;\n}\n\n.outline-green-300 {\n  box-shadow: 0 0 0 3px #9ae6b4;\n}\n\n.outline-green-400 {\n  box-shadow: 0 0 0 3px #68d391;\n}\n\n.outline-green-500 {\n  box-shadow: 0 0 0 3px #48bb78;\n}\n\n.outline-green-600 {\n  box-shadow: 0 0 0 3px #38a169;\n}\n\n.outline-green-700 {\n  box-shadow: 0 0 0 3px #2f855a;\n}\n\n.outline-green-800 {\n  box-shadow: 0 0 0 3px #276749;\n}\n\n.outline-green-900 {\n  box-shadow: 0 0 0 3px #22543d;\n}\n\n.outline-teal-100 {\n  box-shadow: 0 0 0 3px #e6fffa;\n}\n\n.outline-teal-200 {\n  box-shadow: 0 0 0 3px #b2f5ea;\n}\n\n.outline-teal-300 {\n  box-shadow: 0 0 0 3px #81e6d9;\n}\n\n.outline-teal-400 {\n  box-shadow: 0 0 0 3px #4fd1c5;\n}\n\n.outline-teal-500 {\n  box-shadow: 0 0 0 3px #38b2ac;\n}\n\n.outline-teal-600 {\n  box-shadow: 0 0 0 3px #319795;\n}\n\n.outline-teal-700 {\n  box-shadow: 0 0 0 3px #2c7a7b;\n}\n\n.outline-teal-800 {\n  box-shadow: 0 0 0 3px #285e61;\n}\n\n.outline-teal-900 {\n  box-shadow: 0 0 0 3px #234e52;\n}\n\n.outline-blue-100 {\n  box-shadow: 0 0 0 3px #ebf8ff;\n}\n\n.outline-blue-200 {\n  box-shadow: 0 0 0 3px #bee3f8;\n}\n\n.outline-blue-300 {\n  box-shadow: 0 0 0 3px #90cdf4;\n}\n\n.outline-blue-400 {\n  box-shadow: 0 0 0 3px #63b3ed;\n}\n\n.outline-blue-500 {\n  box-shadow: 0 0 0 3px #4299e1;\n}\n\n.outline-blue-600 {\n  box-shadow: 0 0 0 3px #3182ce;\n}\n\n.outline-blue-700 {\n  box-shadow: 0 0 0 3px #2b6cb0;\n}\n\n.outline-blue-800 {\n  box-shadow: 0 0 0 3px #2c5282;\n}\n\n.outline-blue-900 {\n  box-shadow: 0 0 0 3px #2a4365;\n}\n\n.outline-indigo-100 {\n  box-shadow: 0 0 0 3px #ebf4ff;\n}\n\n.outline-indigo-200 {\n  box-shadow: 0 0 0 3px #c3dafe;\n}\n\n.outline-indigo-300 {\n  box-shadow: 0 0 0 3px #a3bffa;\n}\n\n.outline-indigo-400 {\n  box-shadow: 0 0 0 3px #7f9cf5;\n}\n\n.outline-indigo-500 {\n  box-shadow: 0 0 0 3px #667eea;\n}\n\n.outline-indigo-600 {\n  box-shadow: 0 0 0 3px #5a67d8;\n}\n\n.outline-indigo-700 {\n  box-shadow: 0 0 0 3px #4c51bf;\n}\n\n.outline-indigo-800 {\n  box-shadow: 0 0 0 3px #434190;\n}\n\n.outline-indigo-900 {\n  box-shadow: 0 0 0 3px #3c366b;\n}\n\n.outline-purple-100 {\n  box-shadow: 0 0 0 3px #faf5ff;\n}\n\n.outline-purple-200 {\n  box-shadow: 0 0 0 3px #e9d8fd;\n}\n\n.outline-purple-300 {\n  box-shadow: 0 0 0 3px #d6bcfa;\n}\n\n.outline-purple-400 {\n  box-shadow: 0 0 0 3px #b794f4;\n}\n\n.outline-purple-500 {\n  box-shadow: 0 0 0 3px #9f7aea;\n}\n\n.outline-purple-600 {\n  box-shadow: 0 0 0 3px #805ad5;\n}\n\n.outline-purple-700 {\n  box-shadow: 0 0 0 3px #6b46c1;\n}\n\n.outline-purple-800 {\n  box-shadow: 0 0 0 3px #553c9a;\n}\n\n.outline-purple-900 {\n  box-shadow: 0 0 0 3px #44337a;\n}\n\n.outline-pink-100 {\n  box-shadow: 0 0 0 3px #fff5f7;\n}\n\n.outline-pink-200 {\n  box-shadow: 0 0 0 3px #fed7e2;\n}\n\n.outline-pink-300 {\n  box-shadow: 0 0 0 3px #fbb6ce;\n}\n\n.outline-pink-400 {\n  box-shadow: 0 0 0 3px #f687b3;\n}\n\n.outline-pink-500 {\n  box-shadow: 0 0 0 3px #ed64a6;\n}\n\n.outline-pink-600 {\n  box-shadow: 0 0 0 3px #d53f8c;\n}\n\n.outline-pink-700 {\n  box-shadow: 0 0 0 3px #b83280;\n}\n\n.outline-pink-800 {\n  box-shadow: 0 0 0 3px #97266d;\n}\n\n.outline-pink-900 {\n  box-shadow: 0 0 0 3px #702459;\n}\n\n.outline-grayscale-80 {\n  box-shadow: 0 0 0 3px hsl(0, 0%, 8%);\n}\n\n.outline-grayscale-100 {\n  box-shadow: 0 0 0 3px hsl(0, 0%, 10%);\n}\n\n.outline-grayscale-200 {\n  box-shadow: 0 0 0 3px hsl(0, 0%, 20%);\n}\n\n.outline-grayscale-300 {\n  box-shadow: 0 0 0 3px hsl(0, 0%, 30%);\n}\n\n.outline-grayscale-400 {\n  box-shadow: 0 0 0 3px hsl(0, 0%, 40%);\n}\n\n.outline-grayscale-500 {\n  box-shadow: 0 0 0 3px hsl(0, 0%, 50%);\n}\n\n.outline-grayscale-600 {\n  box-shadow: 0 0 0 3px hsl(0, 0%, 60%);\n}\n\n.outline-grayscale-700 {\n  box-shadow: 0 0 0 3px hsl(0, 0%, 70%);\n}\n\n.outline-grayscale-800 {\n  box-shadow: 0 0 0 3px hsl(0, 0%, 80%);\n}\n\n.outline-grayscale-840 {\n  box-shadow: 0 0 0 3px hsl(0, 0%, 84%);\n}\n\n.outline-grayscale-870 {\n  box-shadow: 0 0 0 3px hsl(0, 0%, 87%);\n}\n\n.outline-grayscale-900 {\n  box-shadow: 0 0 0 3px hsl(0, 0%, 90%);\n}\n\n.outline-grayscale-930 {\n  box-shadow: 0 0 0 3px hsl(0, 0%, 93%);\n}\n\n.outline-primary {\n  box-shadow: 0 0 0 3px hsl(210, 100%, 52%);\n}\n\n.outline-background-main {\n  box-shadow: 0 0 0 3px var(--main-background);\n}\n\n.outline-background-secondary {\n  box-shadow: 0 0 0 3px var(--secondary-background);\n}\n\n.outline-foreground {\n  box-shadow: 0 0 0 3px var(--foreground);\n}\n\n.outline-panels-bg {\n  box-shadow: 0 0 0 3px var(--panels-background);\n}\n\n.focus\\:outline-transparent:focus {\n  box-shadow: 0 0 0 3px transparent;\n}\n\n.focus\\:outline-current:focus {\n  box-shadow: 0 0 0 3px currentColor;\n}\n\n.focus\\:outline-black:focus {\n  box-shadow: 0 0 0 3px #000;\n}\n\n.focus\\:outline-white:focus {\n  box-shadow: 0 0 0 3px #fff;\n}\n\n.focus\\:outline-gray-100:focus {\n  box-shadow: 0 0 0 3px #f7fafc;\n}\n\n.focus\\:outline-gray-200:focus {\n  box-shadow: 0 0 0 3px #edf2f7;\n}\n\n.focus\\:outline-gray-300:focus {\n  box-shadow: 0 0 0 3px #e2e8f0;\n}\n\n.focus\\:outline-gray-400:focus {\n  box-shadow: 0 0 0 3px #cbd5e0;\n}\n\n.focus\\:outline-gray-500:focus {\n  box-shadow: 0 0 0 3px #a0aec0;\n}\n\n.focus\\:outline-gray-600:focus {\n  box-shadow: 0 0 0 3px #718096;\n}\n\n.focus\\:outline-gray-700:focus {\n  box-shadow: 0 0 0 3px #4a5568;\n}\n\n.focus\\:outline-gray-800:focus {\n  box-shadow: 0 0 0 3px #2d3748;\n}\n\n.focus\\:outline-gray-900:focus {\n  box-shadow: 0 0 0 3px #1a202c;\n}\n\n.focus\\:outline-red-100:focus {\n  box-shadow: 0 0 0 3px #fff5f5;\n}\n\n.focus\\:outline-red-200:focus {\n  box-shadow: 0 0 0 3px #fed7d7;\n}\n\n.focus\\:outline-red-300:focus {\n  box-shadow: 0 0 0 3px #feb2b2;\n}\n\n.focus\\:outline-red-400:focus {\n  box-shadow: 0 0 0 3px #fc8181;\n}\n\n.focus\\:outline-red-500:focus {\n  box-shadow: 0 0 0 3px #f56565;\n}\n\n.focus\\:outline-red-600:focus {\n  box-shadow: 0 0 0 3px #e53e3e;\n}\n\n.focus\\:outline-red-700:focus {\n  box-shadow: 0 0 0 3px #c53030;\n}\n\n.focus\\:outline-red-800:focus {\n  box-shadow: 0 0 0 3px #9b2c2c;\n}\n\n.focus\\:outline-red-900:focus {\n  box-shadow: 0 0 0 3px #742a2a;\n}\n\n.focus\\:outline-orange-100:focus {\n  box-shadow: 0 0 0 3px #fffaf0;\n}\n\n.focus\\:outline-orange-200:focus {\n  box-shadow: 0 0 0 3px #feebc8;\n}\n\n.focus\\:outline-orange-300:focus {\n  box-shadow: 0 0 0 3px #fbd38d;\n}\n\n.focus\\:outline-orange-400:focus {\n  box-shadow: 0 0 0 3px #f6ad55;\n}\n\n.focus\\:outline-orange-500:focus {\n  box-shadow: 0 0 0 3px #ed8936;\n}\n\n.focus\\:outline-orange-600:focus {\n  box-shadow: 0 0 0 3px #dd6b20;\n}\n\n.focus\\:outline-orange-700:focus {\n  box-shadow: 0 0 0 3px #c05621;\n}\n\n.focus\\:outline-orange-800:focus {\n  box-shadow: 0 0 0 3px #9c4221;\n}\n\n.focus\\:outline-orange-900:focus {\n  box-shadow: 0 0 0 3px #7b341e;\n}\n\n.focus\\:outline-yellow-100:focus {\n  box-shadow: 0 0 0 3px #fffff0;\n}\n\n.focus\\:outline-yellow-200:focus {\n  box-shadow: 0 0 0 3px #fefcbf;\n}\n\n.focus\\:outline-yellow-300:focus {\n  box-shadow: 0 0 0 3px #faf089;\n}\n\n.focus\\:outline-yellow-400:focus {\n  box-shadow: 0 0 0 3px #f6e05e;\n}\n\n.focus\\:outline-yellow-500:focus {\n  box-shadow: 0 0 0 3px #ecc94b;\n}\n\n.focus\\:outline-yellow-600:focus {\n  box-shadow: 0 0 0 3px #d69e2e;\n}\n\n.focus\\:outline-yellow-700:focus {\n  box-shadow: 0 0 0 3px #b7791f;\n}\n\n.focus\\:outline-yellow-800:focus {\n  box-shadow: 0 0 0 3px #975a16;\n}\n\n.focus\\:outline-yellow-900:focus {\n  box-shadow: 0 0 0 3px #744210;\n}\n\n.focus\\:outline-green-100:focus {\n  box-shadow: 0 0 0 3px #f0fff4;\n}\n\n.focus\\:outline-green-200:focus {\n  box-shadow: 0 0 0 3px #c6f6d5;\n}\n\n.focus\\:outline-green-300:focus {\n  box-shadow: 0 0 0 3px #9ae6b4;\n}\n\n.focus\\:outline-green-400:focus {\n  box-shadow: 0 0 0 3px #68d391;\n}\n\n.focus\\:outline-green-500:focus {\n  box-shadow: 0 0 0 3px #48bb78;\n}\n\n.focus\\:outline-green-600:focus {\n  box-shadow: 0 0 0 3px #38a169;\n}\n\n.focus\\:outline-green-700:focus {\n  box-shadow: 0 0 0 3px #2f855a;\n}\n\n.focus\\:outline-green-800:focus {\n  box-shadow: 0 0 0 3px #276749;\n}\n\n.focus\\:outline-green-900:focus {\n  box-shadow: 0 0 0 3px #22543d;\n}\n\n.focus\\:outline-teal-100:focus {\n  box-shadow: 0 0 0 3px #e6fffa;\n}\n\n.focus\\:outline-teal-200:focus {\n  box-shadow: 0 0 0 3px #b2f5ea;\n}\n\n.focus\\:outline-teal-300:focus {\n  box-shadow: 0 0 0 3px #81e6d9;\n}\n\n.focus\\:outline-teal-400:focus {\n  box-shadow: 0 0 0 3px #4fd1c5;\n}\n\n.focus\\:outline-teal-500:focus {\n  box-shadow: 0 0 0 3px #38b2ac;\n}\n\n.focus\\:outline-teal-600:focus {\n  box-shadow: 0 0 0 3px #319795;\n}\n\n.focus\\:outline-teal-700:focus {\n  box-shadow: 0 0 0 3px #2c7a7b;\n}\n\n.focus\\:outline-teal-800:focus {\n  box-shadow: 0 0 0 3px #285e61;\n}\n\n.focus\\:outline-teal-900:focus {\n  box-shadow: 0 0 0 3px #234e52;\n}\n\n.focus\\:outline-blue-100:focus {\n  box-shadow: 0 0 0 3px #ebf8ff;\n}\n\n.focus\\:outline-blue-200:focus {\n  box-shadow: 0 0 0 3px #bee3f8;\n}\n\n.focus\\:outline-blue-300:focus {\n  box-shadow: 0 0 0 3px #90cdf4;\n}\n\n.focus\\:outline-blue-400:focus {\n  box-shadow: 0 0 0 3px #63b3ed;\n}\n\n.focus\\:outline-blue-500:focus {\n  box-shadow: 0 0 0 3px #4299e1;\n}\n\n.focus\\:outline-blue-600:focus {\n  box-shadow: 0 0 0 3px #3182ce;\n}\n\n.focus\\:outline-blue-700:focus {\n  box-shadow: 0 0 0 3px #2b6cb0;\n}\n\n.focus\\:outline-blue-800:focus {\n  box-shadow: 0 0 0 3px #2c5282;\n}\n\n.focus\\:outline-blue-900:focus {\n  box-shadow: 0 0 0 3px #2a4365;\n}\n\n.focus\\:outline-indigo-100:focus {\n  box-shadow: 0 0 0 3px #ebf4ff;\n}\n\n.focus\\:outline-indigo-200:focus {\n  box-shadow: 0 0 0 3px #c3dafe;\n}\n\n.focus\\:outline-indigo-300:focus {\n  box-shadow: 0 0 0 3px #a3bffa;\n}\n\n.focus\\:outline-indigo-400:focus {\n  box-shadow: 0 0 0 3px #7f9cf5;\n}\n\n.focus\\:outline-indigo-500:focus {\n  box-shadow: 0 0 0 3px #667eea;\n}\n\n.focus\\:outline-indigo-600:focus {\n  box-shadow: 0 0 0 3px #5a67d8;\n}\n\n.focus\\:outline-indigo-700:focus {\n  box-shadow: 0 0 0 3px #4c51bf;\n}\n\n.focus\\:outline-indigo-800:focus {\n  box-shadow: 0 0 0 3px #434190;\n}\n\n.focus\\:outline-indigo-900:focus {\n  box-shadow: 0 0 0 3px #3c366b;\n}\n\n.focus\\:outline-purple-100:focus {\n  box-shadow: 0 0 0 3px #faf5ff;\n}\n\n.focus\\:outline-purple-200:focus {\n  box-shadow: 0 0 0 3px #e9d8fd;\n}\n\n.focus\\:outline-purple-300:focus {\n  box-shadow: 0 0 0 3px #d6bcfa;\n}\n\n.focus\\:outline-purple-400:focus {\n  box-shadow: 0 0 0 3px #b794f4;\n}\n\n.focus\\:outline-purple-500:focus {\n  box-shadow: 0 0 0 3px #9f7aea;\n}\n\n.focus\\:outline-purple-600:focus {\n  box-shadow: 0 0 0 3px #805ad5;\n}\n\n.focus\\:outline-purple-700:focus {\n  box-shadow: 0 0 0 3px #6b46c1;\n}\n\n.focus\\:outline-purple-800:focus {\n  box-shadow: 0 0 0 3px #553c9a;\n}\n\n.focus\\:outline-purple-900:focus {\n  box-shadow: 0 0 0 3px #44337a;\n}\n\n.focus\\:outline-pink-100:focus {\n  box-shadow: 0 0 0 3px #fff5f7;\n}\n\n.focus\\:outline-pink-200:focus {\n  box-shadow: 0 0 0 3px #fed7e2;\n}\n\n.focus\\:outline-pink-300:focus {\n  box-shadow: 0 0 0 3px #fbb6ce;\n}\n\n.focus\\:outline-pink-400:focus {\n  box-shadow: 0 0 0 3px #f687b3;\n}\n\n.focus\\:outline-pink-500:focus {\n  box-shadow: 0 0 0 3px #ed64a6;\n}\n\n.focus\\:outline-pink-600:focus {\n  box-shadow: 0 0 0 3px #d53f8c;\n}\n\n.focus\\:outline-pink-700:focus {\n  box-shadow: 0 0 0 3px #b83280;\n}\n\n.focus\\:outline-pink-800:focus {\n  box-shadow: 0 0 0 3px #97266d;\n}\n\n.focus\\:outline-pink-900:focus {\n  box-shadow: 0 0 0 3px #702459;\n}\n\n.focus\\:outline-grayscale-80:focus {\n  box-shadow: 0 0 0 3px hsl(0, 0%, 8%);\n}\n\n.focus\\:outline-grayscale-100:focus {\n  box-shadow: 0 0 0 3px hsl(0, 0%, 10%);\n}\n\n.focus\\:outline-grayscale-200:focus {\n  box-shadow: 0 0 0 3px hsl(0, 0%, 20%);\n}\n\n.focus\\:outline-grayscale-300:focus {\n  box-shadow: 0 0 0 3px hsl(0, 0%, 30%);\n}\n\n.focus\\:outline-grayscale-400:focus {\n  box-shadow: 0 0 0 3px hsl(0, 0%, 40%);\n}\n\n.focus\\:outline-grayscale-500:focus {\n  box-shadow: 0 0 0 3px hsl(0, 0%, 50%);\n}\n\n.focus\\:outline-grayscale-600:focus {\n  box-shadow: 0 0 0 3px hsl(0, 0%, 60%);\n}\n\n.focus\\:outline-grayscale-700:focus {\n  box-shadow: 0 0 0 3px hsl(0, 0%, 70%);\n}\n\n.focus\\:outline-grayscale-800:focus {\n  box-shadow: 0 0 0 3px hsl(0, 0%, 80%);\n}\n\n.focus\\:outline-grayscale-840:focus {\n  box-shadow: 0 0 0 3px hsl(0, 0%, 84%);\n}\n\n.focus\\:outline-grayscale-870:focus {\n  box-shadow: 0 0 0 3px hsl(0, 0%, 87%);\n}\n\n.focus\\:outline-grayscale-900:focus {\n  box-shadow: 0 0 0 3px hsl(0, 0%, 90%);\n}\n\n.focus\\:outline-grayscale-930:focus {\n  box-shadow: 0 0 0 3px hsl(0, 0%, 93%);\n}\n\n.focus\\:outline-primary:focus {\n  box-shadow: 0 0 0 3px hsl(210, 100%, 52%);\n}\n\n.focus\\:outline-background-main:focus {\n  box-shadow: 0 0 0 3px var(--main-background);\n}\n\n.focus\\:outline-background-secondary:focus {\n  box-shadow: 0 0 0 3px var(--secondary-background);\n}\n\n.focus\\:outline-foreground:focus {\n  box-shadow: 0 0 0 3px var(--foreground);\n}\n\n.focus\\:outline-panels-bg:focus {\n  box-shadow: 0 0 0 3px var(--panels-background);\n}\n\n:root {\n  --main-scroll: hsl(0, 0%, 30%);\n  --panels-scroll: hsl(180, 2%, 17%);\n  --tag-background: hsl(210, 100%, 38%);\n  --tag-text: #fff;\n  --toast-background: hsla(240, 12%, 16%, 0.85);\n  --toast-secondary: hsla(240, 12%, 16%, 0.15);\n  --toast-text: hsla(0, 0%, 100%, 0.85);\n  --primary-color: hsl(210, 100%, 52%);\n  --primary-text: hsl(0, 0%, 87%);\n  --secondary-color: hsl(46, 100%, 57%);\n}\n\n:root[data-theme='light'] {\n  --main-background: #fff;\n  --secondary-background: hsl(0, 0%, 93%);\n  --foreground: hsl(0, 0%, 20%);\n  --panels-background: hsl(216, 4%, 78%);\n  --table-bg: #fff;\n  --table-zebra: hsl(0, 0%, 90%);\n  --table-highlight: hsl(0, 0%, 84%);\n}\n\n:root[data-theme='dark'] {\n  --main-background: hsl(240, 10%, 8%);\n  --secondary-background: hsl(240, 12%, 16%);\n  --foreground: hsl(0, 0%, 93%);\n  --panels-background: hsl(240, 15%, 12%);\n  --table-bg: hsl(240, 10%, 8%);\n  --table-zebra: hsl(240, 15%, 11%);\n  --table-highlight: hsl(240, 10%, 22%);\n}\n\n:root[data-theme='purple'] {\n  --main-background: hsl(261, 74%, 6%);\n  --secondary-background: hsl(257, 61%, 10%);\n  --foreground: hsl(0, 0%, 93%);\n  --panels-background: hsl(257, 70%, 9%);\n  --table-bg: hsl(261, 74%, 6%);\n  --table-zebra: hsl(257, 61%, 10%);\n  --table-highlight: hsl(257, 66%, 27%);\n}\n\nhtml {\n  height: 100vh;\n}\n\nbody {\n  margin: 0px;\n  width: 100%;\n  height: 100%;\n  font-family: 'Open Sans', 'sans-serif';\n  overflow: hidden;\n  background: var(--main-background);\n  color: var(--foreground);\n}\n\n* {\n  margin: 0;\n  padding: 0;\n  box-sizing: border-box;\n}\n\n:root {\n  font-size: 16px;\n}\n\ntable,\ncaption,\ntbody,\ntfoot,\nthead,\ntr,\nth,\ntd {\n  margin: 0;\n  padding: 0;\n  border: 0;\n  font-size: 100%;\n  font: inherit;\n  vertical-align: baseline;\n}\n\ntable {\n  border-collapse: collapse;\n  border-spacing: 0;\n}\n\n/* Taken from Tailwind Preflight */\n\nbutton,\n[type='button'],\n[type='reset'],\n[type='submit'] {\n  -webkit-appearance: button;\n}\n\ninput[type='text'],\ninput[type='password'],\ninput[type='number'],\ninput[type='search'],\ninput[type='checkbox'],\nselect {\n  -webkit-appearance: none;\n  -moz-appearance: none;\n       appearance: none;\n}\n\n[type='number']::-webkit-inner-spin-button,\n[type='number']::-webkit-outer-spin-button {\n  height: auto;\n}\n\nbutton,\n[role='button'] {\n  cursor: pointer;\n}\n\n*,\n::before,\n::after {\n  border-width: 0;\n  border-style: solid;\n}\n\n@keyframes spin {\n  0% {\n    transform: rotate(0deg);\n  }\n\n  100% {\n    transform: rotate(360deg);\n  }\n}\n\n@-webkit-keyframes indeterminate {\n  0% {\n    left: -35%;\n    right: 100%;\n  }\n\n  60% {\n    left: 100%;\n    right: -90%;\n  }\n\n  100% {\n    left: 100%;\n    right: -90%;\n  }\n}\n\n@keyframes indeterminate {\n  0% {\n    left: -35%;\n    right: 100%;\n  }\n\n  60% {\n    left: 100%;\n    right: -90%;\n  }\n\n  100% {\n    left: 100%;\n    right: -90%;\n  }\n}\n\n@-webkit-keyframes indeterminate-short {\n  0% {\n    left: -200%;\n    right: 100%;\n  }\n\n  60% {\n    left: 107%;\n    right: -8%;\n  }\n\n  100% {\n    left: 107%;\n    right: -8%;\n  }\n}\n\n@keyframes indeterminate-short {\n  0% {\n    left: -200%;\n    right: 100%;\n  }\n\n  60% {\n    left: 107%;\n    right: -8%;\n  }\n\n  100% {\n    left: 107%;\n    right: -8%;\n  }\n}\n\ninput[type='text'],\ninput[type='password'],\ninput[type='number'] {\n  width: calc(100% - 16px);\n  border: 0px solid black;\n  line-height: 36px;\n  padding: 0px 8px;\n  border-radius: 4px;\n  background-color: var(--secondary-background);\n  color: var(--foreground);\n  margin-bottom: 8px;\n}\n\ninput[type='search']::-webkit-search-cancel-button {\n  -webkit-appearance: none;\n  width: 28px;\n  height: 28px;\n  background-color: var(--foreground);\n  -webkit-mask-image: url(\"data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' height='28' viewBox='0 0 24 24' width='28'%3E%%3Cpath fill='%23ffffff' d='M22 3H7c-.69 0-1.23.35-1.59.88L0 12l5.41 8.11c.36.53.9.89 1.59.89h15c1.1 0 2-.9 2-2V5c0-1.1-.9-2-2-2zm-3 12.59L17.59 17 14 13.41 10.41 17 9 15.59 12.59 12 9 8.41 10.41 7 14 10.59 17.59 7 19 8.41 15.41 12 19 15.59z'/%3E3Cpath d='M0 0h24v24H0z' fill='none'/%3E%3C/svg%3E\");\n  mask-image: url(\"data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' height='28' viewBox='0 0 24 24' width='28'%3E%%3Cpath fill='%23ffffff' d='M22 3H7c-.69 0-1.23.35-1.59.88L0 12l5.41 8.11c.36.53.9.89 1.59.89h15c1.1 0 2-.9 2-2V5c0-1.1-.9-2-2-2zm-3 12.59L17.59 17 14 13.41 10.41 17 9 15.59 12.59 12 9 8.41 10.41 7 14 10.59 17.59 7 19 8.41 15.41 12 19 15.59z'/%3E3Cpath d='M0 0h24v24H0z' fill='none'/%3E%3C/svg%3E\");\n}\n\ninput[type='checkbox'] {\n  background-color: none;\n  border: 2px solid gray;\n  opacity: 0.5;\n  border-radius: 2px;\n  padding: 7px;\n  margin: 3px;\n  display: inline-block;\n  position: relative;\n}\n\ninput[type='checkbox']:checked {\n  opacity: 1;\n  background-color: var(--primary-color);\n  background-image: url(\"data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' height='18' viewBox='3 3 18 18' width='18'%3E%3Cpath fill='%23ffffff' d='M 10,17 5,12 6.41,10.59 10,14.17 17.59,6.58 19,8 Z'/%3E%3Cpath d='M0 0h24v24H0z' fill='none'/%3E%3C/svg%3E\");\n  background-position: center center;\n  border: 0px solid var(--primary-color);\n  border-radius: 2px;\n  padding: 9px;\n  margin: 3px;\n  color: var(--primary-text);\n}\n\nselect {\n  width: 100%;\n  border: 0px solid black;\n  line-height: 36px;\n  padding: 0px 40px 0px 8px;\n  border-radius: 4px;\n  background-color: var(--secondary-background);\n  background-image: url(\"data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' height='24' viewBox='0 0 24 24' width='24'%3E%3Cpath style='fill%3A%23000000%3Bfill-opacity%3A0.25' d='M7 10l5 5 5-5z'/%3E%3Cpath d='M0 0h24v24H0z' fill='none'/%3E%3C/svg%3E\");\n  background-repeat: no-repeat;\n  background-size: 24px;\n  background-position: calc(100% - 8px) center;\n  background-clip: border-box;\n  color: var(--foreground);\n  margin-bottom: 8px;\n}\n\np {\n  word-break: break-word;\n}\n\nimg.rounded {\n  border-radius: 5px;\n}\n\nimg.circle {\n  border-radius: 50%;\n}\n\ni.disabled {\n  opacity: 0.5;\n  cursor: default;\n}\n\ni.explicit_icon {\n  color: #91919c;\n  margin-right: 0.3125em;\n  margin-left: -3px;\n}\n\ni.explicit_icon.explicit_icon--right {\n  margin-left: 0.3125em;\n  margin-right: 0px;\n}\n\nspan.tag {\n  background-color: var(--tag-background);\n  border-radius: 2px;\n  color: var(--tag-text);\n  display: inline-block;\n  font-size: 10px;\n  padding: 3px 6px;\n  text-transform: capitalize;\n}\n\na.single-cover {\n  position: relative;\n  display: inline-block;\n  color: white;\n}\n\n.clickable {\n  cursor: pointer !important;\n}\n\n.table--tracklist .clickable:hover,\n.table--charts .clickable:hover {\n  text-decoration: underline;\n}\n\n.fixed_footer footer {\n  position: -webkit-sticky;\n  position: sticky;\n  display: flex;\n  align-items: center;\n  flex-direction: row;\n  justify-content: flex-end;\n  background-color: var(--main-background);\n  bottom: 0px;\n  height: 64px;\n  width: 100%;\n  margin-top: 24px;\n}\n\n.fab {\n  width: 56px;\n  height: 56px;\n  border-radius: 28px;\n  display: inline-block;\n  background-color: var(--primary-color);\n  color: var(--primary-text);\n  cursor: pointer;\n}\n\n.fab i {\n  font-size: 24px;\n  padding: 16px;\n}\n\n.with_checkbox {\n  display: flex;\n  align-items: center;\n}\n\n.with_checkbox [type='checkbox'] {\n  cursor: pointer;\n}\n\n.with_checkbox .checkbox_text {\n  margin-left: 10px;\n  cursor: pointer;\n  -webkit-user-select: none;\n     -moz-user-select: none;\n      -ms-user-select: none;\n          user-select: none;\n}\n\n.loading_placeholder {\n  display: flex;\n  justify-content: center;\n  align-items: center;\n  flex-direction: column;\n  flex: 1;\n  height: 100%;\n}\n\n.loading_placeholder.loading_placeholder--hidden {\n  display: none;\n}\n\n.loading_placeholder__text {\n  margin-bottom: 20px;\n}\n\n.loading_placeholder#search_placeholder {\n  height: calc(100% - 93px);\n}\n\n.loading_placeholder#start_app_placeholder {\n  position: absolute;\n  top: 0;\n  left: 0;\n  width: 100vw;\n  height: 100vh;\n  background: black;\n  z-index: 1000;\n}\n\n.coverart {\n  background-color: var(--secondary-background);\n}\n\n.cover_container {\n  position: relative;\n}\n\n.cover_container .coverart {\n  opacity: 1;\n  display: block;\n  width: 100%;\n  height: auto;\n  transition: 0.5s ease;\n  -webkit-backface-visibility: hidden;\n          backface-visibility: hidden;\n}\n\n.cover_container .download_overlay {\n  transition: 0.5s ease;\n  opacity: 0;\n  position: absolute;\n  top: 50%;\n  left: 50%;\n  transform: translate(-50%, -50%);\n  text-align: center;\n  background-color: #000000;\n  border-radius: 50%;\n  min-width: 32px;\n  padding: 0px;\n  height: 44px;\n  border: 0px;\n}\n\n.cover_container .download_overlay i {\n  color: white;\n  padding: 10px;\n  cursor: pointer;\n}\n\n.cover_container .download_overlay:focus {\n  opacity: 1;\n}\n\n.cover_container:hover .coverart {\n  opacity: 0.75;\n}\n\n.cover_container:hover .download_overlay {\n  opacity: 1;\n  border: 0px;\n}\n\n.inline-flex {\n  display: flex;\n  align-items: center;\n}\n\n.inline-flex .right {\n  margin-left: auto;\n}\n\n.right {\n  float: right;\n}\n\n.hide {\n  display: none !important;\n}\n\n.changing-theme {\n  transition: all 200ms ease-in-out;\n}\n\n[v-cloak] {\n  display: none;\n}\n\n.material-icons {\n  -webkit-user-select: none;\n     -moz-user-select: none;\n      -ms-user-select: none;\n          user-select: none;\n}\n\n.material-icons.md-18 {\n  font-size: 18px;\n}\n\n.material-icons.md-24 {\n  font-size: 24px;\n}\n\n.material-icons.md-36 {\n  font-size: 36px;\n}\n\n.material-icons.md-48 {\n  font-size: 48px;\n}\n\n.material-icons.mirrored {\n  transform: scaleX(-1);\n}\n\n.table {\n  width: 100%;\n  -webkit-border-horizontal-spacing: 0px;\n  -webkit-border-vertical-spacing: 0px;\n  /* === Tracks Table === */\n  /* === Tracklist Table === */\n  /* === Charts Table === */\n}\n\n.table tbody tr:not(.table__row-no-highlight):hover {\n  background: var(--table-highlight);\n  cursor: default;\n}\n\n.table tr {\n  background: var(--table-bg);\n  transition: background-color 175ms ease-in-out;\n}\n\n.table tr:nth-child(even) {\n  background: var(--table-zebra);\n  transition: background-color 175ms ease-in-out;\n}\n\n.table tr:not(:last-child) {\n  border-bottom: 1px solid var(--table-highlight);\n}\n\n.table td,\n  .table th {\n  vertical-align: middle;\n}\n\n.table th .sortable {\n  -webkit-user-select: none;\n  -moz-user-select: none;\n   -ms-user-select: none;\n       user-select: none;\n}\n\n.table th .sort-asc::after,\n  .table th .sort-desc::after {\n  font-size: 0.7em;\n  padding-left: 3px;\n  line-height: 0.7em;\n}\n\n.table th .sort-asc::after {\n  content: '\\25b2';\n}\n\n.table th .sort-desc::after {\n  content: '\\25bc';\n}\n\n.table td {\n  padding: 7px 10px;\n}\n\n.table td:first-child {\n  padding: 7px 10px 7px 20px;\n}\n\n.table td:last-child {\n  padding: 7px 20px 7px 10px;\n}\n\n.table td img {\n  vertical-align: middle;\n}\n\n.table--tracks {\n  border-collapse: collapse;\n}\n\n.table--tracks thead {\n  border-bottom: 2px solid var(--table-highlight);\n}\n\n.table--tracks th {\n  padding-bottom: 10px;\n  height: 45px;\n}\n\n.table--tracks td {\n  height: 35px;\n}\n\n.table--tracks td.breakline {\n  word-break: break-word;\n}\n\n.table--tracks tr:first-child td:first-child {\n  border-top-left-radius: 3px;\n}\n\n.table--tracks tr:first-child td:last-child {\n  border-top-right-radius: 3px;\n}\n\n.table--tracks tr:last-child td:first-child {\n  border-bottom-left-radius: 3px;\n}\n\n.table--tracks tr:last-child td:last-child {\n  border-bottom-right-radius: 3px;\n}\n\n.table--tracklist thead {\n  border-bottom: 2px solid var(--table-highlight);\n  text-transform: capitalize;\n}\n\n.table--tracklist th {\n  height: 45px;\n  padding: 7px 10px;\n}\n\n.table--tracklist th:first-child {\n  padding: 7px 10px 7px 20px;\n}\n\n.table--tracklist th:last-child {\n  padding: 7px 20px 7px 10px;\n}\n\n.table--tracklist td {\n  height: 35px;\n}\n\n.table--charts td {\n  height: 35px;\n}\n\n.table .table__icon {\n  box-sizing: content-box;\n  width: 32px;\n}\n\n.table .table__icon--big {\n  width: 48px;\n  text-align: center;\n}\n\n.table .table__cell--x-small {\n  width: 0.32%;\n}\n\n.table .table__cell--small {\n  width: 3.2%;\n}\n\n.table .table__cell--medium {\n  width: 28.7%;\n}\n\n.table .table__cell--large {\n  width: 50%;\n}\n\n.table .table__cell--left {\n  text-align: left;\n}\n\n.table .table__cell--center {\n  text-align: center;\n}\n\n.table .table__cell--right {\n  text-align: right;\n}\n\n.table .table__cell--download {\n  cursor: pointer;\n}\n\n.table .table__cell--download i.material-icons {\n  transition: color 175ms ease-in-out;\n}\n\n.table .table__cell--download:hover i.material-icons {\n  --text-opacity: 1;\n  color: hsl(210, 100%, 52%);\n  color: rgba(10.20000000000001, 132.59999999999988, 255, var(--text-opacity));\n}\n\n.table .table__cell-content.table__cell-content--vertical-center {\n  display: flex;\n  align-items: center;\n}\n\n.track_row > td > img {\n  width: 32px;\n  height: 32px;\n}\n\n.track_row > td > a > img {\n  width: 56px;\n  height: 56px;\n}\n\n.top-tracks-position {\n  padding: 12px;\n  text-align: center;\n  cursor: default;\n}\n\n#download_tab_container #queue_buttons {\n  position: absolute;\n  top: 0;\n  right: 0;\n  opacity: 1;\n  visibility: visible;\n  transition: all 250ms ease-in-out;\n}\n\n#download_tab_container.tab_hidden {\n  width: 32px;\n}\n\n#download_tab_container.tab_hidden #toggle_download_tab {\n  margin-left: 4px;\n}\n\n#download_tab_container.tab_hidden #toggle_download_tab::before {\n  content: 'chevron_left';\n}\n\n#download_tab_container.tab_hidden #queue_buttons {\n  opacity: 0;\n  visibility: hidden;\n}\n\n#download_tab_container.tab_hidden::after {\n  content: attr(data-label);\n  display: flex;\n  align-items: center;\n  text-transform: capitalize;\n  -ms-writing-mode: tb-rl;\n      writing-mode: vertical-rl;\n  line-height: 32px;\n}\n\n#toggle_download_tab {\n  width: 25px;\n  height: 25px;\n  margin-left: 20px;\n}\n\n#toggle_download_tab::before {\n  font-family: 'Material Icons';\n  font-style: normal;\n  font-weight: 400;\n  content: 'chevron_right';\n}\n\n#main_search .search_section {\n  float: none;\n  padding-top: 20px;\n  padding-bottom: 20px;\n}\n\n#main_search .search_section:not(:first-child) {\n  border-top: 1px solid hsl(0, 0%, 50%);\n}\n\n#main_search .top_result_header {\n  display: block;\n  cursor: default;\n  font-size: 2rem;\n  text-align: center;\n}\n\n.search_header {\n  display: inline-block;\n  cursor: pointer;\n  font-size: 1.75rem;\n  margin-bottom: 25px;\n  text-transform: capitalize;\n}\n\n.search_header:not(.top_result_header) {\n  transition: color 200ms ease-in-out;\n}\n\n.search_header:not(.top_result_header):hover {\n  color: var(--primary-color);\n}\n\n/* Top Result */\n\n.top_result {\n  display: flex;\n  align-items: center;\n  flex-direction: column;\n}\n\n.top_result > .cover_container {\n  width: 156px;\n  height: 156px;\n}\n\n.top_result .info_box {\n  display: flex;\n  flex-direction: column;\n  justify-content: center;\n  align-items: center;\n  margin-top: 15px;\n}\n\n.top_result .info_box .primary-text,\n    .top_result .info_box .secondary-text {\n  font-size: 18px;\n  text-align: center;\n}\n\n.top_result .info_box .primary-text {\n  margin-bottom: 5px;\n}\n\n.top_result .info_box .secondary-text {\n  margin-bottom: 10px;\n}\n\n.top_result .info_box .tag {\n  width: 40px;\n  text-align: center;\n}\n\n/* Releases */\n\n.release .primary-text,\n.release .secondary-text {\n  margin: 0px;\n  margin-bottom: 4px;\n}\n\n.release .secondary-text {\n  opacity: 0.75;\n  font-size: 14px;\n}\n\n.release .secondary-text .material-icons {\n  font-size: 17px !important;\n  margin-left: 4px;\n}\n\n.release_grid {\n  display: grid;\n  grid-template-columns: repeat(auto-fill, minmax(156px, 1fr));\n  grid-gap: 1rem;\n}\n\n.release_grid.firstrow_only {\n  grid-template-rows: 1fr;\n  grid-auto-rows: 0;\n  grid-row-gap: 0px;\n  overflow-y: hidden;\n}\n\n#settings_picture {\n  width: 125px;\n  height: 125px;\n}\n\n#log_info {\n  display: flex;\n  flex-direction: column;\n  align-items: center;\n}\n\n#open_login_prompt {\n  margin: 8px 0px;\n}\n\n.inline-flex input {\n  margin-bottom: 0px;\n}\n\n#spotify_icon {\n  width: 24px;\n  height: 24px;\n  fill: #1db954;\n  margin-right: 15px;\n}\n\n/* Settings group */\n\n.settings-group {\n  display: flex;\n  flex-direction: column;\n  justify-content: center;\n  border-top: 1px solid hsl(0, 0%, 50%);\n  /* Need less opacity */\n  padding-top: 20px;\n  padding-bottom: 20px;\n}\n\n.settings-group > * {\n  margin-bottom: 15px;\n}\n\n/* Settings group header */\n\n.settings-group__header {\n  font-size: 1.5rem;\n  margin-bottom: 25px;\n}\n\n.settings-group__header.settings-group__header--with-icon {\n  display: inline-flex;\n  align-items: center;\n}\n\n.settings-group__header.settings-group__header--with-icon i.material-icons {\n  margin-right: 15px;\n}\n\n/* Settings container */\n\n.settings-container {\n  display: flex;\n}\n\n.settings-container__half {\n  width: 50%;\n}\n\n.settings-container__third {\n  width: 33%;\n}\n\n.settings-container__third--only-checkbox {\n  display: flex;\n  flex-direction: column;\n  justify-content: center;\n  align-items: start;\n}\n\n.settings-container__half > *,\n  .settings-container__third > * {\n  margin-bottom: 15px;\n}\n\n/* Input group */\n\n.input_group {\n  margin-bottom: 25px;\n}\n\n.input_group .input_group_text {\n  margin-bottom: 7px;\n}\n\n.with_checkbox + .input_group {\n  margin-top: 10px;\n}\n\n.release {\n  display: inline-block;\n  width: 156px;\n}\n\n.release .cover_container {\n  width: 156px;\n  height: 156px;\n  margin-bottom: 10px;\n}\n\n#container {\n  --container-width: 95%;\n}\n\n@media only screen and (min-width: 601px) {\n  #container {\n    --container-width: 85%;\n  }\n}\n\n@media only screen and (min-width: 993px) {\n  #container {\n    --container-width: 70%;\n  }\n}\n\n/* Modal Content */\n\n.smallmodal-content {\n  --modal-content-width: 95%;\n}\n\n@media only screen and (min-width: 601px) {\n  .smallmodal-content {\n    --modal-content-width: 85%;\n  }\n}\n\n@media only screen and (min-width: 993px) {\n  .smallmodal-content {\n    --modal-content-width: 70%;\n  }\n}\n\n.image_header header {\n  background-size: cover;\n  padding-top: 14rem;\n  padding-left: 1.5rem;\n  padding-right: 1.5rem;\n  padding-bottom: 0.5rem;\n  border-top-left-radius: 0.5rem;\n  border-top-right-radius: 0.5rem;\n  background-position: 0% 35%;\n}\n\n@media (min-width: 640px) {\n  .sm\\:container {\n    width: 100%;\n  }\n\n  @media (min-width: 640px) {\n    .sm\\:container {\n      max-width: 640px;\n    }\n  }\n\n  @media (min-width: 768px) {\n    .sm\\:container {\n      max-width: 768px;\n    }\n  }\n\n  @media (min-width: 1024px) {\n    .sm\\:container {\n      max-width: 1024px;\n    }\n  }\n\n  @media (min-width: 1280px) {\n    .sm\\:container {\n      max-width: 1280px;\n    }\n  }\n\n  .sm\\:space-y-0 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(0px * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(0px * var(--space-y-reverse));\n  }\n\n  .sm\\:space-x-0 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(0px * var(--space-x-reverse));\n    margin-left: calc(0px * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:space-y-1 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(0.25rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(0.25rem * var(--space-y-reverse));\n  }\n\n  .sm\\:space-x-1 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(0.25rem * var(--space-x-reverse));\n    margin-left: calc(0.25rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:space-y-2 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(0.5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(0.5rem * var(--space-y-reverse));\n  }\n\n  .sm\\:space-x-2 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(0.5rem * var(--space-x-reverse));\n    margin-left: calc(0.5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:space-y-3 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(0.75rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(0.75rem * var(--space-y-reverse));\n  }\n\n  .sm\\:space-x-3 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(0.75rem * var(--space-x-reverse));\n    margin-left: calc(0.75rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:space-y-4 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(1rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(1rem * var(--space-y-reverse));\n  }\n\n  .sm\\:space-x-4 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(1rem * var(--space-x-reverse));\n    margin-left: calc(1rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:space-y-5 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(1.25rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(1.25rem * var(--space-y-reverse));\n  }\n\n  .sm\\:space-x-5 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(1.25rem * var(--space-x-reverse));\n    margin-left: calc(1.25rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:space-y-6 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(1.5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(1.5rem * var(--space-y-reverse));\n  }\n\n  .sm\\:space-x-6 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(1.5rem * var(--space-x-reverse));\n    margin-left: calc(1.5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:space-y-8 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(2rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(2rem * var(--space-y-reverse));\n  }\n\n  .sm\\:space-x-8 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(2rem * var(--space-x-reverse));\n    margin-left: calc(2rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:space-y-10 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(2.5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(2.5rem * var(--space-y-reverse));\n  }\n\n  .sm\\:space-x-10 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(2.5rem * var(--space-x-reverse));\n    margin-left: calc(2.5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:space-y-12 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(3rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(3rem * var(--space-y-reverse));\n  }\n\n  .sm\\:space-x-12 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(3rem * var(--space-x-reverse));\n    margin-left: calc(3rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:space-y-16 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(4rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(4rem * var(--space-y-reverse));\n  }\n\n  .sm\\:space-x-16 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(4rem * var(--space-x-reverse));\n    margin-left: calc(4rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:space-y-20 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(5rem * var(--space-y-reverse));\n  }\n\n  .sm\\:space-x-20 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(5rem * var(--space-x-reverse));\n    margin-left: calc(5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:space-y-24 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(6rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(6rem * var(--space-y-reverse));\n  }\n\n  .sm\\:space-x-24 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(6rem * var(--space-x-reverse));\n    margin-left: calc(6rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:space-y-32 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(8rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(8rem * var(--space-y-reverse));\n  }\n\n  .sm\\:space-x-32 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(8rem * var(--space-x-reverse));\n    margin-left: calc(8rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:space-y-40 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(10rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(10rem * var(--space-y-reverse));\n  }\n\n  .sm\\:space-x-40 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(10rem * var(--space-x-reverse));\n    margin-left: calc(10rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:space-y-48 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(12rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(12rem * var(--space-y-reverse));\n  }\n\n  .sm\\:space-x-48 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(12rem * var(--space-x-reverse));\n    margin-left: calc(12rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:space-y-56 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(14rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(14rem * var(--space-y-reverse));\n  }\n\n  .sm\\:space-x-56 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(14rem * var(--space-x-reverse));\n    margin-left: calc(14rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:space-y-64 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(16rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(16rem * var(--space-y-reverse));\n  }\n\n  .sm\\:space-x-64 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(16rem * var(--space-x-reverse));\n    margin-left: calc(16rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:space-y-px > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(1px * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(1px * var(--space-y-reverse));\n  }\n\n  .sm\\:space-x-px > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(1px * var(--space-x-reverse));\n    margin-left: calc(1px * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:-space-y-1 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-0.25rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-0.25rem * var(--space-y-reverse));\n  }\n\n  .sm\\:-space-x-1 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-0.25rem * var(--space-x-reverse));\n    margin-left: calc(-0.25rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:-space-y-2 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-0.5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-0.5rem * var(--space-y-reverse));\n  }\n\n  .sm\\:-space-x-2 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-0.5rem * var(--space-x-reverse));\n    margin-left: calc(-0.5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:-space-y-3 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-0.75rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-0.75rem * var(--space-y-reverse));\n  }\n\n  .sm\\:-space-x-3 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-0.75rem * var(--space-x-reverse));\n    margin-left: calc(-0.75rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:-space-y-4 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-1rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-1rem * var(--space-y-reverse));\n  }\n\n  .sm\\:-space-x-4 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-1rem * var(--space-x-reverse));\n    margin-left: calc(-1rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:-space-y-5 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-1.25rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-1.25rem * var(--space-y-reverse));\n  }\n\n  .sm\\:-space-x-5 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-1.25rem * var(--space-x-reverse));\n    margin-left: calc(-1.25rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:-space-y-6 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-1.5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-1.5rem * var(--space-y-reverse));\n  }\n\n  .sm\\:-space-x-6 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-1.5rem * var(--space-x-reverse));\n    margin-left: calc(-1.5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:-space-y-8 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-2rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-2rem * var(--space-y-reverse));\n  }\n\n  .sm\\:-space-x-8 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-2rem * var(--space-x-reverse));\n    margin-left: calc(-2rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:-space-y-10 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-2.5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-2.5rem * var(--space-y-reverse));\n  }\n\n  .sm\\:-space-x-10 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-2.5rem * var(--space-x-reverse));\n    margin-left: calc(-2.5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:-space-y-12 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-3rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-3rem * var(--space-y-reverse));\n  }\n\n  .sm\\:-space-x-12 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-3rem * var(--space-x-reverse));\n    margin-left: calc(-3rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:-space-y-16 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-4rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-4rem * var(--space-y-reverse));\n  }\n\n  .sm\\:-space-x-16 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-4rem * var(--space-x-reverse));\n    margin-left: calc(-4rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:-space-y-20 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-5rem * var(--space-y-reverse));\n  }\n\n  .sm\\:-space-x-20 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-5rem * var(--space-x-reverse));\n    margin-left: calc(-5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:-space-y-24 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-6rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-6rem * var(--space-y-reverse));\n  }\n\n  .sm\\:-space-x-24 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-6rem * var(--space-x-reverse));\n    margin-left: calc(-6rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:-space-y-32 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-8rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-8rem * var(--space-y-reverse));\n  }\n\n  .sm\\:-space-x-32 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-8rem * var(--space-x-reverse));\n    margin-left: calc(-8rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:-space-y-40 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-10rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-10rem * var(--space-y-reverse));\n  }\n\n  .sm\\:-space-x-40 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-10rem * var(--space-x-reverse));\n    margin-left: calc(-10rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:-space-y-48 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-12rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-12rem * var(--space-y-reverse));\n  }\n\n  .sm\\:-space-x-48 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-12rem * var(--space-x-reverse));\n    margin-left: calc(-12rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:-space-y-56 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-14rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-14rem * var(--space-y-reverse));\n  }\n\n  .sm\\:-space-x-56 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-14rem * var(--space-x-reverse));\n    margin-left: calc(-14rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:-space-y-64 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-16rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-16rem * var(--space-y-reverse));\n  }\n\n  .sm\\:-space-x-64 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-16rem * var(--space-x-reverse));\n    margin-left: calc(-16rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:-space-y-px > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-1px * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-1px * var(--space-y-reverse));\n  }\n\n  .sm\\:-space-x-px > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-1px * var(--space-x-reverse));\n    margin-left: calc(-1px * calc(1 - var(--space-x-reverse)));\n  }\n\n  .sm\\:space-y-reverse > :not(template) ~ :not(template) {\n    --space-y-reverse: 1;\n  }\n\n  .sm\\:space-x-reverse > :not(template) ~ :not(template) {\n    --space-x-reverse: 1;\n  }\n\n  .sm\\:divide-y-0 > :not(template) ~ :not(template) {\n    --divide-y-reverse: 0;\n    border-top-width: calc(0px * calc(1 - var(--divide-y-reverse)));\n    border-bottom-width: calc(0px * var(--divide-y-reverse));\n  }\n\n  .sm\\:divide-x-0 > :not(template) ~ :not(template) {\n    --divide-x-reverse: 0;\n    border-right-width: calc(0px * var(--divide-x-reverse));\n    border-left-width: calc(0px * calc(1 - var(--divide-x-reverse)));\n  }\n\n  .sm\\:divide-y-2 > :not(template) ~ :not(template) {\n    --divide-y-reverse: 0;\n    border-top-width: calc(2px * calc(1 - var(--divide-y-reverse)));\n    border-bottom-width: calc(2px * var(--divide-y-reverse));\n  }\n\n  .sm\\:divide-x-2 > :not(template) ~ :not(template) {\n    --divide-x-reverse: 0;\n    border-right-width: calc(2px * var(--divide-x-reverse));\n    border-left-width: calc(2px * calc(1 - var(--divide-x-reverse)));\n  }\n\n  .sm\\:divide-y-4 > :not(template) ~ :not(template) {\n    --divide-y-reverse: 0;\n    border-top-width: calc(4px * calc(1 - var(--divide-y-reverse)));\n    border-bottom-width: calc(4px * var(--divide-y-reverse));\n  }\n\n  .sm\\:divide-x-4 > :not(template) ~ :not(template) {\n    --divide-x-reverse: 0;\n    border-right-width: calc(4px * var(--divide-x-reverse));\n    border-left-width: calc(4px * calc(1 - var(--divide-x-reverse)));\n  }\n\n  .sm\\:divide-y-8 > :not(template) ~ :not(template) {\n    --divide-y-reverse: 0;\n    border-top-width: calc(8px * calc(1 - var(--divide-y-reverse)));\n    border-bottom-width: calc(8px * var(--divide-y-reverse));\n  }\n\n  .sm\\:divide-x-8 > :not(template) ~ :not(template) {\n    --divide-x-reverse: 0;\n    border-right-width: calc(8px * var(--divide-x-reverse));\n    border-left-width: calc(8px * calc(1 - var(--divide-x-reverse)));\n  }\n\n  .sm\\:divide-y > :not(template) ~ :not(template) {\n    --divide-y-reverse: 0;\n    border-top-width: calc(1px * calc(1 - var(--divide-y-reverse)));\n    border-bottom-width: calc(1px * var(--divide-y-reverse));\n  }\n\n  .sm\\:divide-x > :not(template) ~ :not(template) {\n    --divide-x-reverse: 0;\n    border-right-width: calc(1px * var(--divide-x-reverse));\n    border-left-width: calc(1px * calc(1 - var(--divide-x-reverse)));\n  }\n\n  .sm\\:divide-y-reverse > :not(template) ~ :not(template) {\n    --divide-y-reverse: 1;\n  }\n\n  .sm\\:divide-x-reverse > :not(template) ~ :not(template) {\n    --divide-x-reverse: 1;\n  }\n\n  .sm\\:divide-transparent > :not(template) ~ :not(template) {\n    border-color: transparent;\n  }\n\n  .sm\\:divide-current > :not(template) ~ :not(template) {\n    border-color: currentColor;\n  }\n\n  .sm\\:divide-black > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #000;\n    border-color: rgba(0, 0, 0, var(--divide-opacity));\n  }\n\n  .sm\\:divide-white > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fff;\n    border-color: rgba(255, 255, 255, var(--divide-opacity));\n  }\n\n  .sm\\:divide-gray-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #f7fafc;\n    border-color: rgba(247, 250, 252, var(--divide-opacity));\n  }\n\n  .sm\\:divide-gray-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #edf2f7;\n    border-color: rgba(237, 242, 247, var(--divide-opacity));\n  }\n\n  .sm\\:divide-gray-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #e2e8f0;\n    border-color: rgba(226, 232, 240, var(--divide-opacity));\n  }\n\n  .sm\\:divide-gray-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #cbd5e0;\n    border-color: rgba(203, 213, 224, var(--divide-opacity));\n  }\n\n  .sm\\:divide-gray-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #a0aec0;\n    border-color: rgba(160, 174, 192, var(--divide-opacity));\n  }\n\n  .sm\\:divide-gray-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #718096;\n    border-color: rgba(113, 128, 150, var(--divide-opacity));\n  }\n\n  .sm\\:divide-gray-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #4a5568;\n    border-color: rgba(74, 85, 104, var(--divide-opacity));\n  }\n\n  .sm\\:divide-gray-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #2d3748;\n    border-color: rgba(45, 55, 72, var(--divide-opacity));\n  }\n\n  .sm\\:divide-gray-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #1a202c;\n    border-color: rgba(26, 32, 44, var(--divide-opacity));\n  }\n\n  .sm\\:divide-red-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fff5f5;\n    border-color: rgba(255, 245, 245, var(--divide-opacity));\n  }\n\n  .sm\\:divide-red-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fed7d7;\n    border-color: rgba(254, 215, 215, var(--divide-opacity));\n  }\n\n  .sm\\:divide-red-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #feb2b2;\n    border-color: rgba(254, 178, 178, var(--divide-opacity));\n  }\n\n  .sm\\:divide-red-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fc8181;\n    border-color: rgba(252, 129, 129, var(--divide-opacity));\n  }\n\n  .sm\\:divide-red-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #f56565;\n    border-color: rgba(245, 101, 101, var(--divide-opacity));\n  }\n\n  .sm\\:divide-red-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #e53e3e;\n    border-color: rgba(229, 62, 62, var(--divide-opacity));\n  }\n\n  .sm\\:divide-red-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #c53030;\n    border-color: rgba(197, 48, 48, var(--divide-opacity));\n  }\n\n  .sm\\:divide-red-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #9b2c2c;\n    border-color: rgba(155, 44, 44, var(--divide-opacity));\n  }\n\n  .sm\\:divide-red-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #742a2a;\n    border-color: rgba(116, 42, 42, var(--divide-opacity));\n  }\n\n  .sm\\:divide-orange-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fffaf0;\n    border-color: rgba(255, 250, 240, var(--divide-opacity));\n  }\n\n  .sm\\:divide-orange-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #feebc8;\n    border-color: rgba(254, 235, 200, var(--divide-opacity));\n  }\n\n  .sm\\:divide-orange-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fbd38d;\n    border-color: rgba(251, 211, 141, var(--divide-opacity));\n  }\n\n  .sm\\:divide-orange-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #f6ad55;\n    border-color: rgba(246, 173, 85, var(--divide-opacity));\n  }\n\n  .sm\\:divide-orange-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #ed8936;\n    border-color: rgba(237, 137, 54, var(--divide-opacity));\n  }\n\n  .sm\\:divide-orange-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #dd6b20;\n    border-color: rgba(221, 107, 32, var(--divide-opacity));\n  }\n\n  .sm\\:divide-orange-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #c05621;\n    border-color: rgba(192, 86, 33, var(--divide-opacity));\n  }\n\n  .sm\\:divide-orange-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #9c4221;\n    border-color: rgba(156, 66, 33, var(--divide-opacity));\n  }\n\n  .sm\\:divide-orange-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #7b341e;\n    border-color: rgba(123, 52, 30, var(--divide-opacity));\n  }\n\n  .sm\\:divide-yellow-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fffff0;\n    border-color: rgba(255, 255, 240, var(--divide-opacity));\n  }\n\n  .sm\\:divide-yellow-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fefcbf;\n    border-color: rgba(254, 252, 191, var(--divide-opacity));\n  }\n\n  .sm\\:divide-yellow-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #faf089;\n    border-color: rgba(250, 240, 137, var(--divide-opacity));\n  }\n\n  .sm\\:divide-yellow-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #f6e05e;\n    border-color: rgba(246, 224, 94, var(--divide-opacity));\n  }\n\n  .sm\\:divide-yellow-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #ecc94b;\n    border-color: rgba(236, 201, 75, var(--divide-opacity));\n  }\n\n  .sm\\:divide-yellow-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #d69e2e;\n    border-color: rgba(214, 158, 46, var(--divide-opacity));\n  }\n\n  .sm\\:divide-yellow-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #b7791f;\n    border-color: rgba(183, 121, 31, var(--divide-opacity));\n  }\n\n  .sm\\:divide-yellow-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #975a16;\n    border-color: rgba(151, 90, 22, var(--divide-opacity));\n  }\n\n  .sm\\:divide-yellow-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #744210;\n    border-color: rgba(116, 66, 16, var(--divide-opacity));\n  }\n\n  .sm\\:divide-green-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #f0fff4;\n    border-color: rgba(240, 255, 244, var(--divide-opacity));\n  }\n\n  .sm\\:divide-green-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #c6f6d5;\n    border-color: rgba(198, 246, 213, var(--divide-opacity));\n  }\n\n  .sm\\:divide-green-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #9ae6b4;\n    border-color: rgba(154, 230, 180, var(--divide-opacity));\n  }\n\n  .sm\\:divide-green-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #68d391;\n    border-color: rgba(104, 211, 145, var(--divide-opacity));\n  }\n\n  .sm\\:divide-green-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #48bb78;\n    border-color: rgba(72, 187, 120, var(--divide-opacity));\n  }\n\n  .sm\\:divide-green-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #38a169;\n    border-color: rgba(56, 161, 105, var(--divide-opacity));\n  }\n\n  .sm\\:divide-green-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #2f855a;\n    border-color: rgba(47, 133, 90, var(--divide-opacity));\n  }\n\n  .sm\\:divide-green-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #276749;\n    border-color: rgba(39, 103, 73, var(--divide-opacity));\n  }\n\n  .sm\\:divide-green-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #22543d;\n    border-color: rgba(34, 84, 61, var(--divide-opacity));\n  }\n\n  .sm\\:divide-teal-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #e6fffa;\n    border-color: rgba(230, 255, 250, var(--divide-opacity));\n  }\n\n  .sm\\:divide-teal-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #b2f5ea;\n    border-color: rgba(178, 245, 234, var(--divide-opacity));\n  }\n\n  .sm\\:divide-teal-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #81e6d9;\n    border-color: rgba(129, 230, 217, var(--divide-opacity));\n  }\n\n  .sm\\:divide-teal-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #4fd1c5;\n    border-color: rgba(79, 209, 197, var(--divide-opacity));\n  }\n\n  .sm\\:divide-teal-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #38b2ac;\n    border-color: rgba(56, 178, 172, var(--divide-opacity));\n  }\n\n  .sm\\:divide-teal-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #319795;\n    border-color: rgba(49, 151, 149, var(--divide-opacity));\n  }\n\n  .sm\\:divide-teal-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #2c7a7b;\n    border-color: rgba(44, 122, 123, var(--divide-opacity));\n  }\n\n  .sm\\:divide-teal-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #285e61;\n    border-color: rgba(40, 94, 97, var(--divide-opacity));\n  }\n\n  .sm\\:divide-teal-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #234e52;\n    border-color: rgba(35, 78, 82, var(--divide-opacity));\n  }\n\n  .sm\\:divide-blue-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #ebf8ff;\n    border-color: rgba(235, 248, 255, var(--divide-opacity));\n  }\n\n  .sm\\:divide-blue-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #bee3f8;\n    border-color: rgba(190, 227, 248, var(--divide-opacity));\n  }\n\n  .sm\\:divide-blue-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #90cdf4;\n    border-color: rgba(144, 205, 244, var(--divide-opacity));\n  }\n\n  .sm\\:divide-blue-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #63b3ed;\n    border-color: rgba(99, 179, 237, var(--divide-opacity));\n  }\n\n  .sm\\:divide-blue-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #4299e1;\n    border-color: rgba(66, 153, 225, var(--divide-opacity));\n  }\n\n  .sm\\:divide-blue-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #3182ce;\n    border-color: rgba(49, 130, 206, var(--divide-opacity));\n  }\n\n  .sm\\:divide-blue-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #2b6cb0;\n    border-color: rgba(43, 108, 176, var(--divide-opacity));\n  }\n\n  .sm\\:divide-blue-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #2c5282;\n    border-color: rgba(44, 82, 130, var(--divide-opacity));\n  }\n\n  .sm\\:divide-blue-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #2a4365;\n    border-color: rgba(42, 67, 101, var(--divide-opacity));\n  }\n\n  .sm\\:divide-indigo-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #ebf4ff;\n    border-color: rgba(235, 244, 255, var(--divide-opacity));\n  }\n\n  .sm\\:divide-indigo-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #c3dafe;\n    border-color: rgba(195, 218, 254, var(--divide-opacity));\n  }\n\n  .sm\\:divide-indigo-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #a3bffa;\n    border-color: rgba(163, 191, 250, var(--divide-opacity));\n  }\n\n  .sm\\:divide-indigo-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #7f9cf5;\n    border-color: rgba(127, 156, 245, var(--divide-opacity));\n  }\n\n  .sm\\:divide-indigo-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #667eea;\n    border-color: rgba(102, 126, 234, var(--divide-opacity));\n  }\n\n  .sm\\:divide-indigo-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #5a67d8;\n    border-color: rgba(90, 103, 216, var(--divide-opacity));\n  }\n\n  .sm\\:divide-indigo-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #4c51bf;\n    border-color: rgba(76, 81, 191, var(--divide-opacity));\n  }\n\n  .sm\\:divide-indigo-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #434190;\n    border-color: rgba(67, 65, 144, var(--divide-opacity));\n  }\n\n  .sm\\:divide-indigo-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #3c366b;\n    border-color: rgba(60, 54, 107, var(--divide-opacity));\n  }\n\n  .sm\\:divide-purple-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #faf5ff;\n    border-color: rgba(250, 245, 255, var(--divide-opacity));\n  }\n\n  .sm\\:divide-purple-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #e9d8fd;\n    border-color: rgba(233, 216, 253, var(--divide-opacity));\n  }\n\n  .sm\\:divide-purple-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #d6bcfa;\n    border-color: rgba(214, 188, 250, var(--divide-opacity));\n  }\n\n  .sm\\:divide-purple-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #b794f4;\n    border-color: rgba(183, 148, 244, var(--divide-opacity));\n  }\n\n  .sm\\:divide-purple-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #9f7aea;\n    border-color: rgba(159, 122, 234, var(--divide-opacity));\n  }\n\n  .sm\\:divide-purple-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #805ad5;\n    border-color: rgba(128, 90, 213, var(--divide-opacity));\n  }\n\n  .sm\\:divide-purple-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #6b46c1;\n    border-color: rgba(107, 70, 193, var(--divide-opacity));\n  }\n\n  .sm\\:divide-purple-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #553c9a;\n    border-color: rgba(85, 60, 154, var(--divide-opacity));\n  }\n\n  .sm\\:divide-purple-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #44337a;\n    border-color: rgba(68, 51, 122, var(--divide-opacity));\n  }\n\n  .sm\\:divide-pink-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fff5f7;\n    border-color: rgba(255, 245, 247, var(--divide-opacity));\n  }\n\n  .sm\\:divide-pink-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fed7e2;\n    border-color: rgba(254, 215, 226, var(--divide-opacity));\n  }\n\n  .sm\\:divide-pink-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fbb6ce;\n    border-color: rgba(251, 182, 206, var(--divide-opacity));\n  }\n\n  .sm\\:divide-pink-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #f687b3;\n    border-color: rgba(246, 135, 179, var(--divide-opacity));\n  }\n\n  .sm\\:divide-pink-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #ed64a6;\n    border-color: rgba(237, 100, 166, var(--divide-opacity));\n  }\n\n  .sm\\:divide-pink-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #d53f8c;\n    border-color: rgba(213, 63, 140, var(--divide-opacity));\n  }\n\n  .sm\\:divide-pink-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #b83280;\n    border-color: rgba(184, 50, 128, var(--divide-opacity));\n  }\n\n  .sm\\:divide-pink-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #97266d;\n    border-color: rgba(151, 38, 109, var(--divide-opacity));\n  }\n\n  .sm\\:divide-pink-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #702459;\n    border-color: rgba(112, 36, 89, var(--divide-opacity));\n  }\n\n  .sm\\:divide-grayscale-80 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 8%);\n    border-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--divide-opacity));\n  }\n\n  .sm\\:divide-grayscale-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 10%);\n    border-color: rgba(25.5, 25.5, 25.5, var(--divide-opacity));\n  }\n\n  .sm\\:divide-grayscale-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 20%);\n    border-color: rgba(51, 51, 51, var(--divide-opacity));\n  }\n\n  .sm\\:divide-grayscale-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 30%);\n    border-color: rgba(76.5, 76.5, 76.5, var(--divide-opacity));\n  }\n\n  .sm\\:divide-grayscale-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 40%);\n    border-color: rgba(102, 102, 102, var(--divide-opacity));\n  }\n\n  .sm\\:divide-grayscale-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 50%);\n    border-color: rgba(127.5, 127.5, 127.5, var(--divide-opacity));\n  }\n\n  .sm\\:divide-grayscale-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 60%);\n    border-color: rgba(153, 153, 153, var(--divide-opacity));\n  }\n\n  .sm\\:divide-grayscale-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 70%);\n    border-color: rgba(178.5, 178.5, 178.5, var(--divide-opacity));\n  }\n\n  .sm\\:divide-grayscale-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 80%);\n    border-color: rgba(204, 204, 204, var(--divide-opacity));\n  }\n\n  .sm\\:divide-grayscale-840 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 84%);\n    border-color: rgba(214.2, 214.2, 214.2, var(--divide-opacity));\n  }\n\n  .sm\\:divide-grayscale-870 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 87%);\n    border-color: rgba(221.85, 221.85, 221.85, var(--divide-opacity));\n  }\n\n  .sm\\:divide-grayscale-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 90%);\n    border-color: rgba(229.5, 229.5, 229.5, var(--divide-opacity));\n  }\n\n  .sm\\:divide-grayscale-930 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 93%);\n    border-color: rgba(237.15, 237.15, 237.15, var(--divide-opacity));\n  }\n\n  .sm\\:divide-primary > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(210, 100%, 52%);\n    border-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--divide-opacity));\n  }\n\n  .sm\\:divide-background-main > :not(template) ~ :not(template) {\n    border-color: var(--main-background);\n  }\n\n  .sm\\:divide-background-secondary > :not(template) ~ :not(template) {\n    border-color: var(--secondary-background);\n  }\n\n  .sm\\:divide-foreground > :not(template) ~ :not(template) {\n    border-color: var(--foreground);\n  }\n\n  .sm\\:divide-panels-bg > :not(template) ~ :not(template) {\n    border-color: var(--panels-background);\n  }\n\n  .sm\\:divide-solid > :not(template) ~ :not(template) {\n    border-style: solid;\n  }\n\n  .sm\\:divide-dashed > :not(template) ~ :not(template) {\n    border-style: dashed;\n  }\n\n  .sm\\:divide-dotted > :not(template) ~ :not(template) {\n    border-style: dotted;\n  }\n\n  .sm\\:divide-double > :not(template) ~ :not(template) {\n    border-style: double;\n  }\n\n  .sm\\:divide-none > :not(template) ~ :not(template) {\n    border-style: none;\n  }\n\n  .sm\\:divide-opacity-0 > :not(template) ~ :not(template) {\n    --divide-opacity: 0;\n  }\n\n  .sm\\:divide-opacity-25 > :not(template) ~ :not(template) {\n    --divide-opacity: 0.25;\n  }\n\n  .sm\\:divide-opacity-50 > :not(template) ~ :not(template) {\n    --divide-opacity: 0.5;\n  }\n\n  .sm\\:divide-opacity-75 > :not(template) ~ :not(template) {\n    --divide-opacity: 0.75;\n  }\n\n  .sm\\:divide-opacity-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n  }\n\n  .sm\\:sr-only {\n    position: absolute;\n    width: 1px;\n    height: 1px;\n    padding: 0;\n    margin: -1px;\n    overflow: hidden;\n    clip: rect(0, 0, 0, 0);\n    white-space: nowrap;\n    border-width: 0;\n  }\n\n  .sm\\:not-sr-only {\n    position: static;\n    width: auto;\n    height: auto;\n    padding: 0;\n    margin: 0;\n    overflow: visible;\n    clip: auto;\n    white-space: normal;\n  }\n\n  .sm\\:focus\\:sr-only:focus {\n    position: absolute;\n    width: 1px;\n    height: 1px;\n    padding: 0;\n    margin: -1px;\n    overflow: hidden;\n    clip: rect(0, 0, 0, 0);\n    white-space: nowrap;\n    border-width: 0;\n  }\n\n  .sm\\:focus\\:not-sr-only:focus {\n    position: static;\n    width: auto;\n    height: auto;\n    padding: 0;\n    margin: 0;\n    overflow: visible;\n    clip: auto;\n    white-space: normal;\n  }\n\n  .sm\\:appearance-none {\n    -webkit-appearance: none;\n       -moz-appearance: none;\n            appearance: none;\n  }\n\n  .sm\\:bg-fixed {\n    background-attachment: fixed;\n  }\n\n  .sm\\:bg-local {\n    background-attachment: local;\n  }\n\n  .sm\\:bg-scroll {\n    background-attachment: scroll;\n  }\n\n  .sm\\:bg-clip-border {\n    background-clip: border-box;\n  }\n\n  .sm\\:bg-clip-padding {\n    background-clip: padding-box;\n  }\n\n  .sm\\:bg-clip-content {\n    background-clip: content-box;\n  }\n\n  .sm\\:bg-clip-text {\n    -webkit-background-clip: text;\n            background-clip: text;\n  }\n\n  .sm\\:bg-transparent {\n    background-color: transparent;\n  }\n\n  .sm\\:bg-current {\n    background-color: currentColor;\n  }\n\n  .sm\\:bg-black {\n    --bg-opacity: 1;\n    background-color: #000;\n    background-color: rgba(0, 0, 0, var(--bg-opacity));\n  }\n\n  .sm\\:bg-white {\n    --bg-opacity: 1;\n    background-color: #fff;\n    background-color: rgba(255, 255, 255, var(--bg-opacity));\n  }\n\n  .sm\\:bg-gray-100 {\n    --bg-opacity: 1;\n    background-color: #f7fafc;\n    background-color: rgba(247, 250, 252, var(--bg-opacity));\n  }\n\n  .sm\\:bg-gray-200 {\n    --bg-opacity: 1;\n    background-color: #edf2f7;\n    background-color: rgba(237, 242, 247, var(--bg-opacity));\n  }\n\n  .sm\\:bg-gray-300 {\n    --bg-opacity: 1;\n    background-color: #e2e8f0;\n    background-color: rgba(226, 232, 240, var(--bg-opacity));\n  }\n\n  .sm\\:bg-gray-400 {\n    --bg-opacity: 1;\n    background-color: #cbd5e0;\n    background-color: rgba(203, 213, 224, var(--bg-opacity));\n  }\n\n  .sm\\:bg-gray-500 {\n    --bg-opacity: 1;\n    background-color: #a0aec0;\n    background-color: rgba(160, 174, 192, var(--bg-opacity));\n  }\n\n  .sm\\:bg-gray-600 {\n    --bg-opacity: 1;\n    background-color: #718096;\n    background-color: rgba(113, 128, 150, var(--bg-opacity));\n  }\n\n  .sm\\:bg-gray-700 {\n    --bg-opacity: 1;\n    background-color: #4a5568;\n    background-color: rgba(74, 85, 104, var(--bg-opacity));\n  }\n\n  .sm\\:bg-gray-800 {\n    --bg-opacity: 1;\n    background-color: #2d3748;\n    background-color: rgba(45, 55, 72, var(--bg-opacity));\n  }\n\n  .sm\\:bg-gray-900 {\n    --bg-opacity: 1;\n    background-color: #1a202c;\n    background-color: rgba(26, 32, 44, var(--bg-opacity));\n  }\n\n  .sm\\:bg-red-100 {\n    --bg-opacity: 1;\n    background-color: #fff5f5;\n    background-color: rgba(255, 245, 245, var(--bg-opacity));\n  }\n\n  .sm\\:bg-red-200 {\n    --bg-opacity: 1;\n    background-color: #fed7d7;\n    background-color: rgba(254, 215, 215, var(--bg-opacity));\n  }\n\n  .sm\\:bg-red-300 {\n    --bg-opacity: 1;\n    background-color: #feb2b2;\n    background-color: rgba(254, 178, 178, var(--bg-opacity));\n  }\n\n  .sm\\:bg-red-400 {\n    --bg-opacity: 1;\n    background-color: #fc8181;\n    background-color: rgba(252, 129, 129, var(--bg-opacity));\n  }\n\n  .sm\\:bg-red-500 {\n    --bg-opacity: 1;\n    background-color: #f56565;\n    background-color: rgba(245, 101, 101, var(--bg-opacity));\n  }\n\n  .sm\\:bg-red-600 {\n    --bg-opacity: 1;\n    background-color: #e53e3e;\n    background-color: rgba(229, 62, 62, var(--bg-opacity));\n  }\n\n  .sm\\:bg-red-700 {\n    --bg-opacity: 1;\n    background-color: #c53030;\n    background-color: rgba(197, 48, 48, var(--bg-opacity));\n  }\n\n  .sm\\:bg-red-800 {\n    --bg-opacity: 1;\n    background-color: #9b2c2c;\n    background-color: rgba(155, 44, 44, var(--bg-opacity));\n  }\n\n  .sm\\:bg-red-900 {\n    --bg-opacity: 1;\n    background-color: #742a2a;\n    background-color: rgba(116, 42, 42, var(--bg-opacity));\n  }\n\n  .sm\\:bg-orange-100 {\n    --bg-opacity: 1;\n    background-color: #fffaf0;\n    background-color: rgba(255, 250, 240, var(--bg-opacity));\n  }\n\n  .sm\\:bg-orange-200 {\n    --bg-opacity: 1;\n    background-color: #feebc8;\n    background-color: rgba(254, 235, 200, var(--bg-opacity));\n  }\n\n  .sm\\:bg-orange-300 {\n    --bg-opacity: 1;\n    background-color: #fbd38d;\n    background-color: rgba(251, 211, 141, var(--bg-opacity));\n  }\n\n  .sm\\:bg-orange-400 {\n    --bg-opacity: 1;\n    background-color: #f6ad55;\n    background-color: rgba(246, 173, 85, var(--bg-opacity));\n  }\n\n  .sm\\:bg-orange-500 {\n    --bg-opacity: 1;\n    background-color: #ed8936;\n    background-color: rgba(237, 137, 54, var(--bg-opacity));\n  }\n\n  .sm\\:bg-orange-600 {\n    --bg-opacity: 1;\n    background-color: #dd6b20;\n    background-color: rgba(221, 107, 32, var(--bg-opacity));\n  }\n\n  .sm\\:bg-orange-700 {\n    --bg-opacity: 1;\n    background-color: #c05621;\n    background-color: rgba(192, 86, 33, var(--bg-opacity));\n  }\n\n  .sm\\:bg-orange-800 {\n    --bg-opacity: 1;\n    background-color: #9c4221;\n    background-color: rgba(156, 66, 33, var(--bg-opacity));\n  }\n\n  .sm\\:bg-orange-900 {\n    --bg-opacity: 1;\n    background-color: #7b341e;\n    background-color: rgba(123, 52, 30, var(--bg-opacity));\n  }\n\n  .sm\\:bg-yellow-100 {\n    --bg-opacity: 1;\n    background-color: #fffff0;\n    background-color: rgba(255, 255, 240, var(--bg-opacity));\n  }\n\n  .sm\\:bg-yellow-200 {\n    --bg-opacity: 1;\n    background-color: #fefcbf;\n    background-color: rgba(254, 252, 191, var(--bg-opacity));\n  }\n\n  .sm\\:bg-yellow-300 {\n    --bg-opacity: 1;\n    background-color: #faf089;\n    background-color: rgba(250, 240, 137, var(--bg-opacity));\n  }\n\n  .sm\\:bg-yellow-400 {\n    --bg-opacity: 1;\n    background-color: #f6e05e;\n    background-color: rgba(246, 224, 94, var(--bg-opacity));\n  }\n\n  .sm\\:bg-yellow-500 {\n    --bg-opacity: 1;\n    background-color: #ecc94b;\n    background-color: rgba(236, 201, 75, var(--bg-opacity));\n  }\n\n  .sm\\:bg-yellow-600 {\n    --bg-opacity: 1;\n    background-color: #d69e2e;\n    background-color: rgba(214, 158, 46, var(--bg-opacity));\n  }\n\n  .sm\\:bg-yellow-700 {\n    --bg-opacity: 1;\n    background-color: #b7791f;\n    background-color: rgba(183, 121, 31, var(--bg-opacity));\n  }\n\n  .sm\\:bg-yellow-800 {\n    --bg-opacity: 1;\n    background-color: #975a16;\n    background-color: rgba(151, 90, 22, var(--bg-opacity));\n  }\n\n  .sm\\:bg-yellow-900 {\n    --bg-opacity: 1;\n    background-color: #744210;\n    background-color: rgba(116, 66, 16, var(--bg-opacity));\n  }\n\n  .sm\\:bg-green-100 {\n    --bg-opacity: 1;\n    background-color: #f0fff4;\n    background-color: rgba(240, 255, 244, var(--bg-opacity));\n  }\n\n  .sm\\:bg-green-200 {\n    --bg-opacity: 1;\n    background-color: #c6f6d5;\n    background-color: rgba(198, 246, 213, var(--bg-opacity));\n  }\n\n  .sm\\:bg-green-300 {\n    --bg-opacity: 1;\n    background-color: #9ae6b4;\n    background-color: rgba(154, 230, 180, var(--bg-opacity));\n  }\n\n  .sm\\:bg-green-400 {\n    --bg-opacity: 1;\n    background-color: #68d391;\n    background-color: rgba(104, 211, 145, var(--bg-opacity));\n  }\n\n  .sm\\:bg-green-500 {\n    --bg-opacity: 1;\n    background-color: #48bb78;\n    background-color: rgba(72, 187, 120, var(--bg-opacity));\n  }\n\n  .sm\\:bg-green-600 {\n    --bg-opacity: 1;\n    background-color: #38a169;\n    background-color: rgba(56, 161, 105, var(--bg-opacity));\n  }\n\n  .sm\\:bg-green-700 {\n    --bg-opacity: 1;\n    background-color: #2f855a;\n    background-color: rgba(47, 133, 90, var(--bg-opacity));\n  }\n\n  .sm\\:bg-green-800 {\n    --bg-opacity: 1;\n    background-color: #276749;\n    background-color: rgba(39, 103, 73, var(--bg-opacity));\n  }\n\n  .sm\\:bg-green-900 {\n    --bg-opacity: 1;\n    background-color: #22543d;\n    background-color: rgba(34, 84, 61, var(--bg-opacity));\n  }\n\n  .sm\\:bg-teal-100 {\n    --bg-opacity: 1;\n    background-color: #e6fffa;\n    background-color: rgba(230, 255, 250, var(--bg-opacity));\n  }\n\n  .sm\\:bg-teal-200 {\n    --bg-opacity: 1;\n    background-color: #b2f5ea;\n    background-color: rgba(178, 245, 234, var(--bg-opacity));\n  }\n\n  .sm\\:bg-teal-300 {\n    --bg-opacity: 1;\n    background-color: #81e6d9;\n    background-color: rgba(129, 230, 217, var(--bg-opacity));\n  }\n\n  .sm\\:bg-teal-400 {\n    --bg-opacity: 1;\n    background-color: #4fd1c5;\n    background-color: rgba(79, 209, 197, var(--bg-opacity));\n  }\n\n  .sm\\:bg-teal-500 {\n    --bg-opacity: 1;\n    background-color: #38b2ac;\n    background-color: rgba(56, 178, 172, var(--bg-opacity));\n  }\n\n  .sm\\:bg-teal-600 {\n    --bg-opacity: 1;\n    background-color: #319795;\n    background-color: rgba(49, 151, 149, var(--bg-opacity));\n  }\n\n  .sm\\:bg-teal-700 {\n    --bg-opacity: 1;\n    background-color: #2c7a7b;\n    background-color: rgba(44, 122, 123, var(--bg-opacity));\n  }\n\n  .sm\\:bg-teal-800 {\n    --bg-opacity: 1;\n    background-color: #285e61;\n    background-color: rgba(40, 94, 97, var(--bg-opacity));\n  }\n\n  .sm\\:bg-teal-900 {\n    --bg-opacity: 1;\n    background-color: #234e52;\n    background-color: rgba(35, 78, 82, var(--bg-opacity));\n  }\n\n  .sm\\:bg-blue-100 {\n    --bg-opacity: 1;\n    background-color: #ebf8ff;\n    background-color: rgba(235, 248, 255, var(--bg-opacity));\n  }\n\n  .sm\\:bg-blue-200 {\n    --bg-opacity: 1;\n    background-color: #bee3f8;\n    background-color: rgba(190, 227, 248, var(--bg-opacity));\n  }\n\n  .sm\\:bg-blue-300 {\n    --bg-opacity: 1;\n    background-color: #90cdf4;\n    background-color: rgba(144, 205, 244, var(--bg-opacity));\n  }\n\n  .sm\\:bg-blue-400 {\n    --bg-opacity: 1;\n    background-color: #63b3ed;\n    background-color: rgba(99, 179, 237, var(--bg-opacity));\n  }\n\n  .sm\\:bg-blue-500 {\n    --bg-opacity: 1;\n    background-color: #4299e1;\n    background-color: rgba(66, 153, 225, var(--bg-opacity));\n  }\n\n  .sm\\:bg-blue-600 {\n    --bg-opacity: 1;\n    background-color: #3182ce;\n    background-color: rgba(49, 130, 206, var(--bg-opacity));\n  }\n\n  .sm\\:bg-blue-700 {\n    --bg-opacity: 1;\n    background-color: #2b6cb0;\n    background-color: rgba(43, 108, 176, var(--bg-opacity));\n  }\n\n  .sm\\:bg-blue-800 {\n    --bg-opacity: 1;\n    background-color: #2c5282;\n    background-color: rgba(44, 82, 130, var(--bg-opacity));\n  }\n\n  .sm\\:bg-blue-900 {\n    --bg-opacity: 1;\n    background-color: #2a4365;\n    background-color: rgba(42, 67, 101, var(--bg-opacity));\n  }\n\n  .sm\\:bg-indigo-100 {\n    --bg-opacity: 1;\n    background-color: #ebf4ff;\n    background-color: rgba(235, 244, 255, var(--bg-opacity));\n  }\n\n  .sm\\:bg-indigo-200 {\n    --bg-opacity: 1;\n    background-color: #c3dafe;\n    background-color: rgba(195, 218, 254, var(--bg-opacity));\n  }\n\n  .sm\\:bg-indigo-300 {\n    --bg-opacity: 1;\n    background-color: #a3bffa;\n    background-color: rgba(163, 191, 250, var(--bg-opacity));\n  }\n\n  .sm\\:bg-indigo-400 {\n    --bg-opacity: 1;\n    background-color: #7f9cf5;\n    background-color: rgba(127, 156, 245, var(--bg-opacity));\n  }\n\n  .sm\\:bg-indigo-500 {\n    --bg-opacity: 1;\n    background-color: #667eea;\n    background-color: rgba(102, 126, 234, var(--bg-opacity));\n  }\n\n  .sm\\:bg-indigo-600 {\n    --bg-opacity: 1;\n    background-color: #5a67d8;\n    background-color: rgba(90, 103, 216, var(--bg-opacity));\n  }\n\n  .sm\\:bg-indigo-700 {\n    --bg-opacity: 1;\n    background-color: #4c51bf;\n    background-color: rgba(76, 81, 191, var(--bg-opacity));\n  }\n\n  .sm\\:bg-indigo-800 {\n    --bg-opacity: 1;\n    background-color: #434190;\n    background-color: rgba(67, 65, 144, var(--bg-opacity));\n  }\n\n  .sm\\:bg-indigo-900 {\n    --bg-opacity: 1;\n    background-color: #3c366b;\n    background-color: rgba(60, 54, 107, var(--bg-opacity));\n  }\n\n  .sm\\:bg-purple-100 {\n    --bg-opacity: 1;\n    background-color: #faf5ff;\n    background-color: rgba(250, 245, 255, var(--bg-opacity));\n  }\n\n  .sm\\:bg-purple-200 {\n    --bg-opacity: 1;\n    background-color: #e9d8fd;\n    background-color: rgba(233, 216, 253, var(--bg-opacity));\n  }\n\n  .sm\\:bg-purple-300 {\n    --bg-opacity: 1;\n    background-color: #d6bcfa;\n    background-color: rgba(214, 188, 250, var(--bg-opacity));\n  }\n\n  .sm\\:bg-purple-400 {\n    --bg-opacity: 1;\n    background-color: #b794f4;\n    background-color: rgba(183, 148, 244, var(--bg-opacity));\n  }\n\n  .sm\\:bg-purple-500 {\n    --bg-opacity: 1;\n    background-color: #9f7aea;\n    background-color: rgba(159, 122, 234, var(--bg-opacity));\n  }\n\n  .sm\\:bg-purple-600 {\n    --bg-opacity: 1;\n    background-color: #805ad5;\n    background-color: rgba(128, 90, 213, var(--bg-opacity));\n  }\n\n  .sm\\:bg-purple-700 {\n    --bg-opacity: 1;\n    background-color: #6b46c1;\n    background-color: rgba(107, 70, 193, var(--bg-opacity));\n  }\n\n  .sm\\:bg-purple-800 {\n    --bg-opacity: 1;\n    background-color: #553c9a;\n    background-color: rgba(85, 60, 154, var(--bg-opacity));\n  }\n\n  .sm\\:bg-purple-900 {\n    --bg-opacity: 1;\n    background-color: #44337a;\n    background-color: rgba(68, 51, 122, var(--bg-opacity));\n  }\n\n  .sm\\:bg-pink-100 {\n    --bg-opacity: 1;\n    background-color: #fff5f7;\n    background-color: rgba(255, 245, 247, var(--bg-opacity));\n  }\n\n  .sm\\:bg-pink-200 {\n    --bg-opacity: 1;\n    background-color: #fed7e2;\n    background-color: rgba(254, 215, 226, var(--bg-opacity));\n  }\n\n  .sm\\:bg-pink-300 {\n    --bg-opacity: 1;\n    background-color: #fbb6ce;\n    background-color: rgba(251, 182, 206, var(--bg-opacity));\n  }\n\n  .sm\\:bg-pink-400 {\n    --bg-opacity: 1;\n    background-color: #f687b3;\n    background-color: rgba(246, 135, 179, var(--bg-opacity));\n  }\n\n  .sm\\:bg-pink-500 {\n    --bg-opacity: 1;\n    background-color: #ed64a6;\n    background-color: rgba(237, 100, 166, var(--bg-opacity));\n  }\n\n  .sm\\:bg-pink-600 {\n    --bg-opacity: 1;\n    background-color: #d53f8c;\n    background-color: rgba(213, 63, 140, var(--bg-opacity));\n  }\n\n  .sm\\:bg-pink-700 {\n    --bg-opacity: 1;\n    background-color: #b83280;\n    background-color: rgba(184, 50, 128, var(--bg-opacity));\n  }\n\n  .sm\\:bg-pink-800 {\n    --bg-opacity: 1;\n    background-color: #97266d;\n    background-color: rgba(151, 38, 109, var(--bg-opacity));\n  }\n\n  .sm\\:bg-pink-900 {\n    --bg-opacity: 1;\n    background-color: #702459;\n    background-color: rgba(112, 36, 89, var(--bg-opacity));\n  }\n\n  .sm\\:bg-grayscale-80 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 8%);\n    background-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--bg-opacity));\n  }\n\n  .sm\\:bg-grayscale-100 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 10%);\n    background-color: rgba(25.5, 25.5, 25.5, var(--bg-opacity));\n  }\n\n  .sm\\:bg-grayscale-200 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 20%);\n    background-color: rgba(51, 51, 51, var(--bg-opacity));\n  }\n\n  .sm\\:bg-grayscale-300 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 30%);\n    background-color: rgba(76.5, 76.5, 76.5, var(--bg-opacity));\n  }\n\n  .sm\\:bg-grayscale-400 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 40%);\n    background-color: rgba(102, 102, 102, var(--bg-opacity));\n  }\n\n  .sm\\:bg-grayscale-500 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 50%);\n    background-color: rgba(127.5, 127.5, 127.5, var(--bg-opacity));\n  }\n\n  .sm\\:bg-grayscale-600 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 60%);\n    background-color: rgba(153, 153, 153, var(--bg-opacity));\n  }\n\n  .sm\\:bg-grayscale-700 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 70%);\n    background-color: rgba(178.5, 178.5, 178.5, var(--bg-opacity));\n  }\n\n  .sm\\:bg-grayscale-800 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 80%);\n    background-color: rgba(204, 204, 204, var(--bg-opacity));\n  }\n\n  .sm\\:bg-grayscale-840 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 84%);\n    background-color: rgba(214.2, 214.2, 214.2, var(--bg-opacity));\n  }\n\n  .sm\\:bg-grayscale-870 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 87%);\n    background-color: rgba(221.85, 221.85, 221.85, var(--bg-opacity));\n  }\n\n  .sm\\:bg-grayscale-900 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 90%);\n    background-color: rgba(229.5, 229.5, 229.5, var(--bg-opacity));\n  }\n\n  .sm\\:bg-grayscale-930 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 93%);\n    background-color: rgba(237.15, 237.15, 237.15, var(--bg-opacity));\n  }\n\n  .sm\\:bg-primary {\n    --bg-opacity: 1;\n    background-color: hsl(210, 100%, 52%);\n    background-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--bg-opacity));\n  }\n\n  .sm\\:bg-background-main {\n    background-color: var(--main-background);\n  }\n\n  .sm\\:bg-background-secondary {\n    background-color: var(--secondary-background);\n  }\n\n  .sm\\:bg-foreground {\n    background-color: var(--foreground);\n  }\n\n  .sm\\:bg-panels-bg {\n    background-color: var(--panels-background);\n  }\n\n  .sm\\:hover\\:bg-transparent:hover {\n    background-color: transparent;\n  }\n\n  .sm\\:hover\\:bg-current:hover {\n    background-color: currentColor;\n  }\n\n  .sm\\:hover\\:bg-black:hover {\n    --bg-opacity: 1;\n    background-color: #000;\n    background-color: rgba(0, 0, 0, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-white:hover {\n    --bg-opacity: 1;\n    background-color: #fff;\n    background-color: rgba(255, 255, 255, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-gray-100:hover {\n    --bg-opacity: 1;\n    background-color: #f7fafc;\n    background-color: rgba(247, 250, 252, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-gray-200:hover {\n    --bg-opacity: 1;\n    background-color: #edf2f7;\n    background-color: rgba(237, 242, 247, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-gray-300:hover {\n    --bg-opacity: 1;\n    background-color: #e2e8f0;\n    background-color: rgba(226, 232, 240, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-gray-400:hover {\n    --bg-opacity: 1;\n    background-color: #cbd5e0;\n    background-color: rgba(203, 213, 224, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-gray-500:hover {\n    --bg-opacity: 1;\n    background-color: #a0aec0;\n    background-color: rgba(160, 174, 192, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-gray-600:hover {\n    --bg-opacity: 1;\n    background-color: #718096;\n    background-color: rgba(113, 128, 150, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-gray-700:hover {\n    --bg-opacity: 1;\n    background-color: #4a5568;\n    background-color: rgba(74, 85, 104, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-gray-800:hover {\n    --bg-opacity: 1;\n    background-color: #2d3748;\n    background-color: rgba(45, 55, 72, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-gray-900:hover {\n    --bg-opacity: 1;\n    background-color: #1a202c;\n    background-color: rgba(26, 32, 44, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-red-100:hover {\n    --bg-opacity: 1;\n    background-color: #fff5f5;\n    background-color: rgba(255, 245, 245, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-red-200:hover {\n    --bg-opacity: 1;\n    background-color: #fed7d7;\n    background-color: rgba(254, 215, 215, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-red-300:hover {\n    --bg-opacity: 1;\n    background-color: #feb2b2;\n    background-color: rgba(254, 178, 178, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-red-400:hover {\n    --bg-opacity: 1;\n    background-color: #fc8181;\n    background-color: rgba(252, 129, 129, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-red-500:hover {\n    --bg-opacity: 1;\n    background-color: #f56565;\n    background-color: rgba(245, 101, 101, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-red-600:hover {\n    --bg-opacity: 1;\n    background-color: #e53e3e;\n    background-color: rgba(229, 62, 62, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-red-700:hover {\n    --bg-opacity: 1;\n    background-color: #c53030;\n    background-color: rgba(197, 48, 48, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-red-800:hover {\n    --bg-opacity: 1;\n    background-color: #9b2c2c;\n    background-color: rgba(155, 44, 44, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-red-900:hover {\n    --bg-opacity: 1;\n    background-color: #742a2a;\n    background-color: rgba(116, 42, 42, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-orange-100:hover {\n    --bg-opacity: 1;\n    background-color: #fffaf0;\n    background-color: rgba(255, 250, 240, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-orange-200:hover {\n    --bg-opacity: 1;\n    background-color: #feebc8;\n    background-color: rgba(254, 235, 200, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-orange-300:hover {\n    --bg-opacity: 1;\n    background-color: #fbd38d;\n    background-color: rgba(251, 211, 141, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-orange-400:hover {\n    --bg-opacity: 1;\n    background-color: #f6ad55;\n    background-color: rgba(246, 173, 85, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-orange-500:hover {\n    --bg-opacity: 1;\n    background-color: #ed8936;\n    background-color: rgba(237, 137, 54, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-orange-600:hover {\n    --bg-opacity: 1;\n    background-color: #dd6b20;\n    background-color: rgba(221, 107, 32, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-orange-700:hover {\n    --bg-opacity: 1;\n    background-color: #c05621;\n    background-color: rgba(192, 86, 33, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-orange-800:hover {\n    --bg-opacity: 1;\n    background-color: #9c4221;\n    background-color: rgba(156, 66, 33, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-orange-900:hover {\n    --bg-opacity: 1;\n    background-color: #7b341e;\n    background-color: rgba(123, 52, 30, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-yellow-100:hover {\n    --bg-opacity: 1;\n    background-color: #fffff0;\n    background-color: rgba(255, 255, 240, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-yellow-200:hover {\n    --bg-opacity: 1;\n    background-color: #fefcbf;\n    background-color: rgba(254, 252, 191, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-yellow-300:hover {\n    --bg-opacity: 1;\n    background-color: #faf089;\n    background-color: rgba(250, 240, 137, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-yellow-400:hover {\n    --bg-opacity: 1;\n    background-color: #f6e05e;\n    background-color: rgba(246, 224, 94, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-yellow-500:hover {\n    --bg-opacity: 1;\n    background-color: #ecc94b;\n    background-color: rgba(236, 201, 75, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-yellow-600:hover {\n    --bg-opacity: 1;\n    background-color: #d69e2e;\n    background-color: rgba(214, 158, 46, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-yellow-700:hover {\n    --bg-opacity: 1;\n    background-color: #b7791f;\n    background-color: rgba(183, 121, 31, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-yellow-800:hover {\n    --bg-opacity: 1;\n    background-color: #975a16;\n    background-color: rgba(151, 90, 22, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-yellow-900:hover {\n    --bg-opacity: 1;\n    background-color: #744210;\n    background-color: rgba(116, 66, 16, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-green-100:hover {\n    --bg-opacity: 1;\n    background-color: #f0fff4;\n    background-color: rgba(240, 255, 244, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-green-200:hover {\n    --bg-opacity: 1;\n    background-color: #c6f6d5;\n    background-color: rgba(198, 246, 213, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-green-300:hover {\n    --bg-opacity: 1;\n    background-color: #9ae6b4;\n    background-color: rgba(154, 230, 180, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-green-400:hover {\n    --bg-opacity: 1;\n    background-color: #68d391;\n    background-color: rgba(104, 211, 145, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-green-500:hover {\n    --bg-opacity: 1;\n    background-color: #48bb78;\n    background-color: rgba(72, 187, 120, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-green-600:hover {\n    --bg-opacity: 1;\n    background-color: #38a169;\n    background-color: rgba(56, 161, 105, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-green-700:hover {\n    --bg-opacity: 1;\n    background-color: #2f855a;\n    background-color: rgba(47, 133, 90, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-green-800:hover {\n    --bg-opacity: 1;\n    background-color: #276749;\n    background-color: rgba(39, 103, 73, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-green-900:hover {\n    --bg-opacity: 1;\n    background-color: #22543d;\n    background-color: rgba(34, 84, 61, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-teal-100:hover {\n    --bg-opacity: 1;\n    background-color: #e6fffa;\n    background-color: rgba(230, 255, 250, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-teal-200:hover {\n    --bg-opacity: 1;\n    background-color: #b2f5ea;\n    background-color: rgba(178, 245, 234, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-teal-300:hover {\n    --bg-opacity: 1;\n    background-color: #81e6d9;\n    background-color: rgba(129, 230, 217, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-teal-400:hover {\n    --bg-opacity: 1;\n    background-color: #4fd1c5;\n    background-color: rgba(79, 209, 197, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-teal-500:hover {\n    --bg-opacity: 1;\n    background-color: #38b2ac;\n    background-color: rgba(56, 178, 172, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-teal-600:hover {\n    --bg-opacity: 1;\n    background-color: #319795;\n    background-color: rgba(49, 151, 149, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-teal-700:hover {\n    --bg-opacity: 1;\n    background-color: #2c7a7b;\n    background-color: rgba(44, 122, 123, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-teal-800:hover {\n    --bg-opacity: 1;\n    background-color: #285e61;\n    background-color: rgba(40, 94, 97, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-teal-900:hover {\n    --bg-opacity: 1;\n    background-color: #234e52;\n    background-color: rgba(35, 78, 82, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-blue-100:hover {\n    --bg-opacity: 1;\n    background-color: #ebf8ff;\n    background-color: rgba(235, 248, 255, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-blue-200:hover {\n    --bg-opacity: 1;\n    background-color: #bee3f8;\n    background-color: rgba(190, 227, 248, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-blue-300:hover {\n    --bg-opacity: 1;\n    background-color: #90cdf4;\n    background-color: rgba(144, 205, 244, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-blue-400:hover {\n    --bg-opacity: 1;\n    background-color: #63b3ed;\n    background-color: rgba(99, 179, 237, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-blue-500:hover {\n    --bg-opacity: 1;\n    background-color: #4299e1;\n    background-color: rgba(66, 153, 225, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-blue-600:hover {\n    --bg-opacity: 1;\n    background-color: #3182ce;\n    background-color: rgba(49, 130, 206, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-blue-700:hover {\n    --bg-opacity: 1;\n    background-color: #2b6cb0;\n    background-color: rgba(43, 108, 176, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-blue-800:hover {\n    --bg-opacity: 1;\n    background-color: #2c5282;\n    background-color: rgba(44, 82, 130, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-blue-900:hover {\n    --bg-opacity: 1;\n    background-color: #2a4365;\n    background-color: rgba(42, 67, 101, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-indigo-100:hover {\n    --bg-opacity: 1;\n    background-color: #ebf4ff;\n    background-color: rgba(235, 244, 255, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-indigo-200:hover {\n    --bg-opacity: 1;\n    background-color: #c3dafe;\n    background-color: rgba(195, 218, 254, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-indigo-300:hover {\n    --bg-opacity: 1;\n    background-color: #a3bffa;\n    background-color: rgba(163, 191, 250, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-indigo-400:hover {\n    --bg-opacity: 1;\n    background-color: #7f9cf5;\n    background-color: rgba(127, 156, 245, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-indigo-500:hover {\n    --bg-opacity: 1;\n    background-color: #667eea;\n    background-color: rgba(102, 126, 234, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-indigo-600:hover {\n    --bg-opacity: 1;\n    background-color: #5a67d8;\n    background-color: rgba(90, 103, 216, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-indigo-700:hover {\n    --bg-opacity: 1;\n    background-color: #4c51bf;\n    background-color: rgba(76, 81, 191, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-indigo-800:hover {\n    --bg-opacity: 1;\n    background-color: #434190;\n    background-color: rgba(67, 65, 144, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-indigo-900:hover {\n    --bg-opacity: 1;\n    background-color: #3c366b;\n    background-color: rgba(60, 54, 107, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-purple-100:hover {\n    --bg-opacity: 1;\n    background-color: #faf5ff;\n    background-color: rgba(250, 245, 255, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-purple-200:hover {\n    --bg-opacity: 1;\n    background-color: #e9d8fd;\n    background-color: rgba(233, 216, 253, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-purple-300:hover {\n    --bg-opacity: 1;\n    background-color: #d6bcfa;\n    background-color: rgba(214, 188, 250, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-purple-400:hover {\n    --bg-opacity: 1;\n    background-color: #b794f4;\n    background-color: rgba(183, 148, 244, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-purple-500:hover {\n    --bg-opacity: 1;\n    background-color: #9f7aea;\n    background-color: rgba(159, 122, 234, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-purple-600:hover {\n    --bg-opacity: 1;\n    background-color: #805ad5;\n    background-color: rgba(128, 90, 213, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-purple-700:hover {\n    --bg-opacity: 1;\n    background-color: #6b46c1;\n    background-color: rgba(107, 70, 193, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-purple-800:hover {\n    --bg-opacity: 1;\n    background-color: #553c9a;\n    background-color: rgba(85, 60, 154, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-purple-900:hover {\n    --bg-opacity: 1;\n    background-color: #44337a;\n    background-color: rgba(68, 51, 122, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-pink-100:hover {\n    --bg-opacity: 1;\n    background-color: #fff5f7;\n    background-color: rgba(255, 245, 247, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-pink-200:hover {\n    --bg-opacity: 1;\n    background-color: #fed7e2;\n    background-color: rgba(254, 215, 226, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-pink-300:hover {\n    --bg-opacity: 1;\n    background-color: #fbb6ce;\n    background-color: rgba(251, 182, 206, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-pink-400:hover {\n    --bg-opacity: 1;\n    background-color: #f687b3;\n    background-color: rgba(246, 135, 179, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-pink-500:hover {\n    --bg-opacity: 1;\n    background-color: #ed64a6;\n    background-color: rgba(237, 100, 166, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-pink-600:hover {\n    --bg-opacity: 1;\n    background-color: #d53f8c;\n    background-color: rgba(213, 63, 140, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-pink-700:hover {\n    --bg-opacity: 1;\n    background-color: #b83280;\n    background-color: rgba(184, 50, 128, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-pink-800:hover {\n    --bg-opacity: 1;\n    background-color: #97266d;\n    background-color: rgba(151, 38, 109, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-pink-900:hover {\n    --bg-opacity: 1;\n    background-color: #702459;\n    background-color: rgba(112, 36, 89, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-grayscale-80:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 8%);\n    background-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-grayscale-100:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 10%);\n    background-color: rgba(25.5, 25.5, 25.5, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-grayscale-200:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 20%);\n    background-color: rgba(51, 51, 51, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-grayscale-300:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 30%);\n    background-color: rgba(76.5, 76.5, 76.5, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-grayscale-400:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 40%);\n    background-color: rgba(102, 102, 102, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-grayscale-500:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 50%);\n    background-color: rgba(127.5, 127.5, 127.5, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-grayscale-600:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 60%);\n    background-color: rgba(153, 153, 153, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-grayscale-700:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 70%);\n    background-color: rgba(178.5, 178.5, 178.5, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-grayscale-800:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 80%);\n    background-color: rgba(204, 204, 204, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-grayscale-840:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 84%);\n    background-color: rgba(214.2, 214.2, 214.2, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-grayscale-870:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 87%);\n    background-color: rgba(221.85, 221.85, 221.85, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-grayscale-900:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 90%);\n    background-color: rgba(229.5, 229.5, 229.5, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-grayscale-930:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 93%);\n    background-color: rgba(237.15, 237.15, 237.15, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-primary:hover {\n    --bg-opacity: 1;\n    background-color: hsl(210, 100%, 52%);\n    background-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--bg-opacity));\n  }\n\n  .sm\\:hover\\:bg-background-main:hover {\n    background-color: var(--main-background);\n  }\n\n  .sm\\:hover\\:bg-background-secondary:hover {\n    background-color: var(--secondary-background);\n  }\n\n  .sm\\:hover\\:bg-foreground:hover {\n    background-color: var(--foreground);\n  }\n\n  .sm\\:hover\\:bg-panels-bg:hover {\n    background-color: var(--panels-background);\n  }\n\n  .sm\\:focus\\:bg-transparent:focus {\n    background-color: transparent;\n  }\n\n  .sm\\:focus\\:bg-current:focus {\n    background-color: currentColor;\n  }\n\n  .sm\\:focus\\:bg-black:focus {\n    --bg-opacity: 1;\n    background-color: #000;\n    background-color: rgba(0, 0, 0, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-white:focus {\n    --bg-opacity: 1;\n    background-color: #fff;\n    background-color: rgba(255, 255, 255, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-gray-100:focus {\n    --bg-opacity: 1;\n    background-color: #f7fafc;\n    background-color: rgba(247, 250, 252, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-gray-200:focus {\n    --bg-opacity: 1;\n    background-color: #edf2f7;\n    background-color: rgba(237, 242, 247, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-gray-300:focus {\n    --bg-opacity: 1;\n    background-color: #e2e8f0;\n    background-color: rgba(226, 232, 240, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-gray-400:focus {\n    --bg-opacity: 1;\n    background-color: #cbd5e0;\n    background-color: rgba(203, 213, 224, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-gray-500:focus {\n    --bg-opacity: 1;\n    background-color: #a0aec0;\n    background-color: rgba(160, 174, 192, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-gray-600:focus {\n    --bg-opacity: 1;\n    background-color: #718096;\n    background-color: rgba(113, 128, 150, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-gray-700:focus {\n    --bg-opacity: 1;\n    background-color: #4a5568;\n    background-color: rgba(74, 85, 104, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-gray-800:focus {\n    --bg-opacity: 1;\n    background-color: #2d3748;\n    background-color: rgba(45, 55, 72, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-gray-900:focus {\n    --bg-opacity: 1;\n    background-color: #1a202c;\n    background-color: rgba(26, 32, 44, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-red-100:focus {\n    --bg-opacity: 1;\n    background-color: #fff5f5;\n    background-color: rgba(255, 245, 245, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-red-200:focus {\n    --bg-opacity: 1;\n    background-color: #fed7d7;\n    background-color: rgba(254, 215, 215, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-red-300:focus {\n    --bg-opacity: 1;\n    background-color: #feb2b2;\n    background-color: rgba(254, 178, 178, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-red-400:focus {\n    --bg-opacity: 1;\n    background-color: #fc8181;\n    background-color: rgba(252, 129, 129, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-red-500:focus {\n    --bg-opacity: 1;\n    background-color: #f56565;\n    background-color: rgba(245, 101, 101, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-red-600:focus {\n    --bg-opacity: 1;\n    background-color: #e53e3e;\n    background-color: rgba(229, 62, 62, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-red-700:focus {\n    --bg-opacity: 1;\n    background-color: #c53030;\n    background-color: rgba(197, 48, 48, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-red-800:focus {\n    --bg-opacity: 1;\n    background-color: #9b2c2c;\n    background-color: rgba(155, 44, 44, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-red-900:focus {\n    --bg-opacity: 1;\n    background-color: #742a2a;\n    background-color: rgba(116, 42, 42, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-orange-100:focus {\n    --bg-opacity: 1;\n    background-color: #fffaf0;\n    background-color: rgba(255, 250, 240, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-orange-200:focus {\n    --bg-opacity: 1;\n    background-color: #feebc8;\n    background-color: rgba(254, 235, 200, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-orange-300:focus {\n    --bg-opacity: 1;\n    background-color: #fbd38d;\n    background-color: rgba(251, 211, 141, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-orange-400:focus {\n    --bg-opacity: 1;\n    background-color: #f6ad55;\n    background-color: rgba(246, 173, 85, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-orange-500:focus {\n    --bg-opacity: 1;\n    background-color: #ed8936;\n    background-color: rgba(237, 137, 54, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-orange-600:focus {\n    --bg-opacity: 1;\n    background-color: #dd6b20;\n    background-color: rgba(221, 107, 32, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-orange-700:focus {\n    --bg-opacity: 1;\n    background-color: #c05621;\n    background-color: rgba(192, 86, 33, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-orange-800:focus {\n    --bg-opacity: 1;\n    background-color: #9c4221;\n    background-color: rgba(156, 66, 33, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-orange-900:focus {\n    --bg-opacity: 1;\n    background-color: #7b341e;\n    background-color: rgba(123, 52, 30, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-yellow-100:focus {\n    --bg-opacity: 1;\n    background-color: #fffff0;\n    background-color: rgba(255, 255, 240, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-yellow-200:focus {\n    --bg-opacity: 1;\n    background-color: #fefcbf;\n    background-color: rgba(254, 252, 191, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-yellow-300:focus {\n    --bg-opacity: 1;\n    background-color: #faf089;\n    background-color: rgba(250, 240, 137, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-yellow-400:focus {\n    --bg-opacity: 1;\n    background-color: #f6e05e;\n    background-color: rgba(246, 224, 94, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-yellow-500:focus {\n    --bg-opacity: 1;\n    background-color: #ecc94b;\n    background-color: rgba(236, 201, 75, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-yellow-600:focus {\n    --bg-opacity: 1;\n    background-color: #d69e2e;\n    background-color: rgba(214, 158, 46, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-yellow-700:focus {\n    --bg-opacity: 1;\n    background-color: #b7791f;\n    background-color: rgba(183, 121, 31, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-yellow-800:focus {\n    --bg-opacity: 1;\n    background-color: #975a16;\n    background-color: rgba(151, 90, 22, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-yellow-900:focus {\n    --bg-opacity: 1;\n    background-color: #744210;\n    background-color: rgba(116, 66, 16, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-green-100:focus {\n    --bg-opacity: 1;\n    background-color: #f0fff4;\n    background-color: rgba(240, 255, 244, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-green-200:focus {\n    --bg-opacity: 1;\n    background-color: #c6f6d5;\n    background-color: rgba(198, 246, 213, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-green-300:focus {\n    --bg-opacity: 1;\n    background-color: #9ae6b4;\n    background-color: rgba(154, 230, 180, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-green-400:focus {\n    --bg-opacity: 1;\n    background-color: #68d391;\n    background-color: rgba(104, 211, 145, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-green-500:focus {\n    --bg-opacity: 1;\n    background-color: #48bb78;\n    background-color: rgba(72, 187, 120, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-green-600:focus {\n    --bg-opacity: 1;\n    background-color: #38a169;\n    background-color: rgba(56, 161, 105, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-green-700:focus {\n    --bg-opacity: 1;\n    background-color: #2f855a;\n    background-color: rgba(47, 133, 90, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-green-800:focus {\n    --bg-opacity: 1;\n    background-color: #276749;\n    background-color: rgba(39, 103, 73, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-green-900:focus {\n    --bg-opacity: 1;\n    background-color: #22543d;\n    background-color: rgba(34, 84, 61, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-teal-100:focus {\n    --bg-opacity: 1;\n    background-color: #e6fffa;\n    background-color: rgba(230, 255, 250, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-teal-200:focus {\n    --bg-opacity: 1;\n    background-color: #b2f5ea;\n    background-color: rgba(178, 245, 234, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-teal-300:focus {\n    --bg-opacity: 1;\n    background-color: #81e6d9;\n    background-color: rgba(129, 230, 217, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-teal-400:focus {\n    --bg-opacity: 1;\n    background-color: #4fd1c5;\n    background-color: rgba(79, 209, 197, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-teal-500:focus {\n    --bg-opacity: 1;\n    background-color: #38b2ac;\n    background-color: rgba(56, 178, 172, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-teal-600:focus {\n    --bg-opacity: 1;\n    background-color: #319795;\n    background-color: rgba(49, 151, 149, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-teal-700:focus {\n    --bg-opacity: 1;\n    background-color: #2c7a7b;\n    background-color: rgba(44, 122, 123, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-teal-800:focus {\n    --bg-opacity: 1;\n    background-color: #285e61;\n    background-color: rgba(40, 94, 97, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-teal-900:focus {\n    --bg-opacity: 1;\n    background-color: #234e52;\n    background-color: rgba(35, 78, 82, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-blue-100:focus {\n    --bg-opacity: 1;\n    background-color: #ebf8ff;\n    background-color: rgba(235, 248, 255, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-blue-200:focus {\n    --bg-opacity: 1;\n    background-color: #bee3f8;\n    background-color: rgba(190, 227, 248, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-blue-300:focus {\n    --bg-opacity: 1;\n    background-color: #90cdf4;\n    background-color: rgba(144, 205, 244, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-blue-400:focus {\n    --bg-opacity: 1;\n    background-color: #63b3ed;\n    background-color: rgba(99, 179, 237, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-blue-500:focus {\n    --bg-opacity: 1;\n    background-color: #4299e1;\n    background-color: rgba(66, 153, 225, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-blue-600:focus {\n    --bg-opacity: 1;\n    background-color: #3182ce;\n    background-color: rgba(49, 130, 206, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-blue-700:focus {\n    --bg-opacity: 1;\n    background-color: #2b6cb0;\n    background-color: rgba(43, 108, 176, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-blue-800:focus {\n    --bg-opacity: 1;\n    background-color: #2c5282;\n    background-color: rgba(44, 82, 130, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-blue-900:focus {\n    --bg-opacity: 1;\n    background-color: #2a4365;\n    background-color: rgba(42, 67, 101, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-indigo-100:focus {\n    --bg-opacity: 1;\n    background-color: #ebf4ff;\n    background-color: rgba(235, 244, 255, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-indigo-200:focus {\n    --bg-opacity: 1;\n    background-color: #c3dafe;\n    background-color: rgba(195, 218, 254, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-indigo-300:focus {\n    --bg-opacity: 1;\n    background-color: #a3bffa;\n    background-color: rgba(163, 191, 250, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-indigo-400:focus {\n    --bg-opacity: 1;\n    background-color: #7f9cf5;\n    background-color: rgba(127, 156, 245, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-indigo-500:focus {\n    --bg-opacity: 1;\n    background-color: #667eea;\n    background-color: rgba(102, 126, 234, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-indigo-600:focus {\n    --bg-opacity: 1;\n    background-color: #5a67d8;\n    background-color: rgba(90, 103, 216, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-indigo-700:focus {\n    --bg-opacity: 1;\n    background-color: #4c51bf;\n    background-color: rgba(76, 81, 191, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-indigo-800:focus {\n    --bg-opacity: 1;\n    background-color: #434190;\n    background-color: rgba(67, 65, 144, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-indigo-900:focus {\n    --bg-opacity: 1;\n    background-color: #3c366b;\n    background-color: rgba(60, 54, 107, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-purple-100:focus {\n    --bg-opacity: 1;\n    background-color: #faf5ff;\n    background-color: rgba(250, 245, 255, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-purple-200:focus {\n    --bg-opacity: 1;\n    background-color: #e9d8fd;\n    background-color: rgba(233, 216, 253, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-purple-300:focus {\n    --bg-opacity: 1;\n    background-color: #d6bcfa;\n    background-color: rgba(214, 188, 250, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-purple-400:focus {\n    --bg-opacity: 1;\n    background-color: #b794f4;\n    background-color: rgba(183, 148, 244, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-purple-500:focus {\n    --bg-opacity: 1;\n    background-color: #9f7aea;\n    background-color: rgba(159, 122, 234, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-purple-600:focus {\n    --bg-opacity: 1;\n    background-color: #805ad5;\n    background-color: rgba(128, 90, 213, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-purple-700:focus {\n    --bg-opacity: 1;\n    background-color: #6b46c1;\n    background-color: rgba(107, 70, 193, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-purple-800:focus {\n    --bg-opacity: 1;\n    background-color: #553c9a;\n    background-color: rgba(85, 60, 154, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-purple-900:focus {\n    --bg-opacity: 1;\n    background-color: #44337a;\n    background-color: rgba(68, 51, 122, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-pink-100:focus {\n    --bg-opacity: 1;\n    background-color: #fff5f7;\n    background-color: rgba(255, 245, 247, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-pink-200:focus {\n    --bg-opacity: 1;\n    background-color: #fed7e2;\n    background-color: rgba(254, 215, 226, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-pink-300:focus {\n    --bg-opacity: 1;\n    background-color: #fbb6ce;\n    background-color: rgba(251, 182, 206, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-pink-400:focus {\n    --bg-opacity: 1;\n    background-color: #f687b3;\n    background-color: rgba(246, 135, 179, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-pink-500:focus {\n    --bg-opacity: 1;\n    background-color: #ed64a6;\n    background-color: rgba(237, 100, 166, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-pink-600:focus {\n    --bg-opacity: 1;\n    background-color: #d53f8c;\n    background-color: rgba(213, 63, 140, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-pink-700:focus {\n    --bg-opacity: 1;\n    background-color: #b83280;\n    background-color: rgba(184, 50, 128, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-pink-800:focus {\n    --bg-opacity: 1;\n    background-color: #97266d;\n    background-color: rgba(151, 38, 109, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-pink-900:focus {\n    --bg-opacity: 1;\n    background-color: #702459;\n    background-color: rgba(112, 36, 89, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-grayscale-80:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 8%);\n    background-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-grayscale-100:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 10%);\n    background-color: rgba(25.5, 25.5, 25.5, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-grayscale-200:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 20%);\n    background-color: rgba(51, 51, 51, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-grayscale-300:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 30%);\n    background-color: rgba(76.5, 76.5, 76.5, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-grayscale-400:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 40%);\n    background-color: rgba(102, 102, 102, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-grayscale-500:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 50%);\n    background-color: rgba(127.5, 127.5, 127.5, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-grayscale-600:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 60%);\n    background-color: rgba(153, 153, 153, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-grayscale-700:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 70%);\n    background-color: rgba(178.5, 178.5, 178.5, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-grayscale-800:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 80%);\n    background-color: rgba(204, 204, 204, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-grayscale-840:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 84%);\n    background-color: rgba(214.2, 214.2, 214.2, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-grayscale-870:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 87%);\n    background-color: rgba(221.85, 221.85, 221.85, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-grayscale-900:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 90%);\n    background-color: rgba(229.5, 229.5, 229.5, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-grayscale-930:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 93%);\n    background-color: rgba(237.15, 237.15, 237.15, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-primary:focus {\n    --bg-opacity: 1;\n    background-color: hsl(210, 100%, 52%);\n    background-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--bg-opacity));\n  }\n\n  .sm\\:focus\\:bg-background-main:focus {\n    background-color: var(--main-background);\n  }\n\n  .sm\\:focus\\:bg-background-secondary:focus {\n    background-color: var(--secondary-background);\n  }\n\n  .sm\\:focus\\:bg-foreground:focus {\n    background-color: var(--foreground);\n  }\n\n  .sm\\:focus\\:bg-panels-bg:focus {\n    background-color: var(--panels-background);\n  }\n\n  .sm\\:bg-none {\n    background-image: none;\n  }\n\n  .sm\\:bg-gradient-to-t {\n    background-image: linear-gradient(to top, var(--gradient-color-stops));\n  }\n\n  .sm\\:bg-gradient-to-tr {\n    background-image: linear-gradient(to top right, var(--gradient-color-stops));\n  }\n\n  .sm\\:bg-gradient-to-r {\n    background-image: linear-gradient(to right, var(--gradient-color-stops));\n  }\n\n  .sm\\:bg-gradient-to-br {\n    background-image: linear-gradient(to bottom right, var(--gradient-color-stops));\n  }\n\n  .sm\\:bg-gradient-to-b {\n    background-image: linear-gradient(to bottom, var(--gradient-color-stops));\n  }\n\n  .sm\\:bg-gradient-to-bl {\n    background-image: linear-gradient(to bottom left, var(--gradient-color-stops));\n  }\n\n  .sm\\:bg-gradient-to-l {\n    background-image: linear-gradient(to left, var(--gradient-color-stops));\n  }\n\n  .sm\\:bg-gradient-to-tl {\n    background-image: linear-gradient(to top left, var(--gradient-color-stops));\n  }\n\n  .sm\\:from-transparent {\n    --gradient-from-color: transparent;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .sm\\:from-current {\n    --gradient-from-color: currentColor;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:from-black {\n    --gradient-from-color: #000;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .sm\\:from-white {\n    --gradient-from-color: #fff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:from-gray-100 {\n    --gradient-from-color: #f7fafc;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n  }\n\n  .sm\\:from-gray-200 {\n    --gradient-from-color: #edf2f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n  }\n\n  .sm\\:from-gray-300 {\n    --gradient-from-color: #e2e8f0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n  }\n\n  .sm\\:from-gray-400 {\n    --gradient-from-color: #cbd5e0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n  }\n\n  .sm\\:from-gray-500 {\n    --gradient-from-color: #a0aec0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n  }\n\n  .sm\\:from-gray-600 {\n    --gradient-from-color: #718096;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n  }\n\n  .sm\\:from-gray-700 {\n    --gradient-from-color: #4a5568;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n  }\n\n  .sm\\:from-gray-800 {\n    --gradient-from-color: #2d3748;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n  }\n\n  .sm\\:from-gray-900 {\n    --gradient-from-color: #1a202c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n  }\n\n  .sm\\:from-red-100 {\n    --gradient-from-color: #fff5f5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n  }\n\n  .sm\\:from-red-200 {\n    --gradient-from-color: #fed7d7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n  }\n\n  .sm\\:from-red-300 {\n    --gradient-from-color: #feb2b2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n  }\n\n  .sm\\:from-red-400 {\n    --gradient-from-color: #fc8181;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n  }\n\n  .sm\\:from-red-500 {\n    --gradient-from-color: #f56565;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n  }\n\n  .sm\\:from-red-600 {\n    --gradient-from-color: #e53e3e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n  }\n\n  .sm\\:from-red-700 {\n    --gradient-from-color: #c53030;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n  }\n\n  .sm\\:from-red-800 {\n    --gradient-from-color: #9b2c2c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n  }\n\n  .sm\\:from-red-900 {\n    --gradient-from-color: #742a2a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n  }\n\n  .sm\\:from-orange-100 {\n    --gradient-from-color: #fffaf0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n  }\n\n  .sm\\:from-orange-200 {\n    --gradient-from-color: #feebc8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n  }\n\n  .sm\\:from-orange-300 {\n    --gradient-from-color: #fbd38d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n  }\n\n  .sm\\:from-orange-400 {\n    --gradient-from-color: #f6ad55;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n  }\n\n  .sm\\:from-orange-500 {\n    --gradient-from-color: #ed8936;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n  }\n\n  .sm\\:from-orange-600 {\n    --gradient-from-color: #dd6b20;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n  }\n\n  .sm\\:from-orange-700 {\n    --gradient-from-color: #c05621;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n  }\n\n  .sm\\:from-orange-800 {\n    --gradient-from-color: #9c4221;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n  }\n\n  .sm\\:from-orange-900 {\n    --gradient-from-color: #7b341e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n  }\n\n  .sm\\:from-yellow-100 {\n    --gradient-from-color: #fffff0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n  }\n\n  .sm\\:from-yellow-200 {\n    --gradient-from-color: #fefcbf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n  }\n\n  .sm\\:from-yellow-300 {\n    --gradient-from-color: #faf089;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n  }\n\n  .sm\\:from-yellow-400 {\n    --gradient-from-color: #f6e05e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n  }\n\n  .sm\\:from-yellow-500 {\n    --gradient-from-color: #ecc94b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n  }\n\n  .sm\\:from-yellow-600 {\n    --gradient-from-color: #d69e2e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n  }\n\n  .sm\\:from-yellow-700 {\n    --gradient-from-color: #b7791f;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n  }\n\n  .sm\\:from-yellow-800 {\n    --gradient-from-color: #975a16;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n  }\n\n  .sm\\:from-yellow-900 {\n    --gradient-from-color: #744210;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n  }\n\n  .sm\\:from-green-100 {\n    --gradient-from-color: #f0fff4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n  }\n\n  .sm\\:from-green-200 {\n    --gradient-from-color: #c6f6d5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n  }\n\n  .sm\\:from-green-300 {\n    --gradient-from-color: #9ae6b4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n  }\n\n  .sm\\:from-green-400 {\n    --gradient-from-color: #68d391;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n  }\n\n  .sm\\:from-green-500 {\n    --gradient-from-color: #48bb78;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n  }\n\n  .sm\\:from-green-600 {\n    --gradient-from-color: #38a169;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n  }\n\n  .sm\\:from-green-700 {\n    --gradient-from-color: #2f855a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n  }\n\n  .sm\\:from-green-800 {\n    --gradient-from-color: #276749;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n  }\n\n  .sm\\:from-green-900 {\n    --gradient-from-color: #22543d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n  }\n\n  .sm\\:from-teal-100 {\n    --gradient-from-color: #e6fffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n  }\n\n  .sm\\:from-teal-200 {\n    --gradient-from-color: #b2f5ea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n  }\n\n  .sm\\:from-teal-300 {\n    --gradient-from-color: #81e6d9;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n  }\n\n  .sm\\:from-teal-400 {\n    --gradient-from-color: #4fd1c5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n  }\n\n  .sm\\:from-teal-500 {\n    --gradient-from-color: #38b2ac;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n  }\n\n  .sm\\:from-teal-600 {\n    --gradient-from-color: #319795;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n  }\n\n  .sm\\:from-teal-700 {\n    --gradient-from-color: #2c7a7b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n  }\n\n  .sm\\:from-teal-800 {\n    --gradient-from-color: #285e61;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n  }\n\n  .sm\\:from-teal-900 {\n    --gradient-from-color: #234e52;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n  }\n\n  .sm\\:from-blue-100 {\n    --gradient-from-color: #ebf8ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n  }\n\n  .sm\\:from-blue-200 {\n    --gradient-from-color: #bee3f8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n  }\n\n  .sm\\:from-blue-300 {\n    --gradient-from-color: #90cdf4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n  }\n\n  .sm\\:from-blue-400 {\n    --gradient-from-color: #63b3ed;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n  }\n\n  .sm\\:from-blue-500 {\n    --gradient-from-color: #4299e1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n  }\n\n  .sm\\:from-blue-600 {\n    --gradient-from-color: #3182ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n  }\n\n  .sm\\:from-blue-700 {\n    --gradient-from-color: #2b6cb0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n  }\n\n  .sm\\:from-blue-800 {\n    --gradient-from-color: #2c5282;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n  }\n\n  .sm\\:from-blue-900 {\n    --gradient-from-color: #2a4365;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n  }\n\n  .sm\\:from-indigo-100 {\n    --gradient-from-color: #ebf4ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n  }\n\n  .sm\\:from-indigo-200 {\n    --gradient-from-color: #c3dafe;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n  }\n\n  .sm\\:from-indigo-300 {\n    --gradient-from-color: #a3bffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n  }\n\n  .sm\\:from-indigo-400 {\n    --gradient-from-color: #7f9cf5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n  }\n\n  .sm\\:from-indigo-500 {\n    --gradient-from-color: #667eea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n  }\n\n  .sm\\:from-indigo-600 {\n    --gradient-from-color: #5a67d8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n  }\n\n  .sm\\:from-indigo-700 {\n    --gradient-from-color: #4c51bf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n  }\n\n  .sm\\:from-indigo-800 {\n    --gradient-from-color: #434190;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n  }\n\n  .sm\\:from-indigo-900 {\n    --gradient-from-color: #3c366b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n  }\n\n  .sm\\:from-purple-100 {\n    --gradient-from-color: #faf5ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n  }\n\n  .sm\\:from-purple-200 {\n    --gradient-from-color: #e9d8fd;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n  }\n\n  .sm\\:from-purple-300 {\n    --gradient-from-color: #d6bcfa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n  }\n\n  .sm\\:from-purple-400 {\n    --gradient-from-color: #b794f4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n  }\n\n  .sm\\:from-purple-500 {\n    --gradient-from-color: #9f7aea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n  }\n\n  .sm\\:from-purple-600 {\n    --gradient-from-color: #805ad5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n  }\n\n  .sm\\:from-purple-700 {\n    --gradient-from-color: #6b46c1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n  }\n\n  .sm\\:from-purple-800 {\n    --gradient-from-color: #553c9a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n  }\n\n  .sm\\:from-purple-900 {\n    --gradient-from-color: #44337a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n  }\n\n  .sm\\:from-pink-100 {\n    --gradient-from-color: #fff5f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n  }\n\n  .sm\\:from-pink-200 {\n    --gradient-from-color: #fed7e2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n  }\n\n  .sm\\:from-pink-300 {\n    --gradient-from-color: #fbb6ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n  }\n\n  .sm\\:from-pink-400 {\n    --gradient-from-color: #f687b3;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n  }\n\n  .sm\\:from-pink-500 {\n    --gradient-from-color: #ed64a6;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n  }\n\n  .sm\\:from-pink-600 {\n    --gradient-from-color: #d53f8c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n  }\n\n  .sm\\:from-pink-700 {\n    --gradient-from-color: #b83280;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n  }\n\n  .sm\\:from-pink-800 {\n    --gradient-from-color: #97266d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n  }\n\n  .sm\\:from-pink-900 {\n    --gradient-from-color: #702459;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n  }\n\n  .sm\\:from-grayscale-80 {\n    --gradient-from-color: hsl(0, 0%, 8%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n  }\n\n  .sm\\:from-grayscale-100 {\n    --gradient-from-color: hsl(0, 0%, 10%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n  }\n\n  .sm\\:from-grayscale-200 {\n    --gradient-from-color: hsl(0, 0%, 20%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n  }\n\n  .sm\\:from-grayscale-300 {\n    --gradient-from-color: hsl(0, 0%, 30%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n  }\n\n  .sm\\:from-grayscale-400 {\n    --gradient-from-color: hsl(0, 0%, 40%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n  }\n\n  .sm\\:from-grayscale-500 {\n    --gradient-from-color: hsl(0, 0%, 50%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n  }\n\n  .sm\\:from-grayscale-600 {\n    --gradient-from-color: hsl(0, 0%, 60%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n  }\n\n  .sm\\:from-grayscale-700 {\n    --gradient-from-color: hsl(0, 0%, 70%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n  }\n\n  .sm\\:from-grayscale-800 {\n    --gradient-from-color: hsl(0, 0%, 80%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n  }\n\n  .sm\\:from-grayscale-840 {\n    --gradient-from-color: hsl(0, 0%, 84%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n  }\n\n  .sm\\:from-grayscale-870 {\n    --gradient-from-color: hsl(0, 0%, 87%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n  }\n\n  .sm\\:from-grayscale-900 {\n    --gradient-from-color: hsl(0, 0%, 90%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n  }\n\n  .sm\\:from-grayscale-930 {\n    --gradient-from-color: hsl(0, 0%, 93%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n  }\n\n  .sm\\:from-primary {\n    --gradient-from-color: hsl(210, 100%, 52%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n  }\n\n  .sm\\:from-background-main {\n    --gradient-from-color: var(--main-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:from-background-secondary {\n    --gradient-from-color: var(--secondary-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:from-foreground {\n    --gradient-from-color: var(--foreground);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:from-panels-bg {\n    --gradient-from-color: var(--panels-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:via-transparent {\n    --gradient-via-color: transparent;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .sm\\:via-current {\n    --gradient-via-color: currentColor;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:via-black {\n    --gradient-via-color: #000;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .sm\\:via-white {\n    --gradient-via-color: #fff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:via-gray-100 {\n    --gradient-via-color: #f7fafc;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n  }\n\n  .sm\\:via-gray-200 {\n    --gradient-via-color: #edf2f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n  }\n\n  .sm\\:via-gray-300 {\n    --gradient-via-color: #e2e8f0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n  }\n\n  .sm\\:via-gray-400 {\n    --gradient-via-color: #cbd5e0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n  }\n\n  .sm\\:via-gray-500 {\n    --gradient-via-color: #a0aec0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n  }\n\n  .sm\\:via-gray-600 {\n    --gradient-via-color: #718096;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n  }\n\n  .sm\\:via-gray-700 {\n    --gradient-via-color: #4a5568;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n  }\n\n  .sm\\:via-gray-800 {\n    --gradient-via-color: #2d3748;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n  }\n\n  .sm\\:via-gray-900 {\n    --gradient-via-color: #1a202c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n  }\n\n  .sm\\:via-red-100 {\n    --gradient-via-color: #fff5f5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n  }\n\n  .sm\\:via-red-200 {\n    --gradient-via-color: #fed7d7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n  }\n\n  .sm\\:via-red-300 {\n    --gradient-via-color: #feb2b2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n  }\n\n  .sm\\:via-red-400 {\n    --gradient-via-color: #fc8181;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n  }\n\n  .sm\\:via-red-500 {\n    --gradient-via-color: #f56565;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n  }\n\n  .sm\\:via-red-600 {\n    --gradient-via-color: #e53e3e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n  }\n\n  .sm\\:via-red-700 {\n    --gradient-via-color: #c53030;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n  }\n\n  .sm\\:via-red-800 {\n    --gradient-via-color: #9b2c2c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n  }\n\n  .sm\\:via-red-900 {\n    --gradient-via-color: #742a2a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n  }\n\n  .sm\\:via-orange-100 {\n    --gradient-via-color: #fffaf0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n  }\n\n  .sm\\:via-orange-200 {\n    --gradient-via-color: #feebc8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n  }\n\n  .sm\\:via-orange-300 {\n    --gradient-via-color: #fbd38d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n  }\n\n  .sm\\:via-orange-400 {\n    --gradient-via-color: #f6ad55;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n  }\n\n  .sm\\:via-orange-500 {\n    --gradient-via-color: #ed8936;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n  }\n\n  .sm\\:via-orange-600 {\n    --gradient-via-color: #dd6b20;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n  }\n\n  .sm\\:via-orange-700 {\n    --gradient-via-color: #c05621;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n  }\n\n  .sm\\:via-orange-800 {\n    --gradient-via-color: #9c4221;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n  }\n\n  .sm\\:via-orange-900 {\n    --gradient-via-color: #7b341e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n  }\n\n  .sm\\:via-yellow-100 {\n    --gradient-via-color: #fffff0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n  }\n\n  .sm\\:via-yellow-200 {\n    --gradient-via-color: #fefcbf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n  }\n\n  .sm\\:via-yellow-300 {\n    --gradient-via-color: #faf089;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n  }\n\n  .sm\\:via-yellow-400 {\n    --gradient-via-color: #f6e05e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n  }\n\n  .sm\\:via-yellow-500 {\n    --gradient-via-color: #ecc94b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n  }\n\n  .sm\\:via-yellow-600 {\n    --gradient-via-color: #d69e2e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n  }\n\n  .sm\\:via-yellow-700 {\n    --gradient-via-color: #b7791f;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n  }\n\n  .sm\\:via-yellow-800 {\n    --gradient-via-color: #975a16;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n  }\n\n  .sm\\:via-yellow-900 {\n    --gradient-via-color: #744210;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n  }\n\n  .sm\\:via-green-100 {\n    --gradient-via-color: #f0fff4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n  }\n\n  .sm\\:via-green-200 {\n    --gradient-via-color: #c6f6d5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n  }\n\n  .sm\\:via-green-300 {\n    --gradient-via-color: #9ae6b4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n  }\n\n  .sm\\:via-green-400 {\n    --gradient-via-color: #68d391;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n  }\n\n  .sm\\:via-green-500 {\n    --gradient-via-color: #48bb78;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n  }\n\n  .sm\\:via-green-600 {\n    --gradient-via-color: #38a169;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n  }\n\n  .sm\\:via-green-700 {\n    --gradient-via-color: #2f855a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n  }\n\n  .sm\\:via-green-800 {\n    --gradient-via-color: #276749;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n  }\n\n  .sm\\:via-green-900 {\n    --gradient-via-color: #22543d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n  }\n\n  .sm\\:via-teal-100 {\n    --gradient-via-color: #e6fffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n  }\n\n  .sm\\:via-teal-200 {\n    --gradient-via-color: #b2f5ea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n  }\n\n  .sm\\:via-teal-300 {\n    --gradient-via-color: #81e6d9;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n  }\n\n  .sm\\:via-teal-400 {\n    --gradient-via-color: #4fd1c5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n  }\n\n  .sm\\:via-teal-500 {\n    --gradient-via-color: #38b2ac;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n  }\n\n  .sm\\:via-teal-600 {\n    --gradient-via-color: #319795;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n  }\n\n  .sm\\:via-teal-700 {\n    --gradient-via-color: #2c7a7b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n  }\n\n  .sm\\:via-teal-800 {\n    --gradient-via-color: #285e61;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n  }\n\n  .sm\\:via-teal-900 {\n    --gradient-via-color: #234e52;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n  }\n\n  .sm\\:via-blue-100 {\n    --gradient-via-color: #ebf8ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n  }\n\n  .sm\\:via-blue-200 {\n    --gradient-via-color: #bee3f8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n  }\n\n  .sm\\:via-blue-300 {\n    --gradient-via-color: #90cdf4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n  }\n\n  .sm\\:via-blue-400 {\n    --gradient-via-color: #63b3ed;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n  }\n\n  .sm\\:via-blue-500 {\n    --gradient-via-color: #4299e1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n  }\n\n  .sm\\:via-blue-600 {\n    --gradient-via-color: #3182ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n  }\n\n  .sm\\:via-blue-700 {\n    --gradient-via-color: #2b6cb0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n  }\n\n  .sm\\:via-blue-800 {\n    --gradient-via-color: #2c5282;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n  }\n\n  .sm\\:via-blue-900 {\n    --gradient-via-color: #2a4365;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n  }\n\n  .sm\\:via-indigo-100 {\n    --gradient-via-color: #ebf4ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n  }\n\n  .sm\\:via-indigo-200 {\n    --gradient-via-color: #c3dafe;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n  }\n\n  .sm\\:via-indigo-300 {\n    --gradient-via-color: #a3bffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n  }\n\n  .sm\\:via-indigo-400 {\n    --gradient-via-color: #7f9cf5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n  }\n\n  .sm\\:via-indigo-500 {\n    --gradient-via-color: #667eea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n  }\n\n  .sm\\:via-indigo-600 {\n    --gradient-via-color: #5a67d8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n  }\n\n  .sm\\:via-indigo-700 {\n    --gradient-via-color: #4c51bf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n  }\n\n  .sm\\:via-indigo-800 {\n    --gradient-via-color: #434190;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n  }\n\n  .sm\\:via-indigo-900 {\n    --gradient-via-color: #3c366b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n  }\n\n  .sm\\:via-purple-100 {\n    --gradient-via-color: #faf5ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n  }\n\n  .sm\\:via-purple-200 {\n    --gradient-via-color: #e9d8fd;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n  }\n\n  .sm\\:via-purple-300 {\n    --gradient-via-color: #d6bcfa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n  }\n\n  .sm\\:via-purple-400 {\n    --gradient-via-color: #b794f4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n  }\n\n  .sm\\:via-purple-500 {\n    --gradient-via-color: #9f7aea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n  }\n\n  .sm\\:via-purple-600 {\n    --gradient-via-color: #805ad5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n  }\n\n  .sm\\:via-purple-700 {\n    --gradient-via-color: #6b46c1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n  }\n\n  .sm\\:via-purple-800 {\n    --gradient-via-color: #553c9a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n  }\n\n  .sm\\:via-purple-900 {\n    --gradient-via-color: #44337a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n  }\n\n  .sm\\:via-pink-100 {\n    --gradient-via-color: #fff5f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n  }\n\n  .sm\\:via-pink-200 {\n    --gradient-via-color: #fed7e2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n  }\n\n  .sm\\:via-pink-300 {\n    --gradient-via-color: #fbb6ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n  }\n\n  .sm\\:via-pink-400 {\n    --gradient-via-color: #f687b3;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n  }\n\n  .sm\\:via-pink-500 {\n    --gradient-via-color: #ed64a6;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n  }\n\n  .sm\\:via-pink-600 {\n    --gradient-via-color: #d53f8c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n  }\n\n  .sm\\:via-pink-700 {\n    --gradient-via-color: #b83280;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n  }\n\n  .sm\\:via-pink-800 {\n    --gradient-via-color: #97266d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n  }\n\n  .sm\\:via-pink-900 {\n    --gradient-via-color: #702459;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n  }\n\n  .sm\\:via-grayscale-80 {\n    --gradient-via-color: hsl(0, 0%, 8%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n  }\n\n  .sm\\:via-grayscale-100 {\n    --gradient-via-color: hsl(0, 0%, 10%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n  }\n\n  .sm\\:via-grayscale-200 {\n    --gradient-via-color: hsl(0, 0%, 20%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n  }\n\n  .sm\\:via-grayscale-300 {\n    --gradient-via-color: hsl(0, 0%, 30%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n  }\n\n  .sm\\:via-grayscale-400 {\n    --gradient-via-color: hsl(0, 0%, 40%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n  }\n\n  .sm\\:via-grayscale-500 {\n    --gradient-via-color: hsl(0, 0%, 50%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n  }\n\n  .sm\\:via-grayscale-600 {\n    --gradient-via-color: hsl(0, 0%, 60%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n  }\n\n  .sm\\:via-grayscale-700 {\n    --gradient-via-color: hsl(0, 0%, 70%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n  }\n\n  .sm\\:via-grayscale-800 {\n    --gradient-via-color: hsl(0, 0%, 80%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n  }\n\n  .sm\\:via-grayscale-840 {\n    --gradient-via-color: hsl(0, 0%, 84%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n  }\n\n  .sm\\:via-grayscale-870 {\n    --gradient-via-color: hsl(0, 0%, 87%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n  }\n\n  .sm\\:via-grayscale-900 {\n    --gradient-via-color: hsl(0, 0%, 90%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n  }\n\n  .sm\\:via-grayscale-930 {\n    --gradient-via-color: hsl(0, 0%, 93%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n  }\n\n  .sm\\:via-primary {\n    --gradient-via-color: hsl(210, 100%, 52%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n  }\n\n  .sm\\:via-background-main {\n    --gradient-via-color: var(--main-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:via-background-secondary {\n    --gradient-via-color: var(--secondary-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:via-foreground {\n    --gradient-via-color: var(--foreground);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:via-panels-bg {\n    --gradient-via-color: var(--panels-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:to-transparent {\n    --gradient-to-color: transparent;\n  }\n\n  .sm\\:to-current {\n    --gradient-to-color: currentColor;\n  }\n\n  .sm\\:to-black {\n    --gradient-to-color: #000;\n  }\n\n  .sm\\:to-white {\n    --gradient-to-color: #fff;\n  }\n\n  .sm\\:to-gray-100 {\n    --gradient-to-color: #f7fafc;\n  }\n\n  .sm\\:to-gray-200 {\n    --gradient-to-color: #edf2f7;\n  }\n\n  .sm\\:to-gray-300 {\n    --gradient-to-color: #e2e8f0;\n  }\n\n  .sm\\:to-gray-400 {\n    --gradient-to-color: #cbd5e0;\n  }\n\n  .sm\\:to-gray-500 {\n    --gradient-to-color: #a0aec0;\n  }\n\n  .sm\\:to-gray-600 {\n    --gradient-to-color: #718096;\n  }\n\n  .sm\\:to-gray-700 {\n    --gradient-to-color: #4a5568;\n  }\n\n  .sm\\:to-gray-800 {\n    --gradient-to-color: #2d3748;\n  }\n\n  .sm\\:to-gray-900 {\n    --gradient-to-color: #1a202c;\n  }\n\n  .sm\\:to-red-100 {\n    --gradient-to-color: #fff5f5;\n  }\n\n  .sm\\:to-red-200 {\n    --gradient-to-color: #fed7d7;\n  }\n\n  .sm\\:to-red-300 {\n    --gradient-to-color: #feb2b2;\n  }\n\n  .sm\\:to-red-400 {\n    --gradient-to-color: #fc8181;\n  }\n\n  .sm\\:to-red-500 {\n    --gradient-to-color: #f56565;\n  }\n\n  .sm\\:to-red-600 {\n    --gradient-to-color: #e53e3e;\n  }\n\n  .sm\\:to-red-700 {\n    --gradient-to-color: #c53030;\n  }\n\n  .sm\\:to-red-800 {\n    --gradient-to-color: #9b2c2c;\n  }\n\n  .sm\\:to-red-900 {\n    --gradient-to-color: #742a2a;\n  }\n\n  .sm\\:to-orange-100 {\n    --gradient-to-color: #fffaf0;\n  }\n\n  .sm\\:to-orange-200 {\n    --gradient-to-color: #feebc8;\n  }\n\n  .sm\\:to-orange-300 {\n    --gradient-to-color: #fbd38d;\n  }\n\n  .sm\\:to-orange-400 {\n    --gradient-to-color: #f6ad55;\n  }\n\n  .sm\\:to-orange-500 {\n    --gradient-to-color: #ed8936;\n  }\n\n  .sm\\:to-orange-600 {\n    --gradient-to-color: #dd6b20;\n  }\n\n  .sm\\:to-orange-700 {\n    --gradient-to-color: #c05621;\n  }\n\n  .sm\\:to-orange-800 {\n    --gradient-to-color: #9c4221;\n  }\n\n  .sm\\:to-orange-900 {\n    --gradient-to-color: #7b341e;\n  }\n\n  .sm\\:to-yellow-100 {\n    --gradient-to-color: #fffff0;\n  }\n\n  .sm\\:to-yellow-200 {\n    --gradient-to-color: #fefcbf;\n  }\n\n  .sm\\:to-yellow-300 {\n    --gradient-to-color: #faf089;\n  }\n\n  .sm\\:to-yellow-400 {\n    --gradient-to-color: #f6e05e;\n  }\n\n  .sm\\:to-yellow-500 {\n    --gradient-to-color: #ecc94b;\n  }\n\n  .sm\\:to-yellow-600 {\n    --gradient-to-color: #d69e2e;\n  }\n\n  .sm\\:to-yellow-700 {\n    --gradient-to-color: #b7791f;\n  }\n\n  .sm\\:to-yellow-800 {\n    --gradient-to-color: #975a16;\n  }\n\n  .sm\\:to-yellow-900 {\n    --gradient-to-color: #744210;\n  }\n\n  .sm\\:to-green-100 {\n    --gradient-to-color: #f0fff4;\n  }\n\n  .sm\\:to-green-200 {\n    --gradient-to-color: #c6f6d5;\n  }\n\n  .sm\\:to-green-300 {\n    --gradient-to-color: #9ae6b4;\n  }\n\n  .sm\\:to-green-400 {\n    --gradient-to-color: #68d391;\n  }\n\n  .sm\\:to-green-500 {\n    --gradient-to-color: #48bb78;\n  }\n\n  .sm\\:to-green-600 {\n    --gradient-to-color: #38a169;\n  }\n\n  .sm\\:to-green-700 {\n    --gradient-to-color: #2f855a;\n  }\n\n  .sm\\:to-green-800 {\n    --gradient-to-color: #276749;\n  }\n\n  .sm\\:to-green-900 {\n    --gradient-to-color: #22543d;\n  }\n\n  .sm\\:to-teal-100 {\n    --gradient-to-color: #e6fffa;\n  }\n\n  .sm\\:to-teal-200 {\n    --gradient-to-color: #b2f5ea;\n  }\n\n  .sm\\:to-teal-300 {\n    --gradient-to-color: #81e6d9;\n  }\n\n  .sm\\:to-teal-400 {\n    --gradient-to-color: #4fd1c5;\n  }\n\n  .sm\\:to-teal-500 {\n    --gradient-to-color: #38b2ac;\n  }\n\n  .sm\\:to-teal-600 {\n    --gradient-to-color: #319795;\n  }\n\n  .sm\\:to-teal-700 {\n    --gradient-to-color: #2c7a7b;\n  }\n\n  .sm\\:to-teal-800 {\n    --gradient-to-color: #285e61;\n  }\n\n  .sm\\:to-teal-900 {\n    --gradient-to-color: #234e52;\n  }\n\n  .sm\\:to-blue-100 {\n    --gradient-to-color: #ebf8ff;\n  }\n\n  .sm\\:to-blue-200 {\n    --gradient-to-color: #bee3f8;\n  }\n\n  .sm\\:to-blue-300 {\n    --gradient-to-color: #90cdf4;\n  }\n\n  .sm\\:to-blue-400 {\n    --gradient-to-color: #63b3ed;\n  }\n\n  .sm\\:to-blue-500 {\n    --gradient-to-color: #4299e1;\n  }\n\n  .sm\\:to-blue-600 {\n    --gradient-to-color: #3182ce;\n  }\n\n  .sm\\:to-blue-700 {\n    --gradient-to-color: #2b6cb0;\n  }\n\n  .sm\\:to-blue-800 {\n    --gradient-to-color: #2c5282;\n  }\n\n  .sm\\:to-blue-900 {\n    --gradient-to-color: #2a4365;\n  }\n\n  .sm\\:to-indigo-100 {\n    --gradient-to-color: #ebf4ff;\n  }\n\n  .sm\\:to-indigo-200 {\n    --gradient-to-color: #c3dafe;\n  }\n\n  .sm\\:to-indigo-300 {\n    --gradient-to-color: #a3bffa;\n  }\n\n  .sm\\:to-indigo-400 {\n    --gradient-to-color: #7f9cf5;\n  }\n\n  .sm\\:to-indigo-500 {\n    --gradient-to-color: #667eea;\n  }\n\n  .sm\\:to-indigo-600 {\n    --gradient-to-color: #5a67d8;\n  }\n\n  .sm\\:to-indigo-700 {\n    --gradient-to-color: #4c51bf;\n  }\n\n  .sm\\:to-indigo-800 {\n    --gradient-to-color: #434190;\n  }\n\n  .sm\\:to-indigo-900 {\n    --gradient-to-color: #3c366b;\n  }\n\n  .sm\\:to-purple-100 {\n    --gradient-to-color: #faf5ff;\n  }\n\n  .sm\\:to-purple-200 {\n    --gradient-to-color: #e9d8fd;\n  }\n\n  .sm\\:to-purple-300 {\n    --gradient-to-color: #d6bcfa;\n  }\n\n  .sm\\:to-purple-400 {\n    --gradient-to-color: #b794f4;\n  }\n\n  .sm\\:to-purple-500 {\n    --gradient-to-color: #9f7aea;\n  }\n\n  .sm\\:to-purple-600 {\n    --gradient-to-color: #805ad5;\n  }\n\n  .sm\\:to-purple-700 {\n    --gradient-to-color: #6b46c1;\n  }\n\n  .sm\\:to-purple-800 {\n    --gradient-to-color: #553c9a;\n  }\n\n  .sm\\:to-purple-900 {\n    --gradient-to-color: #44337a;\n  }\n\n  .sm\\:to-pink-100 {\n    --gradient-to-color: #fff5f7;\n  }\n\n  .sm\\:to-pink-200 {\n    --gradient-to-color: #fed7e2;\n  }\n\n  .sm\\:to-pink-300 {\n    --gradient-to-color: #fbb6ce;\n  }\n\n  .sm\\:to-pink-400 {\n    --gradient-to-color: #f687b3;\n  }\n\n  .sm\\:to-pink-500 {\n    --gradient-to-color: #ed64a6;\n  }\n\n  .sm\\:to-pink-600 {\n    --gradient-to-color: #d53f8c;\n  }\n\n  .sm\\:to-pink-700 {\n    --gradient-to-color: #b83280;\n  }\n\n  .sm\\:to-pink-800 {\n    --gradient-to-color: #97266d;\n  }\n\n  .sm\\:to-pink-900 {\n    --gradient-to-color: #702459;\n  }\n\n  .sm\\:to-grayscale-80 {\n    --gradient-to-color: hsl(0, 0%, 8%);\n  }\n\n  .sm\\:to-grayscale-100 {\n    --gradient-to-color: hsl(0, 0%, 10%);\n  }\n\n  .sm\\:to-grayscale-200 {\n    --gradient-to-color: hsl(0, 0%, 20%);\n  }\n\n  .sm\\:to-grayscale-300 {\n    --gradient-to-color: hsl(0, 0%, 30%);\n  }\n\n  .sm\\:to-grayscale-400 {\n    --gradient-to-color: hsl(0, 0%, 40%);\n  }\n\n  .sm\\:to-grayscale-500 {\n    --gradient-to-color: hsl(0, 0%, 50%);\n  }\n\n  .sm\\:to-grayscale-600 {\n    --gradient-to-color: hsl(0, 0%, 60%);\n  }\n\n  .sm\\:to-grayscale-700 {\n    --gradient-to-color: hsl(0, 0%, 70%);\n  }\n\n  .sm\\:to-grayscale-800 {\n    --gradient-to-color: hsl(0, 0%, 80%);\n  }\n\n  .sm\\:to-grayscale-840 {\n    --gradient-to-color: hsl(0, 0%, 84%);\n  }\n\n  .sm\\:to-grayscale-870 {\n    --gradient-to-color: hsl(0, 0%, 87%);\n  }\n\n  .sm\\:to-grayscale-900 {\n    --gradient-to-color: hsl(0, 0%, 90%);\n  }\n\n  .sm\\:to-grayscale-930 {\n    --gradient-to-color: hsl(0, 0%, 93%);\n  }\n\n  .sm\\:to-primary {\n    --gradient-to-color: hsl(210, 100%, 52%);\n  }\n\n  .sm\\:to-background-main {\n    --gradient-to-color: var(--main-background);\n  }\n\n  .sm\\:to-background-secondary {\n    --gradient-to-color: var(--secondary-background);\n  }\n\n  .sm\\:to-foreground {\n    --gradient-to-color: var(--foreground);\n  }\n\n  .sm\\:to-panels-bg {\n    --gradient-to-color: var(--panels-background);\n  }\n\n  .sm\\:hover\\:from-transparent:hover {\n    --gradient-from-color: transparent;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .sm\\:hover\\:from-current:hover {\n    --gradient-from-color: currentColor;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:hover\\:from-black:hover {\n    --gradient-from-color: #000;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .sm\\:hover\\:from-white:hover {\n    --gradient-from-color: #fff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:hover\\:from-gray-100:hover {\n    --gradient-from-color: #f7fafc;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n  }\n\n  .sm\\:hover\\:from-gray-200:hover {\n    --gradient-from-color: #edf2f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n  }\n\n  .sm\\:hover\\:from-gray-300:hover {\n    --gradient-from-color: #e2e8f0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n  }\n\n  .sm\\:hover\\:from-gray-400:hover {\n    --gradient-from-color: #cbd5e0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n  }\n\n  .sm\\:hover\\:from-gray-500:hover {\n    --gradient-from-color: #a0aec0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n  }\n\n  .sm\\:hover\\:from-gray-600:hover {\n    --gradient-from-color: #718096;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n  }\n\n  .sm\\:hover\\:from-gray-700:hover {\n    --gradient-from-color: #4a5568;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n  }\n\n  .sm\\:hover\\:from-gray-800:hover {\n    --gradient-from-color: #2d3748;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n  }\n\n  .sm\\:hover\\:from-gray-900:hover {\n    --gradient-from-color: #1a202c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n  }\n\n  .sm\\:hover\\:from-red-100:hover {\n    --gradient-from-color: #fff5f5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n  }\n\n  .sm\\:hover\\:from-red-200:hover {\n    --gradient-from-color: #fed7d7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n  }\n\n  .sm\\:hover\\:from-red-300:hover {\n    --gradient-from-color: #feb2b2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n  }\n\n  .sm\\:hover\\:from-red-400:hover {\n    --gradient-from-color: #fc8181;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n  }\n\n  .sm\\:hover\\:from-red-500:hover {\n    --gradient-from-color: #f56565;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n  }\n\n  .sm\\:hover\\:from-red-600:hover {\n    --gradient-from-color: #e53e3e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n  }\n\n  .sm\\:hover\\:from-red-700:hover {\n    --gradient-from-color: #c53030;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n  }\n\n  .sm\\:hover\\:from-red-800:hover {\n    --gradient-from-color: #9b2c2c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n  }\n\n  .sm\\:hover\\:from-red-900:hover {\n    --gradient-from-color: #742a2a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n  }\n\n  .sm\\:hover\\:from-orange-100:hover {\n    --gradient-from-color: #fffaf0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n  }\n\n  .sm\\:hover\\:from-orange-200:hover {\n    --gradient-from-color: #feebc8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n  }\n\n  .sm\\:hover\\:from-orange-300:hover {\n    --gradient-from-color: #fbd38d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n  }\n\n  .sm\\:hover\\:from-orange-400:hover {\n    --gradient-from-color: #f6ad55;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n  }\n\n  .sm\\:hover\\:from-orange-500:hover {\n    --gradient-from-color: #ed8936;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n  }\n\n  .sm\\:hover\\:from-orange-600:hover {\n    --gradient-from-color: #dd6b20;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n  }\n\n  .sm\\:hover\\:from-orange-700:hover {\n    --gradient-from-color: #c05621;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n  }\n\n  .sm\\:hover\\:from-orange-800:hover {\n    --gradient-from-color: #9c4221;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n  }\n\n  .sm\\:hover\\:from-orange-900:hover {\n    --gradient-from-color: #7b341e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n  }\n\n  .sm\\:hover\\:from-yellow-100:hover {\n    --gradient-from-color: #fffff0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n  }\n\n  .sm\\:hover\\:from-yellow-200:hover {\n    --gradient-from-color: #fefcbf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n  }\n\n  .sm\\:hover\\:from-yellow-300:hover {\n    --gradient-from-color: #faf089;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n  }\n\n  .sm\\:hover\\:from-yellow-400:hover {\n    --gradient-from-color: #f6e05e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n  }\n\n  .sm\\:hover\\:from-yellow-500:hover {\n    --gradient-from-color: #ecc94b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n  }\n\n  .sm\\:hover\\:from-yellow-600:hover {\n    --gradient-from-color: #d69e2e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n  }\n\n  .sm\\:hover\\:from-yellow-700:hover {\n    --gradient-from-color: #b7791f;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n  }\n\n  .sm\\:hover\\:from-yellow-800:hover {\n    --gradient-from-color: #975a16;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n  }\n\n  .sm\\:hover\\:from-yellow-900:hover {\n    --gradient-from-color: #744210;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n  }\n\n  .sm\\:hover\\:from-green-100:hover {\n    --gradient-from-color: #f0fff4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n  }\n\n  .sm\\:hover\\:from-green-200:hover {\n    --gradient-from-color: #c6f6d5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n  }\n\n  .sm\\:hover\\:from-green-300:hover {\n    --gradient-from-color: #9ae6b4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n  }\n\n  .sm\\:hover\\:from-green-400:hover {\n    --gradient-from-color: #68d391;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n  }\n\n  .sm\\:hover\\:from-green-500:hover {\n    --gradient-from-color: #48bb78;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n  }\n\n  .sm\\:hover\\:from-green-600:hover {\n    --gradient-from-color: #38a169;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n  }\n\n  .sm\\:hover\\:from-green-700:hover {\n    --gradient-from-color: #2f855a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n  }\n\n  .sm\\:hover\\:from-green-800:hover {\n    --gradient-from-color: #276749;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n  }\n\n  .sm\\:hover\\:from-green-900:hover {\n    --gradient-from-color: #22543d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n  }\n\n  .sm\\:hover\\:from-teal-100:hover {\n    --gradient-from-color: #e6fffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n  }\n\n  .sm\\:hover\\:from-teal-200:hover {\n    --gradient-from-color: #b2f5ea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n  }\n\n  .sm\\:hover\\:from-teal-300:hover {\n    --gradient-from-color: #81e6d9;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n  }\n\n  .sm\\:hover\\:from-teal-400:hover {\n    --gradient-from-color: #4fd1c5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n  }\n\n  .sm\\:hover\\:from-teal-500:hover {\n    --gradient-from-color: #38b2ac;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n  }\n\n  .sm\\:hover\\:from-teal-600:hover {\n    --gradient-from-color: #319795;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n  }\n\n  .sm\\:hover\\:from-teal-700:hover {\n    --gradient-from-color: #2c7a7b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n  }\n\n  .sm\\:hover\\:from-teal-800:hover {\n    --gradient-from-color: #285e61;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n  }\n\n  .sm\\:hover\\:from-teal-900:hover {\n    --gradient-from-color: #234e52;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n  }\n\n  .sm\\:hover\\:from-blue-100:hover {\n    --gradient-from-color: #ebf8ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n  }\n\n  .sm\\:hover\\:from-blue-200:hover {\n    --gradient-from-color: #bee3f8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n  }\n\n  .sm\\:hover\\:from-blue-300:hover {\n    --gradient-from-color: #90cdf4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n  }\n\n  .sm\\:hover\\:from-blue-400:hover {\n    --gradient-from-color: #63b3ed;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n  }\n\n  .sm\\:hover\\:from-blue-500:hover {\n    --gradient-from-color: #4299e1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n  }\n\n  .sm\\:hover\\:from-blue-600:hover {\n    --gradient-from-color: #3182ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n  }\n\n  .sm\\:hover\\:from-blue-700:hover {\n    --gradient-from-color: #2b6cb0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n  }\n\n  .sm\\:hover\\:from-blue-800:hover {\n    --gradient-from-color: #2c5282;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n  }\n\n  .sm\\:hover\\:from-blue-900:hover {\n    --gradient-from-color: #2a4365;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n  }\n\n  .sm\\:hover\\:from-indigo-100:hover {\n    --gradient-from-color: #ebf4ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n  }\n\n  .sm\\:hover\\:from-indigo-200:hover {\n    --gradient-from-color: #c3dafe;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n  }\n\n  .sm\\:hover\\:from-indigo-300:hover {\n    --gradient-from-color: #a3bffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n  }\n\n  .sm\\:hover\\:from-indigo-400:hover {\n    --gradient-from-color: #7f9cf5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n  }\n\n  .sm\\:hover\\:from-indigo-500:hover {\n    --gradient-from-color: #667eea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n  }\n\n  .sm\\:hover\\:from-indigo-600:hover {\n    --gradient-from-color: #5a67d8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n  }\n\n  .sm\\:hover\\:from-indigo-700:hover {\n    --gradient-from-color: #4c51bf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n  }\n\n  .sm\\:hover\\:from-indigo-800:hover {\n    --gradient-from-color: #434190;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n  }\n\n  .sm\\:hover\\:from-indigo-900:hover {\n    --gradient-from-color: #3c366b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n  }\n\n  .sm\\:hover\\:from-purple-100:hover {\n    --gradient-from-color: #faf5ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n  }\n\n  .sm\\:hover\\:from-purple-200:hover {\n    --gradient-from-color: #e9d8fd;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n  }\n\n  .sm\\:hover\\:from-purple-300:hover {\n    --gradient-from-color: #d6bcfa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n  }\n\n  .sm\\:hover\\:from-purple-400:hover {\n    --gradient-from-color: #b794f4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n  }\n\n  .sm\\:hover\\:from-purple-500:hover {\n    --gradient-from-color: #9f7aea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n  }\n\n  .sm\\:hover\\:from-purple-600:hover {\n    --gradient-from-color: #805ad5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n  }\n\n  .sm\\:hover\\:from-purple-700:hover {\n    --gradient-from-color: #6b46c1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n  }\n\n  .sm\\:hover\\:from-purple-800:hover {\n    --gradient-from-color: #553c9a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n  }\n\n  .sm\\:hover\\:from-purple-900:hover {\n    --gradient-from-color: #44337a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n  }\n\n  .sm\\:hover\\:from-pink-100:hover {\n    --gradient-from-color: #fff5f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n  }\n\n  .sm\\:hover\\:from-pink-200:hover {\n    --gradient-from-color: #fed7e2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n  }\n\n  .sm\\:hover\\:from-pink-300:hover {\n    --gradient-from-color: #fbb6ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n  }\n\n  .sm\\:hover\\:from-pink-400:hover {\n    --gradient-from-color: #f687b3;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n  }\n\n  .sm\\:hover\\:from-pink-500:hover {\n    --gradient-from-color: #ed64a6;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n  }\n\n  .sm\\:hover\\:from-pink-600:hover {\n    --gradient-from-color: #d53f8c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n  }\n\n  .sm\\:hover\\:from-pink-700:hover {\n    --gradient-from-color: #b83280;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n  }\n\n  .sm\\:hover\\:from-pink-800:hover {\n    --gradient-from-color: #97266d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n  }\n\n  .sm\\:hover\\:from-pink-900:hover {\n    --gradient-from-color: #702459;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n  }\n\n  .sm\\:hover\\:from-grayscale-80:hover {\n    --gradient-from-color: hsl(0, 0%, 8%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n  }\n\n  .sm\\:hover\\:from-grayscale-100:hover {\n    --gradient-from-color: hsl(0, 0%, 10%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n  }\n\n  .sm\\:hover\\:from-grayscale-200:hover {\n    --gradient-from-color: hsl(0, 0%, 20%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n  }\n\n  .sm\\:hover\\:from-grayscale-300:hover {\n    --gradient-from-color: hsl(0, 0%, 30%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n  }\n\n  .sm\\:hover\\:from-grayscale-400:hover {\n    --gradient-from-color: hsl(0, 0%, 40%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n  }\n\n  .sm\\:hover\\:from-grayscale-500:hover {\n    --gradient-from-color: hsl(0, 0%, 50%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n  }\n\n  .sm\\:hover\\:from-grayscale-600:hover {\n    --gradient-from-color: hsl(0, 0%, 60%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n  }\n\n  .sm\\:hover\\:from-grayscale-700:hover {\n    --gradient-from-color: hsl(0, 0%, 70%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n  }\n\n  .sm\\:hover\\:from-grayscale-800:hover {\n    --gradient-from-color: hsl(0, 0%, 80%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n  }\n\n  .sm\\:hover\\:from-grayscale-840:hover {\n    --gradient-from-color: hsl(0, 0%, 84%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n  }\n\n  .sm\\:hover\\:from-grayscale-870:hover {\n    --gradient-from-color: hsl(0, 0%, 87%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n  }\n\n  .sm\\:hover\\:from-grayscale-900:hover {\n    --gradient-from-color: hsl(0, 0%, 90%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n  }\n\n  .sm\\:hover\\:from-grayscale-930:hover {\n    --gradient-from-color: hsl(0, 0%, 93%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n  }\n\n  .sm\\:hover\\:from-primary:hover {\n    --gradient-from-color: hsl(210, 100%, 52%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n  }\n\n  .sm\\:hover\\:from-background-main:hover {\n    --gradient-from-color: var(--main-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:hover\\:from-background-secondary:hover {\n    --gradient-from-color: var(--secondary-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:hover\\:from-foreground:hover {\n    --gradient-from-color: var(--foreground);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:hover\\:from-panels-bg:hover {\n    --gradient-from-color: var(--panels-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:hover\\:via-transparent:hover {\n    --gradient-via-color: transparent;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .sm\\:hover\\:via-current:hover {\n    --gradient-via-color: currentColor;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:hover\\:via-black:hover {\n    --gradient-via-color: #000;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .sm\\:hover\\:via-white:hover {\n    --gradient-via-color: #fff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:hover\\:via-gray-100:hover {\n    --gradient-via-color: #f7fafc;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n  }\n\n  .sm\\:hover\\:via-gray-200:hover {\n    --gradient-via-color: #edf2f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n  }\n\n  .sm\\:hover\\:via-gray-300:hover {\n    --gradient-via-color: #e2e8f0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n  }\n\n  .sm\\:hover\\:via-gray-400:hover {\n    --gradient-via-color: #cbd5e0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n  }\n\n  .sm\\:hover\\:via-gray-500:hover {\n    --gradient-via-color: #a0aec0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n  }\n\n  .sm\\:hover\\:via-gray-600:hover {\n    --gradient-via-color: #718096;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n  }\n\n  .sm\\:hover\\:via-gray-700:hover {\n    --gradient-via-color: #4a5568;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n  }\n\n  .sm\\:hover\\:via-gray-800:hover {\n    --gradient-via-color: #2d3748;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n  }\n\n  .sm\\:hover\\:via-gray-900:hover {\n    --gradient-via-color: #1a202c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n  }\n\n  .sm\\:hover\\:via-red-100:hover {\n    --gradient-via-color: #fff5f5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n  }\n\n  .sm\\:hover\\:via-red-200:hover {\n    --gradient-via-color: #fed7d7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n  }\n\n  .sm\\:hover\\:via-red-300:hover {\n    --gradient-via-color: #feb2b2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n  }\n\n  .sm\\:hover\\:via-red-400:hover {\n    --gradient-via-color: #fc8181;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n  }\n\n  .sm\\:hover\\:via-red-500:hover {\n    --gradient-via-color: #f56565;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n  }\n\n  .sm\\:hover\\:via-red-600:hover {\n    --gradient-via-color: #e53e3e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n  }\n\n  .sm\\:hover\\:via-red-700:hover {\n    --gradient-via-color: #c53030;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n  }\n\n  .sm\\:hover\\:via-red-800:hover {\n    --gradient-via-color: #9b2c2c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n  }\n\n  .sm\\:hover\\:via-red-900:hover {\n    --gradient-via-color: #742a2a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n  }\n\n  .sm\\:hover\\:via-orange-100:hover {\n    --gradient-via-color: #fffaf0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n  }\n\n  .sm\\:hover\\:via-orange-200:hover {\n    --gradient-via-color: #feebc8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n  }\n\n  .sm\\:hover\\:via-orange-300:hover {\n    --gradient-via-color: #fbd38d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n  }\n\n  .sm\\:hover\\:via-orange-400:hover {\n    --gradient-via-color: #f6ad55;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n  }\n\n  .sm\\:hover\\:via-orange-500:hover {\n    --gradient-via-color: #ed8936;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n  }\n\n  .sm\\:hover\\:via-orange-600:hover {\n    --gradient-via-color: #dd6b20;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n  }\n\n  .sm\\:hover\\:via-orange-700:hover {\n    --gradient-via-color: #c05621;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n  }\n\n  .sm\\:hover\\:via-orange-800:hover {\n    --gradient-via-color: #9c4221;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n  }\n\n  .sm\\:hover\\:via-orange-900:hover {\n    --gradient-via-color: #7b341e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n  }\n\n  .sm\\:hover\\:via-yellow-100:hover {\n    --gradient-via-color: #fffff0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n  }\n\n  .sm\\:hover\\:via-yellow-200:hover {\n    --gradient-via-color: #fefcbf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n  }\n\n  .sm\\:hover\\:via-yellow-300:hover {\n    --gradient-via-color: #faf089;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n  }\n\n  .sm\\:hover\\:via-yellow-400:hover {\n    --gradient-via-color: #f6e05e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n  }\n\n  .sm\\:hover\\:via-yellow-500:hover {\n    --gradient-via-color: #ecc94b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n  }\n\n  .sm\\:hover\\:via-yellow-600:hover {\n    --gradient-via-color: #d69e2e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n  }\n\n  .sm\\:hover\\:via-yellow-700:hover {\n    --gradient-via-color: #b7791f;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n  }\n\n  .sm\\:hover\\:via-yellow-800:hover {\n    --gradient-via-color: #975a16;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n  }\n\n  .sm\\:hover\\:via-yellow-900:hover {\n    --gradient-via-color: #744210;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n  }\n\n  .sm\\:hover\\:via-green-100:hover {\n    --gradient-via-color: #f0fff4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n  }\n\n  .sm\\:hover\\:via-green-200:hover {\n    --gradient-via-color: #c6f6d5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n  }\n\n  .sm\\:hover\\:via-green-300:hover {\n    --gradient-via-color: #9ae6b4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n  }\n\n  .sm\\:hover\\:via-green-400:hover {\n    --gradient-via-color: #68d391;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n  }\n\n  .sm\\:hover\\:via-green-500:hover {\n    --gradient-via-color: #48bb78;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n  }\n\n  .sm\\:hover\\:via-green-600:hover {\n    --gradient-via-color: #38a169;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n  }\n\n  .sm\\:hover\\:via-green-700:hover {\n    --gradient-via-color: #2f855a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n  }\n\n  .sm\\:hover\\:via-green-800:hover {\n    --gradient-via-color: #276749;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n  }\n\n  .sm\\:hover\\:via-green-900:hover {\n    --gradient-via-color: #22543d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n  }\n\n  .sm\\:hover\\:via-teal-100:hover {\n    --gradient-via-color: #e6fffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n  }\n\n  .sm\\:hover\\:via-teal-200:hover {\n    --gradient-via-color: #b2f5ea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n  }\n\n  .sm\\:hover\\:via-teal-300:hover {\n    --gradient-via-color: #81e6d9;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n  }\n\n  .sm\\:hover\\:via-teal-400:hover {\n    --gradient-via-color: #4fd1c5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n  }\n\n  .sm\\:hover\\:via-teal-500:hover {\n    --gradient-via-color: #38b2ac;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n  }\n\n  .sm\\:hover\\:via-teal-600:hover {\n    --gradient-via-color: #319795;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n  }\n\n  .sm\\:hover\\:via-teal-700:hover {\n    --gradient-via-color: #2c7a7b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n  }\n\n  .sm\\:hover\\:via-teal-800:hover {\n    --gradient-via-color: #285e61;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n  }\n\n  .sm\\:hover\\:via-teal-900:hover {\n    --gradient-via-color: #234e52;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n  }\n\n  .sm\\:hover\\:via-blue-100:hover {\n    --gradient-via-color: #ebf8ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n  }\n\n  .sm\\:hover\\:via-blue-200:hover {\n    --gradient-via-color: #bee3f8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n  }\n\n  .sm\\:hover\\:via-blue-300:hover {\n    --gradient-via-color: #90cdf4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n  }\n\n  .sm\\:hover\\:via-blue-400:hover {\n    --gradient-via-color: #63b3ed;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n  }\n\n  .sm\\:hover\\:via-blue-500:hover {\n    --gradient-via-color: #4299e1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n  }\n\n  .sm\\:hover\\:via-blue-600:hover {\n    --gradient-via-color: #3182ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n  }\n\n  .sm\\:hover\\:via-blue-700:hover {\n    --gradient-via-color: #2b6cb0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n  }\n\n  .sm\\:hover\\:via-blue-800:hover {\n    --gradient-via-color: #2c5282;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n  }\n\n  .sm\\:hover\\:via-blue-900:hover {\n    --gradient-via-color: #2a4365;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n  }\n\n  .sm\\:hover\\:via-indigo-100:hover {\n    --gradient-via-color: #ebf4ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n  }\n\n  .sm\\:hover\\:via-indigo-200:hover {\n    --gradient-via-color: #c3dafe;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n  }\n\n  .sm\\:hover\\:via-indigo-300:hover {\n    --gradient-via-color: #a3bffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n  }\n\n  .sm\\:hover\\:via-indigo-400:hover {\n    --gradient-via-color: #7f9cf5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n  }\n\n  .sm\\:hover\\:via-indigo-500:hover {\n    --gradient-via-color: #667eea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n  }\n\n  .sm\\:hover\\:via-indigo-600:hover {\n    --gradient-via-color: #5a67d8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n  }\n\n  .sm\\:hover\\:via-indigo-700:hover {\n    --gradient-via-color: #4c51bf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n  }\n\n  .sm\\:hover\\:via-indigo-800:hover {\n    --gradient-via-color: #434190;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n  }\n\n  .sm\\:hover\\:via-indigo-900:hover {\n    --gradient-via-color: #3c366b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n  }\n\n  .sm\\:hover\\:via-purple-100:hover {\n    --gradient-via-color: #faf5ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n  }\n\n  .sm\\:hover\\:via-purple-200:hover {\n    --gradient-via-color: #e9d8fd;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n  }\n\n  .sm\\:hover\\:via-purple-300:hover {\n    --gradient-via-color: #d6bcfa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n  }\n\n  .sm\\:hover\\:via-purple-400:hover {\n    --gradient-via-color: #b794f4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n  }\n\n  .sm\\:hover\\:via-purple-500:hover {\n    --gradient-via-color: #9f7aea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n  }\n\n  .sm\\:hover\\:via-purple-600:hover {\n    --gradient-via-color: #805ad5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n  }\n\n  .sm\\:hover\\:via-purple-700:hover {\n    --gradient-via-color: #6b46c1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n  }\n\n  .sm\\:hover\\:via-purple-800:hover {\n    --gradient-via-color: #553c9a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n  }\n\n  .sm\\:hover\\:via-purple-900:hover {\n    --gradient-via-color: #44337a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n  }\n\n  .sm\\:hover\\:via-pink-100:hover {\n    --gradient-via-color: #fff5f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n  }\n\n  .sm\\:hover\\:via-pink-200:hover {\n    --gradient-via-color: #fed7e2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n  }\n\n  .sm\\:hover\\:via-pink-300:hover {\n    --gradient-via-color: #fbb6ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n  }\n\n  .sm\\:hover\\:via-pink-400:hover {\n    --gradient-via-color: #f687b3;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n  }\n\n  .sm\\:hover\\:via-pink-500:hover {\n    --gradient-via-color: #ed64a6;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n  }\n\n  .sm\\:hover\\:via-pink-600:hover {\n    --gradient-via-color: #d53f8c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n  }\n\n  .sm\\:hover\\:via-pink-700:hover {\n    --gradient-via-color: #b83280;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n  }\n\n  .sm\\:hover\\:via-pink-800:hover {\n    --gradient-via-color: #97266d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n  }\n\n  .sm\\:hover\\:via-pink-900:hover {\n    --gradient-via-color: #702459;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n  }\n\n  .sm\\:hover\\:via-grayscale-80:hover {\n    --gradient-via-color: hsl(0, 0%, 8%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n  }\n\n  .sm\\:hover\\:via-grayscale-100:hover {\n    --gradient-via-color: hsl(0, 0%, 10%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n  }\n\n  .sm\\:hover\\:via-grayscale-200:hover {\n    --gradient-via-color: hsl(0, 0%, 20%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n  }\n\n  .sm\\:hover\\:via-grayscale-300:hover {\n    --gradient-via-color: hsl(0, 0%, 30%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n  }\n\n  .sm\\:hover\\:via-grayscale-400:hover {\n    --gradient-via-color: hsl(0, 0%, 40%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n  }\n\n  .sm\\:hover\\:via-grayscale-500:hover {\n    --gradient-via-color: hsl(0, 0%, 50%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n  }\n\n  .sm\\:hover\\:via-grayscale-600:hover {\n    --gradient-via-color: hsl(0, 0%, 60%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n  }\n\n  .sm\\:hover\\:via-grayscale-700:hover {\n    --gradient-via-color: hsl(0, 0%, 70%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n  }\n\n  .sm\\:hover\\:via-grayscale-800:hover {\n    --gradient-via-color: hsl(0, 0%, 80%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n  }\n\n  .sm\\:hover\\:via-grayscale-840:hover {\n    --gradient-via-color: hsl(0, 0%, 84%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n  }\n\n  .sm\\:hover\\:via-grayscale-870:hover {\n    --gradient-via-color: hsl(0, 0%, 87%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n  }\n\n  .sm\\:hover\\:via-grayscale-900:hover {\n    --gradient-via-color: hsl(0, 0%, 90%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n  }\n\n  .sm\\:hover\\:via-grayscale-930:hover {\n    --gradient-via-color: hsl(0, 0%, 93%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n  }\n\n  .sm\\:hover\\:via-primary:hover {\n    --gradient-via-color: hsl(210, 100%, 52%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n  }\n\n  .sm\\:hover\\:via-background-main:hover {\n    --gradient-via-color: var(--main-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:hover\\:via-background-secondary:hover {\n    --gradient-via-color: var(--secondary-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:hover\\:via-foreground:hover {\n    --gradient-via-color: var(--foreground);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:hover\\:via-panels-bg:hover {\n    --gradient-via-color: var(--panels-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:hover\\:to-transparent:hover {\n    --gradient-to-color: transparent;\n  }\n\n  .sm\\:hover\\:to-current:hover {\n    --gradient-to-color: currentColor;\n  }\n\n  .sm\\:hover\\:to-black:hover {\n    --gradient-to-color: #000;\n  }\n\n  .sm\\:hover\\:to-white:hover {\n    --gradient-to-color: #fff;\n  }\n\n  .sm\\:hover\\:to-gray-100:hover {\n    --gradient-to-color: #f7fafc;\n  }\n\n  .sm\\:hover\\:to-gray-200:hover {\n    --gradient-to-color: #edf2f7;\n  }\n\n  .sm\\:hover\\:to-gray-300:hover {\n    --gradient-to-color: #e2e8f0;\n  }\n\n  .sm\\:hover\\:to-gray-400:hover {\n    --gradient-to-color: #cbd5e0;\n  }\n\n  .sm\\:hover\\:to-gray-500:hover {\n    --gradient-to-color: #a0aec0;\n  }\n\n  .sm\\:hover\\:to-gray-600:hover {\n    --gradient-to-color: #718096;\n  }\n\n  .sm\\:hover\\:to-gray-700:hover {\n    --gradient-to-color: #4a5568;\n  }\n\n  .sm\\:hover\\:to-gray-800:hover {\n    --gradient-to-color: #2d3748;\n  }\n\n  .sm\\:hover\\:to-gray-900:hover {\n    --gradient-to-color: #1a202c;\n  }\n\n  .sm\\:hover\\:to-red-100:hover {\n    --gradient-to-color: #fff5f5;\n  }\n\n  .sm\\:hover\\:to-red-200:hover {\n    --gradient-to-color: #fed7d7;\n  }\n\n  .sm\\:hover\\:to-red-300:hover {\n    --gradient-to-color: #feb2b2;\n  }\n\n  .sm\\:hover\\:to-red-400:hover {\n    --gradient-to-color: #fc8181;\n  }\n\n  .sm\\:hover\\:to-red-500:hover {\n    --gradient-to-color: #f56565;\n  }\n\n  .sm\\:hover\\:to-red-600:hover {\n    --gradient-to-color: #e53e3e;\n  }\n\n  .sm\\:hover\\:to-red-700:hover {\n    --gradient-to-color: #c53030;\n  }\n\n  .sm\\:hover\\:to-red-800:hover {\n    --gradient-to-color: #9b2c2c;\n  }\n\n  .sm\\:hover\\:to-red-900:hover {\n    --gradient-to-color: #742a2a;\n  }\n\n  .sm\\:hover\\:to-orange-100:hover {\n    --gradient-to-color: #fffaf0;\n  }\n\n  .sm\\:hover\\:to-orange-200:hover {\n    --gradient-to-color: #feebc8;\n  }\n\n  .sm\\:hover\\:to-orange-300:hover {\n    --gradient-to-color: #fbd38d;\n  }\n\n  .sm\\:hover\\:to-orange-400:hover {\n    --gradient-to-color: #f6ad55;\n  }\n\n  .sm\\:hover\\:to-orange-500:hover {\n    --gradient-to-color: #ed8936;\n  }\n\n  .sm\\:hover\\:to-orange-600:hover {\n    --gradient-to-color: #dd6b20;\n  }\n\n  .sm\\:hover\\:to-orange-700:hover {\n    --gradient-to-color: #c05621;\n  }\n\n  .sm\\:hover\\:to-orange-800:hover {\n    --gradient-to-color: #9c4221;\n  }\n\n  .sm\\:hover\\:to-orange-900:hover {\n    --gradient-to-color: #7b341e;\n  }\n\n  .sm\\:hover\\:to-yellow-100:hover {\n    --gradient-to-color: #fffff0;\n  }\n\n  .sm\\:hover\\:to-yellow-200:hover {\n    --gradient-to-color: #fefcbf;\n  }\n\n  .sm\\:hover\\:to-yellow-300:hover {\n    --gradient-to-color: #faf089;\n  }\n\n  .sm\\:hover\\:to-yellow-400:hover {\n    --gradient-to-color: #f6e05e;\n  }\n\n  .sm\\:hover\\:to-yellow-500:hover {\n    --gradient-to-color: #ecc94b;\n  }\n\n  .sm\\:hover\\:to-yellow-600:hover {\n    --gradient-to-color: #d69e2e;\n  }\n\n  .sm\\:hover\\:to-yellow-700:hover {\n    --gradient-to-color: #b7791f;\n  }\n\n  .sm\\:hover\\:to-yellow-800:hover {\n    --gradient-to-color: #975a16;\n  }\n\n  .sm\\:hover\\:to-yellow-900:hover {\n    --gradient-to-color: #744210;\n  }\n\n  .sm\\:hover\\:to-green-100:hover {\n    --gradient-to-color: #f0fff4;\n  }\n\n  .sm\\:hover\\:to-green-200:hover {\n    --gradient-to-color: #c6f6d5;\n  }\n\n  .sm\\:hover\\:to-green-300:hover {\n    --gradient-to-color: #9ae6b4;\n  }\n\n  .sm\\:hover\\:to-green-400:hover {\n    --gradient-to-color: #68d391;\n  }\n\n  .sm\\:hover\\:to-green-500:hover {\n    --gradient-to-color: #48bb78;\n  }\n\n  .sm\\:hover\\:to-green-600:hover {\n    --gradient-to-color: #38a169;\n  }\n\n  .sm\\:hover\\:to-green-700:hover {\n    --gradient-to-color: #2f855a;\n  }\n\n  .sm\\:hover\\:to-green-800:hover {\n    --gradient-to-color: #276749;\n  }\n\n  .sm\\:hover\\:to-green-900:hover {\n    --gradient-to-color: #22543d;\n  }\n\n  .sm\\:hover\\:to-teal-100:hover {\n    --gradient-to-color: #e6fffa;\n  }\n\n  .sm\\:hover\\:to-teal-200:hover {\n    --gradient-to-color: #b2f5ea;\n  }\n\n  .sm\\:hover\\:to-teal-300:hover {\n    --gradient-to-color: #81e6d9;\n  }\n\n  .sm\\:hover\\:to-teal-400:hover {\n    --gradient-to-color: #4fd1c5;\n  }\n\n  .sm\\:hover\\:to-teal-500:hover {\n    --gradient-to-color: #38b2ac;\n  }\n\n  .sm\\:hover\\:to-teal-600:hover {\n    --gradient-to-color: #319795;\n  }\n\n  .sm\\:hover\\:to-teal-700:hover {\n    --gradient-to-color: #2c7a7b;\n  }\n\n  .sm\\:hover\\:to-teal-800:hover {\n    --gradient-to-color: #285e61;\n  }\n\n  .sm\\:hover\\:to-teal-900:hover {\n    --gradient-to-color: #234e52;\n  }\n\n  .sm\\:hover\\:to-blue-100:hover {\n    --gradient-to-color: #ebf8ff;\n  }\n\n  .sm\\:hover\\:to-blue-200:hover {\n    --gradient-to-color: #bee3f8;\n  }\n\n  .sm\\:hover\\:to-blue-300:hover {\n    --gradient-to-color: #90cdf4;\n  }\n\n  .sm\\:hover\\:to-blue-400:hover {\n    --gradient-to-color: #63b3ed;\n  }\n\n  .sm\\:hover\\:to-blue-500:hover {\n    --gradient-to-color: #4299e1;\n  }\n\n  .sm\\:hover\\:to-blue-600:hover {\n    --gradient-to-color: #3182ce;\n  }\n\n  .sm\\:hover\\:to-blue-700:hover {\n    --gradient-to-color: #2b6cb0;\n  }\n\n  .sm\\:hover\\:to-blue-800:hover {\n    --gradient-to-color: #2c5282;\n  }\n\n  .sm\\:hover\\:to-blue-900:hover {\n    --gradient-to-color: #2a4365;\n  }\n\n  .sm\\:hover\\:to-indigo-100:hover {\n    --gradient-to-color: #ebf4ff;\n  }\n\n  .sm\\:hover\\:to-indigo-200:hover {\n    --gradient-to-color: #c3dafe;\n  }\n\n  .sm\\:hover\\:to-indigo-300:hover {\n    --gradient-to-color: #a3bffa;\n  }\n\n  .sm\\:hover\\:to-indigo-400:hover {\n    --gradient-to-color: #7f9cf5;\n  }\n\n  .sm\\:hover\\:to-indigo-500:hover {\n    --gradient-to-color: #667eea;\n  }\n\n  .sm\\:hover\\:to-indigo-600:hover {\n    --gradient-to-color: #5a67d8;\n  }\n\n  .sm\\:hover\\:to-indigo-700:hover {\n    --gradient-to-color: #4c51bf;\n  }\n\n  .sm\\:hover\\:to-indigo-800:hover {\n    --gradient-to-color: #434190;\n  }\n\n  .sm\\:hover\\:to-indigo-900:hover {\n    --gradient-to-color: #3c366b;\n  }\n\n  .sm\\:hover\\:to-purple-100:hover {\n    --gradient-to-color: #faf5ff;\n  }\n\n  .sm\\:hover\\:to-purple-200:hover {\n    --gradient-to-color: #e9d8fd;\n  }\n\n  .sm\\:hover\\:to-purple-300:hover {\n    --gradient-to-color: #d6bcfa;\n  }\n\n  .sm\\:hover\\:to-purple-400:hover {\n    --gradient-to-color: #b794f4;\n  }\n\n  .sm\\:hover\\:to-purple-500:hover {\n    --gradient-to-color: #9f7aea;\n  }\n\n  .sm\\:hover\\:to-purple-600:hover {\n    --gradient-to-color: #805ad5;\n  }\n\n  .sm\\:hover\\:to-purple-700:hover {\n    --gradient-to-color: #6b46c1;\n  }\n\n  .sm\\:hover\\:to-purple-800:hover {\n    --gradient-to-color: #553c9a;\n  }\n\n  .sm\\:hover\\:to-purple-900:hover {\n    --gradient-to-color: #44337a;\n  }\n\n  .sm\\:hover\\:to-pink-100:hover {\n    --gradient-to-color: #fff5f7;\n  }\n\n  .sm\\:hover\\:to-pink-200:hover {\n    --gradient-to-color: #fed7e2;\n  }\n\n  .sm\\:hover\\:to-pink-300:hover {\n    --gradient-to-color: #fbb6ce;\n  }\n\n  .sm\\:hover\\:to-pink-400:hover {\n    --gradient-to-color: #f687b3;\n  }\n\n  .sm\\:hover\\:to-pink-500:hover {\n    --gradient-to-color: #ed64a6;\n  }\n\n  .sm\\:hover\\:to-pink-600:hover {\n    --gradient-to-color: #d53f8c;\n  }\n\n  .sm\\:hover\\:to-pink-700:hover {\n    --gradient-to-color: #b83280;\n  }\n\n  .sm\\:hover\\:to-pink-800:hover {\n    --gradient-to-color: #97266d;\n  }\n\n  .sm\\:hover\\:to-pink-900:hover {\n    --gradient-to-color: #702459;\n  }\n\n  .sm\\:hover\\:to-grayscale-80:hover {\n    --gradient-to-color: hsl(0, 0%, 8%);\n  }\n\n  .sm\\:hover\\:to-grayscale-100:hover {\n    --gradient-to-color: hsl(0, 0%, 10%);\n  }\n\n  .sm\\:hover\\:to-grayscale-200:hover {\n    --gradient-to-color: hsl(0, 0%, 20%);\n  }\n\n  .sm\\:hover\\:to-grayscale-300:hover {\n    --gradient-to-color: hsl(0, 0%, 30%);\n  }\n\n  .sm\\:hover\\:to-grayscale-400:hover {\n    --gradient-to-color: hsl(0, 0%, 40%);\n  }\n\n  .sm\\:hover\\:to-grayscale-500:hover {\n    --gradient-to-color: hsl(0, 0%, 50%);\n  }\n\n  .sm\\:hover\\:to-grayscale-600:hover {\n    --gradient-to-color: hsl(0, 0%, 60%);\n  }\n\n  .sm\\:hover\\:to-grayscale-700:hover {\n    --gradient-to-color: hsl(0, 0%, 70%);\n  }\n\n  .sm\\:hover\\:to-grayscale-800:hover {\n    --gradient-to-color: hsl(0, 0%, 80%);\n  }\n\n  .sm\\:hover\\:to-grayscale-840:hover {\n    --gradient-to-color: hsl(0, 0%, 84%);\n  }\n\n  .sm\\:hover\\:to-grayscale-870:hover {\n    --gradient-to-color: hsl(0, 0%, 87%);\n  }\n\n  .sm\\:hover\\:to-grayscale-900:hover {\n    --gradient-to-color: hsl(0, 0%, 90%);\n  }\n\n  .sm\\:hover\\:to-grayscale-930:hover {\n    --gradient-to-color: hsl(0, 0%, 93%);\n  }\n\n  .sm\\:hover\\:to-primary:hover {\n    --gradient-to-color: hsl(210, 100%, 52%);\n  }\n\n  .sm\\:hover\\:to-background-main:hover {\n    --gradient-to-color: var(--main-background);\n  }\n\n  .sm\\:hover\\:to-background-secondary:hover {\n    --gradient-to-color: var(--secondary-background);\n  }\n\n  .sm\\:hover\\:to-foreground:hover {\n    --gradient-to-color: var(--foreground);\n  }\n\n  .sm\\:hover\\:to-panels-bg:hover {\n    --gradient-to-color: var(--panels-background);\n  }\n\n  .sm\\:focus\\:from-transparent:focus {\n    --gradient-from-color: transparent;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .sm\\:focus\\:from-current:focus {\n    --gradient-from-color: currentColor;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:focus\\:from-black:focus {\n    --gradient-from-color: #000;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .sm\\:focus\\:from-white:focus {\n    --gradient-from-color: #fff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:focus\\:from-gray-100:focus {\n    --gradient-from-color: #f7fafc;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n  }\n\n  .sm\\:focus\\:from-gray-200:focus {\n    --gradient-from-color: #edf2f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n  }\n\n  .sm\\:focus\\:from-gray-300:focus {\n    --gradient-from-color: #e2e8f0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n  }\n\n  .sm\\:focus\\:from-gray-400:focus {\n    --gradient-from-color: #cbd5e0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n  }\n\n  .sm\\:focus\\:from-gray-500:focus {\n    --gradient-from-color: #a0aec0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n  }\n\n  .sm\\:focus\\:from-gray-600:focus {\n    --gradient-from-color: #718096;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n  }\n\n  .sm\\:focus\\:from-gray-700:focus {\n    --gradient-from-color: #4a5568;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n  }\n\n  .sm\\:focus\\:from-gray-800:focus {\n    --gradient-from-color: #2d3748;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n  }\n\n  .sm\\:focus\\:from-gray-900:focus {\n    --gradient-from-color: #1a202c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n  }\n\n  .sm\\:focus\\:from-red-100:focus {\n    --gradient-from-color: #fff5f5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n  }\n\n  .sm\\:focus\\:from-red-200:focus {\n    --gradient-from-color: #fed7d7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n  }\n\n  .sm\\:focus\\:from-red-300:focus {\n    --gradient-from-color: #feb2b2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n  }\n\n  .sm\\:focus\\:from-red-400:focus {\n    --gradient-from-color: #fc8181;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n  }\n\n  .sm\\:focus\\:from-red-500:focus {\n    --gradient-from-color: #f56565;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n  }\n\n  .sm\\:focus\\:from-red-600:focus {\n    --gradient-from-color: #e53e3e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n  }\n\n  .sm\\:focus\\:from-red-700:focus {\n    --gradient-from-color: #c53030;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n  }\n\n  .sm\\:focus\\:from-red-800:focus {\n    --gradient-from-color: #9b2c2c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n  }\n\n  .sm\\:focus\\:from-red-900:focus {\n    --gradient-from-color: #742a2a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n  }\n\n  .sm\\:focus\\:from-orange-100:focus {\n    --gradient-from-color: #fffaf0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n  }\n\n  .sm\\:focus\\:from-orange-200:focus {\n    --gradient-from-color: #feebc8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n  }\n\n  .sm\\:focus\\:from-orange-300:focus {\n    --gradient-from-color: #fbd38d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n  }\n\n  .sm\\:focus\\:from-orange-400:focus {\n    --gradient-from-color: #f6ad55;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n  }\n\n  .sm\\:focus\\:from-orange-500:focus {\n    --gradient-from-color: #ed8936;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n  }\n\n  .sm\\:focus\\:from-orange-600:focus {\n    --gradient-from-color: #dd6b20;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n  }\n\n  .sm\\:focus\\:from-orange-700:focus {\n    --gradient-from-color: #c05621;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n  }\n\n  .sm\\:focus\\:from-orange-800:focus {\n    --gradient-from-color: #9c4221;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n  }\n\n  .sm\\:focus\\:from-orange-900:focus {\n    --gradient-from-color: #7b341e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n  }\n\n  .sm\\:focus\\:from-yellow-100:focus {\n    --gradient-from-color: #fffff0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n  }\n\n  .sm\\:focus\\:from-yellow-200:focus {\n    --gradient-from-color: #fefcbf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n  }\n\n  .sm\\:focus\\:from-yellow-300:focus {\n    --gradient-from-color: #faf089;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n  }\n\n  .sm\\:focus\\:from-yellow-400:focus {\n    --gradient-from-color: #f6e05e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n  }\n\n  .sm\\:focus\\:from-yellow-500:focus {\n    --gradient-from-color: #ecc94b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n  }\n\n  .sm\\:focus\\:from-yellow-600:focus {\n    --gradient-from-color: #d69e2e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n  }\n\n  .sm\\:focus\\:from-yellow-700:focus {\n    --gradient-from-color: #b7791f;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n  }\n\n  .sm\\:focus\\:from-yellow-800:focus {\n    --gradient-from-color: #975a16;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n  }\n\n  .sm\\:focus\\:from-yellow-900:focus {\n    --gradient-from-color: #744210;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n  }\n\n  .sm\\:focus\\:from-green-100:focus {\n    --gradient-from-color: #f0fff4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n  }\n\n  .sm\\:focus\\:from-green-200:focus {\n    --gradient-from-color: #c6f6d5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n  }\n\n  .sm\\:focus\\:from-green-300:focus {\n    --gradient-from-color: #9ae6b4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n  }\n\n  .sm\\:focus\\:from-green-400:focus {\n    --gradient-from-color: #68d391;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n  }\n\n  .sm\\:focus\\:from-green-500:focus {\n    --gradient-from-color: #48bb78;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n  }\n\n  .sm\\:focus\\:from-green-600:focus {\n    --gradient-from-color: #38a169;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n  }\n\n  .sm\\:focus\\:from-green-700:focus {\n    --gradient-from-color: #2f855a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n  }\n\n  .sm\\:focus\\:from-green-800:focus {\n    --gradient-from-color: #276749;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n  }\n\n  .sm\\:focus\\:from-green-900:focus {\n    --gradient-from-color: #22543d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n  }\n\n  .sm\\:focus\\:from-teal-100:focus {\n    --gradient-from-color: #e6fffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n  }\n\n  .sm\\:focus\\:from-teal-200:focus {\n    --gradient-from-color: #b2f5ea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n  }\n\n  .sm\\:focus\\:from-teal-300:focus {\n    --gradient-from-color: #81e6d9;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n  }\n\n  .sm\\:focus\\:from-teal-400:focus {\n    --gradient-from-color: #4fd1c5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n  }\n\n  .sm\\:focus\\:from-teal-500:focus {\n    --gradient-from-color: #38b2ac;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n  }\n\n  .sm\\:focus\\:from-teal-600:focus {\n    --gradient-from-color: #319795;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n  }\n\n  .sm\\:focus\\:from-teal-700:focus {\n    --gradient-from-color: #2c7a7b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n  }\n\n  .sm\\:focus\\:from-teal-800:focus {\n    --gradient-from-color: #285e61;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n  }\n\n  .sm\\:focus\\:from-teal-900:focus {\n    --gradient-from-color: #234e52;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n  }\n\n  .sm\\:focus\\:from-blue-100:focus {\n    --gradient-from-color: #ebf8ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n  }\n\n  .sm\\:focus\\:from-blue-200:focus {\n    --gradient-from-color: #bee3f8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n  }\n\n  .sm\\:focus\\:from-blue-300:focus {\n    --gradient-from-color: #90cdf4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n  }\n\n  .sm\\:focus\\:from-blue-400:focus {\n    --gradient-from-color: #63b3ed;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n  }\n\n  .sm\\:focus\\:from-blue-500:focus {\n    --gradient-from-color: #4299e1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n  }\n\n  .sm\\:focus\\:from-blue-600:focus {\n    --gradient-from-color: #3182ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n  }\n\n  .sm\\:focus\\:from-blue-700:focus {\n    --gradient-from-color: #2b6cb0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n  }\n\n  .sm\\:focus\\:from-blue-800:focus {\n    --gradient-from-color: #2c5282;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n  }\n\n  .sm\\:focus\\:from-blue-900:focus {\n    --gradient-from-color: #2a4365;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n  }\n\n  .sm\\:focus\\:from-indigo-100:focus {\n    --gradient-from-color: #ebf4ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n  }\n\n  .sm\\:focus\\:from-indigo-200:focus {\n    --gradient-from-color: #c3dafe;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n  }\n\n  .sm\\:focus\\:from-indigo-300:focus {\n    --gradient-from-color: #a3bffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n  }\n\n  .sm\\:focus\\:from-indigo-400:focus {\n    --gradient-from-color: #7f9cf5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n  }\n\n  .sm\\:focus\\:from-indigo-500:focus {\n    --gradient-from-color: #667eea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n  }\n\n  .sm\\:focus\\:from-indigo-600:focus {\n    --gradient-from-color: #5a67d8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n  }\n\n  .sm\\:focus\\:from-indigo-700:focus {\n    --gradient-from-color: #4c51bf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n  }\n\n  .sm\\:focus\\:from-indigo-800:focus {\n    --gradient-from-color: #434190;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n  }\n\n  .sm\\:focus\\:from-indigo-900:focus {\n    --gradient-from-color: #3c366b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n  }\n\n  .sm\\:focus\\:from-purple-100:focus {\n    --gradient-from-color: #faf5ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n  }\n\n  .sm\\:focus\\:from-purple-200:focus {\n    --gradient-from-color: #e9d8fd;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n  }\n\n  .sm\\:focus\\:from-purple-300:focus {\n    --gradient-from-color: #d6bcfa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n  }\n\n  .sm\\:focus\\:from-purple-400:focus {\n    --gradient-from-color: #b794f4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n  }\n\n  .sm\\:focus\\:from-purple-500:focus {\n    --gradient-from-color: #9f7aea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n  }\n\n  .sm\\:focus\\:from-purple-600:focus {\n    --gradient-from-color: #805ad5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n  }\n\n  .sm\\:focus\\:from-purple-700:focus {\n    --gradient-from-color: #6b46c1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n  }\n\n  .sm\\:focus\\:from-purple-800:focus {\n    --gradient-from-color: #553c9a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n  }\n\n  .sm\\:focus\\:from-purple-900:focus {\n    --gradient-from-color: #44337a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n  }\n\n  .sm\\:focus\\:from-pink-100:focus {\n    --gradient-from-color: #fff5f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n  }\n\n  .sm\\:focus\\:from-pink-200:focus {\n    --gradient-from-color: #fed7e2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n  }\n\n  .sm\\:focus\\:from-pink-300:focus {\n    --gradient-from-color: #fbb6ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n  }\n\n  .sm\\:focus\\:from-pink-400:focus {\n    --gradient-from-color: #f687b3;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n  }\n\n  .sm\\:focus\\:from-pink-500:focus {\n    --gradient-from-color: #ed64a6;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n  }\n\n  .sm\\:focus\\:from-pink-600:focus {\n    --gradient-from-color: #d53f8c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n  }\n\n  .sm\\:focus\\:from-pink-700:focus {\n    --gradient-from-color: #b83280;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n  }\n\n  .sm\\:focus\\:from-pink-800:focus {\n    --gradient-from-color: #97266d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n  }\n\n  .sm\\:focus\\:from-pink-900:focus {\n    --gradient-from-color: #702459;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n  }\n\n  .sm\\:focus\\:from-grayscale-80:focus {\n    --gradient-from-color: hsl(0, 0%, 8%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n  }\n\n  .sm\\:focus\\:from-grayscale-100:focus {\n    --gradient-from-color: hsl(0, 0%, 10%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n  }\n\n  .sm\\:focus\\:from-grayscale-200:focus {\n    --gradient-from-color: hsl(0, 0%, 20%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n  }\n\n  .sm\\:focus\\:from-grayscale-300:focus {\n    --gradient-from-color: hsl(0, 0%, 30%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n  }\n\n  .sm\\:focus\\:from-grayscale-400:focus {\n    --gradient-from-color: hsl(0, 0%, 40%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n  }\n\n  .sm\\:focus\\:from-grayscale-500:focus {\n    --gradient-from-color: hsl(0, 0%, 50%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n  }\n\n  .sm\\:focus\\:from-grayscale-600:focus {\n    --gradient-from-color: hsl(0, 0%, 60%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n  }\n\n  .sm\\:focus\\:from-grayscale-700:focus {\n    --gradient-from-color: hsl(0, 0%, 70%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n  }\n\n  .sm\\:focus\\:from-grayscale-800:focus {\n    --gradient-from-color: hsl(0, 0%, 80%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n  }\n\n  .sm\\:focus\\:from-grayscale-840:focus {\n    --gradient-from-color: hsl(0, 0%, 84%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n  }\n\n  .sm\\:focus\\:from-grayscale-870:focus {\n    --gradient-from-color: hsl(0, 0%, 87%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n  }\n\n  .sm\\:focus\\:from-grayscale-900:focus {\n    --gradient-from-color: hsl(0, 0%, 90%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n  }\n\n  .sm\\:focus\\:from-grayscale-930:focus {\n    --gradient-from-color: hsl(0, 0%, 93%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n  }\n\n  .sm\\:focus\\:from-primary:focus {\n    --gradient-from-color: hsl(210, 100%, 52%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n  }\n\n  .sm\\:focus\\:from-background-main:focus {\n    --gradient-from-color: var(--main-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:focus\\:from-background-secondary:focus {\n    --gradient-from-color: var(--secondary-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:focus\\:from-foreground:focus {\n    --gradient-from-color: var(--foreground);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:focus\\:from-panels-bg:focus {\n    --gradient-from-color: var(--panels-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:focus\\:via-transparent:focus {\n    --gradient-via-color: transparent;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .sm\\:focus\\:via-current:focus {\n    --gradient-via-color: currentColor;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:focus\\:via-black:focus {\n    --gradient-via-color: #000;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .sm\\:focus\\:via-white:focus {\n    --gradient-via-color: #fff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:focus\\:via-gray-100:focus {\n    --gradient-via-color: #f7fafc;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n  }\n\n  .sm\\:focus\\:via-gray-200:focus {\n    --gradient-via-color: #edf2f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n  }\n\n  .sm\\:focus\\:via-gray-300:focus {\n    --gradient-via-color: #e2e8f0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n  }\n\n  .sm\\:focus\\:via-gray-400:focus {\n    --gradient-via-color: #cbd5e0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n  }\n\n  .sm\\:focus\\:via-gray-500:focus {\n    --gradient-via-color: #a0aec0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n  }\n\n  .sm\\:focus\\:via-gray-600:focus {\n    --gradient-via-color: #718096;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n  }\n\n  .sm\\:focus\\:via-gray-700:focus {\n    --gradient-via-color: #4a5568;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n  }\n\n  .sm\\:focus\\:via-gray-800:focus {\n    --gradient-via-color: #2d3748;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n  }\n\n  .sm\\:focus\\:via-gray-900:focus {\n    --gradient-via-color: #1a202c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n  }\n\n  .sm\\:focus\\:via-red-100:focus {\n    --gradient-via-color: #fff5f5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n  }\n\n  .sm\\:focus\\:via-red-200:focus {\n    --gradient-via-color: #fed7d7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n  }\n\n  .sm\\:focus\\:via-red-300:focus {\n    --gradient-via-color: #feb2b2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n  }\n\n  .sm\\:focus\\:via-red-400:focus {\n    --gradient-via-color: #fc8181;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n  }\n\n  .sm\\:focus\\:via-red-500:focus {\n    --gradient-via-color: #f56565;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n  }\n\n  .sm\\:focus\\:via-red-600:focus {\n    --gradient-via-color: #e53e3e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n  }\n\n  .sm\\:focus\\:via-red-700:focus {\n    --gradient-via-color: #c53030;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n  }\n\n  .sm\\:focus\\:via-red-800:focus {\n    --gradient-via-color: #9b2c2c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n  }\n\n  .sm\\:focus\\:via-red-900:focus {\n    --gradient-via-color: #742a2a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n  }\n\n  .sm\\:focus\\:via-orange-100:focus {\n    --gradient-via-color: #fffaf0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n  }\n\n  .sm\\:focus\\:via-orange-200:focus {\n    --gradient-via-color: #feebc8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n  }\n\n  .sm\\:focus\\:via-orange-300:focus {\n    --gradient-via-color: #fbd38d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n  }\n\n  .sm\\:focus\\:via-orange-400:focus {\n    --gradient-via-color: #f6ad55;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n  }\n\n  .sm\\:focus\\:via-orange-500:focus {\n    --gradient-via-color: #ed8936;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n  }\n\n  .sm\\:focus\\:via-orange-600:focus {\n    --gradient-via-color: #dd6b20;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n  }\n\n  .sm\\:focus\\:via-orange-700:focus {\n    --gradient-via-color: #c05621;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n  }\n\n  .sm\\:focus\\:via-orange-800:focus {\n    --gradient-via-color: #9c4221;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n  }\n\n  .sm\\:focus\\:via-orange-900:focus {\n    --gradient-via-color: #7b341e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n  }\n\n  .sm\\:focus\\:via-yellow-100:focus {\n    --gradient-via-color: #fffff0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n  }\n\n  .sm\\:focus\\:via-yellow-200:focus {\n    --gradient-via-color: #fefcbf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n  }\n\n  .sm\\:focus\\:via-yellow-300:focus {\n    --gradient-via-color: #faf089;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n  }\n\n  .sm\\:focus\\:via-yellow-400:focus {\n    --gradient-via-color: #f6e05e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n  }\n\n  .sm\\:focus\\:via-yellow-500:focus {\n    --gradient-via-color: #ecc94b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n  }\n\n  .sm\\:focus\\:via-yellow-600:focus {\n    --gradient-via-color: #d69e2e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n  }\n\n  .sm\\:focus\\:via-yellow-700:focus {\n    --gradient-via-color: #b7791f;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n  }\n\n  .sm\\:focus\\:via-yellow-800:focus {\n    --gradient-via-color: #975a16;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n  }\n\n  .sm\\:focus\\:via-yellow-900:focus {\n    --gradient-via-color: #744210;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n  }\n\n  .sm\\:focus\\:via-green-100:focus {\n    --gradient-via-color: #f0fff4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n  }\n\n  .sm\\:focus\\:via-green-200:focus {\n    --gradient-via-color: #c6f6d5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n  }\n\n  .sm\\:focus\\:via-green-300:focus {\n    --gradient-via-color: #9ae6b4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n  }\n\n  .sm\\:focus\\:via-green-400:focus {\n    --gradient-via-color: #68d391;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n  }\n\n  .sm\\:focus\\:via-green-500:focus {\n    --gradient-via-color: #48bb78;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n  }\n\n  .sm\\:focus\\:via-green-600:focus {\n    --gradient-via-color: #38a169;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n  }\n\n  .sm\\:focus\\:via-green-700:focus {\n    --gradient-via-color: #2f855a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n  }\n\n  .sm\\:focus\\:via-green-800:focus {\n    --gradient-via-color: #276749;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n  }\n\n  .sm\\:focus\\:via-green-900:focus {\n    --gradient-via-color: #22543d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n  }\n\n  .sm\\:focus\\:via-teal-100:focus {\n    --gradient-via-color: #e6fffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n  }\n\n  .sm\\:focus\\:via-teal-200:focus {\n    --gradient-via-color: #b2f5ea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n  }\n\n  .sm\\:focus\\:via-teal-300:focus {\n    --gradient-via-color: #81e6d9;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n  }\n\n  .sm\\:focus\\:via-teal-400:focus {\n    --gradient-via-color: #4fd1c5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n  }\n\n  .sm\\:focus\\:via-teal-500:focus {\n    --gradient-via-color: #38b2ac;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n  }\n\n  .sm\\:focus\\:via-teal-600:focus {\n    --gradient-via-color: #319795;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n  }\n\n  .sm\\:focus\\:via-teal-700:focus {\n    --gradient-via-color: #2c7a7b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n  }\n\n  .sm\\:focus\\:via-teal-800:focus {\n    --gradient-via-color: #285e61;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n  }\n\n  .sm\\:focus\\:via-teal-900:focus {\n    --gradient-via-color: #234e52;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n  }\n\n  .sm\\:focus\\:via-blue-100:focus {\n    --gradient-via-color: #ebf8ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n  }\n\n  .sm\\:focus\\:via-blue-200:focus {\n    --gradient-via-color: #bee3f8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n  }\n\n  .sm\\:focus\\:via-blue-300:focus {\n    --gradient-via-color: #90cdf4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n  }\n\n  .sm\\:focus\\:via-blue-400:focus {\n    --gradient-via-color: #63b3ed;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n  }\n\n  .sm\\:focus\\:via-blue-500:focus {\n    --gradient-via-color: #4299e1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n  }\n\n  .sm\\:focus\\:via-blue-600:focus {\n    --gradient-via-color: #3182ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n  }\n\n  .sm\\:focus\\:via-blue-700:focus {\n    --gradient-via-color: #2b6cb0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n  }\n\n  .sm\\:focus\\:via-blue-800:focus {\n    --gradient-via-color: #2c5282;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n  }\n\n  .sm\\:focus\\:via-blue-900:focus {\n    --gradient-via-color: #2a4365;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n  }\n\n  .sm\\:focus\\:via-indigo-100:focus {\n    --gradient-via-color: #ebf4ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n  }\n\n  .sm\\:focus\\:via-indigo-200:focus {\n    --gradient-via-color: #c3dafe;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n  }\n\n  .sm\\:focus\\:via-indigo-300:focus {\n    --gradient-via-color: #a3bffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n  }\n\n  .sm\\:focus\\:via-indigo-400:focus {\n    --gradient-via-color: #7f9cf5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n  }\n\n  .sm\\:focus\\:via-indigo-500:focus {\n    --gradient-via-color: #667eea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n  }\n\n  .sm\\:focus\\:via-indigo-600:focus {\n    --gradient-via-color: #5a67d8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n  }\n\n  .sm\\:focus\\:via-indigo-700:focus {\n    --gradient-via-color: #4c51bf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n  }\n\n  .sm\\:focus\\:via-indigo-800:focus {\n    --gradient-via-color: #434190;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n  }\n\n  .sm\\:focus\\:via-indigo-900:focus {\n    --gradient-via-color: #3c366b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n  }\n\n  .sm\\:focus\\:via-purple-100:focus {\n    --gradient-via-color: #faf5ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n  }\n\n  .sm\\:focus\\:via-purple-200:focus {\n    --gradient-via-color: #e9d8fd;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n  }\n\n  .sm\\:focus\\:via-purple-300:focus {\n    --gradient-via-color: #d6bcfa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n  }\n\n  .sm\\:focus\\:via-purple-400:focus {\n    --gradient-via-color: #b794f4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n  }\n\n  .sm\\:focus\\:via-purple-500:focus {\n    --gradient-via-color: #9f7aea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n  }\n\n  .sm\\:focus\\:via-purple-600:focus {\n    --gradient-via-color: #805ad5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n  }\n\n  .sm\\:focus\\:via-purple-700:focus {\n    --gradient-via-color: #6b46c1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n  }\n\n  .sm\\:focus\\:via-purple-800:focus {\n    --gradient-via-color: #553c9a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n  }\n\n  .sm\\:focus\\:via-purple-900:focus {\n    --gradient-via-color: #44337a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n  }\n\n  .sm\\:focus\\:via-pink-100:focus {\n    --gradient-via-color: #fff5f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n  }\n\n  .sm\\:focus\\:via-pink-200:focus {\n    --gradient-via-color: #fed7e2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n  }\n\n  .sm\\:focus\\:via-pink-300:focus {\n    --gradient-via-color: #fbb6ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n  }\n\n  .sm\\:focus\\:via-pink-400:focus {\n    --gradient-via-color: #f687b3;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n  }\n\n  .sm\\:focus\\:via-pink-500:focus {\n    --gradient-via-color: #ed64a6;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n  }\n\n  .sm\\:focus\\:via-pink-600:focus {\n    --gradient-via-color: #d53f8c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n  }\n\n  .sm\\:focus\\:via-pink-700:focus {\n    --gradient-via-color: #b83280;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n  }\n\n  .sm\\:focus\\:via-pink-800:focus {\n    --gradient-via-color: #97266d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n  }\n\n  .sm\\:focus\\:via-pink-900:focus {\n    --gradient-via-color: #702459;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n  }\n\n  .sm\\:focus\\:via-grayscale-80:focus {\n    --gradient-via-color: hsl(0, 0%, 8%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n  }\n\n  .sm\\:focus\\:via-grayscale-100:focus {\n    --gradient-via-color: hsl(0, 0%, 10%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n  }\n\n  .sm\\:focus\\:via-grayscale-200:focus {\n    --gradient-via-color: hsl(0, 0%, 20%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n  }\n\n  .sm\\:focus\\:via-grayscale-300:focus {\n    --gradient-via-color: hsl(0, 0%, 30%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n  }\n\n  .sm\\:focus\\:via-grayscale-400:focus {\n    --gradient-via-color: hsl(0, 0%, 40%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n  }\n\n  .sm\\:focus\\:via-grayscale-500:focus {\n    --gradient-via-color: hsl(0, 0%, 50%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n  }\n\n  .sm\\:focus\\:via-grayscale-600:focus {\n    --gradient-via-color: hsl(0, 0%, 60%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n  }\n\n  .sm\\:focus\\:via-grayscale-700:focus {\n    --gradient-via-color: hsl(0, 0%, 70%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n  }\n\n  .sm\\:focus\\:via-grayscale-800:focus {\n    --gradient-via-color: hsl(0, 0%, 80%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n  }\n\n  .sm\\:focus\\:via-grayscale-840:focus {\n    --gradient-via-color: hsl(0, 0%, 84%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n  }\n\n  .sm\\:focus\\:via-grayscale-870:focus {\n    --gradient-via-color: hsl(0, 0%, 87%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n  }\n\n  .sm\\:focus\\:via-grayscale-900:focus {\n    --gradient-via-color: hsl(0, 0%, 90%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n  }\n\n  .sm\\:focus\\:via-grayscale-930:focus {\n    --gradient-via-color: hsl(0, 0%, 93%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n  }\n\n  .sm\\:focus\\:via-primary:focus {\n    --gradient-via-color: hsl(210, 100%, 52%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n  }\n\n  .sm\\:focus\\:via-background-main:focus {\n    --gradient-via-color: var(--main-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:focus\\:via-background-secondary:focus {\n    --gradient-via-color: var(--secondary-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:focus\\:via-foreground:focus {\n    --gradient-via-color: var(--foreground);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:focus\\:via-panels-bg:focus {\n    --gradient-via-color: var(--panels-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .sm\\:focus\\:to-transparent:focus {\n    --gradient-to-color: transparent;\n  }\n\n  .sm\\:focus\\:to-current:focus {\n    --gradient-to-color: currentColor;\n  }\n\n  .sm\\:focus\\:to-black:focus {\n    --gradient-to-color: #000;\n  }\n\n  .sm\\:focus\\:to-white:focus {\n    --gradient-to-color: #fff;\n  }\n\n  .sm\\:focus\\:to-gray-100:focus {\n    --gradient-to-color: #f7fafc;\n  }\n\n  .sm\\:focus\\:to-gray-200:focus {\n    --gradient-to-color: #edf2f7;\n  }\n\n  .sm\\:focus\\:to-gray-300:focus {\n    --gradient-to-color: #e2e8f0;\n  }\n\n  .sm\\:focus\\:to-gray-400:focus {\n    --gradient-to-color: #cbd5e0;\n  }\n\n  .sm\\:focus\\:to-gray-500:focus {\n    --gradient-to-color: #a0aec0;\n  }\n\n  .sm\\:focus\\:to-gray-600:focus {\n    --gradient-to-color: #718096;\n  }\n\n  .sm\\:focus\\:to-gray-700:focus {\n    --gradient-to-color: #4a5568;\n  }\n\n  .sm\\:focus\\:to-gray-800:focus {\n    --gradient-to-color: #2d3748;\n  }\n\n  .sm\\:focus\\:to-gray-900:focus {\n    --gradient-to-color: #1a202c;\n  }\n\n  .sm\\:focus\\:to-red-100:focus {\n    --gradient-to-color: #fff5f5;\n  }\n\n  .sm\\:focus\\:to-red-200:focus {\n    --gradient-to-color: #fed7d7;\n  }\n\n  .sm\\:focus\\:to-red-300:focus {\n    --gradient-to-color: #feb2b2;\n  }\n\n  .sm\\:focus\\:to-red-400:focus {\n    --gradient-to-color: #fc8181;\n  }\n\n  .sm\\:focus\\:to-red-500:focus {\n    --gradient-to-color: #f56565;\n  }\n\n  .sm\\:focus\\:to-red-600:focus {\n    --gradient-to-color: #e53e3e;\n  }\n\n  .sm\\:focus\\:to-red-700:focus {\n    --gradient-to-color: #c53030;\n  }\n\n  .sm\\:focus\\:to-red-800:focus {\n    --gradient-to-color: #9b2c2c;\n  }\n\n  .sm\\:focus\\:to-red-900:focus {\n    --gradient-to-color: #742a2a;\n  }\n\n  .sm\\:focus\\:to-orange-100:focus {\n    --gradient-to-color: #fffaf0;\n  }\n\n  .sm\\:focus\\:to-orange-200:focus {\n    --gradient-to-color: #feebc8;\n  }\n\n  .sm\\:focus\\:to-orange-300:focus {\n    --gradient-to-color: #fbd38d;\n  }\n\n  .sm\\:focus\\:to-orange-400:focus {\n    --gradient-to-color: #f6ad55;\n  }\n\n  .sm\\:focus\\:to-orange-500:focus {\n    --gradient-to-color: #ed8936;\n  }\n\n  .sm\\:focus\\:to-orange-600:focus {\n    --gradient-to-color: #dd6b20;\n  }\n\n  .sm\\:focus\\:to-orange-700:focus {\n    --gradient-to-color: #c05621;\n  }\n\n  .sm\\:focus\\:to-orange-800:focus {\n    --gradient-to-color: #9c4221;\n  }\n\n  .sm\\:focus\\:to-orange-900:focus {\n    --gradient-to-color: #7b341e;\n  }\n\n  .sm\\:focus\\:to-yellow-100:focus {\n    --gradient-to-color: #fffff0;\n  }\n\n  .sm\\:focus\\:to-yellow-200:focus {\n    --gradient-to-color: #fefcbf;\n  }\n\n  .sm\\:focus\\:to-yellow-300:focus {\n    --gradient-to-color: #faf089;\n  }\n\n  .sm\\:focus\\:to-yellow-400:focus {\n    --gradient-to-color: #f6e05e;\n  }\n\n  .sm\\:focus\\:to-yellow-500:focus {\n    --gradient-to-color: #ecc94b;\n  }\n\n  .sm\\:focus\\:to-yellow-600:focus {\n    --gradient-to-color: #d69e2e;\n  }\n\n  .sm\\:focus\\:to-yellow-700:focus {\n    --gradient-to-color: #b7791f;\n  }\n\n  .sm\\:focus\\:to-yellow-800:focus {\n    --gradient-to-color: #975a16;\n  }\n\n  .sm\\:focus\\:to-yellow-900:focus {\n    --gradient-to-color: #744210;\n  }\n\n  .sm\\:focus\\:to-green-100:focus {\n    --gradient-to-color: #f0fff4;\n  }\n\n  .sm\\:focus\\:to-green-200:focus {\n    --gradient-to-color: #c6f6d5;\n  }\n\n  .sm\\:focus\\:to-green-300:focus {\n    --gradient-to-color: #9ae6b4;\n  }\n\n  .sm\\:focus\\:to-green-400:focus {\n    --gradient-to-color: #68d391;\n  }\n\n  .sm\\:focus\\:to-green-500:focus {\n    --gradient-to-color: #48bb78;\n  }\n\n  .sm\\:focus\\:to-green-600:focus {\n    --gradient-to-color: #38a169;\n  }\n\n  .sm\\:focus\\:to-green-700:focus {\n    --gradient-to-color: #2f855a;\n  }\n\n  .sm\\:focus\\:to-green-800:focus {\n    --gradient-to-color: #276749;\n  }\n\n  .sm\\:focus\\:to-green-900:focus {\n    --gradient-to-color: #22543d;\n  }\n\n  .sm\\:focus\\:to-teal-100:focus {\n    --gradient-to-color: #e6fffa;\n  }\n\n  .sm\\:focus\\:to-teal-200:focus {\n    --gradient-to-color: #b2f5ea;\n  }\n\n  .sm\\:focus\\:to-teal-300:focus {\n    --gradient-to-color: #81e6d9;\n  }\n\n  .sm\\:focus\\:to-teal-400:focus {\n    --gradient-to-color: #4fd1c5;\n  }\n\n  .sm\\:focus\\:to-teal-500:focus {\n    --gradient-to-color: #38b2ac;\n  }\n\n  .sm\\:focus\\:to-teal-600:focus {\n    --gradient-to-color: #319795;\n  }\n\n  .sm\\:focus\\:to-teal-700:focus {\n    --gradient-to-color: #2c7a7b;\n  }\n\n  .sm\\:focus\\:to-teal-800:focus {\n    --gradient-to-color: #285e61;\n  }\n\n  .sm\\:focus\\:to-teal-900:focus {\n    --gradient-to-color: #234e52;\n  }\n\n  .sm\\:focus\\:to-blue-100:focus {\n    --gradient-to-color: #ebf8ff;\n  }\n\n  .sm\\:focus\\:to-blue-200:focus {\n    --gradient-to-color: #bee3f8;\n  }\n\n  .sm\\:focus\\:to-blue-300:focus {\n    --gradient-to-color: #90cdf4;\n  }\n\n  .sm\\:focus\\:to-blue-400:focus {\n    --gradient-to-color: #63b3ed;\n  }\n\n  .sm\\:focus\\:to-blue-500:focus {\n    --gradient-to-color: #4299e1;\n  }\n\n  .sm\\:focus\\:to-blue-600:focus {\n    --gradient-to-color: #3182ce;\n  }\n\n  .sm\\:focus\\:to-blue-700:focus {\n    --gradient-to-color: #2b6cb0;\n  }\n\n  .sm\\:focus\\:to-blue-800:focus {\n    --gradient-to-color: #2c5282;\n  }\n\n  .sm\\:focus\\:to-blue-900:focus {\n    --gradient-to-color: #2a4365;\n  }\n\n  .sm\\:focus\\:to-indigo-100:focus {\n    --gradient-to-color: #ebf4ff;\n  }\n\n  .sm\\:focus\\:to-indigo-200:focus {\n    --gradient-to-color: #c3dafe;\n  }\n\n  .sm\\:focus\\:to-indigo-300:focus {\n    --gradient-to-color: #a3bffa;\n  }\n\n  .sm\\:focus\\:to-indigo-400:focus {\n    --gradient-to-color: #7f9cf5;\n  }\n\n  .sm\\:focus\\:to-indigo-500:focus {\n    --gradient-to-color: #667eea;\n  }\n\n  .sm\\:focus\\:to-indigo-600:focus {\n    --gradient-to-color: #5a67d8;\n  }\n\n  .sm\\:focus\\:to-indigo-700:focus {\n    --gradient-to-color: #4c51bf;\n  }\n\n  .sm\\:focus\\:to-indigo-800:focus {\n    --gradient-to-color: #434190;\n  }\n\n  .sm\\:focus\\:to-indigo-900:focus {\n    --gradient-to-color: #3c366b;\n  }\n\n  .sm\\:focus\\:to-purple-100:focus {\n    --gradient-to-color: #faf5ff;\n  }\n\n  .sm\\:focus\\:to-purple-200:focus {\n    --gradient-to-color: #e9d8fd;\n  }\n\n  .sm\\:focus\\:to-purple-300:focus {\n    --gradient-to-color: #d6bcfa;\n  }\n\n  .sm\\:focus\\:to-purple-400:focus {\n    --gradient-to-color: #b794f4;\n  }\n\n  .sm\\:focus\\:to-purple-500:focus {\n    --gradient-to-color: #9f7aea;\n  }\n\n  .sm\\:focus\\:to-purple-600:focus {\n    --gradient-to-color: #805ad5;\n  }\n\n  .sm\\:focus\\:to-purple-700:focus {\n    --gradient-to-color: #6b46c1;\n  }\n\n  .sm\\:focus\\:to-purple-800:focus {\n    --gradient-to-color: #553c9a;\n  }\n\n  .sm\\:focus\\:to-purple-900:focus {\n    --gradient-to-color: #44337a;\n  }\n\n  .sm\\:focus\\:to-pink-100:focus {\n    --gradient-to-color: #fff5f7;\n  }\n\n  .sm\\:focus\\:to-pink-200:focus {\n    --gradient-to-color: #fed7e2;\n  }\n\n  .sm\\:focus\\:to-pink-300:focus {\n    --gradient-to-color: #fbb6ce;\n  }\n\n  .sm\\:focus\\:to-pink-400:focus {\n    --gradient-to-color: #f687b3;\n  }\n\n  .sm\\:focus\\:to-pink-500:focus {\n    --gradient-to-color: #ed64a6;\n  }\n\n  .sm\\:focus\\:to-pink-600:focus {\n    --gradient-to-color: #d53f8c;\n  }\n\n  .sm\\:focus\\:to-pink-700:focus {\n    --gradient-to-color: #b83280;\n  }\n\n  .sm\\:focus\\:to-pink-800:focus {\n    --gradient-to-color: #97266d;\n  }\n\n  .sm\\:focus\\:to-pink-900:focus {\n    --gradient-to-color: #702459;\n  }\n\n  .sm\\:focus\\:to-grayscale-80:focus {\n    --gradient-to-color: hsl(0, 0%, 8%);\n  }\n\n  .sm\\:focus\\:to-grayscale-100:focus {\n    --gradient-to-color: hsl(0, 0%, 10%);\n  }\n\n  .sm\\:focus\\:to-grayscale-200:focus {\n    --gradient-to-color: hsl(0, 0%, 20%);\n  }\n\n  .sm\\:focus\\:to-grayscale-300:focus {\n    --gradient-to-color: hsl(0, 0%, 30%);\n  }\n\n  .sm\\:focus\\:to-grayscale-400:focus {\n    --gradient-to-color: hsl(0, 0%, 40%);\n  }\n\n  .sm\\:focus\\:to-grayscale-500:focus {\n    --gradient-to-color: hsl(0, 0%, 50%);\n  }\n\n  .sm\\:focus\\:to-grayscale-600:focus {\n    --gradient-to-color: hsl(0, 0%, 60%);\n  }\n\n  .sm\\:focus\\:to-grayscale-700:focus {\n    --gradient-to-color: hsl(0, 0%, 70%);\n  }\n\n  .sm\\:focus\\:to-grayscale-800:focus {\n    --gradient-to-color: hsl(0, 0%, 80%);\n  }\n\n  .sm\\:focus\\:to-grayscale-840:focus {\n    --gradient-to-color: hsl(0, 0%, 84%);\n  }\n\n  .sm\\:focus\\:to-grayscale-870:focus {\n    --gradient-to-color: hsl(0, 0%, 87%);\n  }\n\n  .sm\\:focus\\:to-grayscale-900:focus {\n    --gradient-to-color: hsl(0, 0%, 90%);\n  }\n\n  .sm\\:focus\\:to-grayscale-930:focus {\n    --gradient-to-color: hsl(0, 0%, 93%);\n  }\n\n  .sm\\:focus\\:to-primary:focus {\n    --gradient-to-color: hsl(210, 100%, 52%);\n  }\n\n  .sm\\:focus\\:to-background-main:focus {\n    --gradient-to-color: var(--main-background);\n  }\n\n  .sm\\:focus\\:to-background-secondary:focus {\n    --gradient-to-color: var(--secondary-background);\n  }\n\n  .sm\\:focus\\:to-foreground:focus {\n    --gradient-to-color: var(--foreground);\n  }\n\n  .sm\\:focus\\:to-panels-bg:focus {\n    --gradient-to-color: var(--panels-background);\n  }\n\n  .sm\\:bg-opacity-0 {\n    --bg-opacity: 0;\n  }\n\n  .sm\\:bg-opacity-25 {\n    --bg-opacity: 0.25;\n  }\n\n  .sm\\:bg-opacity-50 {\n    --bg-opacity: 0.5;\n  }\n\n  .sm\\:bg-opacity-75 {\n    --bg-opacity: 0.75;\n  }\n\n  .sm\\:bg-opacity-100 {\n    --bg-opacity: 1;\n  }\n\n  .sm\\:hover\\:bg-opacity-0:hover {\n    --bg-opacity: 0;\n  }\n\n  .sm\\:hover\\:bg-opacity-25:hover {\n    --bg-opacity: 0.25;\n  }\n\n  .sm\\:hover\\:bg-opacity-50:hover {\n    --bg-opacity: 0.5;\n  }\n\n  .sm\\:hover\\:bg-opacity-75:hover {\n    --bg-opacity: 0.75;\n  }\n\n  .sm\\:hover\\:bg-opacity-100:hover {\n    --bg-opacity: 1;\n  }\n\n  .sm\\:focus\\:bg-opacity-0:focus {\n    --bg-opacity: 0;\n  }\n\n  .sm\\:focus\\:bg-opacity-25:focus {\n    --bg-opacity: 0.25;\n  }\n\n  .sm\\:focus\\:bg-opacity-50:focus {\n    --bg-opacity: 0.5;\n  }\n\n  .sm\\:focus\\:bg-opacity-75:focus {\n    --bg-opacity: 0.75;\n  }\n\n  .sm\\:focus\\:bg-opacity-100:focus {\n    --bg-opacity: 1;\n  }\n\n  .sm\\:bg-bottom {\n    background-position: bottom;\n  }\n\n  .sm\\:bg-center {\n    background-position: center;\n  }\n\n  .sm\\:bg-left {\n    background-position: left;\n  }\n\n  .sm\\:bg-left-bottom {\n    background-position: left bottom;\n  }\n\n  .sm\\:bg-left-top {\n    background-position: left top;\n  }\n\n  .sm\\:bg-right {\n    background-position: right;\n  }\n\n  .sm\\:bg-right-bottom {\n    background-position: right bottom;\n  }\n\n  .sm\\:bg-right-top {\n    background-position: right top;\n  }\n\n  .sm\\:bg-top {\n    background-position: top;\n  }\n\n  .sm\\:bg-repeat {\n    background-repeat: repeat;\n  }\n\n  .sm\\:bg-no-repeat {\n    background-repeat: no-repeat;\n  }\n\n  .sm\\:bg-repeat-x {\n    background-repeat: repeat-x;\n  }\n\n  .sm\\:bg-repeat-y {\n    background-repeat: repeat-y;\n  }\n\n  .sm\\:bg-repeat-round {\n    background-repeat: round;\n  }\n\n  .sm\\:bg-repeat-space {\n    background-repeat: space;\n  }\n\n  .sm\\:bg-auto {\n    background-size: auto;\n  }\n\n  .sm\\:bg-cover {\n    background-size: cover;\n  }\n\n  .sm\\:bg-contain {\n    background-size: contain;\n  }\n\n  .sm\\:border-collapse {\n    border-collapse: collapse;\n  }\n\n  .sm\\:border-separate {\n    border-collapse: separate;\n  }\n\n  .sm\\:border-transparent {\n    border-color: transparent;\n  }\n\n  .sm\\:border-current {\n    border-color: currentColor;\n  }\n\n  .sm\\:border-black {\n    --border-opacity: 1;\n    border-color: #000;\n    border-color: rgba(0, 0, 0, var(--border-opacity));\n  }\n\n  .sm\\:border-white {\n    --border-opacity: 1;\n    border-color: #fff;\n    border-color: rgba(255, 255, 255, var(--border-opacity));\n  }\n\n  .sm\\:border-gray-100 {\n    --border-opacity: 1;\n    border-color: #f7fafc;\n    border-color: rgba(247, 250, 252, var(--border-opacity));\n  }\n\n  .sm\\:border-gray-200 {\n    --border-opacity: 1;\n    border-color: #edf2f7;\n    border-color: rgba(237, 242, 247, var(--border-opacity));\n  }\n\n  .sm\\:border-gray-300 {\n    --border-opacity: 1;\n    border-color: #e2e8f0;\n    border-color: rgba(226, 232, 240, var(--border-opacity));\n  }\n\n  .sm\\:border-gray-400 {\n    --border-opacity: 1;\n    border-color: #cbd5e0;\n    border-color: rgba(203, 213, 224, var(--border-opacity));\n  }\n\n  .sm\\:border-gray-500 {\n    --border-opacity: 1;\n    border-color: #a0aec0;\n    border-color: rgba(160, 174, 192, var(--border-opacity));\n  }\n\n  .sm\\:border-gray-600 {\n    --border-opacity: 1;\n    border-color: #718096;\n    border-color: rgba(113, 128, 150, var(--border-opacity));\n  }\n\n  .sm\\:border-gray-700 {\n    --border-opacity: 1;\n    border-color: #4a5568;\n    border-color: rgba(74, 85, 104, var(--border-opacity));\n  }\n\n  .sm\\:border-gray-800 {\n    --border-opacity: 1;\n    border-color: #2d3748;\n    border-color: rgba(45, 55, 72, var(--border-opacity));\n  }\n\n  .sm\\:border-gray-900 {\n    --border-opacity: 1;\n    border-color: #1a202c;\n    border-color: rgba(26, 32, 44, var(--border-opacity));\n  }\n\n  .sm\\:border-red-100 {\n    --border-opacity: 1;\n    border-color: #fff5f5;\n    border-color: rgba(255, 245, 245, var(--border-opacity));\n  }\n\n  .sm\\:border-red-200 {\n    --border-opacity: 1;\n    border-color: #fed7d7;\n    border-color: rgba(254, 215, 215, var(--border-opacity));\n  }\n\n  .sm\\:border-red-300 {\n    --border-opacity: 1;\n    border-color: #feb2b2;\n    border-color: rgba(254, 178, 178, var(--border-opacity));\n  }\n\n  .sm\\:border-red-400 {\n    --border-opacity: 1;\n    border-color: #fc8181;\n    border-color: rgba(252, 129, 129, var(--border-opacity));\n  }\n\n  .sm\\:border-red-500 {\n    --border-opacity: 1;\n    border-color: #f56565;\n    border-color: rgba(245, 101, 101, var(--border-opacity));\n  }\n\n  .sm\\:border-red-600 {\n    --border-opacity: 1;\n    border-color: #e53e3e;\n    border-color: rgba(229, 62, 62, var(--border-opacity));\n  }\n\n  .sm\\:border-red-700 {\n    --border-opacity: 1;\n    border-color: #c53030;\n    border-color: rgba(197, 48, 48, var(--border-opacity));\n  }\n\n  .sm\\:border-red-800 {\n    --border-opacity: 1;\n    border-color: #9b2c2c;\n    border-color: rgba(155, 44, 44, var(--border-opacity));\n  }\n\n  .sm\\:border-red-900 {\n    --border-opacity: 1;\n    border-color: #742a2a;\n    border-color: rgba(116, 42, 42, var(--border-opacity));\n  }\n\n  .sm\\:border-orange-100 {\n    --border-opacity: 1;\n    border-color: #fffaf0;\n    border-color: rgba(255, 250, 240, var(--border-opacity));\n  }\n\n  .sm\\:border-orange-200 {\n    --border-opacity: 1;\n    border-color: #feebc8;\n    border-color: rgba(254, 235, 200, var(--border-opacity));\n  }\n\n  .sm\\:border-orange-300 {\n    --border-opacity: 1;\n    border-color: #fbd38d;\n    border-color: rgba(251, 211, 141, var(--border-opacity));\n  }\n\n  .sm\\:border-orange-400 {\n    --border-opacity: 1;\n    border-color: #f6ad55;\n    border-color: rgba(246, 173, 85, var(--border-opacity));\n  }\n\n  .sm\\:border-orange-500 {\n    --border-opacity: 1;\n    border-color: #ed8936;\n    border-color: rgba(237, 137, 54, var(--border-opacity));\n  }\n\n  .sm\\:border-orange-600 {\n    --border-opacity: 1;\n    border-color: #dd6b20;\n    border-color: rgba(221, 107, 32, var(--border-opacity));\n  }\n\n  .sm\\:border-orange-700 {\n    --border-opacity: 1;\n    border-color: #c05621;\n    border-color: rgba(192, 86, 33, var(--border-opacity));\n  }\n\n  .sm\\:border-orange-800 {\n    --border-opacity: 1;\n    border-color: #9c4221;\n    border-color: rgba(156, 66, 33, var(--border-opacity));\n  }\n\n  .sm\\:border-orange-900 {\n    --border-opacity: 1;\n    border-color: #7b341e;\n    border-color: rgba(123, 52, 30, var(--border-opacity));\n  }\n\n  .sm\\:border-yellow-100 {\n    --border-opacity: 1;\n    border-color: #fffff0;\n    border-color: rgba(255, 255, 240, var(--border-opacity));\n  }\n\n  .sm\\:border-yellow-200 {\n    --border-opacity: 1;\n    border-color: #fefcbf;\n    border-color: rgba(254, 252, 191, var(--border-opacity));\n  }\n\n  .sm\\:border-yellow-300 {\n    --border-opacity: 1;\n    border-color: #faf089;\n    border-color: rgba(250, 240, 137, var(--border-opacity));\n  }\n\n  .sm\\:border-yellow-400 {\n    --border-opacity: 1;\n    border-color: #f6e05e;\n    border-color: rgba(246, 224, 94, var(--border-opacity));\n  }\n\n  .sm\\:border-yellow-500 {\n    --border-opacity: 1;\n    border-color: #ecc94b;\n    border-color: rgba(236, 201, 75, var(--border-opacity));\n  }\n\n  .sm\\:border-yellow-600 {\n    --border-opacity: 1;\n    border-color: #d69e2e;\n    border-color: rgba(214, 158, 46, var(--border-opacity));\n  }\n\n  .sm\\:border-yellow-700 {\n    --border-opacity: 1;\n    border-color: #b7791f;\n    border-color: rgba(183, 121, 31, var(--border-opacity));\n  }\n\n  .sm\\:border-yellow-800 {\n    --border-opacity: 1;\n    border-color: #975a16;\n    border-color: rgba(151, 90, 22, var(--border-opacity));\n  }\n\n  .sm\\:border-yellow-900 {\n    --border-opacity: 1;\n    border-color: #744210;\n    border-color: rgba(116, 66, 16, var(--border-opacity));\n  }\n\n  .sm\\:border-green-100 {\n    --border-opacity: 1;\n    border-color: #f0fff4;\n    border-color: rgba(240, 255, 244, var(--border-opacity));\n  }\n\n  .sm\\:border-green-200 {\n    --border-opacity: 1;\n    border-color: #c6f6d5;\n    border-color: rgba(198, 246, 213, var(--border-opacity));\n  }\n\n  .sm\\:border-green-300 {\n    --border-opacity: 1;\n    border-color: #9ae6b4;\n    border-color: rgba(154, 230, 180, var(--border-opacity));\n  }\n\n  .sm\\:border-green-400 {\n    --border-opacity: 1;\n    border-color: #68d391;\n    border-color: rgba(104, 211, 145, var(--border-opacity));\n  }\n\n  .sm\\:border-green-500 {\n    --border-opacity: 1;\n    border-color: #48bb78;\n    border-color: rgba(72, 187, 120, var(--border-opacity));\n  }\n\n  .sm\\:border-green-600 {\n    --border-opacity: 1;\n    border-color: #38a169;\n    border-color: rgba(56, 161, 105, var(--border-opacity));\n  }\n\n  .sm\\:border-green-700 {\n    --border-opacity: 1;\n    border-color: #2f855a;\n    border-color: rgba(47, 133, 90, var(--border-opacity));\n  }\n\n  .sm\\:border-green-800 {\n    --border-opacity: 1;\n    border-color: #276749;\n    border-color: rgba(39, 103, 73, var(--border-opacity));\n  }\n\n  .sm\\:border-green-900 {\n    --border-opacity: 1;\n    border-color: #22543d;\n    border-color: rgba(34, 84, 61, var(--border-opacity));\n  }\n\n  .sm\\:border-teal-100 {\n    --border-opacity: 1;\n    border-color: #e6fffa;\n    border-color: rgba(230, 255, 250, var(--border-opacity));\n  }\n\n  .sm\\:border-teal-200 {\n    --border-opacity: 1;\n    border-color: #b2f5ea;\n    border-color: rgba(178, 245, 234, var(--border-opacity));\n  }\n\n  .sm\\:border-teal-300 {\n    --border-opacity: 1;\n    border-color: #81e6d9;\n    border-color: rgba(129, 230, 217, var(--border-opacity));\n  }\n\n  .sm\\:border-teal-400 {\n    --border-opacity: 1;\n    border-color: #4fd1c5;\n    border-color: rgba(79, 209, 197, var(--border-opacity));\n  }\n\n  .sm\\:border-teal-500 {\n    --border-opacity: 1;\n    border-color: #38b2ac;\n    border-color: rgba(56, 178, 172, var(--border-opacity));\n  }\n\n  .sm\\:border-teal-600 {\n    --border-opacity: 1;\n    border-color: #319795;\n    border-color: rgba(49, 151, 149, var(--border-opacity));\n  }\n\n  .sm\\:border-teal-700 {\n    --border-opacity: 1;\n    border-color: #2c7a7b;\n    border-color: rgba(44, 122, 123, var(--border-opacity));\n  }\n\n  .sm\\:border-teal-800 {\n    --border-opacity: 1;\n    border-color: #285e61;\n    border-color: rgba(40, 94, 97, var(--border-opacity));\n  }\n\n  .sm\\:border-teal-900 {\n    --border-opacity: 1;\n    border-color: #234e52;\n    border-color: rgba(35, 78, 82, var(--border-opacity));\n  }\n\n  .sm\\:border-blue-100 {\n    --border-opacity: 1;\n    border-color: #ebf8ff;\n    border-color: rgba(235, 248, 255, var(--border-opacity));\n  }\n\n  .sm\\:border-blue-200 {\n    --border-opacity: 1;\n    border-color: #bee3f8;\n    border-color: rgba(190, 227, 248, var(--border-opacity));\n  }\n\n  .sm\\:border-blue-300 {\n    --border-opacity: 1;\n    border-color: #90cdf4;\n    border-color: rgba(144, 205, 244, var(--border-opacity));\n  }\n\n  .sm\\:border-blue-400 {\n    --border-opacity: 1;\n    border-color: #63b3ed;\n    border-color: rgba(99, 179, 237, var(--border-opacity));\n  }\n\n  .sm\\:border-blue-500 {\n    --border-opacity: 1;\n    border-color: #4299e1;\n    border-color: rgba(66, 153, 225, var(--border-opacity));\n  }\n\n  .sm\\:border-blue-600 {\n    --border-opacity: 1;\n    border-color: #3182ce;\n    border-color: rgba(49, 130, 206, var(--border-opacity));\n  }\n\n  .sm\\:border-blue-700 {\n    --border-opacity: 1;\n    border-color: #2b6cb0;\n    border-color: rgba(43, 108, 176, var(--border-opacity));\n  }\n\n  .sm\\:border-blue-800 {\n    --border-opacity: 1;\n    border-color: #2c5282;\n    border-color: rgba(44, 82, 130, var(--border-opacity));\n  }\n\n  .sm\\:border-blue-900 {\n    --border-opacity: 1;\n    border-color: #2a4365;\n    border-color: rgba(42, 67, 101, var(--border-opacity));\n  }\n\n  .sm\\:border-indigo-100 {\n    --border-opacity: 1;\n    border-color: #ebf4ff;\n    border-color: rgba(235, 244, 255, var(--border-opacity));\n  }\n\n  .sm\\:border-indigo-200 {\n    --border-opacity: 1;\n    border-color: #c3dafe;\n    border-color: rgba(195, 218, 254, var(--border-opacity));\n  }\n\n  .sm\\:border-indigo-300 {\n    --border-opacity: 1;\n    border-color: #a3bffa;\n    border-color: rgba(163, 191, 250, var(--border-opacity));\n  }\n\n  .sm\\:border-indigo-400 {\n    --border-opacity: 1;\n    border-color: #7f9cf5;\n    border-color: rgba(127, 156, 245, var(--border-opacity));\n  }\n\n  .sm\\:border-indigo-500 {\n    --border-opacity: 1;\n    border-color: #667eea;\n    border-color: rgba(102, 126, 234, var(--border-opacity));\n  }\n\n  .sm\\:border-indigo-600 {\n    --border-opacity: 1;\n    border-color: #5a67d8;\n    border-color: rgba(90, 103, 216, var(--border-opacity));\n  }\n\n  .sm\\:border-indigo-700 {\n    --border-opacity: 1;\n    border-color: #4c51bf;\n    border-color: rgba(76, 81, 191, var(--border-opacity));\n  }\n\n  .sm\\:border-indigo-800 {\n    --border-opacity: 1;\n    border-color: #434190;\n    border-color: rgba(67, 65, 144, var(--border-opacity));\n  }\n\n  .sm\\:border-indigo-900 {\n    --border-opacity: 1;\n    border-color: #3c366b;\n    border-color: rgba(60, 54, 107, var(--border-opacity));\n  }\n\n  .sm\\:border-purple-100 {\n    --border-opacity: 1;\n    border-color: #faf5ff;\n    border-color: rgba(250, 245, 255, var(--border-opacity));\n  }\n\n  .sm\\:border-purple-200 {\n    --border-opacity: 1;\n    border-color: #e9d8fd;\n    border-color: rgba(233, 216, 253, var(--border-opacity));\n  }\n\n  .sm\\:border-purple-300 {\n    --border-opacity: 1;\n    border-color: #d6bcfa;\n    border-color: rgba(214, 188, 250, var(--border-opacity));\n  }\n\n  .sm\\:border-purple-400 {\n    --border-opacity: 1;\n    border-color: #b794f4;\n    border-color: rgba(183, 148, 244, var(--border-opacity));\n  }\n\n  .sm\\:border-purple-500 {\n    --border-opacity: 1;\n    border-color: #9f7aea;\n    border-color: rgba(159, 122, 234, var(--border-opacity));\n  }\n\n  .sm\\:border-purple-600 {\n    --border-opacity: 1;\n    border-color: #805ad5;\n    border-color: rgba(128, 90, 213, var(--border-opacity));\n  }\n\n  .sm\\:border-purple-700 {\n    --border-opacity: 1;\n    border-color: #6b46c1;\n    border-color: rgba(107, 70, 193, var(--border-opacity));\n  }\n\n  .sm\\:border-purple-800 {\n    --border-opacity: 1;\n    border-color: #553c9a;\n    border-color: rgba(85, 60, 154, var(--border-opacity));\n  }\n\n  .sm\\:border-purple-900 {\n    --border-opacity: 1;\n    border-color: #44337a;\n    border-color: rgba(68, 51, 122, var(--border-opacity));\n  }\n\n  .sm\\:border-pink-100 {\n    --border-opacity: 1;\n    border-color: #fff5f7;\n    border-color: rgba(255, 245, 247, var(--border-opacity));\n  }\n\n  .sm\\:border-pink-200 {\n    --border-opacity: 1;\n    border-color: #fed7e2;\n    border-color: rgba(254, 215, 226, var(--border-opacity));\n  }\n\n  .sm\\:border-pink-300 {\n    --border-opacity: 1;\n    border-color: #fbb6ce;\n    border-color: rgba(251, 182, 206, var(--border-opacity));\n  }\n\n  .sm\\:border-pink-400 {\n    --border-opacity: 1;\n    border-color: #f687b3;\n    border-color: rgba(246, 135, 179, var(--border-opacity));\n  }\n\n  .sm\\:border-pink-500 {\n    --border-opacity: 1;\n    border-color: #ed64a6;\n    border-color: rgba(237, 100, 166, var(--border-opacity));\n  }\n\n  .sm\\:border-pink-600 {\n    --border-opacity: 1;\n    border-color: #d53f8c;\n    border-color: rgba(213, 63, 140, var(--border-opacity));\n  }\n\n  .sm\\:border-pink-700 {\n    --border-opacity: 1;\n    border-color: #b83280;\n    border-color: rgba(184, 50, 128, var(--border-opacity));\n  }\n\n  .sm\\:border-pink-800 {\n    --border-opacity: 1;\n    border-color: #97266d;\n    border-color: rgba(151, 38, 109, var(--border-opacity));\n  }\n\n  .sm\\:border-pink-900 {\n    --border-opacity: 1;\n    border-color: #702459;\n    border-color: rgba(112, 36, 89, var(--border-opacity));\n  }\n\n  .sm\\:border-grayscale-80 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 8%);\n    border-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--border-opacity));\n  }\n\n  .sm\\:border-grayscale-100 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 10%);\n    border-color: rgba(25.5, 25.5, 25.5, var(--border-opacity));\n  }\n\n  .sm\\:border-grayscale-200 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 20%);\n    border-color: rgba(51, 51, 51, var(--border-opacity));\n  }\n\n  .sm\\:border-grayscale-300 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 30%);\n    border-color: rgba(76.5, 76.5, 76.5, var(--border-opacity));\n  }\n\n  .sm\\:border-grayscale-400 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 40%);\n    border-color: rgba(102, 102, 102, var(--border-opacity));\n  }\n\n  .sm\\:border-grayscale-500 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 50%);\n    border-color: rgba(127.5, 127.5, 127.5, var(--border-opacity));\n  }\n\n  .sm\\:border-grayscale-600 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 60%);\n    border-color: rgba(153, 153, 153, var(--border-opacity));\n  }\n\n  .sm\\:border-grayscale-700 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 70%);\n    border-color: rgba(178.5, 178.5, 178.5, var(--border-opacity));\n  }\n\n  .sm\\:border-grayscale-800 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 80%);\n    border-color: rgba(204, 204, 204, var(--border-opacity));\n  }\n\n  .sm\\:border-grayscale-840 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 84%);\n    border-color: rgba(214.2, 214.2, 214.2, var(--border-opacity));\n  }\n\n  .sm\\:border-grayscale-870 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 87%);\n    border-color: rgba(221.85, 221.85, 221.85, var(--border-opacity));\n  }\n\n  .sm\\:border-grayscale-900 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 90%);\n    border-color: rgba(229.5, 229.5, 229.5, var(--border-opacity));\n  }\n\n  .sm\\:border-grayscale-930 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 93%);\n    border-color: rgba(237.15, 237.15, 237.15, var(--border-opacity));\n  }\n\n  .sm\\:border-primary {\n    --border-opacity: 1;\n    border-color: hsl(210, 100%, 52%);\n    border-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--border-opacity));\n  }\n\n  .sm\\:border-background-main {\n    border-color: var(--main-background);\n  }\n\n  .sm\\:border-background-secondary {\n    border-color: var(--secondary-background);\n  }\n\n  .sm\\:border-foreground {\n    border-color: var(--foreground);\n  }\n\n  .sm\\:border-panels-bg {\n    border-color: var(--panels-background);\n  }\n\n  .sm\\:hover\\:border-transparent:hover {\n    border-color: transparent;\n  }\n\n  .sm\\:hover\\:border-current:hover {\n    border-color: currentColor;\n  }\n\n  .sm\\:hover\\:border-black:hover {\n    --border-opacity: 1;\n    border-color: #000;\n    border-color: rgba(0, 0, 0, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-white:hover {\n    --border-opacity: 1;\n    border-color: #fff;\n    border-color: rgba(255, 255, 255, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-gray-100:hover {\n    --border-opacity: 1;\n    border-color: #f7fafc;\n    border-color: rgba(247, 250, 252, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-gray-200:hover {\n    --border-opacity: 1;\n    border-color: #edf2f7;\n    border-color: rgba(237, 242, 247, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-gray-300:hover {\n    --border-opacity: 1;\n    border-color: #e2e8f0;\n    border-color: rgba(226, 232, 240, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-gray-400:hover {\n    --border-opacity: 1;\n    border-color: #cbd5e0;\n    border-color: rgba(203, 213, 224, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-gray-500:hover {\n    --border-opacity: 1;\n    border-color: #a0aec0;\n    border-color: rgba(160, 174, 192, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-gray-600:hover {\n    --border-opacity: 1;\n    border-color: #718096;\n    border-color: rgba(113, 128, 150, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-gray-700:hover {\n    --border-opacity: 1;\n    border-color: #4a5568;\n    border-color: rgba(74, 85, 104, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-gray-800:hover {\n    --border-opacity: 1;\n    border-color: #2d3748;\n    border-color: rgba(45, 55, 72, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-gray-900:hover {\n    --border-opacity: 1;\n    border-color: #1a202c;\n    border-color: rgba(26, 32, 44, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-red-100:hover {\n    --border-opacity: 1;\n    border-color: #fff5f5;\n    border-color: rgba(255, 245, 245, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-red-200:hover {\n    --border-opacity: 1;\n    border-color: #fed7d7;\n    border-color: rgba(254, 215, 215, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-red-300:hover {\n    --border-opacity: 1;\n    border-color: #feb2b2;\n    border-color: rgba(254, 178, 178, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-red-400:hover {\n    --border-opacity: 1;\n    border-color: #fc8181;\n    border-color: rgba(252, 129, 129, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-red-500:hover {\n    --border-opacity: 1;\n    border-color: #f56565;\n    border-color: rgba(245, 101, 101, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-red-600:hover {\n    --border-opacity: 1;\n    border-color: #e53e3e;\n    border-color: rgba(229, 62, 62, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-red-700:hover {\n    --border-opacity: 1;\n    border-color: #c53030;\n    border-color: rgba(197, 48, 48, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-red-800:hover {\n    --border-opacity: 1;\n    border-color: #9b2c2c;\n    border-color: rgba(155, 44, 44, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-red-900:hover {\n    --border-opacity: 1;\n    border-color: #742a2a;\n    border-color: rgba(116, 42, 42, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-orange-100:hover {\n    --border-opacity: 1;\n    border-color: #fffaf0;\n    border-color: rgba(255, 250, 240, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-orange-200:hover {\n    --border-opacity: 1;\n    border-color: #feebc8;\n    border-color: rgba(254, 235, 200, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-orange-300:hover {\n    --border-opacity: 1;\n    border-color: #fbd38d;\n    border-color: rgba(251, 211, 141, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-orange-400:hover {\n    --border-opacity: 1;\n    border-color: #f6ad55;\n    border-color: rgba(246, 173, 85, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-orange-500:hover {\n    --border-opacity: 1;\n    border-color: #ed8936;\n    border-color: rgba(237, 137, 54, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-orange-600:hover {\n    --border-opacity: 1;\n    border-color: #dd6b20;\n    border-color: rgba(221, 107, 32, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-orange-700:hover {\n    --border-opacity: 1;\n    border-color: #c05621;\n    border-color: rgba(192, 86, 33, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-orange-800:hover {\n    --border-opacity: 1;\n    border-color: #9c4221;\n    border-color: rgba(156, 66, 33, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-orange-900:hover {\n    --border-opacity: 1;\n    border-color: #7b341e;\n    border-color: rgba(123, 52, 30, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-yellow-100:hover {\n    --border-opacity: 1;\n    border-color: #fffff0;\n    border-color: rgba(255, 255, 240, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-yellow-200:hover {\n    --border-opacity: 1;\n    border-color: #fefcbf;\n    border-color: rgba(254, 252, 191, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-yellow-300:hover {\n    --border-opacity: 1;\n    border-color: #faf089;\n    border-color: rgba(250, 240, 137, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-yellow-400:hover {\n    --border-opacity: 1;\n    border-color: #f6e05e;\n    border-color: rgba(246, 224, 94, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-yellow-500:hover {\n    --border-opacity: 1;\n    border-color: #ecc94b;\n    border-color: rgba(236, 201, 75, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-yellow-600:hover {\n    --border-opacity: 1;\n    border-color: #d69e2e;\n    border-color: rgba(214, 158, 46, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-yellow-700:hover {\n    --border-opacity: 1;\n    border-color: #b7791f;\n    border-color: rgba(183, 121, 31, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-yellow-800:hover {\n    --border-opacity: 1;\n    border-color: #975a16;\n    border-color: rgba(151, 90, 22, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-yellow-900:hover {\n    --border-opacity: 1;\n    border-color: #744210;\n    border-color: rgba(116, 66, 16, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-green-100:hover {\n    --border-opacity: 1;\n    border-color: #f0fff4;\n    border-color: rgba(240, 255, 244, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-green-200:hover {\n    --border-opacity: 1;\n    border-color: #c6f6d5;\n    border-color: rgba(198, 246, 213, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-green-300:hover {\n    --border-opacity: 1;\n    border-color: #9ae6b4;\n    border-color: rgba(154, 230, 180, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-green-400:hover {\n    --border-opacity: 1;\n    border-color: #68d391;\n    border-color: rgba(104, 211, 145, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-green-500:hover {\n    --border-opacity: 1;\n    border-color: #48bb78;\n    border-color: rgba(72, 187, 120, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-green-600:hover {\n    --border-opacity: 1;\n    border-color: #38a169;\n    border-color: rgba(56, 161, 105, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-green-700:hover {\n    --border-opacity: 1;\n    border-color: #2f855a;\n    border-color: rgba(47, 133, 90, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-green-800:hover {\n    --border-opacity: 1;\n    border-color: #276749;\n    border-color: rgba(39, 103, 73, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-green-900:hover {\n    --border-opacity: 1;\n    border-color: #22543d;\n    border-color: rgba(34, 84, 61, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-teal-100:hover {\n    --border-opacity: 1;\n    border-color: #e6fffa;\n    border-color: rgba(230, 255, 250, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-teal-200:hover {\n    --border-opacity: 1;\n    border-color: #b2f5ea;\n    border-color: rgba(178, 245, 234, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-teal-300:hover {\n    --border-opacity: 1;\n    border-color: #81e6d9;\n    border-color: rgba(129, 230, 217, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-teal-400:hover {\n    --border-opacity: 1;\n    border-color: #4fd1c5;\n    border-color: rgba(79, 209, 197, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-teal-500:hover {\n    --border-opacity: 1;\n    border-color: #38b2ac;\n    border-color: rgba(56, 178, 172, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-teal-600:hover {\n    --border-opacity: 1;\n    border-color: #319795;\n    border-color: rgba(49, 151, 149, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-teal-700:hover {\n    --border-opacity: 1;\n    border-color: #2c7a7b;\n    border-color: rgba(44, 122, 123, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-teal-800:hover {\n    --border-opacity: 1;\n    border-color: #285e61;\n    border-color: rgba(40, 94, 97, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-teal-900:hover {\n    --border-opacity: 1;\n    border-color: #234e52;\n    border-color: rgba(35, 78, 82, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-blue-100:hover {\n    --border-opacity: 1;\n    border-color: #ebf8ff;\n    border-color: rgba(235, 248, 255, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-blue-200:hover {\n    --border-opacity: 1;\n    border-color: #bee3f8;\n    border-color: rgba(190, 227, 248, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-blue-300:hover {\n    --border-opacity: 1;\n    border-color: #90cdf4;\n    border-color: rgba(144, 205, 244, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-blue-400:hover {\n    --border-opacity: 1;\n    border-color: #63b3ed;\n    border-color: rgba(99, 179, 237, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-blue-500:hover {\n    --border-opacity: 1;\n    border-color: #4299e1;\n    border-color: rgba(66, 153, 225, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-blue-600:hover {\n    --border-opacity: 1;\n    border-color: #3182ce;\n    border-color: rgba(49, 130, 206, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-blue-700:hover {\n    --border-opacity: 1;\n    border-color: #2b6cb0;\n    border-color: rgba(43, 108, 176, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-blue-800:hover {\n    --border-opacity: 1;\n    border-color: #2c5282;\n    border-color: rgba(44, 82, 130, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-blue-900:hover {\n    --border-opacity: 1;\n    border-color: #2a4365;\n    border-color: rgba(42, 67, 101, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-indigo-100:hover {\n    --border-opacity: 1;\n    border-color: #ebf4ff;\n    border-color: rgba(235, 244, 255, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-indigo-200:hover {\n    --border-opacity: 1;\n    border-color: #c3dafe;\n    border-color: rgba(195, 218, 254, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-indigo-300:hover {\n    --border-opacity: 1;\n    border-color: #a3bffa;\n    border-color: rgba(163, 191, 250, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-indigo-400:hover {\n    --border-opacity: 1;\n    border-color: #7f9cf5;\n    border-color: rgba(127, 156, 245, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-indigo-500:hover {\n    --border-opacity: 1;\n    border-color: #667eea;\n    border-color: rgba(102, 126, 234, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-indigo-600:hover {\n    --border-opacity: 1;\n    border-color: #5a67d8;\n    border-color: rgba(90, 103, 216, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-indigo-700:hover {\n    --border-opacity: 1;\n    border-color: #4c51bf;\n    border-color: rgba(76, 81, 191, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-indigo-800:hover {\n    --border-opacity: 1;\n    border-color: #434190;\n    border-color: rgba(67, 65, 144, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-indigo-900:hover {\n    --border-opacity: 1;\n    border-color: #3c366b;\n    border-color: rgba(60, 54, 107, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-purple-100:hover {\n    --border-opacity: 1;\n    border-color: #faf5ff;\n    border-color: rgba(250, 245, 255, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-purple-200:hover {\n    --border-opacity: 1;\n    border-color: #e9d8fd;\n    border-color: rgba(233, 216, 253, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-purple-300:hover {\n    --border-opacity: 1;\n    border-color: #d6bcfa;\n    border-color: rgba(214, 188, 250, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-purple-400:hover {\n    --border-opacity: 1;\n    border-color: #b794f4;\n    border-color: rgba(183, 148, 244, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-purple-500:hover {\n    --border-opacity: 1;\n    border-color: #9f7aea;\n    border-color: rgba(159, 122, 234, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-purple-600:hover {\n    --border-opacity: 1;\n    border-color: #805ad5;\n    border-color: rgba(128, 90, 213, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-purple-700:hover {\n    --border-opacity: 1;\n    border-color: #6b46c1;\n    border-color: rgba(107, 70, 193, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-purple-800:hover {\n    --border-opacity: 1;\n    border-color: #553c9a;\n    border-color: rgba(85, 60, 154, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-purple-900:hover {\n    --border-opacity: 1;\n    border-color: #44337a;\n    border-color: rgba(68, 51, 122, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-pink-100:hover {\n    --border-opacity: 1;\n    border-color: #fff5f7;\n    border-color: rgba(255, 245, 247, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-pink-200:hover {\n    --border-opacity: 1;\n    border-color: #fed7e2;\n    border-color: rgba(254, 215, 226, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-pink-300:hover {\n    --border-opacity: 1;\n    border-color: #fbb6ce;\n    border-color: rgba(251, 182, 206, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-pink-400:hover {\n    --border-opacity: 1;\n    border-color: #f687b3;\n    border-color: rgba(246, 135, 179, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-pink-500:hover {\n    --border-opacity: 1;\n    border-color: #ed64a6;\n    border-color: rgba(237, 100, 166, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-pink-600:hover {\n    --border-opacity: 1;\n    border-color: #d53f8c;\n    border-color: rgba(213, 63, 140, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-pink-700:hover {\n    --border-opacity: 1;\n    border-color: #b83280;\n    border-color: rgba(184, 50, 128, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-pink-800:hover {\n    --border-opacity: 1;\n    border-color: #97266d;\n    border-color: rgba(151, 38, 109, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-pink-900:hover {\n    --border-opacity: 1;\n    border-color: #702459;\n    border-color: rgba(112, 36, 89, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-grayscale-80:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 8%);\n    border-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-grayscale-100:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 10%);\n    border-color: rgba(25.5, 25.5, 25.5, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-grayscale-200:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 20%);\n    border-color: rgba(51, 51, 51, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-grayscale-300:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 30%);\n    border-color: rgba(76.5, 76.5, 76.5, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-grayscale-400:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 40%);\n    border-color: rgba(102, 102, 102, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-grayscale-500:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 50%);\n    border-color: rgba(127.5, 127.5, 127.5, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-grayscale-600:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 60%);\n    border-color: rgba(153, 153, 153, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-grayscale-700:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 70%);\n    border-color: rgba(178.5, 178.5, 178.5, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-grayscale-800:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 80%);\n    border-color: rgba(204, 204, 204, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-grayscale-840:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 84%);\n    border-color: rgba(214.2, 214.2, 214.2, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-grayscale-870:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 87%);\n    border-color: rgba(221.85, 221.85, 221.85, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-grayscale-900:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 90%);\n    border-color: rgba(229.5, 229.5, 229.5, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-grayscale-930:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 93%);\n    border-color: rgba(237.15, 237.15, 237.15, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-primary:hover {\n    --border-opacity: 1;\n    border-color: hsl(210, 100%, 52%);\n    border-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--border-opacity));\n  }\n\n  .sm\\:hover\\:border-background-main:hover {\n    border-color: var(--main-background);\n  }\n\n  .sm\\:hover\\:border-background-secondary:hover {\n    border-color: var(--secondary-background);\n  }\n\n  .sm\\:hover\\:border-foreground:hover {\n    border-color: var(--foreground);\n  }\n\n  .sm\\:hover\\:border-panels-bg:hover {\n    border-color: var(--panels-background);\n  }\n\n  .sm\\:focus\\:border-transparent:focus {\n    border-color: transparent;\n  }\n\n  .sm\\:focus\\:border-current:focus {\n    border-color: currentColor;\n  }\n\n  .sm\\:focus\\:border-black:focus {\n    --border-opacity: 1;\n    border-color: #000;\n    border-color: rgba(0, 0, 0, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-white:focus {\n    --border-opacity: 1;\n    border-color: #fff;\n    border-color: rgba(255, 255, 255, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-gray-100:focus {\n    --border-opacity: 1;\n    border-color: #f7fafc;\n    border-color: rgba(247, 250, 252, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-gray-200:focus {\n    --border-opacity: 1;\n    border-color: #edf2f7;\n    border-color: rgba(237, 242, 247, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-gray-300:focus {\n    --border-opacity: 1;\n    border-color: #e2e8f0;\n    border-color: rgba(226, 232, 240, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-gray-400:focus {\n    --border-opacity: 1;\n    border-color: #cbd5e0;\n    border-color: rgba(203, 213, 224, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-gray-500:focus {\n    --border-opacity: 1;\n    border-color: #a0aec0;\n    border-color: rgba(160, 174, 192, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-gray-600:focus {\n    --border-opacity: 1;\n    border-color: #718096;\n    border-color: rgba(113, 128, 150, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-gray-700:focus {\n    --border-opacity: 1;\n    border-color: #4a5568;\n    border-color: rgba(74, 85, 104, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-gray-800:focus {\n    --border-opacity: 1;\n    border-color: #2d3748;\n    border-color: rgba(45, 55, 72, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-gray-900:focus {\n    --border-opacity: 1;\n    border-color: #1a202c;\n    border-color: rgba(26, 32, 44, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-red-100:focus {\n    --border-opacity: 1;\n    border-color: #fff5f5;\n    border-color: rgba(255, 245, 245, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-red-200:focus {\n    --border-opacity: 1;\n    border-color: #fed7d7;\n    border-color: rgba(254, 215, 215, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-red-300:focus {\n    --border-opacity: 1;\n    border-color: #feb2b2;\n    border-color: rgba(254, 178, 178, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-red-400:focus {\n    --border-opacity: 1;\n    border-color: #fc8181;\n    border-color: rgba(252, 129, 129, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-red-500:focus {\n    --border-opacity: 1;\n    border-color: #f56565;\n    border-color: rgba(245, 101, 101, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-red-600:focus {\n    --border-opacity: 1;\n    border-color: #e53e3e;\n    border-color: rgba(229, 62, 62, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-red-700:focus {\n    --border-opacity: 1;\n    border-color: #c53030;\n    border-color: rgba(197, 48, 48, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-red-800:focus {\n    --border-opacity: 1;\n    border-color: #9b2c2c;\n    border-color: rgba(155, 44, 44, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-red-900:focus {\n    --border-opacity: 1;\n    border-color: #742a2a;\n    border-color: rgba(116, 42, 42, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-orange-100:focus {\n    --border-opacity: 1;\n    border-color: #fffaf0;\n    border-color: rgba(255, 250, 240, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-orange-200:focus {\n    --border-opacity: 1;\n    border-color: #feebc8;\n    border-color: rgba(254, 235, 200, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-orange-300:focus {\n    --border-opacity: 1;\n    border-color: #fbd38d;\n    border-color: rgba(251, 211, 141, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-orange-400:focus {\n    --border-opacity: 1;\n    border-color: #f6ad55;\n    border-color: rgba(246, 173, 85, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-orange-500:focus {\n    --border-opacity: 1;\n    border-color: #ed8936;\n    border-color: rgba(237, 137, 54, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-orange-600:focus {\n    --border-opacity: 1;\n    border-color: #dd6b20;\n    border-color: rgba(221, 107, 32, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-orange-700:focus {\n    --border-opacity: 1;\n    border-color: #c05621;\n    border-color: rgba(192, 86, 33, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-orange-800:focus {\n    --border-opacity: 1;\n    border-color: #9c4221;\n    border-color: rgba(156, 66, 33, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-orange-900:focus {\n    --border-opacity: 1;\n    border-color: #7b341e;\n    border-color: rgba(123, 52, 30, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-yellow-100:focus {\n    --border-opacity: 1;\n    border-color: #fffff0;\n    border-color: rgba(255, 255, 240, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-yellow-200:focus {\n    --border-opacity: 1;\n    border-color: #fefcbf;\n    border-color: rgba(254, 252, 191, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-yellow-300:focus {\n    --border-opacity: 1;\n    border-color: #faf089;\n    border-color: rgba(250, 240, 137, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-yellow-400:focus {\n    --border-opacity: 1;\n    border-color: #f6e05e;\n    border-color: rgba(246, 224, 94, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-yellow-500:focus {\n    --border-opacity: 1;\n    border-color: #ecc94b;\n    border-color: rgba(236, 201, 75, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-yellow-600:focus {\n    --border-opacity: 1;\n    border-color: #d69e2e;\n    border-color: rgba(214, 158, 46, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-yellow-700:focus {\n    --border-opacity: 1;\n    border-color: #b7791f;\n    border-color: rgba(183, 121, 31, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-yellow-800:focus {\n    --border-opacity: 1;\n    border-color: #975a16;\n    border-color: rgba(151, 90, 22, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-yellow-900:focus {\n    --border-opacity: 1;\n    border-color: #744210;\n    border-color: rgba(116, 66, 16, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-green-100:focus {\n    --border-opacity: 1;\n    border-color: #f0fff4;\n    border-color: rgba(240, 255, 244, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-green-200:focus {\n    --border-opacity: 1;\n    border-color: #c6f6d5;\n    border-color: rgba(198, 246, 213, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-green-300:focus {\n    --border-opacity: 1;\n    border-color: #9ae6b4;\n    border-color: rgba(154, 230, 180, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-green-400:focus {\n    --border-opacity: 1;\n    border-color: #68d391;\n    border-color: rgba(104, 211, 145, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-green-500:focus {\n    --border-opacity: 1;\n    border-color: #48bb78;\n    border-color: rgba(72, 187, 120, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-green-600:focus {\n    --border-opacity: 1;\n    border-color: #38a169;\n    border-color: rgba(56, 161, 105, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-green-700:focus {\n    --border-opacity: 1;\n    border-color: #2f855a;\n    border-color: rgba(47, 133, 90, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-green-800:focus {\n    --border-opacity: 1;\n    border-color: #276749;\n    border-color: rgba(39, 103, 73, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-green-900:focus {\n    --border-opacity: 1;\n    border-color: #22543d;\n    border-color: rgba(34, 84, 61, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-teal-100:focus {\n    --border-opacity: 1;\n    border-color: #e6fffa;\n    border-color: rgba(230, 255, 250, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-teal-200:focus {\n    --border-opacity: 1;\n    border-color: #b2f5ea;\n    border-color: rgba(178, 245, 234, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-teal-300:focus {\n    --border-opacity: 1;\n    border-color: #81e6d9;\n    border-color: rgba(129, 230, 217, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-teal-400:focus {\n    --border-opacity: 1;\n    border-color: #4fd1c5;\n    border-color: rgba(79, 209, 197, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-teal-500:focus {\n    --border-opacity: 1;\n    border-color: #38b2ac;\n    border-color: rgba(56, 178, 172, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-teal-600:focus {\n    --border-opacity: 1;\n    border-color: #319795;\n    border-color: rgba(49, 151, 149, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-teal-700:focus {\n    --border-opacity: 1;\n    border-color: #2c7a7b;\n    border-color: rgba(44, 122, 123, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-teal-800:focus {\n    --border-opacity: 1;\n    border-color: #285e61;\n    border-color: rgba(40, 94, 97, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-teal-900:focus {\n    --border-opacity: 1;\n    border-color: #234e52;\n    border-color: rgba(35, 78, 82, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-blue-100:focus {\n    --border-opacity: 1;\n    border-color: #ebf8ff;\n    border-color: rgba(235, 248, 255, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-blue-200:focus {\n    --border-opacity: 1;\n    border-color: #bee3f8;\n    border-color: rgba(190, 227, 248, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-blue-300:focus {\n    --border-opacity: 1;\n    border-color: #90cdf4;\n    border-color: rgba(144, 205, 244, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-blue-400:focus {\n    --border-opacity: 1;\n    border-color: #63b3ed;\n    border-color: rgba(99, 179, 237, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-blue-500:focus {\n    --border-opacity: 1;\n    border-color: #4299e1;\n    border-color: rgba(66, 153, 225, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-blue-600:focus {\n    --border-opacity: 1;\n    border-color: #3182ce;\n    border-color: rgba(49, 130, 206, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-blue-700:focus {\n    --border-opacity: 1;\n    border-color: #2b6cb0;\n    border-color: rgba(43, 108, 176, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-blue-800:focus {\n    --border-opacity: 1;\n    border-color: #2c5282;\n    border-color: rgba(44, 82, 130, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-blue-900:focus {\n    --border-opacity: 1;\n    border-color: #2a4365;\n    border-color: rgba(42, 67, 101, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-indigo-100:focus {\n    --border-opacity: 1;\n    border-color: #ebf4ff;\n    border-color: rgba(235, 244, 255, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-indigo-200:focus {\n    --border-opacity: 1;\n    border-color: #c3dafe;\n    border-color: rgba(195, 218, 254, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-indigo-300:focus {\n    --border-opacity: 1;\n    border-color: #a3bffa;\n    border-color: rgba(163, 191, 250, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-indigo-400:focus {\n    --border-opacity: 1;\n    border-color: #7f9cf5;\n    border-color: rgba(127, 156, 245, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-indigo-500:focus {\n    --border-opacity: 1;\n    border-color: #667eea;\n    border-color: rgba(102, 126, 234, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-indigo-600:focus {\n    --border-opacity: 1;\n    border-color: #5a67d8;\n    border-color: rgba(90, 103, 216, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-indigo-700:focus {\n    --border-opacity: 1;\n    border-color: #4c51bf;\n    border-color: rgba(76, 81, 191, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-indigo-800:focus {\n    --border-opacity: 1;\n    border-color: #434190;\n    border-color: rgba(67, 65, 144, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-indigo-900:focus {\n    --border-opacity: 1;\n    border-color: #3c366b;\n    border-color: rgba(60, 54, 107, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-purple-100:focus {\n    --border-opacity: 1;\n    border-color: #faf5ff;\n    border-color: rgba(250, 245, 255, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-purple-200:focus {\n    --border-opacity: 1;\n    border-color: #e9d8fd;\n    border-color: rgba(233, 216, 253, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-purple-300:focus {\n    --border-opacity: 1;\n    border-color: #d6bcfa;\n    border-color: rgba(214, 188, 250, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-purple-400:focus {\n    --border-opacity: 1;\n    border-color: #b794f4;\n    border-color: rgba(183, 148, 244, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-purple-500:focus {\n    --border-opacity: 1;\n    border-color: #9f7aea;\n    border-color: rgba(159, 122, 234, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-purple-600:focus {\n    --border-opacity: 1;\n    border-color: #805ad5;\n    border-color: rgba(128, 90, 213, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-purple-700:focus {\n    --border-opacity: 1;\n    border-color: #6b46c1;\n    border-color: rgba(107, 70, 193, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-purple-800:focus {\n    --border-opacity: 1;\n    border-color: #553c9a;\n    border-color: rgba(85, 60, 154, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-purple-900:focus {\n    --border-opacity: 1;\n    border-color: #44337a;\n    border-color: rgba(68, 51, 122, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-pink-100:focus {\n    --border-opacity: 1;\n    border-color: #fff5f7;\n    border-color: rgba(255, 245, 247, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-pink-200:focus {\n    --border-opacity: 1;\n    border-color: #fed7e2;\n    border-color: rgba(254, 215, 226, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-pink-300:focus {\n    --border-opacity: 1;\n    border-color: #fbb6ce;\n    border-color: rgba(251, 182, 206, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-pink-400:focus {\n    --border-opacity: 1;\n    border-color: #f687b3;\n    border-color: rgba(246, 135, 179, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-pink-500:focus {\n    --border-opacity: 1;\n    border-color: #ed64a6;\n    border-color: rgba(237, 100, 166, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-pink-600:focus {\n    --border-opacity: 1;\n    border-color: #d53f8c;\n    border-color: rgba(213, 63, 140, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-pink-700:focus {\n    --border-opacity: 1;\n    border-color: #b83280;\n    border-color: rgba(184, 50, 128, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-pink-800:focus {\n    --border-opacity: 1;\n    border-color: #97266d;\n    border-color: rgba(151, 38, 109, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-pink-900:focus {\n    --border-opacity: 1;\n    border-color: #702459;\n    border-color: rgba(112, 36, 89, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-grayscale-80:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 8%);\n    border-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-grayscale-100:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 10%);\n    border-color: rgba(25.5, 25.5, 25.5, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-grayscale-200:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 20%);\n    border-color: rgba(51, 51, 51, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-grayscale-300:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 30%);\n    border-color: rgba(76.5, 76.5, 76.5, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-grayscale-400:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 40%);\n    border-color: rgba(102, 102, 102, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-grayscale-500:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 50%);\n    border-color: rgba(127.5, 127.5, 127.5, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-grayscale-600:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 60%);\n    border-color: rgba(153, 153, 153, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-grayscale-700:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 70%);\n    border-color: rgba(178.5, 178.5, 178.5, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-grayscale-800:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 80%);\n    border-color: rgba(204, 204, 204, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-grayscale-840:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 84%);\n    border-color: rgba(214.2, 214.2, 214.2, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-grayscale-870:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 87%);\n    border-color: rgba(221.85, 221.85, 221.85, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-grayscale-900:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 90%);\n    border-color: rgba(229.5, 229.5, 229.5, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-grayscale-930:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 93%);\n    border-color: rgba(237.15, 237.15, 237.15, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-primary:focus {\n    --border-opacity: 1;\n    border-color: hsl(210, 100%, 52%);\n    border-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--border-opacity));\n  }\n\n  .sm\\:focus\\:border-background-main:focus {\n    border-color: var(--main-background);\n  }\n\n  .sm\\:focus\\:border-background-secondary:focus {\n    border-color: var(--secondary-background);\n  }\n\n  .sm\\:focus\\:border-foreground:focus {\n    border-color: var(--foreground);\n  }\n\n  .sm\\:focus\\:border-panels-bg:focus {\n    border-color: var(--panels-background);\n  }\n\n  .sm\\:border-opacity-0 {\n    --border-opacity: 0;\n  }\n\n  .sm\\:border-opacity-25 {\n    --border-opacity: 0.25;\n  }\n\n  .sm\\:border-opacity-50 {\n    --border-opacity: 0.5;\n  }\n\n  .sm\\:border-opacity-75 {\n    --border-opacity: 0.75;\n  }\n\n  .sm\\:border-opacity-100 {\n    --border-opacity: 1;\n  }\n\n  .sm\\:hover\\:border-opacity-0:hover {\n    --border-opacity: 0;\n  }\n\n  .sm\\:hover\\:border-opacity-25:hover {\n    --border-opacity: 0.25;\n  }\n\n  .sm\\:hover\\:border-opacity-50:hover {\n    --border-opacity: 0.5;\n  }\n\n  .sm\\:hover\\:border-opacity-75:hover {\n    --border-opacity: 0.75;\n  }\n\n  .sm\\:hover\\:border-opacity-100:hover {\n    --border-opacity: 1;\n  }\n\n  .sm\\:focus\\:border-opacity-0:focus {\n    --border-opacity: 0;\n  }\n\n  .sm\\:focus\\:border-opacity-25:focus {\n    --border-opacity: 0.25;\n  }\n\n  .sm\\:focus\\:border-opacity-50:focus {\n    --border-opacity: 0.5;\n  }\n\n  .sm\\:focus\\:border-opacity-75:focus {\n    --border-opacity: 0.75;\n  }\n\n  .sm\\:focus\\:border-opacity-100:focus {\n    --border-opacity: 1;\n  }\n\n  .sm\\:rounded-none {\n    border-radius: 0;\n  }\n\n  .sm\\:rounded-sm {\n    border-radius: 0.125rem;\n  }\n\n  .sm\\:rounded {\n    border-radius: 0.25rem;\n  }\n\n  .sm\\:rounded-md {\n    border-radius: 0.375rem;\n  }\n\n  .sm\\:rounded-lg {\n    border-radius: 0.5rem;\n  }\n\n  .sm\\:rounded-xl {\n    border-radius: 0.75rem;\n  }\n\n  .sm\\:rounded-2xl {\n    border-radius: 1rem;\n  }\n\n  .sm\\:rounded-3xl {\n    border-radius: 1.5rem;\n  }\n\n  .sm\\:rounded-full {\n    border-radius: 9999px;\n  }\n\n  .sm\\:rounded-t-none {\n    border-top-left-radius: 0;\n    border-top-right-radius: 0;\n  }\n\n  .sm\\:rounded-r-none {\n    border-top-right-radius: 0;\n    border-bottom-right-radius: 0;\n  }\n\n  .sm\\:rounded-b-none {\n    border-bottom-right-radius: 0;\n    border-bottom-left-radius: 0;\n  }\n\n  .sm\\:rounded-l-none {\n    border-top-left-radius: 0;\n    border-bottom-left-radius: 0;\n  }\n\n  .sm\\:rounded-t-sm {\n    border-top-left-radius: 0.125rem;\n    border-top-right-radius: 0.125rem;\n  }\n\n  .sm\\:rounded-r-sm {\n    border-top-right-radius: 0.125rem;\n    border-bottom-right-radius: 0.125rem;\n  }\n\n  .sm\\:rounded-b-sm {\n    border-bottom-right-radius: 0.125rem;\n    border-bottom-left-radius: 0.125rem;\n  }\n\n  .sm\\:rounded-l-sm {\n    border-top-left-radius: 0.125rem;\n    border-bottom-left-radius: 0.125rem;\n  }\n\n  .sm\\:rounded-t {\n    border-top-left-radius: 0.25rem;\n    border-top-right-radius: 0.25rem;\n  }\n\n  .sm\\:rounded-r {\n    border-top-right-radius: 0.25rem;\n    border-bottom-right-radius: 0.25rem;\n  }\n\n  .sm\\:rounded-b {\n    border-bottom-right-radius: 0.25rem;\n    border-bottom-left-radius: 0.25rem;\n  }\n\n  .sm\\:rounded-l {\n    border-top-left-radius: 0.25rem;\n    border-bottom-left-radius: 0.25rem;\n  }\n\n  .sm\\:rounded-t-md {\n    border-top-left-radius: 0.375rem;\n    border-top-right-radius: 0.375rem;\n  }\n\n  .sm\\:rounded-r-md {\n    border-top-right-radius: 0.375rem;\n    border-bottom-right-radius: 0.375rem;\n  }\n\n  .sm\\:rounded-b-md {\n    border-bottom-right-radius: 0.375rem;\n    border-bottom-left-radius: 0.375rem;\n  }\n\n  .sm\\:rounded-l-md {\n    border-top-left-radius: 0.375rem;\n    border-bottom-left-radius: 0.375rem;\n  }\n\n  .sm\\:rounded-t-lg {\n    border-top-left-radius: 0.5rem;\n    border-top-right-radius: 0.5rem;\n  }\n\n  .sm\\:rounded-r-lg {\n    border-top-right-radius: 0.5rem;\n    border-bottom-right-radius: 0.5rem;\n  }\n\n  .sm\\:rounded-b-lg {\n    border-bottom-right-radius: 0.5rem;\n    border-bottom-left-radius: 0.5rem;\n  }\n\n  .sm\\:rounded-l-lg {\n    border-top-left-radius: 0.5rem;\n    border-bottom-left-radius: 0.5rem;\n  }\n\n  .sm\\:rounded-t-xl {\n    border-top-left-radius: 0.75rem;\n    border-top-right-radius: 0.75rem;\n  }\n\n  .sm\\:rounded-r-xl {\n    border-top-right-radius: 0.75rem;\n    border-bottom-right-radius: 0.75rem;\n  }\n\n  .sm\\:rounded-b-xl {\n    border-bottom-right-radius: 0.75rem;\n    border-bottom-left-radius: 0.75rem;\n  }\n\n  .sm\\:rounded-l-xl {\n    border-top-left-radius: 0.75rem;\n    border-bottom-left-radius: 0.75rem;\n  }\n\n  .sm\\:rounded-t-2xl {\n    border-top-left-radius: 1rem;\n    border-top-right-radius: 1rem;\n  }\n\n  .sm\\:rounded-r-2xl {\n    border-top-right-radius: 1rem;\n    border-bottom-right-radius: 1rem;\n  }\n\n  .sm\\:rounded-b-2xl {\n    border-bottom-right-radius: 1rem;\n    border-bottom-left-radius: 1rem;\n  }\n\n  .sm\\:rounded-l-2xl {\n    border-top-left-radius: 1rem;\n    border-bottom-left-radius: 1rem;\n  }\n\n  .sm\\:rounded-t-3xl {\n    border-top-left-radius: 1.5rem;\n    border-top-right-radius: 1.5rem;\n  }\n\n  .sm\\:rounded-r-3xl {\n    border-top-right-radius: 1.5rem;\n    border-bottom-right-radius: 1.5rem;\n  }\n\n  .sm\\:rounded-b-3xl {\n    border-bottom-right-radius: 1.5rem;\n    border-bottom-left-radius: 1.5rem;\n  }\n\n  .sm\\:rounded-l-3xl {\n    border-top-left-radius: 1.5rem;\n    border-bottom-left-radius: 1.5rem;\n  }\n\n  .sm\\:rounded-t-full {\n    border-top-left-radius: 9999px;\n    border-top-right-radius: 9999px;\n  }\n\n  .sm\\:rounded-r-full {\n    border-top-right-radius: 9999px;\n    border-bottom-right-radius: 9999px;\n  }\n\n  .sm\\:rounded-b-full {\n    border-bottom-right-radius: 9999px;\n    border-bottom-left-radius: 9999px;\n  }\n\n  .sm\\:rounded-l-full {\n    border-top-left-radius: 9999px;\n    border-bottom-left-radius: 9999px;\n  }\n\n  .sm\\:rounded-tl-none {\n    border-top-left-radius: 0;\n  }\n\n  .sm\\:rounded-tr-none {\n    border-top-right-radius: 0;\n  }\n\n  .sm\\:rounded-br-none {\n    border-bottom-right-radius: 0;\n  }\n\n  .sm\\:rounded-bl-none {\n    border-bottom-left-radius: 0;\n  }\n\n  .sm\\:rounded-tl-sm {\n    border-top-left-radius: 0.125rem;\n  }\n\n  .sm\\:rounded-tr-sm {\n    border-top-right-radius: 0.125rem;\n  }\n\n  .sm\\:rounded-br-sm {\n    border-bottom-right-radius: 0.125rem;\n  }\n\n  .sm\\:rounded-bl-sm {\n    border-bottom-left-radius: 0.125rem;\n  }\n\n  .sm\\:rounded-tl {\n    border-top-left-radius: 0.25rem;\n  }\n\n  .sm\\:rounded-tr {\n    border-top-right-radius: 0.25rem;\n  }\n\n  .sm\\:rounded-br {\n    border-bottom-right-radius: 0.25rem;\n  }\n\n  .sm\\:rounded-bl {\n    border-bottom-left-radius: 0.25rem;\n  }\n\n  .sm\\:rounded-tl-md {\n    border-top-left-radius: 0.375rem;\n  }\n\n  .sm\\:rounded-tr-md {\n    border-top-right-radius: 0.375rem;\n  }\n\n  .sm\\:rounded-br-md {\n    border-bottom-right-radius: 0.375rem;\n  }\n\n  .sm\\:rounded-bl-md {\n    border-bottom-left-radius: 0.375rem;\n  }\n\n  .sm\\:rounded-tl-lg {\n    border-top-left-radius: 0.5rem;\n  }\n\n  .sm\\:rounded-tr-lg {\n    border-top-right-radius: 0.5rem;\n  }\n\n  .sm\\:rounded-br-lg {\n    border-bottom-right-radius: 0.5rem;\n  }\n\n  .sm\\:rounded-bl-lg {\n    border-bottom-left-radius: 0.5rem;\n  }\n\n  .sm\\:rounded-tl-xl {\n    border-top-left-radius: 0.75rem;\n  }\n\n  .sm\\:rounded-tr-xl {\n    border-top-right-radius: 0.75rem;\n  }\n\n  .sm\\:rounded-br-xl {\n    border-bottom-right-radius: 0.75rem;\n  }\n\n  .sm\\:rounded-bl-xl {\n    border-bottom-left-radius: 0.75rem;\n  }\n\n  .sm\\:rounded-tl-2xl {\n    border-top-left-radius: 1rem;\n  }\n\n  .sm\\:rounded-tr-2xl {\n    border-top-right-radius: 1rem;\n  }\n\n  .sm\\:rounded-br-2xl {\n    border-bottom-right-radius: 1rem;\n  }\n\n  .sm\\:rounded-bl-2xl {\n    border-bottom-left-radius: 1rem;\n  }\n\n  .sm\\:rounded-tl-3xl {\n    border-top-left-radius: 1.5rem;\n  }\n\n  .sm\\:rounded-tr-3xl {\n    border-top-right-radius: 1.5rem;\n  }\n\n  .sm\\:rounded-br-3xl {\n    border-bottom-right-radius: 1.5rem;\n  }\n\n  .sm\\:rounded-bl-3xl {\n    border-bottom-left-radius: 1.5rem;\n  }\n\n  .sm\\:rounded-tl-full {\n    border-top-left-radius: 9999px;\n  }\n\n  .sm\\:rounded-tr-full {\n    border-top-right-radius: 9999px;\n  }\n\n  .sm\\:rounded-br-full {\n    border-bottom-right-radius: 9999px;\n  }\n\n  .sm\\:rounded-bl-full {\n    border-bottom-left-radius: 9999px;\n  }\n\n  .sm\\:border-solid {\n    border-style: solid;\n  }\n\n  .sm\\:border-dashed {\n    border-style: dashed;\n  }\n\n  .sm\\:border-dotted {\n    border-style: dotted;\n  }\n\n  .sm\\:border-double {\n    border-style: double;\n  }\n\n  .sm\\:border-none {\n    border-style: none;\n  }\n\n  .sm\\:border-0 {\n    border-width: 0;\n  }\n\n  .sm\\:border-2 {\n    border-width: 2px;\n  }\n\n  .sm\\:border-4 {\n    border-width: 4px;\n  }\n\n  .sm\\:border-8 {\n    border-width: 8px;\n  }\n\n  .sm\\:border {\n    border-width: 1px;\n  }\n\n  .sm\\:border-t-0 {\n    border-top-width: 0;\n  }\n\n  .sm\\:border-r-0 {\n    border-right-width: 0;\n  }\n\n  .sm\\:border-b-0 {\n    border-bottom-width: 0;\n  }\n\n  .sm\\:border-l-0 {\n    border-left-width: 0;\n  }\n\n  .sm\\:border-t-2 {\n    border-top-width: 2px;\n  }\n\n  .sm\\:border-r-2 {\n    border-right-width: 2px;\n  }\n\n  .sm\\:border-b-2 {\n    border-bottom-width: 2px;\n  }\n\n  .sm\\:border-l-2 {\n    border-left-width: 2px;\n  }\n\n  .sm\\:border-t-4 {\n    border-top-width: 4px;\n  }\n\n  .sm\\:border-r-4 {\n    border-right-width: 4px;\n  }\n\n  .sm\\:border-b-4 {\n    border-bottom-width: 4px;\n  }\n\n  .sm\\:border-l-4 {\n    border-left-width: 4px;\n  }\n\n  .sm\\:border-t-8 {\n    border-top-width: 8px;\n  }\n\n  .sm\\:border-r-8 {\n    border-right-width: 8px;\n  }\n\n  .sm\\:border-b-8 {\n    border-bottom-width: 8px;\n  }\n\n  .sm\\:border-l-8 {\n    border-left-width: 8px;\n  }\n\n  .sm\\:border-t {\n    border-top-width: 1px;\n  }\n\n  .sm\\:border-r {\n    border-right-width: 1px;\n  }\n\n  .sm\\:border-b {\n    border-bottom-width: 1px;\n  }\n\n  .sm\\:border-l {\n    border-left-width: 1px;\n  }\n\n  .sm\\:box-border {\n    box-sizing: border-box;\n  }\n\n  .sm\\:box-content {\n    box-sizing: content-box;\n  }\n\n  .sm\\:cursor-auto {\n    cursor: auto;\n  }\n\n  .sm\\:cursor-default {\n    cursor: default;\n  }\n\n  .sm\\:cursor-pointer {\n    cursor: pointer;\n  }\n\n  .sm\\:cursor-wait {\n    cursor: wait;\n  }\n\n  .sm\\:cursor-text {\n    cursor: text;\n  }\n\n  .sm\\:cursor-move {\n    cursor: move;\n  }\n\n  .sm\\:cursor-not-allowed {\n    cursor: not-allowed;\n  }\n\n  .sm\\:block {\n    display: block;\n  }\n\n  .sm\\:inline-block {\n    display: inline-block;\n  }\n\n  .sm\\:inline {\n    display: inline;\n  }\n\n  .sm\\:flex {\n    display: flex;\n  }\n\n  .sm\\:inline-flex {\n    display: inline-flex;\n  }\n\n  .sm\\:table {\n    display: table;\n  }\n\n  .sm\\:table-caption {\n    display: table-caption;\n  }\n\n  .sm\\:table-cell {\n    display: table-cell;\n  }\n\n  .sm\\:table-column {\n    display: table-column;\n  }\n\n  .sm\\:table-column-group {\n    display: table-column-group;\n  }\n\n  .sm\\:table-footer-group {\n    display: table-footer-group;\n  }\n\n  .sm\\:table-header-group {\n    display: table-header-group;\n  }\n\n  .sm\\:table-row-group {\n    display: table-row-group;\n  }\n\n  .sm\\:table-row {\n    display: table-row;\n  }\n\n  .sm\\:flow-root {\n    display: flow-root;\n  }\n\n  .sm\\:grid {\n    display: grid;\n  }\n\n  .sm\\:inline-grid {\n    display: inline-grid;\n  }\n\n  .sm\\:contents {\n    display: contents;\n  }\n\n  .sm\\:hidden {\n    display: none;\n  }\n\n  .sm\\:flex-row {\n    flex-direction: row;\n  }\n\n  .sm\\:flex-row-reverse {\n    flex-direction: row-reverse;\n  }\n\n  .sm\\:flex-col {\n    flex-direction: column;\n  }\n\n  .sm\\:flex-col-reverse {\n    flex-direction: column-reverse;\n  }\n\n  .sm\\:flex-wrap {\n    flex-wrap: wrap;\n  }\n\n  .sm\\:flex-wrap-reverse {\n    flex-wrap: wrap-reverse;\n  }\n\n  .sm\\:flex-no-wrap {\n    flex-wrap: nowrap;\n  }\n\n  .sm\\:place-items-auto {\n    place-items: auto;\n  }\n\n  .sm\\:place-items-start {\n    place-items: start;\n  }\n\n  .sm\\:place-items-end {\n    place-items: end;\n  }\n\n  .sm\\:place-items-center {\n    place-items: center;\n  }\n\n  .sm\\:place-items-stretch {\n    place-items: stretch;\n  }\n\n  .sm\\:place-content-center {\n    place-content: center;\n  }\n\n  .sm\\:place-content-start {\n    place-content: start;\n  }\n\n  .sm\\:place-content-end {\n    place-content: end;\n  }\n\n  .sm\\:place-content-between {\n    place-content: space-between;\n  }\n\n  .sm\\:place-content-around {\n    place-content: space-around;\n  }\n\n  .sm\\:place-content-evenly {\n    place-content: space-evenly;\n  }\n\n  .sm\\:place-content-stretch {\n    place-content: stretch;\n  }\n\n  .sm\\:place-self-auto {\n    place-self: auto;\n  }\n\n  .sm\\:place-self-start {\n    place-self: start;\n  }\n\n  .sm\\:place-self-end {\n    place-self: end;\n  }\n\n  .sm\\:place-self-center {\n    place-self: center;\n  }\n\n  .sm\\:place-self-stretch {\n    place-self: stretch;\n  }\n\n  .sm\\:items-start {\n    align-items: flex-start;\n  }\n\n  .sm\\:items-end {\n    align-items: flex-end;\n  }\n\n  .sm\\:items-center {\n    align-items: center;\n  }\n\n  .sm\\:items-baseline {\n    align-items: baseline;\n  }\n\n  .sm\\:items-stretch {\n    align-items: stretch;\n  }\n\n  .sm\\:content-center {\n    align-content: center;\n  }\n\n  .sm\\:content-start {\n    align-content: flex-start;\n  }\n\n  .sm\\:content-end {\n    align-content: flex-end;\n  }\n\n  .sm\\:content-between {\n    align-content: space-between;\n  }\n\n  .sm\\:content-around {\n    align-content: space-around;\n  }\n\n  .sm\\:content-evenly {\n    align-content: space-evenly;\n  }\n\n  .sm\\:self-auto {\n    align-self: auto;\n  }\n\n  .sm\\:self-start {\n    align-self: flex-start;\n  }\n\n  .sm\\:self-end {\n    align-self: flex-end;\n  }\n\n  .sm\\:self-center {\n    align-self: center;\n  }\n\n  .sm\\:self-stretch {\n    align-self: stretch;\n  }\n\n  .sm\\:justify-items-auto {\n    justify-items: auto;\n  }\n\n  .sm\\:justify-items-start {\n    justify-items: start;\n  }\n\n  .sm\\:justify-items-end {\n    justify-items: end;\n  }\n\n  .sm\\:justify-items-center {\n    justify-items: center;\n  }\n\n  .sm\\:justify-items-stretch {\n    justify-items: stretch;\n  }\n\n  .sm\\:justify-start {\n    justify-content: flex-start;\n  }\n\n  .sm\\:justify-end {\n    justify-content: flex-end;\n  }\n\n  .sm\\:justify-center {\n    justify-content: center;\n  }\n\n  .sm\\:justify-between {\n    justify-content: space-between;\n  }\n\n  .sm\\:justify-around {\n    justify-content: space-around;\n  }\n\n  .sm\\:justify-evenly {\n    justify-content: space-evenly;\n  }\n\n  .sm\\:justify-self-auto {\n    justify-self: auto;\n  }\n\n  .sm\\:justify-self-start {\n    justify-self: start;\n  }\n\n  .sm\\:justify-self-end {\n    justify-self: end;\n  }\n\n  .sm\\:justify-self-center {\n    justify-self: center;\n  }\n\n  .sm\\:justify-self-stretch {\n    justify-self: stretch;\n  }\n\n  .sm\\:flex-1 {\n    flex: 1 1 0%;\n  }\n\n  .sm\\:flex-auto {\n    flex: 1 1 auto;\n  }\n\n  .sm\\:flex-initial {\n    flex: 0 1 auto;\n  }\n\n  .sm\\:flex-none {\n    flex: none;\n  }\n\n  .sm\\:flex-grow-0 {\n    flex-grow: 0;\n  }\n\n  .sm\\:flex-grow {\n    flex-grow: 1;\n  }\n\n  .sm\\:flex-shrink-0 {\n    flex-shrink: 0;\n  }\n\n  .sm\\:flex-shrink {\n    flex-shrink: 1;\n  }\n\n  .sm\\:order-1 {\n    order: 1;\n  }\n\n  .sm\\:order-2 {\n    order: 2;\n  }\n\n  .sm\\:order-3 {\n    order: 3;\n  }\n\n  .sm\\:order-4 {\n    order: 4;\n  }\n\n  .sm\\:order-5 {\n    order: 5;\n  }\n\n  .sm\\:order-6 {\n    order: 6;\n  }\n\n  .sm\\:order-7 {\n    order: 7;\n  }\n\n  .sm\\:order-8 {\n    order: 8;\n  }\n\n  .sm\\:order-9 {\n    order: 9;\n  }\n\n  .sm\\:order-10 {\n    order: 10;\n  }\n\n  .sm\\:order-11 {\n    order: 11;\n  }\n\n  .sm\\:order-12 {\n    order: 12;\n  }\n\n  .sm\\:order-first {\n    order: -9999;\n  }\n\n  .sm\\:order-last {\n    order: 9999;\n  }\n\n  .sm\\:order-none {\n    order: 0;\n  }\n\n  .sm\\:float-right {\n    float: right;\n  }\n\n  .sm\\:float-left {\n    float: left;\n  }\n\n  .sm\\:float-none {\n    float: none;\n  }\n\n  .sm\\:clearfix:after {\n    content: \"\";\n    display: table;\n    clear: both;\n  }\n\n  .sm\\:clear-left {\n    clear: left;\n  }\n\n  .sm\\:clear-right {\n    clear: right;\n  }\n\n  .sm\\:clear-both {\n    clear: both;\n  }\n\n  .sm\\:clear-none {\n    clear: none;\n  }\n\n  .sm\\:font-sans {\n    font-family: system-ui, -apple-system, BlinkMacSystemFont, \"Segoe UI\", Roboto, \"Helvetica Neue\", Arial, \"Noto Sans\", sans-serif, \"Apple Color Emoji\", \"Segoe UI Emoji\", \"Segoe UI Symbol\", \"Noto Color Emoji\";\n  }\n\n  .sm\\:font-serif {\n    font-family: Georgia, Cambria, \"Times New Roman\", Times, serif;\n  }\n\n  .sm\\:font-mono {\n    font-family: Menlo, Monaco, Consolas, \"Liberation Mono\", \"Courier New\", monospace;\n  }\n\n  .sm\\:font-hairline {\n    font-weight: 100;\n  }\n\n  .sm\\:font-thin {\n    font-weight: 200;\n  }\n\n  .sm\\:font-light {\n    font-weight: 300;\n  }\n\n  .sm\\:font-normal {\n    font-weight: 400;\n  }\n\n  .sm\\:font-medium {\n    font-weight: 500;\n  }\n\n  .sm\\:font-semibold {\n    font-weight: 600;\n  }\n\n  .sm\\:font-bold {\n    font-weight: 700;\n  }\n\n  .sm\\:font-extrabold {\n    font-weight: 800;\n  }\n\n  .sm\\:font-black {\n    font-weight: 900;\n  }\n\n  .sm\\:hover\\:font-hairline:hover {\n    font-weight: 100;\n  }\n\n  .sm\\:hover\\:font-thin:hover {\n    font-weight: 200;\n  }\n\n  .sm\\:hover\\:font-light:hover {\n    font-weight: 300;\n  }\n\n  .sm\\:hover\\:font-normal:hover {\n    font-weight: 400;\n  }\n\n  .sm\\:hover\\:font-medium:hover {\n    font-weight: 500;\n  }\n\n  .sm\\:hover\\:font-semibold:hover {\n    font-weight: 600;\n  }\n\n  .sm\\:hover\\:font-bold:hover {\n    font-weight: 700;\n  }\n\n  .sm\\:hover\\:font-extrabold:hover {\n    font-weight: 800;\n  }\n\n  .sm\\:hover\\:font-black:hover {\n    font-weight: 900;\n  }\n\n  .sm\\:focus\\:font-hairline:focus {\n    font-weight: 100;\n  }\n\n  .sm\\:focus\\:font-thin:focus {\n    font-weight: 200;\n  }\n\n  .sm\\:focus\\:font-light:focus {\n    font-weight: 300;\n  }\n\n  .sm\\:focus\\:font-normal:focus {\n    font-weight: 400;\n  }\n\n  .sm\\:focus\\:font-medium:focus {\n    font-weight: 500;\n  }\n\n  .sm\\:focus\\:font-semibold:focus {\n    font-weight: 600;\n  }\n\n  .sm\\:focus\\:font-bold:focus {\n    font-weight: 700;\n  }\n\n  .sm\\:focus\\:font-extrabold:focus {\n    font-weight: 800;\n  }\n\n  .sm\\:focus\\:font-black:focus {\n    font-weight: 900;\n  }\n\n  .sm\\:h-0 {\n    height: 0;\n  }\n\n  .sm\\:h-1 {\n    height: 0.25rem;\n  }\n\n  .sm\\:h-2 {\n    height: 0.5rem;\n  }\n\n  .sm\\:h-3 {\n    height: 0.75rem;\n  }\n\n  .sm\\:h-4 {\n    height: 1rem;\n  }\n\n  .sm\\:h-5 {\n    height: 1.25rem;\n  }\n\n  .sm\\:h-6 {\n    height: 1.5rem;\n  }\n\n  .sm\\:h-8 {\n    height: 2rem;\n  }\n\n  .sm\\:h-10 {\n    height: 2.5rem;\n  }\n\n  .sm\\:h-12 {\n    height: 3rem;\n  }\n\n  .sm\\:h-16 {\n    height: 4rem;\n  }\n\n  .sm\\:h-20 {\n    height: 5rem;\n  }\n\n  .sm\\:h-24 {\n    height: 6rem;\n  }\n\n  .sm\\:h-32 {\n    height: 8rem;\n  }\n\n  .sm\\:h-40 {\n    height: 10rem;\n  }\n\n  .sm\\:h-48 {\n    height: 12rem;\n  }\n\n  .sm\\:h-56 {\n    height: 14rem;\n  }\n\n  .sm\\:h-64 {\n    height: 16rem;\n  }\n\n  .sm\\:h-auto {\n    height: auto;\n  }\n\n  .sm\\:h-px {\n    height: 1px;\n  }\n\n  .sm\\:h-full {\n    height: 100%;\n  }\n\n  .sm\\:h-screen {\n    height: 100vh;\n  }\n\n  .sm\\:text-xs {\n    font-size: 0.75rem;\n  }\n\n  .sm\\:text-sm {\n    font-size: 0.875rem;\n  }\n\n  .sm\\:text-base {\n    font-size: 1rem;\n  }\n\n  .sm\\:text-lg {\n    font-size: 1.125rem;\n  }\n\n  .sm\\:text-xl {\n    font-size: 1.25rem;\n  }\n\n  .sm\\:text-2xl {\n    font-size: 1.5rem;\n  }\n\n  .sm\\:text-3xl {\n    font-size: 1.875rem;\n  }\n\n  .sm\\:text-4xl {\n    font-size: 2.25rem;\n  }\n\n  .sm\\:text-5xl {\n    font-size: 3rem;\n  }\n\n  .sm\\:text-6xl {\n    font-size: 4rem;\n  }\n\n  .sm\\:leading-3 {\n    line-height: .75rem;\n  }\n\n  .sm\\:leading-4 {\n    line-height: 1rem;\n  }\n\n  .sm\\:leading-5 {\n    line-height: 1.25rem;\n  }\n\n  .sm\\:leading-6 {\n    line-height: 1.5rem;\n  }\n\n  .sm\\:leading-7 {\n    line-height: 1.75rem;\n  }\n\n  .sm\\:leading-8 {\n    line-height: 2rem;\n  }\n\n  .sm\\:leading-9 {\n    line-height: 2.25rem;\n  }\n\n  .sm\\:leading-10 {\n    line-height: 2.5rem;\n  }\n\n  .sm\\:leading-none {\n    line-height: 1;\n  }\n\n  .sm\\:leading-tight {\n    line-height: 1.25;\n  }\n\n  .sm\\:leading-snug {\n    line-height: 1.375;\n  }\n\n  .sm\\:leading-normal {\n    line-height: 1.5;\n  }\n\n  .sm\\:leading-relaxed {\n    line-height: 1.625;\n  }\n\n  .sm\\:leading-loose {\n    line-height: 2;\n  }\n\n  .sm\\:list-inside {\n    list-style-position: inside;\n  }\n\n  .sm\\:list-outside {\n    list-style-position: outside;\n  }\n\n  .sm\\:list-none {\n    list-style-type: none;\n  }\n\n  .sm\\:list-disc {\n    list-style-type: disc;\n  }\n\n  .sm\\:list-decimal {\n    list-style-type: decimal;\n  }\n\n  .sm\\:m-0 {\n    margin: 0;\n  }\n\n  .sm\\:m-1 {\n    margin: 0.25rem;\n  }\n\n  .sm\\:m-2 {\n    margin: 0.5rem;\n  }\n\n  .sm\\:m-3 {\n    margin: 0.75rem;\n  }\n\n  .sm\\:m-4 {\n    margin: 1rem;\n  }\n\n  .sm\\:m-5 {\n    margin: 1.25rem;\n  }\n\n  .sm\\:m-6 {\n    margin: 1.5rem;\n  }\n\n  .sm\\:m-8 {\n    margin: 2rem;\n  }\n\n  .sm\\:m-10 {\n    margin: 2.5rem;\n  }\n\n  .sm\\:m-12 {\n    margin: 3rem;\n  }\n\n  .sm\\:m-16 {\n    margin: 4rem;\n  }\n\n  .sm\\:m-20 {\n    margin: 5rem;\n  }\n\n  .sm\\:m-24 {\n    margin: 6rem;\n  }\n\n  .sm\\:m-32 {\n    margin: 8rem;\n  }\n\n  .sm\\:m-40 {\n    margin: 10rem;\n  }\n\n  .sm\\:m-48 {\n    margin: 12rem;\n  }\n\n  .sm\\:m-56 {\n    margin: 14rem;\n  }\n\n  .sm\\:m-64 {\n    margin: 16rem;\n  }\n\n  .sm\\:m-auto {\n    margin: auto;\n  }\n\n  .sm\\:m-px {\n    margin: 1px;\n  }\n\n  .sm\\:-m-1 {\n    margin: -0.25rem;\n  }\n\n  .sm\\:-m-2 {\n    margin: -0.5rem;\n  }\n\n  .sm\\:-m-3 {\n    margin: -0.75rem;\n  }\n\n  .sm\\:-m-4 {\n    margin: -1rem;\n  }\n\n  .sm\\:-m-5 {\n    margin: -1.25rem;\n  }\n\n  .sm\\:-m-6 {\n    margin: -1.5rem;\n  }\n\n  .sm\\:-m-8 {\n    margin: -2rem;\n  }\n\n  .sm\\:-m-10 {\n    margin: -2.5rem;\n  }\n\n  .sm\\:-m-12 {\n    margin: -3rem;\n  }\n\n  .sm\\:-m-16 {\n    margin: -4rem;\n  }\n\n  .sm\\:-m-20 {\n    margin: -5rem;\n  }\n\n  .sm\\:-m-24 {\n    margin: -6rem;\n  }\n\n  .sm\\:-m-32 {\n    margin: -8rem;\n  }\n\n  .sm\\:-m-40 {\n    margin: -10rem;\n  }\n\n  .sm\\:-m-48 {\n    margin: -12rem;\n  }\n\n  .sm\\:-m-56 {\n    margin: -14rem;\n  }\n\n  .sm\\:-m-64 {\n    margin: -16rem;\n  }\n\n  .sm\\:-m-px {\n    margin: -1px;\n  }\n\n  .sm\\:my-0 {\n    margin-top: 0;\n    margin-bottom: 0;\n  }\n\n  .sm\\:mx-0 {\n    margin-left: 0;\n    margin-right: 0;\n  }\n\n  .sm\\:my-1 {\n    margin-top: 0.25rem;\n    margin-bottom: 0.25rem;\n  }\n\n  .sm\\:mx-1 {\n    margin-left: 0.25rem;\n    margin-right: 0.25rem;\n  }\n\n  .sm\\:my-2 {\n    margin-top: 0.5rem;\n    margin-bottom: 0.5rem;\n  }\n\n  .sm\\:mx-2 {\n    margin-left: 0.5rem;\n    margin-right: 0.5rem;\n  }\n\n  .sm\\:my-3 {\n    margin-top: 0.75rem;\n    margin-bottom: 0.75rem;\n  }\n\n  .sm\\:mx-3 {\n    margin-left: 0.75rem;\n    margin-right: 0.75rem;\n  }\n\n  .sm\\:my-4 {\n    margin-top: 1rem;\n    margin-bottom: 1rem;\n  }\n\n  .sm\\:mx-4 {\n    margin-left: 1rem;\n    margin-right: 1rem;\n  }\n\n  .sm\\:my-5 {\n    margin-top: 1.25rem;\n    margin-bottom: 1.25rem;\n  }\n\n  .sm\\:mx-5 {\n    margin-left: 1.25rem;\n    margin-right: 1.25rem;\n  }\n\n  .sm\\:my-6 {\n    margin-top: 1.5rem;\n    margin-bottom: 1.5rem;\n  }\n\n  .sm\\:mx-6 {\n    margin-left: 1.5rem;\n    margin-right: 1.5rem;\n  }\n\n  .sm\\:my-8 {\n    margin-top: 2rem;\n    margin-bottom: 2rem;\n  }\n\n  .sm\\:mx-8 {\n    margin-left: 2rem;\n    margin-right: 2rem;\n  }\n\n  .sm\\:my-10 {\n    margin-top: 2.5rem;\n    margin-bottom: 2.5rem;\n  }\n\n  .sm\\:mx-10 {\n    margin-left: 2.5rem;\n    margin-right: 2.5rem;\n  }\n\n  .sm\\:my-12 {\n    margin-top: 3rem;\n    margin-bottom: 3rem;\n  }\n\n  .sm\\:mx-12 {\n    margin-left: 3rem;\n    margin-right: 3rem;\n  }\n\n  .sm\\:my-16 {\n    margin-top: 4rem;\n    margin-bottom: 4rem;\n  }\n\n  .sm\\:mx-16 {\n    margin-left: 4rem;\n    margin-right: 4rem;\n  }\n\n  .sm\\:my-20 {\n    margin-top: 5rem;\n    margin-bottom: 5rem;\n  }\n\n  .sm\\:mx-20 {\n    margin-left: 5rem;\n    margin-right: 5rem;\n  }\n\n  .sm\\:my-24 {\n    margin-top: 6rem;\n    margin-bottom: 6rem;\n  }\n\n  .sm\\:mx-24 {\n    margin-left: 6rem;\n    margin-right: 6rem;\n  }\n\n  .sm\\:my-32 {\n    margin-top: 8rem;\n    margin-bottom: 8rem;\n  }\n\n  .sm\\:mx-32 {\n    margin-left: 8rem;\n    margin-right: 8rem;\n  }\n\n  .sm\\:my-40 {\n    margin-top: 10rem;\n    margin-bottom: 10rem;\n  }\n\n  .sm\\:mx-40 {\n    margin-left: 10rem;\n    margin-right: 10rem;\n  }\n\n  .sm\\:my-48 {\n    margin-top: 12rem;\n    margin-bottom: 12rem;\n  }\n\n  .sm\\:mx-48 {\n    margin-left: 12rem;\n    margin-right: 12rem;\n  }\n\n  .sm\\:my-56 {\n    margin-top: 14rem;\n    margin-bottom: 14rem;\n  }\n\n  .sm\\:mx-56 {\n    margin-left: 14rem;\n    margin-right: 14rem;\n  }\n\n  .sm\\:my-64 {\n    margin-top: 16rem;\n    margin-bottom: 16rem;\n  }\n\n  .sm\\:mx-64 {\n    margin-left: 16rem;\n    margin-right: 16rem;\n  }\n\n  .sm\\:my-auto {\n    margin-top: auto;\n    margin-bottom: auto;\n  }\n\n  .sm\\:mx-auto {\n    margin-left: auto;\n    margin-right: auto;\n  }\n\n  .sm\\:my-px {\n    margin-top: 1px;\n    margin-bottom: 1px;\n  }\n\n  .sm\\:mx-px {\n    margin-left: 1px;\n    margin-right: 1px;\n  }\n\n  .sm\\:-my-1 {\n    margin-top: -0.25rem;\n    margin-bottom: -0.25rem;\n  }\n\n  .sm\\:-mx-1 {\n    margin-left: -0.25rem;\n    margin-right: -0.25rem;\n  }\n\n  .sm\\:-my-2 {\n    margin-top: -0.5rem;\n    margin-bottom: -0.5rem;\n  }\n\n  .sm\\:-mx-2 {\n    margin-left: -0.5rem;\n    margin-right: -0.5rem;\n  }\n\n  .sm\\:-my-3 {\n    margin-top: -0.75rem;\n    margin-bottom: -0.75rem;\n  }\n\n  .sm\\:-mx-3 {\n    margin-left: -0.75rem;\n    margin-right: -0.75rem;\n  }\n\n  .sm\\:-my-4 {\n    margin-top: -1rem;\n    margin-bottom: -1rem;\n  }\n\n  .sm\\:-mx-4 {\n    margin-left: -1rem;\n    margin-right: -1rem;\n  }\n\n  .sm\\:-my-5 {\n    margin-top: -1.25rem;\n    margin-bottom: -1.25rem;\n  }\n\n  .sm\\:-mx-5 {\n    margin-left: -1.25rem;\n    margin-right: -1.25rem;\n  }\n\n  .sm\\:-my-6 {\n    margin-top: -1.5rem;\n    margin-bottom: -1.5rem;\n  }\n\n  .sm\\:-mx-6 {\n    margin-left: -1.5rem;\n    margin-right: -1.5rem;\n  }\n\n  .sm\\:-my-8 {\n    margin-top: -2rem;\n    margin-bottom: -2rem;\n  }\n\n  .sm\\:-mx-8 {\n    margin-left: -2rem;\n    margin-right: -2rem;\n  }\n\n  .sm\\:-my-10 {\n    margin-top: -2.5rem;\n    margin-bottom: -2.5rem;\n  }\n\n  .sm\\:-mx-10 {\n    margin-left: -2.5rem;\n    margin-right: -2.5rem;\n  }\n\n  .sm\\:-my-12 {\n    margin-top: -3rem;\n    margin-bottom: -3rem;\n  }\n\n  .sm\\:-mx-12 {\n    margin-left: -3rem;\n    margin-right: -3rem;\n  }\n\n  .sm\\:-my-16 {\n    margin-top: -4rem;\n    margin-bottom: -4rem;\n  }\n\n  .sm\\:-mx-16 {\n    margin-left: -4rem;\n    margin-right: -4rem;\n  }\n\n  .sm\\:-my-20 {\n    margin-top: -5rem;\n    margin-bottom: -5rem;\n  }\n\n  .sm\\:-mx-20 {\n    margin-left: -5rem;\n    margin-right: -5rem;\n  }\n\n  .sm\\:-my-24 {\n    margin-top: -6rem;\n    margin-bottom: -6rem;\n  }\n\n  .sm\\:-mx-24 {\n    margin-left: -6rem;\n    margin-right: -6rem;\n  }\n\n  .sm\\:-my-32 {\n    margin-top: -8rem;\n    margin-bottom: -8rem;\n  }\n\n  .sm\\:-mx-32 {\n    margin-left: -8rem;\n    margin-right: -8rem;\n  }\n\n  .sm\\:-my-40 {\n    margin-top: -10rem;\n    margin-bottom: -10rem;\n  }\n\n  .sm\\:-mx-40 {\n    margin-left: -10rem;\n    margin-right: -10rem;\n  }\n\n  .sm\\:-my-48 {\n    margin-top: -12rem;\n    margin-bottom: -12rem;\n  }\n\n  .sm\\:-mx-48 {\n    margin-left: -12rem;\n    margin-right: -12rem;\n  }\n\n  .sm\\:-my-56 {\n    margin-top: -14rem;\n    margin-bottom: -14rem;\n  }\n\n  .sm\\:-mx-56 {\n    margin-left: -14rem;\n    margin-right: -14rem;\n  }\n\n  .sm\\:-my-64 {\n    margin-top: -16rem;\n    margin-bottom: -16rem;\n  }\n\n  .sm\\:-mx-64 {\n    margin-left: -16rem;\n    margin-right: -16rem;\n  }\n\n  .sm\\:-my-px {\n    margin-top: -1px;\n    margin-bottom: -1px;\n  }\n\n  .sm\\:-mx-px {\n    margin-left: -1px;\n    margin-right: -1px;\n  }\n\n  .sm\\:mt-0 {\n    margin-top: 0;\n  }\n\n  .sm\\:mr-0 {\n    margin-right: 0;\n  }\n\n  .sm\\:mb-0 {\n    margin-bottom: 0;\n  }\n\n  .sm\\:ml-0 {\n    margin-left: 0;\n  }\n\n  .sm\\:mt-1 {\n    margin-top: 0.25rem;\n  }\n\n  .sm\\:mr-1 {\n    margin-right: 0.25rem;\n  }\n\n  .sm\\:mb-1 {\n    margin-bottom: 0.25rem;\n  }\n\n  .sm\\:ml-1 {\n    margin-left: 0.25rem;\n  }\n\n  .sm\\:mt-2 {\n    margin-top: 0.5rem;\n  }\n\n  .sm\\:mr-2 {\n    margin-right: 0.5rem;\n  }\n\n  .sm\\:mb-2 {\n    margin-bottom: 0.5rem;\n  }\n\n  .sm\\:ml-2 {\n    margin-left: 0.5rem;\n  }\n\n  .sm\\:mt-3 {\n    margin-top: 0.75rem;\n  }\n\n  .sm\\:mr-3 {\n    margin-right: 0.75rem;\n  }\n\n  .sm\\:mb-3 {\n    margin-bottom: 0.75rem;\n  }\n\n  .sm\\:ml-3 {\n    margin-left: 0.75rem;\n  }\n\n  .sm\\:mt-4 {\n    margin-top: 1rem;\n  }\n\n  .sm\\:mr-4 {\n    margin-right: 1rem;\n  }\n\n  .sm\\:mb-4 {\n    margin-bottom: 1rem;\n  }\n\n  .sm\\:ml-4 {\n    margin-left: 1rem;\n  }\n\n  .sm\\:mt-5 {\n    margin-top: 1.25rem;\n  }\n\n  .sm\\:mr-5 {\n    margin-right: 1.25rem;\n  }\n\n  .sm\\:mb-5 {\n    margin-bottom: 1.25rem;\n  }\n\n  .sm\\:ml-5 {\n    margin-left: 1.25rem;\n  }\n\n  .sm\\:mt-6 {\n    margin-top: 1.5rem;\n  }\n\n  .sm\\:mr-6 {\n    margin-right: 1.5rem;\n  }\n\n  .sm\\:mb-6 {\n    margin-bottom: 1.5rem;\n  }\n\n  .sm\\:ml-6 {\n    margin-left: 1.5rem;\n  }\n\n  .sm\\:mt-8 {\n    margin-top: 2rem;\n  }\n\n  .sm\\:mr-8 {\n    margin-right: 2rem;\n  }\n\n  .sm\\:mb-8 {\n    margin-bottom: 2rem;\n  }\n\n  .sm\\:ml-8 {\n    margin-left: 2rem;\n  }\n\n  .sm\\:mt-10 {\n    margin-top: 2.5rem;\n  }\n\n  .sm\\:mr-10 {\n    margin-right: 2.5rem;\n  }\n\n  .sm\\:mb-10 {\n    margin-bottom: 2.5rem;\n  }\n\n  .sm\\:ml-10 {\n    margin-left: 2.5rem;\n  }\n\n  .sm\\:mt-12 {\n    margin-top: 3rem;\n  }\n\n  .sm\\:mr-12 {\n    margin-right: 3rem;\n  }\n\n  .sm\\:mb-12 {\n    margin-bottom: 3rem;\n  }\n\n  .sm\\:ml-12 {\n    margin-left: 3rem;\n  }\n\n  .sm\\:mt-16 {\n    margin-top: 4rem;\n  }\n\n  .sm\\:mr-16 {\n    margin-right: 4rem;\n  }\n\n  .sm\\:mb-16 {\n    margin-bottom: 4rem;\n  }\n\n  .sm\\:ml-16 {\n    margin-left: 4rem;\n  }\n\n  .sm\\:mt-20 {\n    margin-top: 5rem;\n  }\n\n  .sm\\:mr-20 {\n    margin-right: 5rem;\n  }\n\n  .sm\\:mb-20 {\n    margin-bottom: 5rem;\n  }\n\n  .sm\\:ml-20 {\n    margin-left: 5rem;\n  }\n\n  .sm\\:mt-24 {\n    margin-top: 6rem;\n  }\n\n  .sm\\:mr-24 {\n    margin-right: 6rem;\n  }\n\n  .sm\\:mb-24 {\n    margin-bottom: 6rem;\n  }\n\n  .sm\\:ml-24 {\n    margin-left: 6rem;\n  }\n\n  .sm\\:mt-32 {\n    margin-top: 8rem;\n  }\n\n  .sm\\:mr-32 {\n    margin-right: 8rem;\n  }\n\n  .sm\\:mb-32 {\n    margin-bottom: 8rem;\n  }\n\n  .sm\\:ml-32 {\n    margin-left: 8rem;\n  }\n\n  .sm\\:mt-40 {\n    margin-top: 10rem;\n  }\n\n  .sm\\:mr-40 {\n    margin-right: 10rem;\n  }\n\n  .sm\\:mb-40 {\n    margin-bottom: 10rem;\n  }\n\n  .sm\\:ml-40 {\n    margin-left: 10rem;\n  }\n\n  .sm\\:mt-48 {\n    margin-top: 12rem;\n  }\n\n  .sm\\:mr-48 {\n    margin-right: 12rem;\n  }\n\n  .sm\\:mb-48 {\n    margin-bottom: 12rem;\n  }\n\n  .sm\\:ml-48 {\n    margin-left: 12rem;\n  }\n\n  .sm\\:mt-56 {\n    margin-top: 14rem;\n  }\n\n  .sm\\:mr-56 {\n    margin-right: 14rem;\n  }\n\n  .sm\\:mb-56 {\n    margin-bottom: 14rem;\n  }\n\n  .sm\\:ml-56 {\n    margin-left: 14rem;\n  }\n\n  .sm\\:mt-64 {\n    margin-top: 16rem;\n  }\n\n  .sm\\:mr-64 {\n    margin-right: 16rem;\n  }\n\n  .sm\\:mb-64 {\n    margin-bottom: 16rem;\n  }\n\n  .sm\\:ml-64 {\n    margin-left: 16rem;\n  }\n\n  .sm\\:mt-auto {\n    margin-top: auto;\n  }\n\n  .sm\\:mr-auto {\n    margin-right: auto;\n  }\n\n  .sm\\:mb-auto {\n    margin-bottom: auto;\n  }\n\n  .sm\\:ml-auto {\n    margin-left: auto;\n  }\n\n  .sm\\:mt-px {\n    margin-top: 1px;\n  }\n\n  .sm\\:mr-px {\n    margin-right: 1px;\n  }\n\n  .sm\\:mb-px {\n    margin-bottom: 1px;\n  }\n\n  .sm\\:ml-px {\n    margin-left: 1px;\n  }\n\n  .sm\\:-mt-1 {\n    margin-top: -0.25rem;\n  }\n\n  .sm\\:-mr-1 {\n    margin-right: -0.25rem;\n  }\n\n  .sm\\:-mb-1 {\n    margin-bottom: -0.25rem;\n  }\n\n  .sm\\:-ml-1 {\n    margin-left: -0.25rem;\n  }\n\n  .sm\\:-mt-2 {\n    margin-top: -0.5rem;\n  }\n\n  .sm\\:-mr-2 {\n    margin-right: -0.5rem;\n  }\n\n  .sm\\:-mb-2 {\n    margin-bottom: -0.5rem;\n  }\n\n  .sm\\:-ml-2 {\n    margin-left: -0.5rem;\n  }\n\n  .sm\\:-mt-3 {\n    margin-top: -0.75rem;\n  }\n\n  .sm\\:-mr-3 {\n    margin-right: -0.75rem;\n  }\n\n  .sm\\:-mb-3 {\n    margin-bottom: -0.75rem;\n  }\n\n  .sm\\:-ml-3 {\n    margin-left: -0.75rem;\n  }\n\n  .sm\\:-mt-4 {\n    margin-top: -1rem;\n  }\n\n  .sm\\:-mr-4 {\n    margin-right: -1rem;\n  }\n\n  .sm\\:-mb-4 {\n    margin-bottom: -1rem;\n  }\n\n  .sm\\:-ml-4 {\n    margin-left: -1rem;\n  }\n\n  .sm\\:-mt-5 {\n    margin-top: -1.25rem;\n  }\n\n  .sm\\:-mr-5 {\n    margin-right: -1.25rem;\n  }\n\n  .sm\\:-mb-5 {\n    margin-bottom: -1.25rem;\n  }\n\n  .sm\\:-ml-5 {\n    margin-left: -1.25rem;\n  }\n\n  .sm\\:-mt-6 {\n    margin-top: -1.5rem;\n  }\n\n  .sm\\:-mr-6 {\n    margin-right: -1.5rem;\n  }\n\n  .sm\\:-mb-6 {\n    margin-bottom: -1.5rem;\n  }\n\n  .sm\\:-ml-6 {\n    margin-left: -1.5rem;\n  }\n\n  .sm\\:-mt-8 {\n    margin-top: -2rem;\n  }\n\n  .sm\\:-mr-8 {\n    margin-right: -2rem;\n  }\n\n  .sm\\:-mb-8 {\n    margin-bottom: -2rem;\n  }\n\n  .sm\\:-ml-8 {\n    margin-left: -2rem;\n  }\n\n  .sm\\:-mt-10 {\n    margin-top: -2.5rem;\n  }\n\n  .sm\\:-mr-10 {\n    margin-right: -2.5rem;\n  }\n\n  .sm\\:-mb-10 {\n    margin-bottom: -2.5rem;\n  }\n\n  .sm\\:-ml-10 {\n    margin-left: -2.5rem;\n  }\n\n  .sm\\:-mt-12 {\n    margin-top: -3rem;\n  }\n\n  .sm\\:-mr-12 {\n    margin-right: -3rem;\n  }\n\n  .sm\\:-mb-12 {\n    margin-bottom: -3rem;\n  }\n\n  .sm\\:-ml-12 {\n    margin-left: -3rem;\n  }\n\n  .sm\\:-mt-16 {\n    margin-top: -4rem;\n  }\n\n  .sm\\:-mr-16 {\n    margin-right: -4rem;\n  }\n\n  .sm\\:-mb-16 {\n    margin-bottom: -4rem;\n  }\n\n  .sm\\:-ml-16 {\n    margin-left: -4rem;\n  }\n\n  .sm\\:-mt-20 {\n    margin-top: -5rem;\n  }\n\n  .sm\\:-mr-20 {\n    margin-right: -5rem;\n  }\n\n  .sm\\:-mb-20 {\n    margin-bottom: -5rem;\n  }\n\n  .sm\\:-ml-20 {\n    margin-left: -5rem;\n  }\n\n  .sm\\:-mt-24 {\n    margin-top: -6rem;\n  }\n\n  .sm\\:-mr-24 {\n    margin-right: -6rem;\n  }\n\n  .sm\\:-mb-24 {\n    margin-bottom: -6rem;\n  }\n\n  .sm\\:-ml-24 {\n    margin-left: -6rem;\n  }\n\n  .sm\\:-mt-32 {\n    margin-top: -8rem;\n  }\n\n  .sm\\:-mr-32 {\n    margin-right: -8rem;\n  }\n\n  .sm\\:-mb-32 {\n    margin-bottom: -8rem;\n  }\n\n  .sm\\:-ml-32 {\n    margin-left: -8rem;\n  }\n\n  .sm\\:-mt-40 {\n    margin-top: -10rem;\n  }\n\n  .sm\\:-mr-40 {\n    margin-right: -10rem;\n  }\n\n  .sm\\:-mb-40 {\n    margin-bottom: -10rem;\n  }\n\n  .sm\\:-ml-40 {\n    margin-left: -10rem;\n  }\n\n  .sm\\:-mt-48 {\n    margin-top: -12rem;\n  }\n\n  .sm\\:-mr-48 {\n    margin-right: -12rem;\n  }\n\n  .sm\\:-mb-48 {\n    margin-bottom: -12rem;\n  }\n\n  .sm\\:-ml-48 {\n    margin-left: -12rem;\n  }\n\n  .sm\\:-mt-56 {\n    margin-top: -14rem;\n  }\n\n  .sm\\:-mr-56 {\n    margin-right: -14rem;\n  }\n\n  .sm\\:-mb-56 {\n    margin-bottom: -14rem;\n  }\n\n  .sm\\:-ml-56 {\n    margin-left: -14rem;\n  }\n\n  .sm\\:-mt-64 {\n    margin-top: -16rem;\n  }\n\n  .sm\\:-mr-64 {\n    margin-right: -16rem;\n  }\n\n  .sm\\:-mb-64 {\n    margin-bottom: -16rem;\n  }\n\n  .sm\\:-ml-64 {\n    margin-left: -16rem;\n  }\n\n  .sm\\:-mt-px {\n    margin-top: -1px;\n  }\n\n  .sm\\:-mr-px {\n    margin-right: -1px;\n  }\n\n  .sm\\:-mb-px {\n    margin-bottom: -1px;\n  }\n\n  .sm\\:-ml-px {\n    margin-left: -1px;\n  }\n\n  .sm\\:max-h-full {\n    max-height: 100%;\n  }\n\n  .sm\\:max-h-screen {\n    max-height: 100vh;\n  }\n\n  .sm\\:max-w-none {\n    max-width: none;\n  }\n\n  .sm\\:max-w-xs {\n    max-width: 20rem;\n  }\n\n  .sm\\:max-w-sm {\n    max-width: 24rem;\n  }\n\n  .sm\\:max-w-md {\n    max-width: 28rem;\n  }\n\n  .sm\\:max-w-lg {\n    max-width: 32rem;\n  }\n\n  .sm\\:max-w-xl {\n    max-width: 36rem;\n  }\n\n  .sm\\:max-w-2xl {\n    max-width: 42rem;\n  }\n\n  .sm\\:max-w-3xl {\n    max-width: 48rem;\n  }\n\n  .sm\\:max-w-4xl {\n    max-width: 56rem;\n  }\n\n  .sm\\:max-w-5xl {\n    max-width: 64rem;\n  }\n\n  .sm\\:max-w-6xl {\n    max-width: 72rem;\n  }\n\n  .sm\\:max-w-full {\n    max-width: 100%;\n  }\n\n  .sm\\:max-w-screen-sm {\n    max-width: 640px;\n  }\n\n  .sm\\:max-w-screen-md {\n    max-width: 768px;\n  }\n\n  .sm\\:max-w-screen-lg {\n    max-width: 1024px;\n  }\n\n  .sm\\:max-w-screen-xl {\n    max-width: 1280px;\n  }\n\n  .sm\\:min-h-0 {\n    min-height: 0;\n  }\n\n  .sm\\:min-h-full {\n    min-height: 100%;\n  }\n\n  .sm\\:min-h-screen {\n    min-height: 100vh;\n  }\n\n  .sm\\:min-w-0 {\n    min-width: 0;\n  }\n\n  .sm\\:min-w-full {\n    min-width: 100%;\n  }\n\n  .sm\\:object-contain {\n    -o-object-fit: contain;\n       object-fit: contain;\n  }\n\n  .sm\\:object-cover {\n    -o-object-fit: cover;\n       object-fit: cover;\n  }\n\n  .sm\\:object-fill {\n    -o-object-fit: fill;\n       object-fit: fill;\n  }\n\n  .sm\\:object-none {\n    -o-object-fit: none;\n       object-fit: none;\n  }\n\n  .sm\\:object-scale-down {\n    -o-object-fit: scale-down;\n       object-fit: scale-down;\n  }\n\n  .sm\\:object-bottom {\n    -o-object-position: bottom;\n       object-position: bottom;\n  }\n\n  .sm\\:object-center {\n    -o-object-position: center;\n       object-position: center;\n  }\n\n  .sm\\:object-left {\n    -o-object-position: left;\n       object-position: left;\n  }\n\n  .sm\\:object-left-bottom {\n    -o-object-position: left bottom;\n       object-position: left bottom;\n  }\n\n  .sm\\:object-left-top {\n    -o-object-position: left top;\n       object-position: left top;\n  }\n\n  .sm\\:object-right {\n    -o-object-position: right;\n       object-position: right;\n  }\n\n  .sm\\:object-right-bottom {\n    -o-object-position: right bottom;\n       object-position: right bottom;\n  }\n\n  .sm\\:object-right-top {\n    -o-object-position: right top;\n       object-position: right top;\n  }\n\n  .sm\\:object-top {\n    -o-object-position: top;\n       object-position: top;\n  }\n\n  .sm\\:opacity-0 {\n    opacity: 0;\n  }\n\n  .sm\\:opacity-25 {\n    opacity: 0.25;\n  }\n\n  .sm\\:opacity-50 {\n    opacity: 0.5;\n  }\n\n  .sm\\:opacity-75 {\n    opacity: 0.75;\n  }\n\n  .sm\\:opacity-100 {\n    opacity: 1;\n  }\n\n  .sm\\:hover\\:opacity-0:hover {\n    opacity: 0;\n  }\n\n  .sm\\:hover\\:opacity-25:hover {\n    opacity: 0.25;\n  }\n\n  .sm\\:hover\\:opacity-50:hover {\n    opacity: 0.5;\n  }\n\n  .sm\\:hover\\:opacity-75:hover {\n    opacity: 0.75;\n  }\n\n  .sm\\:hover\\:opacity-100:hover {\n    opacity: 1;\n  }\n\n  .sm\\:focus\\:opacity-0:focus {\n    opacity: 0;\n  }\n\n  .sm\\:focus\\:opacity-25:focus {\n    opacity: 0.25;\n  }\n\n  .sm\\:focus\\:opacity-50:focus {\n    opacity: 0.5;\n  }\n\n  .sm\\:focus\\:opacity-75:focus {\n    opacity: 0.75;\n  }\n\n  .sm\\:focus\\:opacity-100:focus {\n    opacity: 1;\n  }\n\n  .sm\\:outline-none {\n    outline: 2px solid transparent;\n    outline-offset: 2px;\n  }\n\n  .sm\\:outline-white {\n    outline: 2px dotted white;\n    outline-offset: 2px;\n  }\n\n  .sm\\:outline-black {\n    outline: 2px dotted black;\n    outline-offset: 2px;\n  }\n\n  .sm\\:focus\\:outline-none:focus {\n    outline: 2px solid transparent;\n    outline-offset: 2px;\n  }\n\n  .sm\\:focus\\:outline-white:focus {\n    outline: 2px dotted white;\n    outline-offset: 2px;\n  }\n\n  .sm\\:focus\\:outline-black:focus {\n    outline: 2px dotted black;\n    outline-offset: 2px;\n  }\n\n  .sm\\:overflow-auto {\n    overflow: auto;\n  }\n\n  .sm\\:overflow-hidden {\n    overflow: hidden;\n  }\n\n  .sm\\:overflow-visible {\n    overflow: visible;\n  }\n\n  .sm\\:overflow-scroll {\n    overflow: scroll;\n  }\n\n  .sm\\:overflow-x-auto {\n    overflow-x: auto;\n  }\n\n  .sm\\:overflow-y-auto {\n    overflow-y: auto;\n  }\n\n  .sm\\:overflow-x-hidden {\n    overflow-x: hidden;\n  }\n\n  .sm\\:overflow-y-hidden {\n    overflow-y: hidden;\n  }\n\n  .sm\\:overflow-x-visible {\n    overflow-x: visible;\n  }\n\n  .sm\\:overflow-y-visible {\n    overflow-y: visible;\n  }\n\n  .sm\\:overflow-x-scroll {\n    overflow-x: scroll;\n  }\n\n  .sm\\:overflow-y-scroll {\n    overflow-y: scroll;\n  }\n\n  .sm\\:scrolling-touch {\n    -webkit-overflow-scrolling: touch;\n  }\n\n  .sm\\:scrolling-auto {\n    -webkit-overflow-scrolling: auto;\n  }\n\n  .sm\\:overscroll-auto {\n    -ms-scroll-chaining: chained;\n        overscroll-behavior: auto;\n  }\n\n  .sm\\:overscroll-contain {\n    -ms-scroll-chaining: none;\n        overscroll-behavior: contain;\n  }\n\n  .sm\\:overscroll-none {\n    -ms-scroll-chaining: none;\n        overscroll-behavior: none;\n  }\n\n  .sm\\:overscroll-y-auto {\n    overscroll-behavior-y: auto;\n  }\n\n  .sm\\:overscroll-y-contain {\n    overscroll-behavior-y: contain;\n  }\n\n  .sm\\:overscroll-y-none {\n    overscroll-behavior-y: none;\n  }\n\n  .sm\\:overscroll-x-auto {\n    overscroll-behavior-x: auto;\n  }\n\n  .sm\\:overscroll-x-contain {\n    overscroll-behavior-x: contain;\n  }\n\n  .sm\\:overscroll-x-none {\n    overscroll-behavior-x: none;\n  }\n\n  .sm\\:p-0 {\n    padding: 0;\n  }\n\n  .sm\\:p-1 {\n    padding: 0.25rem;\n  }\n\n  .sm\\:p-2 {\n    padding: 0.5rem;\n  }\n\n  .sm\\:p-3 {\n    padding: 0.75rem;\n  }\n\n  .sm\\:p-4 {\n    padding: 1rem;\n  }\n\n  .sm\\:p-5 {\n    padding: 1.25rem;\n  }\n\n  .sm\\:p-6 {\n    padding: 1.5rem;\n  }\n\n  .sm\\:p-8 {\n    padding: 2rem;\n  }\n\n  .sm\\:p-10 {\n    padding: 2.5rem;\n  }\n\n  .sm\\:p-12 {\n    padding: 3rem;\n  }\n\n  .sm\\:p-16 {\n    padding: 4rem;\n  }\n\n  .sm\\:p-20 {\n    padding: 5rem;\n  }\n\n  .sm\\:p-24 {\n    padding: 6rem;\n  }\n\n  .sm\\:p-32 {\n    padding: 8rem;\n  }\n\n  .sm\\:p-40 {\n    padding: 10rem;\n  }\n\n  .sm\\:p-48 {\n    padding: 12rem;\n  }\n\n  .sm\\:p-56 {\n    padding: 14rem;\n  }\n\n  .sm\\:p-64 {\n    padding: 16rem;\n  }\n\n  .sm\\:p-px {\n    padding: 1px;\n  }\n\n  .sm\\:py-0 {\n    padding-top: 0;\n    padding-bottom: 0;\n  }\n\n  .sm\\:px-0 {\n    padding-left: 0;\n    padding-right: 0;\n  }\n\n  .sm\\:py-1 {\n    padding-top: 0.25rem;\n    padding-bottom: 0.25rem;\n  }\n\n  .sm\\:px-1 {\n    padding-left: 0.25rem;\n    padding-right: 0.25rem;\n  }\n\n  .sm\\:py-2 {\n    padding-top: 0.5rem;\n    padding-bottom: 0.5rem;\n  }\n\n  .sm\\:px-2 {\n    padding-left: 0.5rem;\n    padding-right: 0.5rem;\n  }\n\n  .sm\\:py-3 {\n    padding-top: 0.75rem;\n    padding-bottom: 0.75rem;\n  }\n\n  .sm\\:px-3 {\n    padding-left: 0.75rem;\n    padding-right: 0.75rem;\n  }\n\n  .sm\\:py-4 {\n    padding-top: 1rem;\n    padding-bottom: 1rem;\n  }\n\n  .sm\\:px-4 {\n    padding-left: 1rem;\n    padding-right: 1rem;\n  }\n\n  .sm\\:py-5 {\n    padding-top: 1.25rem;\n    padding-bottom: 1.25rem;\n  }\n\n  .sm\\:px-5 {\n    padding-left: 1.25rem;\n    padding-right: 1.25rem;\n  }\n\n  .sm\\:py-6 {\n    padding-top: 1.5rem;\n    padding-bottom: 1.5rem;\n  }\n\n  .sm\\:px-6 {\n    padding-left: 1.5rem;\n    padding-right: 1.5rem;\n  }\n\n  .sm\\:py-8 {\n    padding-top: 2rem;\n    padding-bottom: 2rem;\n  }\n\n  .sm\\:px-8 {\n    padding-left: 2rem;\n    padding-right: 2rem;\n  }\n\n  .sm\\:py-10 {\n    padding-top: 2.5rem;\n    padding-bottom: 2.5rem;\n  }\n\n  .sm\\:px-10 {\n    padding-left: 2.5rem;\n    padding-right: 2.5rem;\n  }\n\n  .sm\\:py-12 {\n    padding-top: 3rem;\n    padding-bottom: 3rem;\n  }\n\n  .sm\\:px-12 {\n    padding-left: 3rem;\n    padding-right: 3rem;\n  }\n\n  .sm\\:py-16 {\n    padding-top: 4rem;\n    padding-bottom: 4rem;\n  }\n\n  .sm\\:px-16 {\n    padding-left: 4rem;\n    padding-right: 4rem;\n  }\n\n  .sm\\:py-20 {\n    padding-top: 5rem;\n    padding-bottom: 5rem;\n  }\n\n  .sm\\:px-20 {\n    padding-left: 5rem;\n    padding-right: 5rem;\n  }\n\n  .sm\\:py-24 {\n    padding-top: 6rem;\n    padding-bottom: 6rem;\n  }\n\n  .sm\\:px-24 {\n    padding-left: 6rem;\n    padding-right: 6rem;\n  }\n\n  .sm\\:py-32 {\n    padding-top: 8rem;\n    padding-bottom: 8rem;\n  }\n\n  .sm\\:px-32 {\n    padding-left: 8rem;\n    padding-right: 8rem;\n  }\n\n  .sm\\:py-40 {\n    padding-top: 10rem;\n    padding-bottom: 10rem;\n  }\n\n  .sm\\:px-40 {\n    padding-left: 10rem;\n    padding-right: 10rem;\n  }\n\n  .sm\\:py-48 {\n    padding-top: 12rem;\n    padding-bottom: 12rem;\n  }\n\n  .sm\\:px-48 {\n    padding-left: 12rem;\n    padding-right: 12rem;\n  }\n\n  .sm\\:py-56 {\n    padding-top: 14rem;\n    padding-bottom: 14rem;\n  }\n\n  .sm\\:px-56 {\n    padding-left: 14rem;\n    padding-right: 14rem;\n  }\n\n  .sm\\:py-64 {\n    padding-top: 16rem;\n    padding-bottom: 16rem;\n  }\n\n  .sm\\:px-64 {\n    padding-left: 16rem;\n    padding-right: 16rem;\n  }\n\n  .sm\\:py-px {\n    padding-top: 1px;\n    padding-bottom: 1px;\n  }\n\n  .sm\\:px-px {\n    padding-left: 1px;\n    padding-right: 1px;\n  }\n\n  .sm\\:pt-0 {\n    padding-top: 0;\n  }\n\n  .sm\\:pr-0 {\n    padding-right: 0;\n  }\n\n  .sm\\:pb-0 {\n    padding-bottom: 0;\n  }\n\n  .sm\\:pl-0 {\n    padding-left: 0;\n  }\n\n  .sm\\:pt-1 {\n    padding-top: 0.25rem;\n  }\n\n  .sm\\:pr-1 {\n    padding-right: 0.25rem;\n  }\n\n  .sm\\:pb-1 {\n    padding-bottom: 0.25rem;\n  }\n\n  .sm\\:pl-1 {\n    padding-left: 0.25rem;\n  }\n\n  .sm\\:pt-2 {\n    padding-top: 0.5rem;\n  }\n\n  .sm\\:pr-2 {\n    padding-right: 0.5rem;\n  }\n\n  .sm\\:pb-2 {\n    padding-bottom: 0.5rem;\n  }\n\n  .sm\\:pl-2 {\n    padding-left: 0.5rem;\n  }\n\n  .sm\\:pt-3 {\n    padding-top: 0.75rem;\n  }\n\n  .sm\\:pr-3 {\n    padding-right: 0.75rem;\n  }\n\n  .sm\\:pb-3 {\n    padding-bottom: 0.75rem;\n  }\n\n  .sm\\:pl-3 {\n    padding-left: 0.75rem;\n  }\n\n  .sm\\:pt-4 {\n    padding-top: 1rem;\n  }\n\n  .sm\\:pr-4 {\n    padding-right: 1rem;\n  }\n\n  .sm\\:pb-4 {\n    padding-bottom: 1rem;\n  }\n\n  .sm\\:pl-4 {\n    padding-left: 1rem;\n  }\n\n  .sm\\:pt-5 {\n    padding-top: 1.25rem;\n  }\n\n  .sm\\:pr-5 {\n    padding-right: 1.25rem;\n  }\n\n  .sm\\:pb-5 {\n    padding-bottom: 1.25rem;\n  }\n\n  .sm\\:pl-5 {\n    padding-left: 1.25rem;\n  }\n\n  .sm\\:pt-6 {\n    padding-top: 1.5rem;\n  }\n\n  .sm\\:pr-6 {\n    padding-right: 1.5rem;\n  }\n\n  .sm\\:pb-6 {\n    padding-bottom: 1.5rem;\n  }\n\n  .sm\\:pl-6 {\n    padding-left: 1.5rem;\n  }\n\n  .sm\\:pt-8 {\n    padding-top: 2rem;\n  }\n\n  .sm\\:pr-8 {\n    padding-right: 2rem;\n  }\n\n  .sm\\:pb-8 {\n    padding-bottom: 2rem;\n  }\n\n  .sm\\:pl-8 {\n    padding-left: 2rem;\n  }\n\n  .sm\\:pt-10 {\n    padding-top: 2.5rem;\n  }\n\n  .sm\\:pr-10 {\n    padding-right: 2.5rem;\n  }\n\n  .sm\\:pb-10 {\n    padding-bottom: 2.5rem;\n  }\n\n  .sm\\:pl-10 {\n    padding-left: 2.5rem;\n  }\n\n  .sm\\:pt-12 {\n    padding-top: 3rem;\n  }\n\n  .sm\\:pr-12 {\n    padding-right: 3rem;\n  }\n\n  .sm\\:pb-12 {\n    padding-bottom: 3rem;\n  }\n\n  .sm\\:pl-12 {\n    padding-left: 3rem;\n  }\n\n  .sm\\:pt-16 {\n    padding-top: 4rem;\n  }\n\n  .sm\\:pr-16 {\n    padding-right: 4rem;\n  }\n\n  .sm\\:pb-16 {\n    padding-bottom: 4rem;\n  }\n\n  .sm\\:pl-16 {\n    padding-left: 4rem;\n  }\n\n  .sm\\:pt-20 {\n    padding-top: 5rem;\n  }\n\n  .sm\\:pr-20 {\n    padding-right: 5rem;\n  }\n\n  .sm\\:pb-20 {\n    padding-bottom: 5rem;\n  }\n\n  .sm\\:pl-20 {\n    padding-left: 5rem;\n  }\n\n  .sm\\:pt-24 {\n    padding-top: 6rem;\n  }\n\n  .sm\\:pr-24 {\n    padding-right: 6rem;\n  }\n\n  .sm\\:pb-24 {\n    padding-bottom: 6rem;\n  }\n\n  .sm\\:pl-24 {\n    padding-left: 6rem;\n  }\n\n  .sm\\:pt-32 {\n    padding-top: 8rem;\n  }\n\n  .sm\\:pr-32 {\n    padding-right: 8rem;\n  }\n\n  .sm\\:pb-32 {\n    padding-bottom: 8rem;\n  }\n\n  .sm\\:pl-32 {\n    padding-left: 8rem;\n  }\n\n  .sm\\:pt-40 {\n    padding-top: 10rem;\n  }\n\n  .sm\\:pr-40 {\n    padding-right: 10rem;\n  }\n\n  .sm\\:pb-40 {\n    padding-bottom: 10rem;\n  }\n\n  .sm\\:pl-40 {\n    padding-left: 10rem;\n  }\n\n  .sm\\:pt-48 {\n    padding-top: 12rem;\n  }\n\n  .sm\\:pr-48 {\n    padding-right: 12rem;\n  }\n\n  .sm\\:pb-48 {\n    padding-bottom: 12rem;\n  }\n\n  .sm\\:pl-48 {\n    padding-left: 12rem;\n  }\n\n  .sm\\:pt-56 {\n    padding-top: 14rem;\n  }\n\n  .sm\\:pr-56 {\n    padding-right: 14rem;\n  }\n\n  .sm\\:pb-56 {\n    padding-bottom: 14rem;\n  }\n\n  .sm\\:pl-56 {\n    padding-left: 14rem;\n  }\n\n  .sm\\:pt-64 {\n    padding-top: 16rem;\n  }\n\n  .sm\\:pr-64 {\n    padding-right: 16rem;\n  }\n\n  .sm\\:pb-64 {\n    padding-bottom: 16rem;\n  }\n\n  .sm\\:pl-64 {\n    padding-left: 16rem;\n  }\n\n  .sm\\:pt-px {\n    padding-top: 1px;\n  }\n\n  .sm\\:pr-px {\n    padding-right: 1px;\n  }\n\n  .sm\\:pb-px {\n    padding-bottom: 1px;\n  }\n\n  .sm\\:pl-px {\n    padding-left: 1px;\n  }\n\n  .sm\\:placeholder-transparent::-moz-placeholder {\n    color: transparent;\n  }\n\n  .sm\\:placeholder-transparent:-ms-input-placeholder {\n    color: transparent;\n  }\n\n  .sm\\:placeholder-transparent::placeholder {\n    color: transparent;\n  }\n\n  .sm\\:placeholder-current::-moz-placeholder {\n    color: currentColor;\n  }\n\n  .sm\\:placeholder-current:-ms-input-placeholder {\n    color: currentColor;\n  }\n\n  .sm\\:placeholder-current::placeholder {\n    color: currentColor;\n  }\n\n  .sm\\:placeholder-black::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-black:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-black::placeholder {\n    --placeholder-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-white::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-white:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-white::placeholder {\n    --placeholder-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-gray-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-red-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-orange-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-yellow-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-green-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-teal-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-blue-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-indigo-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-purple-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-pink-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-80::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-80:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-80::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-100::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-200::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-300::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-400::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-500::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-600::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-700::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-800::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-840::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-840:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-840::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-870::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-870:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-870::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-900::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-930::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-930:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-grayscale-930::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-primary::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-primary:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-primary::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:placeholder-background-main::-moz-placeholder {\n    color: var(--main-background);\n  }\n\n  .sm\\:placeholder-background-main:-ms-input-placeholder {\n    color: var(--main-background);\n  }\n\n  .sm\\:placeholder-background-main::placeholder {\n    color: var(--main-background);\n  }\n\n  .sm\\:placeholder-background-secondary::-moz-placeholder {\n    color: var(--secondary-background);\n  }\n\n  .sm\\:placeholder-background-secondary:-ms-input-placeholder {\n    color: var(--secondary-background);\n  }\n\n  .sm\\:placeholder-background-secondary::placeholder {\n    color: var(--secondary-background);\n  }\n\n  .sm\\:placeholder-foreground::-moz-placeholder {\n    color: var(--foreground);\n  }\n\n  .sm\\:placeholder-foreground:-ms-input-placeholder {\n    color: var(--foreground);\n  }\n\n  .sm\\:placeholder-foreground::placeholder {\n    color: var(--foreground);\n  }\n\n  .sm\\:placeholder-panels-bg::-moz-placeholder {\n    color: var(--panels-background);\n  }\n\n  .sm\\:placeholder-panels-bg:-ms-input-placeholder {\n    color: var(--panels-background);\n  }\n\n  .sm\\:placeholder-panels-bg::placeholder {\n    color: var(--panels-background);\n  }\n\n  .sm\\:focus\\:placeholder-transparent:focus::-moz-placeholder {\n    color: transparent;\n  }\n\n  .sm\\:focus\\:placeholder-transparent:focus:-ms-input-placeholder {\n    color: transparent;\n  }\n\n  .sm\\:focus\\:placeholder-transparent:focus::placeholder {\n    color: transparent;\n  }\n\n  .sm\\:focus\\:placeholder-current:focus::-moz-placeholder {\n    color: currentColor;\n  }\n\n  .sm\\:focus\\:placeholder-current:focus:-ms-input-placeholder {\n    color: currentColor;\n  }\n\n  .sm\\:focus\\:placeholder-current:focus::placeholder {\n    color: currentColor;\n  }\n\n  .sm\\:focus\\:placeholder-black:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-black:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-black:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-white:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-white:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-white:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-gray-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-red-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-orange-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-yellow-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-green-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-teal-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-blue-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-indigo-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-purple-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-pink-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-80:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-80:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-80:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-840:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-840:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-840:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-870:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-870:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-870:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-930:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-930:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-grayscale-930:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-primary:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-primary:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-primary:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n  }\n\n  .sm\\:focus\\:placeholder-background-main:focus::-moz-placeholder {\n    color: var(--main-background);\n  }\n\n  .sm\\:focus\\:placeholder-background-main:focus:-ms-input-placeholder {\n    color: var(--main-background);\n  }\n\n  .sm\\:focus\\:placeholder-background-main:focus::placeholder {\n    color: var(--main-background);\n  }\n\n  .sm\\:focus\\:placeholder-background-secondary:focus::-moz-placeholder {\n    color: var(--secondary-background);\n  }\n\n  .sm\\:focus\\:placeholder-background-secondary:focus:-ms-input-placeholder {\n    color: var(--secondary-background);\n  }\n\n  .sm\\:focus\\:placeholder-background-secondary:focus::placeholder {\n    color: var(--secondary-background);\n  }\n\n  .sm\\:focus\\:placeholder-foreground:focus::-moz-placeholder {\n    color: var(--foreground);\n  }\n\n  .sm\\:focus\\:placeholder-foreground:focus:-ms-input-placeholder {\n    color: var(--foreground);\n  }\n\n  .sm\\:focus\\:placeholder-foreground:focus::placeholder {\n    color: var(--foreground);\n  }\n\n  .sm\\:focus\\:placeholder-panels-bg:focus::-moz-placeholder {\n    color: var(--panels-background);\n  }\n\n  .sm\\:focus\\:placeholder-panels-bg:focus:-ms-input-placeholder {\n    color: var(--panels-background);\n  }\n\n  .sm\\:focus\\:placeholder-panels-bg:focus::placeholder {\n    color: var(--panels-background);\n  }\n\n  .sm\\:placeholder-opacity-0::-moz-placeholder {\n    --placeholder-opacity: 0;\n  }\n\n  .sm\\:placeholder-opacity-0:-ms-input-placeholder {\n    --placeholder-opacity: 0;\n  }\n\n  .sm\\:placeholder-opacity-0::placeholder {\n    --placeholder-opacity: 0;\n  }\n\n  .sm\\:placeholder-opacity-25::-moz-placeholder {\n    --placeholder-opacity: 0.25;\n  }\n\n  .sm\\:placeholder-opacity-25:-ms-input-placeholder {\n    --placeholder-opacity: 0.25;\n  }\n\n  .sm\\:placeholder-opacity-25::placeholder {\n    --placeholder-opacity: 0.25;\n  }\n\n  .sm\\:placeholder-opacity-50::-moz-placeholder {\n    --placeholder-opacity: 0.5;\n  }\n\n  .sm\\:placeholder-opacity-50:-ms-input-placeholder {\n    --placeholder-opacity: 0.5;\n  }\n\n  .sm\\:placeholder-opacity-50::placeholder {\n    --placeholder-opacity: 0.5;\n  }\n\n  .sm\\:placeholder-opacity-75::-moz-placeholder {\n    --placeholder-opacity: 0.75;\n  }\n\n  .sm\\:placeholder-opacity-75:-ms-input-placeholder {\n    --placeholder-opacity: 0.75;\n  }\n\n  .sm\\:placeholder-opacity-75::placeholder {\n    --placeholder-opacity: 0.75;\n  }\n\n  .sm\\:placeholder-opacity-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n  }\n\n  .sm\\:placeholder-opacity-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n  }\n\n  .sm\\:placeholder-opacity-100::placeholder {\n    --placeholder-opacity: 1;\n  }\n\n  .sm\\:focus\\:placeholder-opacity-0:focus::-moz-placeholder {\n    --placeholder-opacity: 0;\n  }\n\n  .sm\\:focus\\:placeholder-opacity-0:focus:-ms-input-placeholder {\n    --placeholder-opacity: 0;\n  }\n\n  .sm\\:focus\\:placeholder-opacity-0:focus::placeholder {\n    --placeholder-opacity: 0;\n  }\n\n  .sm\\:focus\\:placeholder-opacity-25:focus::-moz-placeholder {\n    --placeholder-opacity: 0.25;\n  }\n\n  .sm\\:focus\\:placeholder-opacity-25:focus:-ms-input-placeholder {\n    --placeholder-opacity: 0.25;\n  }\n\n  .sm\\:focus\\:placeholder-opacity-25:focus::placeholder {\n    --placeholder-opacity: 0.25;\n  }\n\n  .sm\\:focus\\:placeholder-opacity-50:focus::-moz-placeholder {\n    --placeholder-opacity: 0.5;\n  }\n\n  .sm\\:focus\\:placeholder-opacity-50:focus:-ms-input-placeholder {\n    --placeholder-opacity: 0.5;\n  }\n\n  .sm\\:focus\\:placeholder-opacity-50:focus::placeholder {\n    --placeholder-opacity: 0.5;\n  }\n\n  .sm\\:focus\\:placeholder-opacity-75:focus::-moz-placeholder {\n    --placeholder-opacity: 0.75;\n  }\n\n  .sm\\:focus\\:placeholder-opacity-75:focus:-ms-input-placeholder {\n    --placeholder-opacity: 0.75;\n  }\n\n  .sm\\:focus\\:placeholder-opacity-75:focus::placeholder {\n    --placeholder-opacity: 0.75;\n  }\n\n  .sm\\:focus\\:placeholder-opacity-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n  }\n\n  .sm\\:focus\\:placeholder-opacity-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n  }\n\n  .sm\\:focus\\:placeholder-opacity-100:focus::placeholder {\n    --placeholder-opacity: 1;\n  }\n\n  .sm\\:pointer-events-none {\n    pointer-events: none;\n  }\n\n  .sm\\:pointer-events-auto {\n    pointer-events: auto;\n  }\n\n  .sm\\:static {\n    position: static;\n  }\n\n  .sm\\:fixed {\n    position: fixed;\n  }\n\n  .sm\\:absolute {\n    position: absolute;\n  }\n\n  .sm\\:relative {\n    position: relative;\n  }\n\n  .sm\\:sticky {\n    position: -webkit-sticky;\n    position: sticky;\n  }\n\n  .sm\\:inset-0 {\n    top: 0;\n    right: 0;\n    bottom: 0;\n    left: 0;\n  }\n\n  .sm\\:inset-auto {\n    top: auto;\n    right: auto;\n    bottom: auto;\n    left: auto;\n  }\n\n  .sm\\:inset-y-0 {\n    top: 0;\n    bottom: 0;\n  }\n\n  .sm\\:inset-x-0 {\n    right: 0;\n    left: 0;\n  }\n\n  .sm\\:inset-y-auto {\n    top: auto;\n    bottom: auto;\n  }\n\n  .sm\\:inset-x-auto {\n    right: auto;\n    left: auto;\n  }\n\n  .sm\\:top-0 {\n    top: 0;\n  }\n\n  .sm\\:right-0 {\n    right: 0;\n  }\n\n  .sm\\:bottom-0 {\n    bottom: 0;\n  }\n\n  .sm\\:left-0 {\n    left: 0;\n  }\n\n  .sm\\:top-auto {\n    top: auto;\n  }\n\n  .sm\\:right-auto {\n    right: auto;\n  }\n\n  .sm\\:bottom-auto {\n    bottom: auto;\n  }\n\n  .sm\\:left-auto {\n    left: auto;\n  }\n\n  .sm\\:resize-none {\n    resize: none;\n  }\n\n  .sm\\:resize-y {\n    resize: vertical;\n  }\n\n  .sm\\:resize-x {\n    resize: horizontal;\n  }\n\n  .sm\\:resize {\n    resize: both;\n  }\n\n  .sm\\:shadow-xs {\n    box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.05);\n  }\n\n  .sm\\:shadow-sm {\n    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);\n  }\n\n  .sm\\:shadow {\n    box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);\n  }\n\n  .sm\\:shadow-md {\n    box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);\n  }\n\n  .sm\\:shadow-lg {\n    box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);\n  }\n\n  .sm\\:shadow-xl {\n    box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04);\n  }\n\n  .sm\\:shadow-2xl {\n    box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);\n  }\n\n  .sm\\:shadow-inner {\n    box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);\n  }\n\n  .sm\\:shadow-outline {\n    box-shadow: 0 0 0 3px rgba(66, 153, 225, 0.5);\n  }\n\n  .sm\\:shadow-none {\n    box-shadow: none;\n  }\n\n  .sm\\:hover\\:shadow-xs:hover {\n    box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.05);\n  }\n\n  .sm\\:hover\\:shadow-sm:hover {\n    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);\n  }\n\n  .sm\\:hover\\:shadow:hover {\n    box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);\n  }\n\n  .sm\\:hover\\:shadow-md:hover {\n    box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);\n  }\n\n  .sm\\:hover\\:shadow-lg:hover {\n    box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);\n  }\n\n  .sm\\:hover\\:shadow-xl:hover {\n    box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04);\n  }\n\n  .sm\\:hover\\:shadow-2xl:hover {\n    box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);\n  }\n\n  .sm\\:hover\\:shadow-inner:hover {\n    box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);\n  }\n\n  .sm\\:hover\\:shadow-outline:hover {\n    box-shadow: 0 0 0 3px rgba(66, 153, 225, 0.5);\n  }\n\n  .sm\\:hover\\:shadow-none:hover {\n    box-shadow: none;\n  }\n\n  .sm\\:focus\\:shadow-xs:focus {\n    box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.05);\n  }\n\n  .sm\\:focus\\:shadow-sm:focus {\n    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);\n  }\n\n  .sm\\:focus\\:shadow:focus {\n    box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);\n  }\n\n  .sm\\:focus\\:shadow-md:focus {\n    box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);\n  }\n\n  .sm\\:focus\\:shadow-lg:focus {\n    box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);\n  }\n\n  .sm\\:focus\\:shadow-xl:focus {\n    box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04);\n  }\n\n  .sm\\:focus\\:shadow-2xl:focus {\n    box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);\n  }\n\n  .sm\\:focus\\:shadow-inner:focus {\n    box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);\n  }\n\n  .sm\\:focus\\:shadow-outline:focus {\n    box-shadow: 0 0 0 3px rgba(66, 153, 225, 0.5);\n  }\n\n  .sm\\:focus\\:shadow-none:focus {\n    box-shadow: none;\n  }\n\n  .sm\\:fill-current {\n    fill: currentColor;\n  }\n\n  .sm\\:stroke-current {\n    stroke: currentColor;\n  }\n\n  .sm\\:stroke-0 {\n    stroke-width: 0;\n  }\n\n  .sm\\:stroke-1 {\n    stroke-width: 1;\n  }\n\n  .sm\\:stroke-2 {\n    stroke-width: 2;\n  }\n\n  .sm\\:table-auto {\n    table-layout: auto;\n  }\n\n  .sm\\:table-fixed {\n    table-layout: fixed;\n  }\n\n  .sm\\:text-left {\n    text-align: left;\n  }\n\n  .sm\\:text-center {\n    text-align: center;\n  }\n\n  .sm\\:text-right {\n    text-align: right;\n  }\n\n  .sm\\:text-justify {\n    text-align: justify;\n  }\n\n  .sm\\:text-transparent {\n    color: transparent;\n  }\n\n  .sm\\:text-current {\n    color: currentColor;\n  }\n\n  .sm\\:text-black {\n    --text-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--text-opacity));\n  }\n\n  .sm\\:text-white {\n    --text-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--text-opacity));\n  }\n\n  .sm\\:text-gray-100 {\n    --text-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--text-opacity));\n  }\n\n  .sm\\:text-gray-200 {\n    --text-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--text-opacity));\n  }\n\n  .sm\\:text-gray-300 {\n    --text-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--text-opacity));\n  }\n\n  .sm\\:text-gray-400 {\n    --text-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--text-opacity));\n  }\n\n  .sm\\:text-gray-500 {\n    --text-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--text-opacity));\n  }\n\n  .sm\\:text-gray-600 {\n    --text-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--text-opacity));\n  }\n\n  .sm\\:text-gray-700 {\n    --text-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--text-opacity));\n  }\n\n  .sm\\:text-gray-800 {\n    --text-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--text-opacity));\n  }\n\n  .sm\\:text-gray-900 {\n    --text-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--text-opacity));\n  }\n\n  .sm\\:text-red-100 {\n    --text-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--text-opacity));\n  }\n\n  .sm\\:text-red-200 {\n    --text-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--text-opacity));\n  }\n\n  .sm\\:text-red-300 {\n    --text-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--text-opacity));\n  }\n\n  .sm\\:text-red-400 {\n    --text-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--text-opacity));\n  }\n\n  .sm\\:text-red-500 {\n    --text-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--text-opacity));\n  }\n\n  .sm\\:text-red-600 {\n    --text-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--text-opacity));\n  }\n\n  .sm\\:text-red-700 {\n    --text-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--text-opacity));\n  }\n\n  .sm\\:text-red-800 {\n    --text-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--text-opacity));\n  }\n\n  .sm\\:text-red-900 {\n    --text-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--text-opacity));\n  }\n\n  .sm\\:text-orange-100 {\n    --text-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--text-opacity));\n  }\n\n  .sm\\:text-orange-200 {\n    --text-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--text-opacity));\n  }\n\n  .sm\\:text-orange-300 {\n    --text-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--text-opacity));\n  }\n\n  .sm\\:text-orange-400 {\n    --text-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--text-opacity));\n  }\n\n  .sm\\:text-orange-500 {\n    --text-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--text-opacity));\n  }\n\n  .sm\\:text-orange-600 {\n    --text-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--text-opacity));\n  }\n\n  .sm\\:text-orange-700 {\n    --text-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--text-opacity));\n  }\n\n  .sm\\:text-orange-800 {\n    --text-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--text-opacity));\n  }\n\n  .sm\\:text-orange-900 {\n    --text-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--text-opacity));\n  }\n\n  .sm\\:text-yellow-100 {\n    --text-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--text-opacity));\n  }\n\n  .sm\\:text-yellow-200 {\n    --text-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--text-opacity));\n  }\n\n  .sm\\:text-yellow-300 {\n    --text-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--text-opacity));\n  }\n\n  .sm\\:text-yellow-400 {\n    --text-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--text-opacity));\n  }\n\n  .sm\\:text-yellow-500 {\n    --text-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--text-opacity));\n  }\n\n  .sm\\:text-yellow-600 {\n    --text-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--text-opacity));\n  }\n\n  .sm\\:text-yellow-700 {\n    --text-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--text-opacity));\n  }\n\n  .sm\\:text-yellow-800 {\n    --text-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--text-opacity));\n  }\n\n  .sm\\:text-yellow-900 {\n    --text-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--text-opacity));\n  }\n\n  .sm\\:text-green-100 {\n    --text-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--text-opacity));\n  }\n\n  .sm\\:text-green-200 {\n    --text-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--text-opacity));\n  }\n\n  .sm\\:text-green-300 {\n    --text-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--text-opacity));\n  }\n\n  .sm\\:text-green-400 {\n    --text-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--text-opacity));\n  }\n\n  .sm\\:text-green-500 {\n    --text-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--text-opacity));\n  }\n\n  .sm\\:text-green-600 {\n    --text-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--text-opacity));\n  }\n\n  .sm\\:text-green-700 {\n    --text-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--text-opacity));\n  }\n\n  .sm\\:text-green-800 {\n    --text-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--text-opacity));\n  }\n\n  .sm\\:text-green-900 {\n    --text-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--text-opacity));\n  }\n\n  .sm\\:text-teal-100 {\n    --text-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--text-opacity));\n  }\n\n  .sm\\:text-teal-200 {\n    --text-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--text-opacity));\n  }\n\n  .sm\\:text-teal-300 {\n    --text-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--text-opacity));\n  }\n\n  .sm\\:text-teal-400 {\n    --text-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--text-opacity));\n  }\n\n  .sm\\:text-teal-500 {\n    --text-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--text-opacity));\n  }\n\n  .sm\\:text-teal-600 {\n    --text-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--text-opacity));\n  }\n\n  .sm\\:text-teal-700 {\n    --text-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--text-opacity));\n  }\n\n  .sm\\:text-teal-800 {\n    --text-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--text-opacity));\n  }\n\n  .sm\\:text-teal-900 {\n    --text-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--text-opacity));\n  }\n\n  .sm\\:text-blue-100 {\n    --text-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--text-opacity));\n  }\n\n  .sm\\:text-blue-200 {\n    --text-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--text-opacity));\n  }\n\n  .sm\\:text-blue-300 {\n    --text-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--text-opacity));\n  }\n\n  .sm\\:text-blue-400 {\n    --text-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--text-opacity));\n  }\n\n  .sm\\:text-blue-500 {\n    --text-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--text-opacity));\n  }\n\n  .sm\\:text-blue-600 {\n    --text-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--text-opacity));\n  }\n\n  .sm\\:text-blue-700 {\n    --text-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--text-opacity));\n  }\n\n  .sm\\:text-blue-800 {\n    --text-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--text-opacity));\n  }\n\n  .sm\\:text-blue-900 {\n    --text-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--text-opacity));\n  }\n\n  .sm\\:text-indigo-100 {\n    --text-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--text-opacity));\n  }\n\n  .sm\\:text-indigo-200 {\n    --text-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--text-opacity));\n  }\n\n  .sm\\:text-indigo-300 {\n    --text-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--text-opacity));\n  }\n\n  .sm\\:text-indigo-400 {\n    --text-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--text-opacity));\n  }\n\n  .sm\\:text-indigo-500 {\n    --text-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--text-opacity));\n  }\n\n  .sm\\:text-indigo-600 {\n    --text-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--text-opacity));\n  }\n\n  .sm\\:text-indigo-700 {\n    --text-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--text-opacity));\n  }\n\n  .sm\\:text-indigo-800 {\n    --text-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--text-opacity));\n  }\n\n  .sm\\:text-indigo-900 {\n    --text-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--text-opacity));\n  }\n\n  .sm\\:text-purple-100 {\n    --text-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--text-opacity));\n  }\n\n  .sm\\:text-purple-200 {\n    --text-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--text-opacity));\n  }\n\n  .sm\\:text-purple-300 {\n    --text-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--text-opacity));\n  }\n\n  .sm\\:text-purple-400 {\n    --text-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--text-opacity));\n  }\n\n  .sm\\:text-purple-500 {\n    --text-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--text-opacity));\n  }\n\n  .sm\\:text-purple-600 {\n    --text-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--text-opacity));\n  }\n\n  .sm\\:text-purple-700 {\n    --text-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--text-opacity));\n  }\n\n  .sm\\:text-purple-800 {\n    --text-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--text-opacity));\n  }\n\n  .sm\\:text-purple-900 {\n    --text-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--text-opacity));\n  }\n\n  .sm\\:text-pink-100 {\n    --text-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--text-opacity));\n  }\n\n  .sm\\:text-pink-200 {\n    --text-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--text-opacity));\n  }\n\n  .sm\\:text-pink-300 {\n    --text-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--text-opacity));\n  }\n\n  .sm\\:text-pink-400 {\n    --text-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--text-opacity));\n  }\n\n  .sm\\:text-pink-500 {\n    --text-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--text-opacity));\n  }\n\n  .sm\\:text-pink-600 {\n    --text-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--text-opacity));\n  }\n\n  .sm\\:text-pink-700 {\n    --text-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--text-opacity));\n  }\n\n  .sm\\:text-pink-800 {\n    --text-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--text-opacity));\n  }\n\n  .sm\\:text-pink-900 {\n    --text-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--text-opacity));\n  }\n\n  .sm\\:text-grayscale-80 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--text-opacity));\n  }\n\n  .sm\\:text-grayscale-100 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--text-opacity));\n  }\n\n  .sm\\:text-grayscale-200 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--text-opacity));\n  }\n\n  .sm\\:text-grayscale-300 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--text-opacity));\n  }\n\n  .sm\\:text-grayscale-400 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--text-opacity));\n  }\n\n  .sm\\:text-grayscale-500 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--text-opacity));\n  }\n\n  .sm\\:text-grayscale-600 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--text-opacity));\n  }\n\n  .sm\\:text-grayscale-700 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--text-opacity));\n  }\n\n  .sm\\:text-grayscale-800 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--text-opacity));\n  }\n\n  .sm\\:text-grayscale-840 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--text-opacity));\n  }\n\n  .sm\\:text-grayscale-870 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--text-opacity));\n  }\n\n  .sm\\:text-grayscale-900 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--text-opacity));\n  }\n\n  .sm\\:text-grayscale-930 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--text-opacity));\n  }\n\n  .sm\\:text-primary {\n    --text-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--text-opacity));\n  }\n\n  .sm\\:text-background-main {\n    color: var(--main-background);\n  }\n\n  .sm\\:text-background-secondary {\n    color: var(--secondary-background);\n  }\n\n  .sm\\:text-foreground {\n    color: var(--foreground);\n  }\n\n  .sm\\:text-panels-bg {\n    color: var(--panels-background);\n  }\n\n  .sm\\:hover\\:text-transparent:hover {\n    color: transparent;\n  }\n\n  .sm\\:hover\\:text-current:hover {\n    color: currentColor;\n  }\n\n  .sm\\:hover\\:text-black:hover {\n    --text-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-white:hover {\n    --text-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-gray-100:hover {\n    --text-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-gray-200:hover {\n    --text-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-gray-300:hover {\n    --text-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-gray-400:hover {\n    --text-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-gray-500:hover {\n    --text-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-gray-600:hover {\n    --text-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-gray-700:hover {\n    --text-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-gray-800:hover {\n    --text-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-gray-900:hover {\n    --text-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-red-100:hover {\n    --text-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-red-200:hover {\n    --text-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-red-300:hover {\n    --text-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-red-400:hover {\n    --text-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-red-500:hover {\n    --text-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-red-600:hover {\n    --text-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-red-700:hover {\n    --text-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-red-800:hover {\n    --text-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-red-900:hover {\n    --text-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-orange-100:hover {\n    --text-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-orange-200:hover {\n    --text-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-orange-300:hover {\n    --text-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-orange-400:hover {\n    --text-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-orange-500:hover {\n    --text-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-orange-600:hover {\n    --text-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-orange-700:hover {\n    --text-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-orange-800:hover {\n    --text-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-orange-900:hover {\n    --text-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-yellow-100:hover {\n    --text-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-yellow-200:hover {\n    --text-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-yellow-300:hover {\n    --text-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-yellow-400:hover {\n    --text-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-yellow-500:hover {\n    --text-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-yellow-600:hover {\n    --text-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-yellow-700:hover {\n    --text-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-yellow-800:hover {\n    --text-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-yellow-900:hover {\n    --text-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-green-100:hover {\n    --text-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-green-200:hover {\n    --text-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-green-300:hover {\n    --text-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-green-400:hover {\n    --text-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-green-500:hover {\n    --text-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-green-600:hover {\n    --text-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-green-700:hover {\n    --text-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-green-800:hover {\n    --text-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-green-900:hover {\n    --text-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-teal-100:hover {\n    --text-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-teal-200:hover {\n    --text-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-teal-300:hover {\n    --text-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-teal-400:hover {\n    --text-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-teal-500:hover {\n    --text-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-teal-600:hover {\n    --text-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-teal-700:hover {\n    --text-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-teal-800:hover {\n    --text-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-teal-900:hover {\n    --text-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-blue-100:hover {\n    --text-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-blue-200:hover {\n    --text-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-blue-300:hover {\n    --text-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-blue-400:hover {\n    --text-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-blue-500:hover {\n    --text-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-blue-600:hover {\n    --text-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-blue-700:hover {\n    --text-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-blue-800:hover {\n    --text-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-blue-900:hover {\n    --text-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-indigo-100:hover {\n    --text-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-indigo-200:hover {\n    --text-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-indigo-300:hover {\n    --text-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-indigo-400:hover {\n    --text-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-indigo-500:hover {\n    --text-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-indigo-600:hover {\n    --text-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-indigo-700:hover {\n    --text-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-indigo-800:hover {\n    --text-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-indigo-900:hover {\n    --text-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-purple-100:hover {\n    --text-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-purple-200:hover {\n    --text-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-purple-300:hover {\n    --text-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-purple-400:hover {\n    --text-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-purple-500:hover {\n    --text-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-purple-600:hover {\n    --text-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-purple-700:hover {\n    --text-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-purple-800:hover {\n    --text-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-purple-900:hover {\n    --text-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-pink-100:hover {\n    --text-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-pink-200:hover {\n    --text-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-pink-300:hover {\n    --text-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-pink-400:hover {\n    --text-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-pink-500:hover {\n    --text-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-pink-600:hover {\n    --text-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-pink-700:hover {\n    --text-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-pink-800:hover {\n    --text-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-pink-900:hover {\n    --text-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-grayscale-80:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-grayscale-100:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-grayscale-200:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-grayscale-300:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-grayscale-400:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-grayscale-500:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-grayscale-600:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-grayscale-700:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-grayscale-800:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-grayscale-840:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-grayscale-870:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-grayscale-900:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-grayscale-930:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-primary:hover {\n    --text-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--text-opacity));\n  }\n\n  .sm\\:hover\\:text-background-main:hover {\n    color: var(--main-background);\n  }\n\n  .sm\\:hover\\:text-background-secondary:hover {\n    color: var(--secondary-background);\n  }\n\n  .sm\\:hover\\:text-foreground:hover {\n    color: var(--foreground);\n  }\n\n  .sm\\:hover\\:text-panels-bg:hover {\n    color: var(--panels-background);\n  }\n\n  .sm\\:focus\\:text-transparent:focus {\n    color: transparent;\n  }\n\n  .sm\\:focus\\:text-current:focus {\n    color: currentColor;\n  }\n\n  .sm\\:focus\\:text-black:focus {\n    --text-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-white:focus {\n    --text-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-gray-100:focus {\n    --text-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-gray-200:focus {\n    --text-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-gray-300:focus {\n    --text-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-gray-400:focus {\n    --text-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-gray-500:focus {\n    --text-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-gray-600:focus {\n    --text-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-gray-700:focus {\n    --text-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-gray-800:focus {\n    --text-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-gray-900:focus {\n    --text-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-red-100:focus {\n    --text-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-red-200:focus {\n    --text-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-red-300:focus {\n    --text-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-red-400:focus {\n    --text-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-red-500:focus {\n    --text-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-red-600:focus {\n    --text-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-red-700:focus {\n    --text-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-red-800:focus {\n    --text-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-red-900:focus {\n    --text-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-orange-100:focus {\n    --text-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-orange-200:focus {\n    --text-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-orange-300:focus {\n    --text-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-orange-400:focus {\n    --text-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-orange-500:focus {\n    --text-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-orange-600:focus {\n    --text-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-orange-700:focus {\n    --text-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-orange-800:focus {\n    --text-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-orange-900:focus {\n    --text-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-yellow-100:focus {\n    --text-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-yellow-200:focus {\n    --text-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-yellow-300:focus {\n    --text-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-yellow-400:focus {\n    --text-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-yellow-500:focus {\n    --text-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-yellow-600:focus {\n    --text-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-yellow-700:focus {\n    --text-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-yellow-800:focus {\n    --text-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-yellow-900:focus {\n    --text-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-green-100:focus {\n    --text-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-green-200:focus {\n    --text-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-green-300:focus {\n    --text-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-green-400:focus {\n    --text-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-green-500:focus {\n    --text-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-green-600:focus {\n    --text-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-green-700:focus {\n    --text-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-green-800:focus {\n    --text-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-green-900:focus {\n    --text-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-teal-100:focus {\n    --text-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-teal-200:focus {\n    --text-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-teal-300:focus {\n    --text-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-teal-400:focus {\n    --text-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-teal-500:focus {\n    --text-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-teal-600:focus {\n    --text-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-teal-700:focus {\n    --text-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-teal-800:focus {\n    --text-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-teal-900:focus {\n    --text-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-blue-100:focus {\n    --text-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-blue-200:focus {\n    --text-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-blue-300:focus {\n    --text-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-blue-400:focus {\n    --text-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-blue-500:focus {\n    --text-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-blue-600:focus {\n    --text-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-blue-700:focus {\n    --text-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-blue-800:focus {\n    --text-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-blue-900:focus {\n    --text-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-indigo-100:focus {\n    --text-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-indigo-200:focus {\n    --text-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-indigo-300:focus {\n    --text-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-indigo-400:focus {\n    --text-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-indigo-500:focus {\n    --text-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-indigo-600:focus {\n    --text-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-indigo-700:focus {\n    --text-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-indigo-800:focus {\n    --text-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-indigo-900:focus {\n    --text-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-purple-100:focus {\n    --text-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-purple-200:focus {\n    --text-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-purple-300:focus {\n    --text-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-purple-400:focus {\n    --text-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-purple-500:focus {\n    --text-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-purple-600:focus {\n    --text-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-purple-700:focus {\n    --text-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-purple-800:focus {\n    --text-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-purple-900:focus {\n    --text-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-pink-100:focus {\n    --text-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-pink-200:focus {\n    --text-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-pink-300:focus {\n    --text-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-pink-400:focus {\n    --text-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-pink-500:focus {\n    --text-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-pink-600:focus {\n    --text-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-pink-700:focus {\n    --text-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-pink-800:focus {\n    --text-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-pink-900:focus {\n    --text-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-grayscale-80:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-grayscale-100:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-grayscale-200:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-grayscale-300:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-grayscale-400:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-grayscale-500:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-grayscale-600:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-grayscale-700:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-grayscale-800:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-grayscale-840:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-grayscale-870:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-grayscale-900:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-grayscale-930:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-primary:focus {\n    --text-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--text-opacity));\n  }\n\n  .sm\\:focus\\:text-background-main:focus {\n    color: var(--main-background);\n  }\n\n  .sm\\:focus\\:text-background-secondary:focus {\n    color: var(--secondary-background);\n  }\n\n  .sm\\:focus\\:text-foreground:focus {\n    color: var(--foreground);\n  }\n\n  .sm\\:focus\\:text-panels-bg:focus {\n    color: var(--panels-background);\n  }\n\n  .group:hover .sm\\:group-hover\\:text-transparent {\n    color: transparent;\n  }\n\n  .group:hover .sm\\:group-hover\\:text-current {\n    color: currentColor;\n  }\n\n  .group:hover .sm\\:group-hover\\:text-black {\n    --text-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-white {\n    --text-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-gray-100 {\n    --text-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-gray-200 {\n    --text-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-gray-300 {\n    --text-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-gray-400 {\n    --text-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-gray-500 {\n    --text-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-gray-600 {\n    --text-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-gray-700 {\n    --text-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-gray-800 {\n    --text-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-gray-900 {\n    --text-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-red-100 {\n    --text-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-red-200 {\n    --text-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-red-300 {\n    --text-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-red-400 {\n    --text-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-red-500 {\n    --text-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-red-600 {\n    --text-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-red-700 {\n    --text-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-red-800 {\n    --text-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-red-900 {\n    --text-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-orange-100 {\n    --text-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-orange-200 {\n    --text-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-orange-300 {\n    --text-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-orange-400 {\n    --text-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-orange-500 {\n    --text-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-orange-600 {\n    --text-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-orange-700 {\n    --text-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-orange-800 {\n    --text-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-orange-900 {\n    --text-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-yellow-100 {\n    --text-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-yellow-200 {\n    --text-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-yellow-300 {\n    --text-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-yellow-400 {\n    --text-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-yellow-500 {\n    --text-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-yellow-600 {\n    --text-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-yellow-700 {\n    --text-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-yellow-800 {\n    --text-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-yellow-900 {\n    --text-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-green-100 {\n    --text-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-green-200 {\n    --text-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-green-300 {\n    --text-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-green-400 {\n    --text-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-green-500 {\n    --text-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-green-600 {\n    --text-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-green-700 {\n    --text-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-green-800 {\n    --text-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-green-900 {\n    --text-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-teal-100 {\n    --text-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-teal-200 {\n    --text-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-teal-300 {\n    --text-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-teal-400 {\n    --text-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-teal-500 {\n    --text-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-teal-600 {\n    --text-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-teal-700 {\n    --text-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-teal-800 {\n    --text-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-teal-900 {\n    --text-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-blue-100 {\n    --text-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-blue-200 {\n    --text-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-blue-300 {\n    --text-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-blue-400 {\n    --text-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-blue-500 {\n    --text-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-blue-600 {\n    --text-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-blue-700 {\n    --text-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-blue-800 {\n    --text-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-blue-900 {\n    --text-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-indigo-100 {\n    --text-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-indigo-200 {\n    --text-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-indigo-300 {\n    --text-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-indigo-400 {\n    --text-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-indigo-500 {\n    --text-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-indigo-600 {\n    --text-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-indigo-700 {\n    --text-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-indigo-800 {\n    --text-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-indigo-900 {\n    --text-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-purple-100 {\n    --text-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-purple-200 {\n    --text-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-purple-300 {\n    --text-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-purple-400 {\n    --text-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-purple-500 {\n    --text-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-purple-600 {\n    --text-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-purple-700 {\n    --text-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-purple-800 {\n    --text-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-purple-900 {\n    --text-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-pink-100 {\n    --text-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-pink-200 {\n    --text-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-pink-300 {\n    --text-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-pink-400 {\n    --text-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-pink-500 {\n    --text-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-pink-600 {\n    --text-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-pink-700 {\n    --text-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-pink-800 {\n    --text-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-pink-900 {\n    --text-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-grayscale-80 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-grayscale-100 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-grayscale-200 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-grayscale-300 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-grayscale-400 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-grayscale-500 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-grayscale-600 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-grayscale-700 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-grayscale-800 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-grayscale-840 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-grayscale-870 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-grayscale-900 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-grayscale-930 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-primary {\n    --text-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--text-opacity));\n  }\n\n  .group:hover .sm\\:group-hover\\:text-background-main {\n    color: var(--main-background);\n  }\n\n  .group:hover .sm\\:group-hover\\:text-background-secondary {\n    color: var(--secondary-background);\n  }\n\n  .group:hover .sm\\:group-hover\\:text-foreground {\n    color: var(--foreground);\n  }\n\n  .group:hover .sm\\:group-hover\\:text-panels-bg {\n    color: var(--panels-background);\n  }\n\n  .sm\\:text-opacity-0 {\n    --text-opacity: 0;\n  }\n\n  .sm\\:text-opacity-25 {\n    --text-opacity: 0.25;\n  }\n\n  .sm\\:text-opacity-50 {\n    --text-opacity: 0.5;\n  }\n\n  .sm\\:text-opacity-75 {\n    --text-opacity: 0.75;\n  }\n\n  .sm\\:text-opacity-100 {\n    --text-opacity: 1;\n  }\n\n  .sm\\:hover\\:text-opacity-0:hover {\n    --text-opacity: 0;\n  }\n\n  .sm\\:hover\\:text-opacity-25:hover {\n    --text-opacity: 0.25;\n  }\n\n  .sm\\:hover\\:text-opacity-50:hover {\n    --text-opacity: 0.5;\n  }\n\n  .sm\\:hover\\:text-opacity-75:hover {\n    --text-opacity: 0.75;\n  }\n\n  .sm\\:hover\\:text-opacity-100:hover {\n    --text-opacity: 1;\n  }\n\n  .sm\\:focus\\:text-opacity-0:focus {\n    --text-opacity: 0;\n  }\n\n  .sm\\:focus\\:text-opacity-25:focus {\n    --text-opacity: 0.25;\n  }\n\n  .sm\\:focus\\:text-opacity-50:focus {\n    --text-opacity: 0.5;\n  }\n\n  .sm\\:focus\\:text-opacity-75:focus {\n    --text-opacity: 0.75;\n  }\n\n  .sm\\:focus\\:text-opacity-100:focus {\n    --text-opacity: 1;\n  }\n\n  .sm\\:italic {\n    font-style: italic;\n  }\n\n  .sm\\:not-italic {\n    font-style: normal;\n  }\n\n  .sm\\:uppercase {\n    text-transform: uppercase;\n  }\n\n  .sm\\:lowercase {\n    text-transform: lowercase;\n  }\n\n  .sm\\:capitalize {\n    text-transform: capitalize;\n  }\n\n  .sm\\:normal-case {\n    text-transform: none;\n  }\n\n  .sm\\:underline {\n    text-decoration: underline;\n  }\n\n  .sm\\:line-through {\n    text-decoration: line-through;\n  }\n\n  .sm\\:no-underline {\n    text-decoration: none;\n  }\n\n  .sm\\:hover\\:underline:hover {\n    text-decoration: underline;\n  }\n\n  .sm\\:hover\\:line-through:hover {\n    text-decoration: line-through;\n  }\n\n  .sm\\:hover\\:no-underline:hover {\n    text-decoration: none;\n  }\n\n  .sm\\:focus\\:underline:focus {\n    text-decoration: underline;\n  }\n\n  .sm\\:focus\\:line-through:focus {\n    text-decoration: line-through;\n  }\n\n  .sm\\:focus\\:no-underline:focus {\n    text-decoration: none;\n  }\n\n  .sm\\:antialiased {\n    -webkit-font-smoothing: antialiased;\n    -moz-osx-font-smoothing: grayscale;\n  }\n\n  .sm\\:subpixel-antialiased {\n    -webkit-font-smoothing: auto;\n    -moz-osx-font-smoothing: auto;\n  }\n\n  .sm\\:ordinal, .sm\\:slashed-zero, .sm\\:lining-nums, .sm\\:oldstyle-nums, .sm\\:proportional-nums, .sm\\:tabular-nums, .sm\\:diagonal-fractions, .sm\\:stacked-fractions {\n    --font-variant-numeric-ordinal: var(--tailwind-empty,/*!*/ /*!*/);\n    --font-variant-numeric-slashed-zero: var(--tailwind-empty,/*!*/ /*!*/);\n    --font-variant-numeric-figure: var(--tailwind-empty,/*!*/ /*!*/);\n    --font-variant-numeric-spacing: var(--tailwind-empty,/*!*/ /*!*/);\n    --font-variant-numeric-fraction: var(--tailwind-empty,/*!*/ /*!*/);\n    font-variant-numeric: var(--font-variant-numeric-ordinal) var(--font-variant-numeric-slashed-zero) var(--font-variant-numeric-figure) var(--font-variant-numeric-spacing) var(--font-variant-numeric-fraction);\n  }\n\n  .sm\\:normal-nums {\n    font-variant-numeric: normal;\n  }\n\n  .sm\\:ordinal {\n    --font-variant-numeric-ordinal: ordinal;\n  }\n\n  .sm\\:slashed-zero {\n    --font-variant-numeric-slashed-zero: slashed-zero;\n  }\n\n  .sm\\:lining-nums {\n    --font-variant-numeric-figure: lining-nums;\n  }\n\n  .sm\\:oldstyle-nums {\n    --font-variant-numeric-figure: oldstyle-nums;\n  }\n\n  .sm\\:proportional-nums {\n    --font-variant-numeric-spacing: proportional-nums;\n  }\n\n  .sm\\:tabular-nums {\n    --font-variant-numeric-spacing: tabular-nums;\n  }\n\n  .sm\\:diagonal-fractions {\n    --font-variant-numeric-fraction: diagonal-fractions;\n  }\n\n  .sm\\:stacked-fractions {\n    --font-variant-numeric-fraction: stacked-fractions;\n  }\n\n  .sm\\:tracking-tighter {\n    letter-spacing: -0.05em;\n  }\n\n  .sm\\:tracking-tight {\n    letter-spacing: -0.025em;\n  }\n\n  .sm\\:tracking-normal {\n    letter-spacing: 0;\n  }\n\n  .sm\\:tracking-wide {\n    letter-spacing: 0.025em;\n  }\n\n  .sm\\:tracking-wider {\n    letter-spacing: 0.05em;\n  }\n\n  .sm\\:tracking-widest {\n    letter-spacing: 0.1em;\n  }\n\n  .sm\\:select-none {\n    -webkit-user-select: none;\n       -moz-user-select: none;\n        -ms-user-select: none;\n            user-select: none;\n  }\n\n  .sm\\:select-text {\n    -webkit-user-select: text;\n       -moz-user-select: text;\n        -ms-user-select: text;\n            user-select: text;\n  }\n\n  .sm\\:select-all {\n    -webkit-user-select: all;\n       -moz-user-select: all;\n        -ms-user-select: all;\n            user-select: all;\n  }\n\n  .sm\\:select-auto {\n    -webkit-user-select: auto;\n       -moz-user-select: auto;\n        -ms-user-select: auto;\n            user-select: auto;\n  }\n\n  .sm\\:align-baseline {\n    vertical-align: baseline;\n  }\n\n  .sm\\:align-top {\n    vertical-align: top;\n  }\n\n  .sm\\:align-middle {\n    vertical-align: middle;\n  }\n\n  .sm\\:align-bottom {\n    vertical-align: bottom;\n  }\n\n  .sm\\:align-text-top {\n    vertical-align: text-top;\n  }\n\n  .sm\\:align-text-bottom {\n    vertical-align: text-bottom;\n  }\n\n  .sm\\:visible {\n    visibility: visible;\n  }\n\n  .sm\\:invisible {\n    visibility: hidden;\n  }\n\n  .sm\\:whitespace-normal {\n    white-space: normal;\n  }\n\n  .sm\\:whitespace-no-wrap {\n    white-space: nowrap;\n  }\n\n  .sm\\:whitespace-pre {\n    white-space: pre;\n  }\n\n  .sm\\:whitespace-pre-line {\n    white-space: pre-line;\n  }\n\n  .sm\\:whitespace-pre-wrap {\n    white-space: pre-wrap;\n  }\n\n  .sm\\:break-normal {\n    word-wrap: normal;\n    overflow-wrap: normal;\n    word-break: normal;\n  }\n\n  .sm\\:break-words {\n    word-wrap: break-word;\n    overflow-wrap: break-word;\n  }\n\n  .sm\\:break-all {\n    word-break: break-all;\n  }\n\n  .sm\\:truncate {\n    overflow: hidden;\n    text-overflow: ellipsis;\n    white-space: nowrap;\n  }\n\n  .sm\\:w-0 {\n    width: 0;\n  }\n\n  .sm\\:w-1 {\n    width: 0.25rem;\n  }\n\n  .sm\\:w-2 {\n    width: 0.5rem;\n  }\n\n  .sm\\:w-3 {\n    width: 0.75rem;\n  }\n\n  .sm\\:w-4 {\n    width: 1rem;\n  }\n\n  .sm\\:w-5 {\n    width: 1.25rem;\n  }\n\n  .sm\\:w-6 {\n    width: 1.5rem;\n  }\n\n  .sm\\:w-8 {\n    width: 2rem;\n  }\n\n  .sm\\:w-10 {\n    width: 2.5rem;\n  }\n\n  .sm\\:w-12 {\n    width: 3rem;\n  }\n\n  .sm\\:w-16 {\n    width: 4rem;\n  }\n\n  .sm\\:w-20 {\n    width: 5rem;\n  }\n\n  .sm\\:w-24 {\n    width: 6rem;\n  }\n\n  .sm\\:w-32 {\n    width: 8rem;\n  }\n\n  .sm\\:w-40 {\n    width: 10rem;\n  }\n\n  .sm\\:w-48 {\n    width: 12rem;\n  }\n\n  .sm\\:w-56 {\n    width: 14rem;\n  }\n\n  .sm\\:w-64 {\n    width: 16rem;\n  }\n\n  .sm\\:w-auto {\n    width: auto;\n  }\n\n  .sm\\:w-px {\n    width: 1px;\n  }\n\n  .sm\\:w-1\\/2 {\n    width: 50%;\n  }\n\n  .sm\\:w-1\\/3 {\n    width: 33.333333%;\n  }\n\n  .sm\\:w-2\\/3 {\n    width: 66.666667%;\n  }\n\n  .sm\\:w-1\\/4 {\n    width: 25%;\n  }\n\n  .sm\\:w-2\\/4 {\n    width: 50%;\n  }\n\n  .sm\\:w-3\\/4 {\n    width: 75%;\n  }\n\n  .sm\\:w-1\\/5 {\n    width: 20%;\n  }\n\n  .sm\\:w-2\\/5 {\n    width: 40%;\n  }\n\n  .sm\\:w-3\\/5 {\n    width: 60%;\n  }\n\n  .sm\\:w-4\\/5 {\n    width: 80%;\n  }\n\n  .sm\\:w-1\\/6 {\n    width: 16.666667%;\n  }\n\n  .sm\\:w-2\\/6 {\n    width: 33.333333%;\n  }\n\n  .sm\\:w-3\\/6 {\n    width: 50%;\n  }\n\n  .sm\\:w-4\\/6 {\n    width: 66.666667%;\n  }\n\n  .sm\\:w-5\\/6 {\n    width: 83.333333%;\n  }\n\n  .sm\\:w-1\\/12 {\n    width: 8.333333%;\n  }\n\n  .sm\\:w-2\\/12 {\n    width: 16.666667%;\n  }\n\n  .sm\\:w-3\\/12 {\n    width: 25%;\n  }\n\n  .sm\\:w-4\\/12 {\n    width: 33.333333%;\n  }\n\n  .sm\\:w-5\\/12 {\n    width: 41.666667%;\n  }\n\n  .sm\\:w-6\\/12 {\n    width: 50%;\n  }\n\n  .sm\\:w-7\\/12 {\n    width: 58.333333%;\n  }\n\n  .sm\\:w-8\\/12 {\n    width: 66.666667%;\n  }\n\n  .sm\\:w-9\\/12 {\n    width: 75%;\n  }\n\n  .sm\\:w-10\\/12 {\n    width: 83.333333%;\n  }\n\n  .sm\\:w-11\\/12 {\n    width: 91.666667%;\n  }\n\n  .sm\\:w-full {\n    width: 100%;\n  }\n\n  .sm\\:w-screen {\n    width: 100vw;\n  }\n\n  .sm\\:z-0 {\n    z-index: 0;\n  }\n\n  .sm\\:z-10 {\n    z-index: 10;\n  }\n\n  .sm\\:z-20 {\n    z-index: 20;\n  }\n\n  .sm\\:z-30 {\n    z-index: 30;\n  }\n\n  .sm\\:z-40 {\n    z-index: 40;\n  }\n\n  .sm\\:z-50 {\n    z-index: 50;\n  }\n\n  .sm\\:z-auto {\n    z-index: auto;\n  }\n\n  .sm\\:gap-0 {\n    grid-gap: 0;\n    gap: 0;\n  }\n\n  .sm\\:gap-1 {\n    grid-gap: 0.25rem;\n    gap: 0.25rem;\n  }\n\n  .sm\\:gap-2 {\n    grid-gap: 0.5rem;\n    gap: 0.5rem;\n  }\n\n  .sm\\:gap-3 {\n    grid-gap: 0.75rem;\n    gap: 0.75rem;\n  }\n\n  .sm\\:gap-4 {\n    grid-gap: 1rem;\n    gap: 1rem;\n  }\n\n  .sm\\:gap-5 {\n    grid-gap: 1.25rem;\n    gap: 1.25rem;\n  }\n\n  .sm\\:gap-6 {\n    grid-gap: 1.5rem;\n    gap: 1.5rem;\n  }\n\n  .sm\\:gap-8 {\n    grid-gap: 2rem;\n    gap: 2rem;\n  }\n\n  .sm\\:gap-10 {\n    grid-gap: 2.5rem;\n    gap: 2.5rem;\n  }\n\n  .sm\\:gap-12 {\n    grid-gap: 3rem;\n    gap: 3rem;\n  }\n\n  .sm\\:gap-16 {\n    grid-gap: 4rem;\n    gap: 4rem;\n  }\n\n  .sm\\:gap-20 {\n    grid-gap: 5rem;\n    gap: 5rem;\n  }\n\n  .sm\\:gap-24 {\n    grid-gap: 6rem;\n    gap: 6rem;\n  }\n\n  .sm\\:gap-32 {\n    grid-gap: 8rem;\n    gap: 8rem;\n  }\n\n  .sm\\:gap-40 {\n    grid-gap: 10rem;\n    gap: 10rem;\n  }\n\n  .sm\\:gap-48 {\n    grid-gap: 12rem;\n    gap: 12rem;\n  }\n\n  .sm\\:gap-56 {\n    grid-gap: 14rem;\n    gap: 14rem;\n  }\n\n  .sm\\:gap-64 {\n    grid-gap: 16rem;\n    gap: 16rem;\n  }\n\n  .sm\\:gap-px {\n    grid-gap: 1px;\n    gap: 1px;\n  }\n\n  .sm\\:gap-x-0 {\n    grid-column-gap: 0;\n    -moz-column-gap: 0;\n         column-gap: 0;\n  }\n\n  .sm\\:gap-x-1 {\n    grid-column-gap: 0.25rem;\n    -moz-column-gap: 0.25rem;\n         column-gap: 0.25rem;\n  }\n\n  .sm\\:gap-x-2 {\n    grid-column-gap: 0.5rem;\n    -moz-column-gap: 0.5rem;\n         column-gap: 0.5rem;\n  }\n\n  .sm\\:gap-x-3 {\n    grid-column-gap: 0.75rem;\n    -moz-column-gap: 0.75rem;\n         column-gap: 0.75rem;\n  }\n\n  .sm\\:gap-x-4 {\n    grid-column-gap: 1rem;\n    -moz-column-gap: 1rem;\n         column-gap: 1rem;\n  }\n\n  .sm\\:gap-x-5 {\n    grid-column-gap: 1.25rem;\n    -moz-column-gap: 1.25rem;\n         column-gap: 1.25rem;\n  }\n\n  .sm\\:gap-x-6 {\n    grid-column-gap: 1.5rem;\n    -moz-column-gap: 1.5rem;\n         column-gap: 1.5rem;\n  }\n\n  .sm\\:gap-x-8 {\n    grid-column-gap: 2rem;\n    -moz-column-gap: 2rem;\n         column-gap: 2rem;\n  }\n\n  .sm\\:gap-x-10 {\n    grid-column-gap: 2.5rem;\n    -moz-column-gap: 2.5rem;\n         column-gap: 2.5rem;\n  }\n\n  .sm\\:gap-x-12 {\n    grid-column-gap: 3rem;\n    -moz-column-gap: 3rem;\n         column-gap: 3rem;\n  }\n\n  .sm\\:gap-x-16 {\n    grid-column-gap: 4rem;\n    -moz-column-gap: 4rem;\n         column-gap: 4rem;\n  }\n\n  .sm\\:gap-x-20 {\n    grid-column-gap: 5rem;\n    -moz-column-gap: 5rem;\n         column-gap: 5rem;\n  }\n\n  .sm\\:gap-x-24 {\n    grid-column-gap: 6rem;\n    -moz-column-gap: 6rem;\n         column-gap: 6rem;\n  }\n\n  .sm\\:gap-x-32 {\n    grid-column-gap: 8rem;\n    -moz-column-gap: 8rem;\n         column-gap: 8rem;\n  }\n\n  .sm\\:gap-x-40 {\n    grid-column-gap: 10rem;\n    -moz-column-gap: 10rem;\n         column-gap: 10rem;\n  }\n\n  .sm\\:gap-x-48 {\n    grid-column-gap: 12rem;\n    -moz-column-gap: 12rem;\n         column-gap: 12rem;\n  }\n\n  .sm\\:gap-x-56 {\n    grid-column-gap: 14rem;\n    -moz-column-gap: 14rem;\n         column-gap: 14rem;\n  }\n\n  .sm\\:gap-x-64 {\n    grid-column-gap: 16rem;\n    -moz-column-gap: 16rem;\n         column-gap: 16rem;\n  }\n\n  .sm\\:gap-x-px {\n    grid-column-gap: 1px;\n    -moz-column-gap: 1px;\n         column-gap: 1px;\n  }\n\n  .sm\\:gap-y-0 {\n    grid-row-gap: 0;\n    row-gap: 0;\n  }\n\n  .sm\\:gap-y-1 {\n    grid-row-gap: 0.25rem;\n    row-gap: 0.25rem;\n  }\n\n  .sm\\:gap-y-2 {\n    grid-row-gap: 0.5rem;\n    row-gap: 0.5rem;\n  }\n\n  .sm\\:gap-y-3 {\n    grid-row-gap: 0.75rem;\n    row-gap: 0.75rem;\n  }\n\n  .sm\\:gap-y-4 {\n    grid-row-gap: 1rem;\n    row-gap: 1rem;\n  }\n\n  .sm\\:gap-y-5 {\n    grid-row-gap: 1.25rem;\n    row-gap: 1.25rem;\n  }\n\n  .sm\\:gap-y-6 {\n    grid-row-gap: 1.5rem;\n    row-gap: 1.5rem;\n  }\n\n  .sm\\:gap-y-8 {\n    grid-row-gap: 2rem;\n    row-gap: 2rem;\n  }\n\n  .sm\\:gap-y-10 {\n    grid-row-gap: 2.5rem;\n    row-gap: 2.5rem;\n  }\n\n  .sm\\:gap-y-12 {\n    grid-row-gap: 3rem;\n    row-gap: 3rem;\n  }\n\n  .sm\\:gap-y-16 {\n    grid-row-gap: 4rem;\n    row-gap: 4rem;\n  }\n\n  .sm\\:gap-y-20 {\n    grid-row-gap: 5rem;\n    row-gap: 5rem;\n  }\n\n  .sm\\:gap-y-24 {\n    grid-row-gap: 6rem;\n    row-gap: 6rem;\n  }\n\n  .sm\\:gap-y-32 {\n    grid-row-gap: 8rem;\n    row-gap: 8rem;\n  }\n\n  .sm\\:gap-y-40 {\n    grid-row-gap: 10rem;\n    row-gap: 10rem;\n  }\n\n  .sm\\:gap-y-48 {\n    grid-row-gap: 12rem;\n    row-gap: 12rem;\n  }\n\n  .sm\\:gap-y-56 {\n    grid-row-gap: 14rem;\n    row-gap: 14rem;\n  }\n\n  .sm\\:gap-y-64 {\n    grid-row-gap: 16rem;\n    row-gap: 16rem;\n  }\n\n  .sm\\:gap-y-px {\n    grid-row-gap: 1px;\n    row-gap: 1px;\n  }\n\n  .sm\\:grid-flow-row {\n    grid-auto-flow: row;\n  }\n\n  .sm\\:grid-flow-col {\n    grid-auto-flow: column;\n  }\n\n  .sm\\:grid-flow-row-dense {\n    grid-auto-flow: row dense;\n  }\n\n  .sm\\:grid-flow-col-dense {\n    grid-auto-flow: column dense;\n  }\n\n  .sm\\:grid-cols-1 {\n    grid-template-columns: repeat(1, minmax(0, 1fr));\n  }\n\n  .sm\\:grid-cols-2 {\n    grid-template-columns: repeat(2, minmax(0, 1fr));\n  }\n\n  .sm\\:grid-cols-3 {\n    grid-template-columns: repeat(3, minmax(0, 1fr));\n  }\n\n  .sm\\:grid-cols-4 {\n    grid-template-columns: repeat(4, minmax(0, 1fr));\n  }\n\n  .sm\\:grid-cols-5 {\n    grid-template-columns: repeat(5, minmax(0, 1fr));\n  }\n\n  .sm\\:grid-cols-6 {\n    grid-template-columns: repeat(6, minmax(0, 1fr));\n  }\n\n  .sm\\:grid-cols-7 {\n    grid-template-columns: repeat(7, minmax(0, 1fr));\n  }\n\n  .sm\\:grid-cols-8 {\n    grid-template-columns: repeat(8, minmax(0, 1fr));\n  }\n\n  .sm\\:grid-cols-9 {\n    grid-template-columns: repeat(9, minmax(0, 1fr));\n  }\n\n  .sm\\:grid-cols-10 {\n    grid-template-columns: repeat(10, minmax(0, 1fr));\n  }\n\n  .sm\\:grid-cols-11 {\n    grid-template-columns: repeat(11, minmax(0, 1fr));\n  }\n\n  .sm\\:grid-cols-12 {\n    grid-template-columns: repeat(12, minmax(0, 1fr));\n  }\n\n  .sm\\:grid-cols-none {\n    grid-template-columns: none;\n  }\n\n  .sm\\:auto-cols-auto {\n    grid-auto-columns: auto;\n  }\n\n  .sm\\:auto-cols-min {\n    grid-auto-columns: -webkit-min-content;\n    grid-auto-columns: min-content;\n  }\n\n  .sm\\:auto-cols-max {\n    grid-auto-columns: -webkit-max-content;\n    grid-auto-columns: max-content;\n  }\n\n  .sm\\:auto-cols-fr {\n    grid-auto-columns: minmax(0, 1fr);\n  }\n\n  .sm\\:col-auto {\n    grid-column: auto;\n  }\n\n  .sm\\:col-span-1 {\n    grid-column: span 1 / span 1;\n  }\n\n  .sm\\:col-span-2 {\n    grid-column: span 2 / span 2;\n  }\n\n  .sm\\:col-span-3 {\n    grid-column: span 3 / span 3;\n  }\n\n  .sm\\:col-span-4 {\n    grid-column: span 4 / span 4;\n  }\n\n  .sm\\:col-span-5 {\n    grid-column: span 5 / span 5;\n  }\n\n  .sm\\:col-span-6 {\n    grid-column: span 6 / span 6;\n  }\n\n  .sm\\:col-span-7 {\n    grid-column: span 7 / span 7;\n  }\n\n  .sm\\:col-span-8 {\n    grid-column: span 8 / span 8;\n  }\n\n  .sm\\:col-span-9 {\n    grid-column: span 9 / span 9;\n  }\n\n  .sm\\:col-span-10 {\n    grid-column: span 10 / span 10;\n  }\n\n  .sm\\:col-span-11 {\n    grid-column: span 11 / span 11;\n  }\n\n  .sm\\:col-span-12 {\n    grid-column: span 12 / span 12;\n  }\n\n  .sm\\:col-span-full {\n    grid-column: 1 / -1;\n  }\n\n  .sm\\:col-start-1 {\n    grid-column-start: 1;\n  }\n\n  .sm\\:col-start-2 {\n    grid-column-start: 2;\n  }\n\n  .sm\\:col-start-3 {\n    grid-column-start: 3;\n  }\n\n  .sm\\:col-start-4 {\n    grid-column-start: 4;\n  }\n\n  .sm\\:col-start-5 {\n    grid-column-start: 5;\n  }\n\n  .sm\\:col-start-6 {\n    grid-column-start: 6;\n  }\n\n  .sm\\:col-start-7 {\n    grid-column-start: 7;\n  }\n\n  .sm\\:col-start-8 {\n    grid-column-start: 8;\n  }\n\n  .sm\\:col-start-9 {\n    grid-column-start: 9;\n  }\n\n  .sm\\:col-start-10 {\n    grid-column-start: 10;\n  }\n\n  .sm\\:col-start-11 {\n    grid-column-start: 11;\n  }\n\n  .sm\\:col-start-12 {\n    grid-column-start: 12;\n  }\n\n  .sm\\:col-start-13 {\n    grid-column-start: 13;\n  }\n\n  .sm\\:col-start-auto {\n    grid-column-start: auto;\n  }\n\n  .sm\\:col-end-1 {\n    grid-column-end: 1;\n  }\n\n  .sm\\:col-end-2 {\n    grid-column-end: 2;\n  }\n\n  .sm\\:col-end-3 {\n    grid-column-end: 3;\n  }\n\n  .sm\\:col-end-4 {\n    grid-column-end: 4;\n  }\n\n  .sm\\:col-end-5 {\n    grid-column-end: 5;\n  }\n\n  .sm\\:col-end-6 {\n    grid-column-end: 6;\n  }\n\n  .sm\\:col-end-7 {\n    grid-column-end: 7;\n  }\n\n  .sm\\:col-end-8 {\n    grid-column-end: 8;\n  }\n\n  .sm\\:col-end-9 {\n    grid-column-end: 9;\n  }\n\n  .sm\\:col-end-10 {\n    grid-column-end: 10;\n  }\n\n  .sm\\:col-end-11 {\n    grid-column-end: 11;\n  }\n\n  .sm\\:col-end-12 {\n    grid-column-end: 12;\n  }\n\n  .sm\\:col-end-13 {\n    grid-column-end: 13;\n  }\n\n  .sm\\:col-end-auto {\n    grid-column-end: auto;\n  }\n\n  .sm\\:grid-rows-1 {\n    grid-template-rows: repeat(1, minmax(0, 1fr));\n  }\n\n  .sm\\:grid-rows-2 {\n    grid-template-rows: repeat(2, minmax(0, 1fr));\n  }\n\n  .sm\\:grid-rows-3 {\n    grid-template-rows: repeat(3, minmax(0, 1fr));\n  }\n\n  .sm\\:grid-rows-4 {\n    grid-template-rows: repeat(4, minmax(0, 1fr));\n  }\n\n  .sm\\:grid-rows-5 {\n    grid-template-rows: repeat(5, minmax(0, 1fr));\n  }\n\n  .sm\\:grid-rows-6 {\n    grid-template-rows: repeat(6, minmax(0, 1fr));\n  }\n\n  .sm\\:grid-rows-none {\n    grid-template-rows: none;\n  }\n\n  .sm\\:auto-rows-auto {\n    grid-auto-rows: auto;\n  }\n\n  .sm\\:auto-rows-min {\n    grid-auto-rows: -webkit-min-content;\n    grid-auto-rows: min-content;\n  }\n\n  .sm\\:auto-rows-max {\n    grid-auto-rows: -webkit-max-content;\n    grid-auto-rows: max-content;\n  }\n\n  .sm\\:auto-rows-fr {\n    grid-auto-rows: minmax(0, 1fr);\n  }\n\n  .sm\\:row-auto {\n    grid-row: auto;\n  }\n\n  .sm\\:row-span-1 {\n    grid-row: span 1 / span 1;\n  }\n\n  .sm\\:row-span-2 {\n    grid-row: span 2 / span 2;\n  }\n\n  .sm\\:row-span-3 {\n    grid-row: span 3 / span 3;\n  }\n\n  .sm\\:row-span-4 {\n    grid-row: span 4 / span 4;\n  }\n\n  .sm\\:row-span-5 {\n    grid-row: span 5 / span 5;\n  }\n\n  .sm\\:row-span-6 {\n    grid-row: span 6 / span 6;\n  }\n\n  .sm\\:row-span-full {\n    grid-row: 1 / -1;\n  }\n\n  .sm\\:row-start-1 {\n    grid-row-start: 1;\n  }\n\n  .sm\\:row-start-2 {\n    grid-row-start: 2;\n  }\n\n  .sm\\:row-start-3 {\n    grid-row-start: 3;\n  }\n\n  .sm\\:row-start-4 {\n    grid-row-start: 4;\n  }\n\n  .sm\\:row-start-5 {\n    grid-row-start: 5;\n  }\n\n  .sm\\:row-start-6 {\n    grid-row-start: 6;\n  }\n\n  .sm\\:row-start-7 {\n    grid-row-start: 7;\n  }\n\n  .sm\\:row-start-auto {\n    grid-row-start: auto;\n  }\n\n  .sm\\:row-end-1 {\n    grid-row-end: 1;\n  }\n\n  .sm\\:row-end-2 {\n    grid-row-end: 2;\n  }\n\n  .sm\\:row-end-3 {\n    grid-row-end: 3;\n  }\n\n  .sm\\:row-end-4 {\n    grid-row-end: 4;\n  }\n\n  .sm\\:row-end-5 {\n    grid-row-end: 5;\n  }\n\n  .sm\\:row-end-6 {\n    grid-row-end: 6;\n  }\n\n  .sm\\:row-end-7 {\n    grid-row-end: 7;\n  }\n\n  .sm\\:row-end-auto {\n    grid-row-end: auto;\n  }\n\n  .sm\\:transform {\n    --transform-translate-x: 0;\n    --transform-translate-y: 0;\n    --transform-rotate: 0;\n    --transform-skew-x: 0;\n    --transform-skew-y: 0;\n    --transform-scale-x: 1;\n    --transform-scale-y: 1;\n    transform: translateX(var(--transform-translate-x)) translateY(var(--transform-translate-y)) rotate(var(--transform-rotate)) skewX(var(--transform-skew-x)) skewY(var(--transform-skew-y)) scaleX(var(--transform-scale-x)) scaleY(var(--transform-scale-y));\n  }\n\n  .sm\\:transform-none {\n    transform: none;\n  }\n\n  .sm\\:origin-center {\n    transform-origin: center;\n  }\n\n  .sm\\:origin-top {\n    transform-origin: top;\n  }\n\n  .sm\\:origin-top-right {\n    transform-origin: top right;\n  }\n\n  .sm\\:origin-right {\n    transform-origin: right;\n  }\n\n  .sm\\:origin-bottom-right {\n    transform-origin: bottom right;\n  }\n\n  .sm\\:origin-bottom {\n    transform-origin: bottom;\n  }\n\n  .sm\\:origin-bottom-left {\n    transform-origin: bottom left;\n  }\n\n  .sm\\:origin-left {\n    transform-origin: left;\n  }\n\n  .sm\\:origin-top-left {\n    transform-origin: top left;\n  }\n\n  .sm\\:scale-0 {\n    --transform-scale-x: 0;\n    --transform-scale-y: 0;\n  }\n\n  .sm\\:scale-50 {\n    --transform-scale-x: .5;\n    --transform-scale-y: .5;\n  }\n\n  .sm\\:scale-75 {\n    --transform-scale-x: .75;\n    --transform-scale-y: .75;\n  }\n\n  .sm\\:scale-90 {\n    --transform-scale-x: .9;\n    --transform-scale-y: .9;\n  }\n\n  .sm\\:scale-95 {\n    --transform-scale-x: .95;\n    --transform-scale-y: .95;\n  }\n\n  .sm\\:scale-100 {\n    --transform-scale-x: 1;\n    --transform-scale-y: 1;\n  }\n\n  .sm\\:scale-105 {\n    --transform-scale-x: 1.05;\n    --transform-scale-y: 1.05;\n  }\n\n  .sm\\:scale-110 {\n    --transform-scale-x: 1.1;\n    --transform-scale-y: 1.1;\n  }\n\n  .sm\\:scale-125 {\n    --transform-scale-x: 1.25;\n    --transform-scale-y: 1.25;\n  }\n\n  .sm\\:scale-150 {\n    --transform-scale-x: 1.5;\n    --transform-scale-y: 1.5;\n  }\n\n  .sm\\:scale-x-0 {\n    --transform-scale-x: 0;\n  }\n\n  .sm\\:scale-x-50 {\n    --transform-scale-x: .5;\n  }\n\n  .sm\\:scale-x-75 {\n    --transform-scale-x: .75;\n  }\n\n  .sm\\:scale-x-90 {\n    --transform-scale-x: .9;\n  }\n\n  .sm\\:scale-x-95 {\n    --transform-scale-x: .95;\n  }\n\n  .sm\\:scale-x-100 {\n    --transform-scale-x: 1;\n  }\n\n  .sm\\:scale-x-105 {\n    --transform-scale-x: 1.05;\n  }\n\n  .sm\\:scale-x-110 {\n    --transform-scale-x: 1.1;\n  }\n\n  .sm\\:scale-x-125 {\n    --transform-scale-x: 1.25;\n  }\n\n  .sm\\:scale-x-150 {\n    --transform-scale-x: 1.5;\n  }\n\n  .sm\\:scale-y-0 {\n    --transform-scale-y: 0;\n  }\n\n  .sm\\:scale-y-50 {\n    --transform-scale-y: .5;\n  }\n\n  .sm\\:scale-y-75 {\n    --transform-scale-y: .75;\n  }\n\n  .sm\\:scale-y-90 {\n    --transform-scale-y: .9;\n  }\n\n  .sm\\:scale-y-95 {\n    --transform-scale-y: .95;\n  }\n\n  .sm\\:scale-y-100 {\n    --transform-scale-y: 1;\n  }\n\n  .sm\\:scale-y-105 {\n    --transform-scale-y: 1.05;\n  }\n\n  .sm\\:scale-y-110 {\n    --transform-scale-y: 1.1;\n  }\n\n  .sm\\:scale-y-125 {\n    --transform-scale-y: 1.25;\n  }\n\n  .sm\\:scale-y-150 {\n    --transform-scale-y: 1.5;\n  }\n\n  .sm\\:hover\\:scale-0:hover {\n    --transform-scale-x: 0;\n    --transform-scale-y: 0;\n  }\n\n  .sm\\:hover\\:scale-50:hover {\n    --transform-scale-x: .5;\n    --transform-scale-y: .5;\n  }\n\n  .sm\\:hover\\:scale-75:hover {\n    --transform-scale-x: .75;\n    --transform-scale-y: .75;\n  }\n\n  .sm\\:hover\\:scale-90:hover {\n    --transform-scale-x: .9;\n    --transform-scale-y: .9;\n  }\n\n  .sm\\:hover\\:scale-95:hover {\n    --transform-scale-x: .95;\n    --transform-scale-y: .95;\n  }\n\n  .sm\\:hover\\:scale-100:hover {\n    --transform-scale-x: 1;\n    --transform-scale-y: 1;\n  }\n\n  .sm\\:hover\\:scale-105:hover {\n    --transform-scale-x: 1.05;\n    --transform-scale-y: 1.05;\n  }\n\n  .sm\\:hover\\:scale-110:hover {\n    --transform-scale-x: 1.1;\n    --transform-scale-y: 1.1;\n  }\n\n  .sm\\:hover\\:scale-125:hover {\n    --transform-scale-x: 1.25;\n    --transform-scale-y: 1.25;\n  }\n\n  .sm\\:hover\\:scale-150:hover {\n    --transform-scale-x: 1.5;\n    --transform-scale-y: 1.5;\n  }\n\n  .sm\\:hover\\:scale-x-0:hover {\n    --transform-scale-x: 0;\n  }\n\n  .sm\\:hover\\:scale-x-50:hover {\n    --transform-scale-x: .5;\n  }\n\n  .sm\\:hover\\:scale-x-75:hover {\n    --transform-scale-x: .75;\n  }\n\n  .sm\\:hover\\:scale-x-90:hover {\n    --transform-scale-x: .9;\n  }\n\n  .sm\\:hover\\:scale-x-95:hover {\n    --transform-scale-x: .95;\n  }\n\n  .sm\\:hover\\:scale-x-100:hover {\n    --transform-scale-x: 1;\n  }\n\n  .sm\\:hover\\:scale-x-105:hover {\n    --transform-scale-x: 1.05;\n  }\n\n  .sm\\:hover\\:scale-x-110:hover {\n    --transform-scale-x: 1.1;\n  }\n\n  .sm\\:hover\\:scale-x-125:hover {\n    --transform-scale-x: 1.25;\n  }\n\n  .sm\\:hover\\:scale-x-150:hover {\n    --transform-scale-x: 1.5;\n  }\n\n  .sm\\:hover\\:scale-y-0:hover {\n    --transform-scale-y: 0;\n  }\n\n  .sm\\:hover\\:scale-y-50:hover {\n    --transform-scale-y: .5;\n  }\n\n  .sm\\:hover\\:scale-y-75:hover {\n    --transform-scale-y: .75;\n  }\n\n  .sm\\:hover\\:scale-y-90:hover {\n    --transform-scale-y: .9;\n  }\n\n  .sm\\:hover\\:scale-y-95:hover {\n    --transform-scale-y: .95;\n  }\n\n  .sm\\:hover\\:scale-y-100:hover {\n    --transform-scale-y: 1;\n  }\n\n  .sm\\:hover\\:scale-y-105:hover {\n    --transform-scale-y: 1.05;\n  }\n\n  .sm\\:hover\\:scale-y-110:hover {\n    --transform-scale-y: 1.1;\n  }\n\n  .sm\\:hover\\:scale-y-125:hover {\n    --transform-scale-y: 1.25;\n  }\n\n  .sm\\:hover\\:scale-y-150:hover {\n    --transform-scale-y: 1.5;\n  }\n\n  .sm\\:focus\\:scale-0:focus {\n    --transform-scale-x: 0;\n    --transform-scale-y: 0;\n  }\n\n  .sm\\:focus\\:scale-50:focus {\n    --transform-scale-x: .5;\n    --transform-scale-y: .5;\n  }\n\n  .sm\\:focus\\:scale-75:focus {\n    --transform-scale-x: .75;\n    --transform-scale-y: .75;\n  }\n\n  .sm\\:focus\\:scale-90:focus {\n    --transform-scale-x: .9;\n    --transform-scale-y: .9;\n  }\n\n  .sm\\:focus\\:scale-95:focus {\n    --transform-scale-x: .95;\n    --transform-scale-y: .95;\n  }\n\n  .sm\\:focus\\:scale-100:focus {\n    --transform-scale-x: 1;\n    --transform-scale-y: 1;\n  }\n\n  .sm\\:focus\\:scale-105:focus {\n    --transform-scale-x: 1.05;\n    --transform-scale-y: 1.05;\n  }\n\n  .sm\\:focus\\:scale-110:focus {\n    --transform-scale-x: 1.1;\n    --transform-scale-y: 1.1;\n  }\n\n  .sm\\:focus\\:scale-125:focus {\n    --transform-scale-x: 1.25;\n    --transform-scale-y: 1.25;\n  }\n\n  .sm\\:focus\\:scale-150:focus {\n    --transform-scale-x: 1.5;\n    --transform-scale-y: 1.5;\n  }\n\n  .sm\\:focus\\:scale-x-0:focus {\n    --transform-scale-x: 0;\n  }\n\n  .sm\\:focus\\:scale-x-50:focus {\n    --transform-scale-x: .5;\n  }\n\n  .sm\\:focus\\:scale-x-75:focus {\n    --transform-scale-x: .75;\n  }\n\n  .sm\\:focus\\:scale-x-90:focus {\n    --transform-scale-x: .9;\n  }\n\n  .sm\\:focus\\:scale-x-95:focus {\n    --transform-scale-x: .95;\n  }\n\n  .sm\\:focus\\:scale-x-100:focus {\n    --transform-scale-x: 1;\n  }\n\n  .sm\\:focus\\:scale-x-105:focus {\n    --transform-scale-x: 1.05;\n  }\n\n  .sm\\:focus\\:scale-x-110:focus {\n    --transform-scale-x: 1.1;\n  }\n\n  .sm\\:focus\\:scale-x-125:focus {\n    --transform-scale-x: 1.25;\n  }\n\n  .sm\\:focus\\:scale-x-150:focus {\n    --transform-scale-x: 1.5;\n  }\n\n  .sm\\:focus\\:scale-y-0:focus {\n    --transform-scale-y: 0;\n  }\n\n  .sm\\:focus\\:scale-y-50:focus {\n    --transform-scale-y: .5;\n  }\n\n  .sm\\:focus\\:scale-y-75:focus {\n    --transform-scale-y: .75;\n  }\n\n  .sm\\:focus\\:scale-y-90:focus {\n    --transform-scale-y: .9;\n  }\n\n  .sm\\:focus\\:scale-y-95:focus {\n    --transform-scale-y: .95;\n  }\n\n  .sm\\:focus\\:scale-y-100:focus {\n    --transform-scale-y: 1;\n  }\n\n  .sm\\:focus\\:scale-y-105:focus {\n    --transform-scale-y: 1.05;\n  }\n\n  .sm\\:focus\\:scale-y-110:focus {\n    --transform-scale-y: 1.1;\n  }\n\n  .sm\\:focus\\:scale-y-125:focus {\n    --transform-scale-y: 1.25;\n  }\n\n  .sm\\:focus\\:scale-y-150:focus {\n    --transform-scale-y: 1.5;\n  }\n\n  .sm\\:rotate-0 {\n    --transform-rotate: 0;\n  }\n\n  .sm\\:rotate-1 {\n    --transform-rotate: 1deg;\n  }\n\n  .sm\\:rotate-2 {\n    --transform-rotate: 2deg;\n  }\n\n  .sm\\:rotate-3 {\n    --transform-rotate: 3deg;\n  }\n\n  .sm\\:rotate-6 {\n    --transform-rotate: 6deg;\n  }\n\n  .sm\\:rotate-12 {\n    --transform-rotate: 12deg;\n  }\n\n  .sm\\:rotate-45 {\n    --transform-rotate: 45deg;\n  }\n\n  .sm\\:rotate-90 {\n    --transform-rotate: 90deg;\n  }\n\n  .sm\\:rotate-180 {\n    --transform-rotate: 180deg;\n  }\n\n  .sm\\:-rotate-180 {\n    --transform-rotate: -180deg;\n  }\n\n  .sm\\:-rotate-90 {\n    --transform-rotate: -90deg;\n  }\n\n  .sm\\:-rotate-45 {\n    --transform-rotate: -45deg;\n  }\n\n  .sm\\:-rotate-12 {\n    --transform-rotate: -12deg;\n  }\n\n  .sm\\:-rotate-6 {\n    --transform-rotate: -6deg;\n  }\n\n  .sm\\:-rotate-3 {\n    --transform-rotate: -3deg;\n  }\n\n  .sm\\:-rotate-2 {\n    --transform-rotate: -2deg;\n  }\n\n  .sm\\:-rotate-1 {\n    --transform-rotate: -1deg;\n  }\n\n  .sm\\:hover\\:rotate-0:hover {\n    --transform-rotate: 0;\n  }\n\n  .sm\\:hover\\:rotate-1:hover {\n    --transform-rotate: 1deg;\n  }\n\n  .sm\\:hover\\:rotate-2:hover {\n    --transform-rotate: 2deg;\n  }\n\n  .sm\\:hover\\:rotate-3:hover {\n    --transform-rotate: 3deg;\n  }\n\n  .sm\\:hover\\:rotate-6:hover {\n    --transform-rotate: 6deg;\n  }\n\n  .sm\\:hover\\:rotate-12:hover {\n    --transform-rotate: 12deg;\n  }\n\n  .sm\\:hover\\:rotate-45:hover {\n    --transform-rotate: 45deg;\n  }\n\n  .sm\\:hover\\:rotate-90:hover {\n    --transform-rotate: 90deg;\n  }\n\n  .sm\\:hover\\:rotate-180:hover {\n    --transform-rotate: 180deg;\n  }\n\n  .sm\\:hover\\:-rotate-180:hover {\n    --transform-rotate: -180deg;\n  }\n\n  .sm\\:hover\\:-rotate-90:hover {\n    --transform-rotate: -90deg;\n  }\n\n  .sm\\:hover\\:-rotate-45:hover {\n    --transform-rotate: -45deg;\n  }\n\n  .sm\\:hover\\:-rotate-12:hover {\n    --transform-rotate: -12deg;\n  }\n\n  .sm\\:hover\\:-rotate-6:hover {\n    --transform-rotate: -6deg;\n  }\n\n  .sm\\:hover\\:-rotate-3:hover {\n    --transform-rotate: -3deg;\n  }\n\n  .sm\\:hover\\:-rotate-2:hover {\n    --transform-rotate: -2deg;\n  }\n\n  .sm\\:hover\\:-rotate-1:hover {\n    --transform-rotate: -1deg;\n  }\n\n  .sm\\:focus\\:rotate-0:focus {\n    --transform-rotate: 0;\n  }\n\n  .sm\\:focus\\:rotate-1:focus {\n    --transform-rotate: 1deg;\n  }\n\n  .sm\\:focus\\:rotate-2:focus {\n    --transform-rotate: 2deg;\n  }\n\n  .sm\\:focus\\:rotate-3:focus {\n    --transform-rotate: 3deg;\n  }\n\n  .sm\\:focus\\:rotate-6:focus {\n    --transform-rotate: 6deg;\n  }\n\n  .sm\\:focus\\:rotate-12:focus {\n    --transform-rotate: 12deg;\n  }\n\n  .sm\\:focus\\:rotate-45:focus {\n    --transform-rotate: 45deg;\n  }\n\n  .sm\\:focus\\:rotate-90:focus {\n    --transform-rotate: 90deg;\n  }\n\n  .sm\\:focus\\:rotate-180:focus {\n    --transform-rotate: 180deg;\n  }\n\n  .sm\\:focus\\:-rotate-180:focus {\n    --transform-rotate: -180deg;\n  }\n\n  .sm\\:focus\\:-rotate-90:focus {\n    --transform-rotate: -90deg;\n  }\n\n  .sm\\:focus\\:-rotate-45:focus {\n    --transform-rotate: -45deg;\n  }\n\n  .sm\\:focus\\:-rotate-12:focus {\n    --transform-rotate: -12deg;\n  }\n\n  .sm\\:focus\\:-rotate-6:focus {\n    --transform-rotate: -6deg;\n  }\n\n  .sm\\:focus\\:-rotate-3:focus {\n    --transform-rotate: -3deg;\n  }\n\n  .sm\\:focus\\:-rotate-2:focus {\n    --transform-rotate: -2deg;\n  }\n\n  .sm\\:focus\\:-rotate-1:focus {\n    --transform-rotate: -1deg;\n  }\n\n  .sm\\:translate-x-0 {\n    --transform-translate-x: 0;\n  }\n\n  .sm\\:translate-x-1 {\n    --transform-translate-x: 0.25rem;\n  }\n\n  .sm\\:translate-x-2 {\n    --transform-translate-x: 0.5rem;\n  }\n\n  .sm\\:translate-x-3 {\n    --transform-translate-x: 0.75rem;\n  }\n\n  .sm\\:translate-x-4 {\n    --transform-translate-x: 1rem;\n  }\n\n  .sm\\:translate-x-5 {\n    --transform-translate-x: 1.25rem;\n  }\n\n  .sm\\:translate-x-6 {\n    --transform-translate-x: 1.5rem;\n  }\n\n  .sm\\:translate-x-8 {\n    --transform-translate-x: 2rem;\n  }\n\n  .sm\\:translate-x-10 {\n    --transform-translate-x: 2.5rem;\n  }\n\n  .sm\\:translate-x-12 {\n    --transform-translate-x: 3rem;\n  }\n\n  .sm\\:translate-x-16 {\n    --transform-translate-x: 4rem;\n  }\n\n  .sm\\:translate-x-20 {\n    --transform-translate-x: 5rem;\n  }\n\n  .sm\\:translate-x-24 {\n    --transform-translate-x: 6rem;\n  }\n\n  .sm\\:translate-x-32 {\n    --transform-translate-x: 8rem;\n  }\n\n  .sm\\:translate-x-40 {\n    --transform-translate-x: 10rem;\n  }\n\n  .sm\\:translate-x-48 {\n    --transform-translate-x: 12rem;\n  }\n\n  .sm\\:translate-x-56 {\n    --transform-translate-x: 14rem;\n  }\n\n  .sm\\:translate-x-64 {\n    --transform-translate-x: 16rem;\n  }\n\n  .sm\\:translate-x-px {\n    --transform-translate-x: 1px;\n  }\n\n  .sm\\:-translate-x-1 {\n    --transform-translate-x: -0.25rem;\n  }\n\n  .sm\\:-translate-x-2 {\n    --transform-translate-x: -0.5rem;\n  }\n\n  .sm\\:-translate-x-3 {\n    --transform-translate-x: -0.75rem;\n  }\n\n  .sm\\:-translate-x-4 {\n    --transform-translate-x: -1rem;\n  }\n\n  .sm\\:-translate-x-5 {\n    --transform-translate-x: -1.25rem;\n  }\n\n  .sm\\:-translate-x-6 {\n    --transform-translate-x: -1.5rem;\n  }\n\n  .sm\\:-translate-x-8 {\n    --transform-translate-x: -2rem;\n  }\n\n  .sm\\:-translate-x-10 {\n    --transform-translate-x: -2.5rem;\n  }\n\n  .sm\\:-translate-x-12 {\n    --transform-translate-x: -3rem;\n  }\n\n  .sm\\:-translate-x-16 {\n    --transform-translate-x: -4rem;\n  }\n\n  .sm\\:-translate-x-20 {\n    --transform-translate-x: -5rem;\n  }\n\n  .sm\\:-translate-x-24 {\n    --transform-translate-x: -6rem;\n  }\n\n  .sm\\:-translate-x-32 {\n    --transform-translate-x: -8rem;\n  }\n\n  .sm\\:-translate-x-40 {\n    --transform-translate-x: -10rem;\n  }\n\n  .sm\\:-translate-x-48 {\n    --transform-translate-x: -12rem;\n  }\n\n  .sm\\:-translate-x-56 {\n    --transform-translate-x: -14rem;\n  }\n\n  .sm\\:-translate-x-64 {\n    --transform-translate-x: -16rem;\n  }\n\n  .sm\\:-translate-x-px {\n    --transform-translate-x: -1px;\n  }\n\n  .sm\\:-translate-x-full {\n    --transform-translate-x: -100%;\n  }\n\n  .sm\\:-translate-x-1\\/2 {\n    --transform-translate-x: -50%;\n  }\n\n  .sm\\:translate-x-1\\/2 {\n    --transform-translate-x: 50%;\n  }\n\n  .sm\\:translate-x-full {\n    --transform-translate-x: 100%;\n  }\n\n  .sm\\:translate-y-0 {\n    --transform-translate-y: 0;\n  }\n\n  .sm\\:translate-y-1 {\n    --transform-translate-y: 0.25rem;\n  }\n\n  .sm\\:translate-y-2 {\n    --transform-translate-y: 0.5rem;\n  }\n\n  .sm\\:translate-y-3 {\n    --transform-translate-y: 0.75rem;\n  }\n\n  .sm\\:translate-y-4 {\n    --transform-translate-y: 1rem;\n  }\n\n  .sm\\:translate-y-5 {\n    --transform-translate-y: 1.25rem;\n  }\n\n  .sm\\:translate-y-6 {\n    --transform-translate-y: 1.5rem;\n  }\n\n  .sm\\:translate-y-8 {\n    --transform-translate-y: 2rem;\n  }\n\n  .sm\\:translate-y-10 {\n    --transform-translate-y: 2.5rem;\n  }\n\n  .sm\\:translate-y-12 {\n    --transform-translate-y: 3rem;\n  }\n\n  .sm\\:translate-y-16 {\n    --transform-translate-y: 4rem;\n  }\n\n  .sm\\:translate-y-20 {\n    --transform-translate-y: 5rem;\n  }\n\n  .sm\\:translate-y-24 {\n    --transform-translate-y: 6rem;\n  }\n\n  .sm\\:translate-y-32 {\n    --transform-translate-y: 8rem;\n  }\n\n  .sm\\:translate-y-40 {\n    --transform-translate-y: 10rem;\n  }\n\n  .sm\\:translate-y-48 {\n    --transform-translate-y: 12rem;\n  }\n\n  .sm\\:translate-y-56 {\n    --transform-translate-y: 14rem;\n  }\n\n  .sm\\:translate-y-64 {\n    --transform-translate-y: 16rem;\n  }\n\n  .sm\\:translate-y-px {\n    --transform-translate-y: 1px;\n  }\n\n  .sm\\:-translate-y-1 {\n    --transform-translate-y: -0.25rem;\n  }\n\n  .sm\\:-translate-y-2 {\n    --transform-translate-y: -0.5rem;\n  }\n\n  .sm\\:-translate-y-3 {\n    --transform-translate-y: -0.75rem;\n  }\n\n  .sm\\:-translate-y-4 {\n    --transform-translate-y: -1rem;\n  }\n\n  .sm\\:-translate-y-5 {\n    --transform-translate-y: -1.25rem;\n  }\n\n  .sm\\:-translate-y-6 {\n    --transform-translate-y: -1.5rem;\n  }\n\n  .sm\\:-translate-y-8 {\n    --transform-translate-y: -2rem;\n  }\n\n  .sm\\:-translate-y-10 {\n    --transform-translate-y: -2.5rem;\n  }\n\n  .sm\\:-translate-y-12 {\n    --transform-translate-y: -3rem;\n  }\n\n  .sm\\:-translate-y-16 {\n    --transform-translate-y: -4rem;\n  }\n\n  .sm\\:-translate-y-20 {\n    --transform-translate-y: -5rem;\n  }\n\n  .sm\\:-translate-y-24 {\n    --transform-translate-y: -6rem;\n  }\n\n  .sm\\:-translate-y-32 {\n    --transform-translate-y: -8rem;\n  }\n\n  .sm\\:-translate-y-40 {\n    --transform-translate-y: -10rem;\n  }\n\n  .sm\\:-translate-y-48 {\n    --transform-translate-y: -12rem;\n  }\n\n  .sm\\:-translate-y-56 {\n    --transform-translate-y: -14rem;\n  }\n\n  .sm\\:-translate-y-64 {\n    --transform-translate-y: -16rem;\n  }\n\n  .sm\\:-translate-y-px {\n    --transform-translate-y: -1px;\n  }\n\n  .sm\\:-translate-y-full {\n    --transform-translate-y: -100%;\n  }\n\n  .sm\\:-translate-y-1\\/2 {\n    --transform-translate-y: -50%;\n  }\n\n  .sm\\:translate-y-1\\/2 {\n    --transform-translate-y: 50%;\n  }\n\n  .sm\\:translate-y-full {\n    --transform-translate-y: 100%;\n  }\n\n  .sm\\:hover\\:translate-x-0:hover {\n    --transform-translate-x: 0;\n  }\n\n  .sm\\:hover\\:translate-x-1:hover {\n    --transform-translate-x: 0.25rem;\n  }\n\n  .sm\\:hover\\:translate-x-2:hover {\n    --transform-translate-x: 0.5rem;\n  }\n\n  .sm\\:hover\\:translate-x-3:hover {\n    --transform-translate-x: 0.75rem;\n  }\n\n  .sm\\:hover\\:translate-x-4:hover {\n    --transform-translate-x: 1rem;\n  }\n\n  .sm\\:hover\\:translate-x-5:hover {\n    --transform-translate-x: 1.25rem;\n  }\n\n  .sm\\:hover\\:translate-x-6:hover {\n    --transform-translate-x: 1.5rem;\n  }\n\n  .sm\\:hover\\:translate-x-8:hover {\n    --transform-translate-x: 2rem;\n  }\n\n  .sm\\:hover\\:translate-x-10:hover {\n    --transform-translate-x: 2.5rem;\n  }\n\n  .sm\\:hover\\:translate-x-12:hover {\n    --transform-translate-x: 3rem;\n  }\n\n  .sm\\:hover\\:translate-x-16:hover {\n    --transform-translate-x: 4rem;\n  }\n\n  .sm\\:hover\\:translate-x-20:hover {\n    --transform-translate-x: 5rem;\n  }\n\n  .sm\\:hover\\:translate-x-24:hover {\n    --transform-translate-x: 6rem;\n  }\n\n  .sm\\:hover\\:translate-x-32:hover {\n    --transform-translate-x: 8rem;\n  }\n\n  .sm\\:hover\\:translate-x-40:hover {\n    --transform-translate-x: 10rem;\n  }\n\n  .sm\\:hover\\:translate-x-48:hover {\n    --transform-translate-x: 12rem;\n  }\n\n  .sm\\:hover\\:translate-x-56:hover {\n    --transform-translate-x: 14rem;\n  }\n\n  .sm\\:hover\\:translate-x-64:hover {\n    --transform-translate-x: 16rem;\n  }\n\n  .sm\\:hover\\:translate-x-px:hover {\n    --transform-translate-x: 1px;\n  }\n\n  .sm\\:hover\\:-translate-x-1:hover {\n    --transform-translate-x: -0.25rem;\n  }\n\n  .sm\\:hover\\:-translate-x-2:hover {\n    --transform-translate-x: -0.5rem;\n  }\n\n  .sm\\:hover\\:-translate-x-3:hover {\n    --transform-translate-x: -0.75rem;\n  }\n\n  .sm\\:hover\\:-translate-x-4:hover {\n    --transform-translate-x: -1rem;\n  }\n\n  .sm\\:hover\\:-translate-x-5:hover {\n    --transform-translate-x: -1.25rem;\n  }\n\n  .sm\\:hover\\:-translate-x-6:hover {\n    --transform-translate-x: -1.5rem;\n  }\n\n  .sm\\:hover\\:-translate-x-8:hover {\n    --transform-translate-x: -2rem;\n  }\n\n  .sm\\:hover\\:-translate-x-10:hover {\n    --transform-translate-x: -2.5rem;\n  }\n\n  .sm\\:hover\\:-translate-x-12:hover {\n    --transform-translate-x: -3rem;\n  }\n\n  .sm\\:hover\\:-translate-x-16:hover {\n    --transform-translate-x: -4rem;\n  }\n\n  .sm\\:hover\\:-translate-x-20:hover {\n    --transform-translate-x: -5rem;\n  }\n\n  .sm\\:hover\\:-translate-x-24:hover {\n    --transform-translate-x: -6rem;\n  }\n\n  .sm\\:hover\\:-translate-x-32:hover {\n    --transform-translate-x: -8rem;\n  }\n\n  .sm\\:hover\\:-translate-x-40:hover {\n    --transform-translate-x: -10rem;\n  }\n\n  .sm\\:hover\\:-translate-x-48:hover {\n    --transform-translate-x: -12rem;\n  }\n\n  .sm\\:hover\\:-translate-x-56:hover {\n    --transform-translate-x: -14rem;\n  }\n\n  .sm\\:hover\\:-translate-x-64:hover {\n    --transform-translate-x: -16rem;\n  }\n\n  .sm\\:hover\\:-translate-x-px:hover {\n    --transform-translate-x: -1px;\n  }\n\n  .sm\\:hover\\:-translate-x-full:hover {\n    --transform-translate-x: -100%;\n  }\n\n  .sm\\:hover\\:-translate-x-1\\/2:hover {\n    --transform-translate-x: -50%;\n  }\n\n  .sm\\:hover\\:translate-x-1\\/2:hover {\n    --transform-translate-x: 50%;\n  }\n\n  .sm\\:hover\\:translate-x-full:hover {\n    --transform-translate-x: 100%;\n  }\n\n  .sm\\:hover\\:translate-y-0:hover {\n    --transform-translate-y: 0;\n  }\n\n  .sm\\:hover\\:translate-y-1:hover {\n    --transform-translate-y: 0.25rem;\n  }\n\n  .sm\\:hover\\:translate-y-2:hover {\n    --transform-translate-y: 0.5rem;\n  }\n\n  .sm\\:hover\\:translate-y-3:hover {\n    --transform-translate-y: 0.75rem;\n  }\n\n  .sm\\:hover\\:translate-y-4:hover {\n    --transform-translate-y: 1rem;\n  }\n\n  .sm\\:hover\\:translate-y-5:hover {\n    --transform-translate-y: 1.25rem;\n  }\n\n  .sm\\:hover\\:translate-y-6:hover {\n    --transform-translate-y: 1.5rem;\n  }\n\n  .sm\\:hover\\:translate-y-8:hover {\n    --transform-translate-y: 2rem;\n  }\n\n  .sm\\:hover\\:translate-y-10:hover {\n    --transform-translate-y: 2.5rem;\n  }\n\n  .sm\\:hover\\:translate-y-12:hover {\n    --transform-translate-y: 3rem;\n  }\n\n  .sm\\:hover\\:translate-y-16:hover {\n    --transform-translate-y: 4rem;\n  }\n\n  .sm\\:hover\\:translate-y-20:hover {\n    --transform-translate-y: 5rem;\n  }\n\n  .sm\\:hover\\:translate-y-24:hover {\n    --transform-translate-y: 6rem;\n  }\n\n  .sm\\:hover\\:translate-y-32:hover {\n    --transform-translate-y: 8rem;\n  }\n\n  .sm\\:hover\\:translate-y-40:hover {\n    --transform-translate-y: 10rem;\n  }\n\n  .sm\\:hover\\:translate-y-48:hover {\n    --transform-translate-y: 12rem;\n  }\n\n  .sm\\:hover\\:translate-y-56:hover {\n    --transform-translate-y: 14rem;\n  }\n\n  .sm\\:hover\\:translate-y-64:hover {\n    --transform-translate-y: 16rem;\n  }\n\n  .sm\\:hover\\:translate-y-px:hover {\n    --transform-translate-y: 1px;\n  }\n\n  .sm\\:hover\\:-translate-y-1:hover {\n    --transform-translate-y: -0.25rem;\n  }\n\n  .sm\\:hover\\:-translate-y-2:hover {\n    --transform-translate-y: -0.5rem;\n  }\n\n  .sm\\:hover\\:-translate-y-3:hover {\n    --transform-translate-y: -0.75rem;\n  }\n\n  .sm\\:hover\\:-translate-y-4:hover {\n    --transform-translate-y: -1rem;\n  }\n\n  .sm\\:hover\\:-translate-y-5:hover {\n    --transform-translate-y: -1.25rem;\n  }\n\n  .sm\\:hover\\:-translate-y-6:hover {\n    --transform-translate-y: -1.5rem;\n  }\n\n  .sm\\:hover\\:-translate-y-8:hover {\n    --transform-translate-y: -2rem;\n  }\n\n  .sm\\:hover\\:-translate-y-10:hover {\n    --transform-translate-y: -2.5rem;\n  }\n\n  .sm\\:hover\\:-translate-y-12:hover {\n    --transform-translate-y: -3rem;\n  }\n\n  .sm\\:hover\\:-translate-y-16:hover {\n    --transform-translate-y: -4rem;\n  }\n\n  .sm\\:hover\\:-translate-y-20:hover {\n    --transform-translate-y: -5rem;\n  }\n\n  .sm\\:hover\\:-translate-y-24:hover {\n    --transform-translate-y: -6rem;\n  }\n\n  .sm\\:hover\\:-translate-y-32:hover {\n    --transform-translate-y: -8rem;\n  }\n\n  .sm\\:hover\\:-translate-y-40:hover {\n    --transform-translate-y: -10rem;\n  }\n\n  .sm\\:hover\\:-translate-y-48:hover {\n    --transform-translate-y: -12rem;\n  }\n\n  .sm\\:hover\\:-translate-y-56:hover {\n    --transform-translate-y: -14rem;\n  }\n\n  .sm\\:hover\\:-translate-y-64:hover {\n    --transform-translate-y: -16rem;\n  }\n\n  .sm\\:hover\\:-translate-y-px:hover {\n    --transform-translate-y: -1px;\n  }\n\n  .sm\\:hover\\:-translate-y-full:hover {\n    --transform-translate-y: -100%;\n  }\n\n  .sm\\:hover\\:-translate-y-1\\/2:hover {\n    --transform-translate-y: -50%;\n  }\n\n  .sm\\:hover\\:translate-y-1\\/2:hover {\n    --transform-translate-y: 50%;\n  }\n\n  .sm\\:hover\\:translate-y-full:hover {\n    --transform-translate-y: 100%;\n  }\n\n  .sm\\:focus\\:translate-x-0:focus {\n    --transform-translate-x: 0;\n  }\n\n  .sm\\:focus\\:translate-x-1:focus {\n    --transform-translate-x: 0.25rem;\n  }\n\n  .sm\\:focus\\:translate-x-2:focus {\n    --transform-translate-x: 0.5rem;\n  }\n\n  .sm\\:focus\\:translate-x-3:focus {\n    --transform-translate-x: 0.75rem;\n  }\n\n  .sm\\:focus\\:translate-x-4:focus {\n    --transform-translate-x: 1rem;\n  }\n\n  .sm\\:focus\\:translate-x-5:focus {\n    --transform-translate-x: 1.25rem;\n  }\n\n  .sm\\:focus\\:translate-x-6:focus {\n    --transform-translate-x: 1.5rem;\n  }\n\n  .sm\\:focus\\:translate-x-8:focus {\n    --transform-translate-x: 2rem;\n  }\n\n  .sm\\:focus\\:translate-x-10:focus {\n    --transform-translate-x: 2.5rem;\n  }\n\n  .sm\\:focus\\:translate-x-12:focus {\n    --transform-translate-x: 3rem;\n  }\n\n  .sm\\:focus\\:translate-x-16:focus {\n    --transform-translate-x: 4rem;\n  }\n\n  .sm\\:focus\\:translate-x-20:focus {\n    --transform-translate-x: 5rem;\n  }\n\n  .sm\\:focus\\:translate-x-24:focus {\n    --transform-translate-x: 6rem;\n  }\n\n  .sm\\:focus\\:translate-x-32:focus {\n    --transform-translate-x: 8rem;\n  }\n\n  .sm\\:focus\\:translate-x-40:focus {\n    --transform-translate-x: 10rem;\n  }\n\n  .sm\\:focus\\:translate-x-48:focus {\n    --transform-translate-x: 12rem;\n  }\n\n  .sm\\:focus\\:translate-x-56:focus {\n    --transform-translate-x: 14rem;\n  }\n\n  .sm\\:focus\\:translate-x-64:focus {\n    --transform-translate-x: 16rem;\n  }\n\n  .sm\\:focus\\:translate-x-px:focus {\n    --transform-translate-x: 1px;\n  }\n\n  .sm\\:focus\\:-translate-x-1:focus {\n    --transform-translate-x: -0.25rem;\n  }\n\n  .sm\\:focus\\:-translate-x-2:focus {\n    --transform-translate-x: -0.5rem;\n  }\n\n  .sm\\:focus\\:-translate-x-3:focus {\n    --transform-translate-x: -0.75rem;\n  }\n\n  .sm\\:focus\\:-translate-x-4:focus {\n    --transform-translate-x: -1rem;\n  }\n\n  .sm\\:focus\\:-translate-x-5:focus {\n    --transform-translate-x: -1.25rem;\n  }\n\n  .sm\\:focus\\:-translate-x-6:focus {\n    --transform-translate-x: -1.5rem;\n  }\n\n  .sm\\:focus\\:-translate-x-8:focus {\n    --transform-translate-x: -2rem;\n  }\n\n  .sm\\:focus\\:-translate-x-10:focus {\n    --transform-translate-x: -2.5rem;\n  }\n\n  .sm\\:focus\\:-translate-x-12:focus {\n    --transform-translate-x: -3rem;\n  }\n\n  .sm\\:focus\\:-translate-x-16:focus {\n    --transform-translate-x: -4rem;\n  }\n\n  .sm\\:focus\\:-translate-x-20:focus {\n    --transform-translate-x: -5rem;\n  }\n\n  .sm\\:focus\\:-translate-x-24:focus {\n    --transform-translate-x: -6rem;\n  }\n\n  .sm\\:focus\\:-translate-x-32:focus {\n    --transform-translate-x: -8rem;\n  }\n\n  .sm\\:focus\\:-translate-x-40:focus {\n    --transform-translate-x: -10rem;\n  }\n\n  .sm\\:focus\\:-translate-x-48:focus {\n    --transform-translate-x: -12rem;\n  }\n\n  .sm\\:focus\\:-translate-x-56:focus {\n    --transform-translate-x: -14rem;\n  }\n\n  .sm\\:focus\\:-translate-x-64:focus {\n    --transform-translate-x: -16rem;\n  }\n\n  .sm\\:focus\\:-translate-x-px:focus {\n    --transform-translate-x: -1px;\n  }\n\n  .sm\\:focus\\:-translate-x-full:focus {\n    --transform-translate-x: -100%;\n  }\n\n  .sm\\:focus\\:-translate-x-1\\/2:focus {\n    --transform-translate-x: -50%;\n  }\n\n  .sm\\:focus\\:translate-x-1\\/2:focus {\n    --transform-translate-x: 50%;\n  }\n\n  .sm\\:focus\\:translate-x-full:focus {\n    --transform-translate-x: 100%;\n  }\n\n  .sm\\:focus\\:translate-y-0:focus {\n    --transform-translate-y: 0;\n  }\n\n  .sm\\:focus\\:translate-y-1:focus {\n    --transform-translate-y: 0.25rem;\n  }\n\n  .sm\\:focus\\:translate-y-2:focus {\n    --transform-translate-y: 0.5rem;\n  }\n\n  .sm\\:focus\\:translate-y-3:focus {\n    --transform-translate-y: 0.75rem;\n  }\n\n  .sm\\:focus\\:translate-y-4:focus {\n    --transform-translate-y: 1rem;\n  }\n\n  .sm\\:focus\\:translate-y-5:focus {\n    --transform-translate-y: 1.25rem;\n  }\n\n  .sm\\:focus\\:translate-y-6:focus {\n    --transform-translate-y: 1.5rem;\n  }\n\n  .sm\\:focus\\:translate-y-8:focus {\n    --transform-translate-y: 2rem;\n  }\n\n  .sm\\:focus\\:translate-y-10:focus {\n    --transform-translate-y: 2.5rem;\n  }\n\n  .sm\\:focus\\:translate-y-12:focus {\n    --transform-translate-y: 3rem;\n  }\n\n  .sm\\:focus\\:translate-y-16:focus {\n    --transform-translate-y: 4rem;\n  }\n\n  .sm\\:focus\\:translate-y-20:focus {\n    --transform-translate-y: 5rem;\n  }\n\n  .sm\\:focus\\:translate-y-24:focus {\n    --transform-translate-y: 6rem;\n  }\n\n  .sm\\:focus\\:translate-y-32:focus {\n    --transform-translate-y: 8rem;\n  }\n\n  .sm\\:focus\\:translate-y-40:focus {\n    --transform-translate-y: 10rem;\n  }\n\n  .sm\\:focus\\:translate-y-48:focus {\n    --transform-translate-y: 12rem;\n  }\n\n  .sm\\:focus\\:translate-y-56:focus {\n    --transform-translate-y: 14rem;\n  }\n\n  .sm\\:focus\\:translate-y-64:focus {\n    --transform-translate-y: 16rem;\n  }\n\n  .sm\\:focus\\:translate-y-px:focus {\n    --transform-translate-y: 1px;\n  }\n\n  .sm\\:focus\\:-translate-y-1:focus {\n    --transform-translate-y: -0.25rem;\n  }\n\n  .sm\\:focus\\:-translate-y-2:focus {\n    --transform-translate-y: -0.5rem;\n  }\n\n  .sm\\:focus\\:-translate-y-3:focus {\n    --transform-translate-y: -0.75rem;\n  }\n\n  .sm\\:focus\\:-translate-y-4:focus {\n    --transform-translate-y: -1rem;\n  }\n\n  .sm\\:focus\\:-translate-y-5:focus {\n    --transform-translate-y: -1.25rem;\n  }\n\n  .sm\\:focus\\:-translate-y-6:focus {\n    --transform-translate-y: -1.5rem;\n  }\n\n  .sm\\:focus\\:-translate-y-8:focus {\n    --transform-translate-y: -2rem;\n  }\n\n  .sm\\:focus\\:-translate-y-10:focus {\n    --transform-translate-y: -2.5rem;\n  }\n\n  .sm\\:focus\\:-translate-y-12:focus {\n    --transform-translate-y: -3rem;\n  }\n\n  .sm\\:focus\\:-translate-y-16:focus {\n    --transform-translate-y: -4rem;\n  }\n\n  .sm\\:focus\\:-translate-y-20:focus {\n    --transform-translate-y: -5rem;\n  }\n\n  .sm\\:focus\\:-translate-y-24:focus {\n    --transform-translate-y: -6rem;\n  }\n\n  .sm\\:focus\\:-translate-y-32:focus {\n    --transform-translate-y: -8rem;\n  }\n\n  .sm\\:focus\\:-translate-y-40:focus {\n    --transform-translate-y: -10rem;\n  }\n\n  .sm\\:focus\\:-translate-y-48:focus {\n    --transform-translate-y: -12rem;\n  }\n\n  .sm\\:focus\\:-translate-y-56:focus {\n    --transform-translate-y: -14rem;\n  }\n\n  .sm\\:focus\\:-translate-y-64:focus {\n    --transform-translate-y: -16rem;\n  }\n\n  .sm\\:focus\\:-translate-y-px:focus {\n    --transform-translate-y: -1px;\n  }\n\n  .sm\\:focus\\:-translate-y-full:focus {\n    --transform-translate-y: -100%;\n  }\n\n  .sm\\:focus\\:-translate-y-1\\/2:focus {\n    --transform-translate-y: -50%;\n  }\n\n  .sm\\:focus\\:translate-y-1\\/2:focus {\n    --transform-translate-y: 50%;\n  }\n\n  .sm\\:focus\\:translate-y-full:focus {\n    --transform-translate-y: 100%;\n  }\n\n  .sm\\:skew-x-0 {\n    --transform-skew-x: 0;\n  }\n\n  .sm\\:skew-x-1 {\n    --transform-skew-x: 1deg;\n  }\n\n  .sm\\:skew-x-2 {\n    --transform-skew-x: 2deg;\n  }\n\n  .sm\\:skew-x-3 {\n    --transform-skew-x: 3deg;\n  }\n\n  .sm\\:skew-x-6 {\n    --transform-skew-x: 6deg;\n  }\n\n  .sm\\:skew-x-12 {\n    --transform-skew-x: 12deg;\n  }\n\n  .sm\\:-skew-x-12 {\n    --transform-skew-x: -12deg;\n  }\n\n  .sm\\:-skew-x-6 {\n    --transform-skew-x: -6deg;\n  }\n\n  .sm\\:-skew-x-3 {\n    --transform-skew-x: -3deg;\n  }\n\n  .sm\\:-skew-x-2 {\n    --transform-skew-x: -2deg;\n  }\n\n  .sm\\:-skew-x-1 {\n    --transform-skew-x: -1deg;\n  }\n\n  .sm\\:skew-y-0 {\n    --transform-skew-y: 0;\n  }\n\n  .sm\\:skew-y-1 {\n    --transform-skew-y: 1deg;\n  }\n\n  .sm\\:skew-y-2 {\n    --transform-skew-y: 2deg;\n  }\n\n  .sm\\:skew-y-3 {\n    --transform-skew-y: 3deg;\n  }\n\n  .sm\\:skew-y-6 {\n    --transform-skew-y: 6deg;\n  }\n\n  .sm\\:skew-y-12 {\n    --transform-skew-y: 12deg;\n  }\n\n  .sm\\:-skew-y-12 {\n    --transform-skew-y: -12deg;\n  }\n\n  .sm\\:-skew-y-6 {\n    --transform-skew-y: -6deg;\n  }\n\n  .sm\\:-skew-y-3 {\n    --transform-skew-y: -3deg;\n  }\n\n  .sm\\:-skew-y-2 {\n    --transform-skew-y: -2deg;\n  }\n\n  .sm\\:-skew-y-1 {\n    --transform-skew-y: -1deg;\n  }\n\n  .sm\\:hover\\:skew-x-0:hover {\n    --transform-skew-x: 0;\n  }\n\n  .sm\\:hover\\:skew-x-1:hover {\n    --transform-skew-x: 1deg;\n  }\n\n  .sm\\:hover\\:skew-x-2:hover {\n    --transform-skew-x: 2deg;\n  }\n\n  .sm\\:hover\\:skew-x-3:hover {\n    --transform-skew-x: 3deg;\n  }\n\n  .sm\\:hover\\:skew-x-6:hover {\n    --transform-skew-x: 6deg;\n  }\n\n  .sm\\:hover\\:skew-x-12:hover {\n    --transform-skew-x: 12deg;\n  }\n\n  .sm\\:hover\\:-skew-x-12:hover {\n    --transform-skew-x: -12deg;\n  }\n\n  .sm\\:hover\\:-skew-x-6:hover {\n    --transform-skew-x: -6deg;\n  }\n\n  .sm\\:hover\\:-skew-x-3:hover {\n    --transform-skew-x: -3deg;\n  }\n\n  .sm\\:hover\\:-skew-x-2:hover {\n    --transform-skew-x: -2deg;\n  }\n\n  .sm\\:hover\\:-skew-x-1:hover {\n    --transform-skew-x: -1deg;\n  }\n\n  .sm\\:hover\\:skew-y-0:hover {\n    --transform-skew-y: 0;\n  }\n\n  .sm\\:hover\\:skew-y-1:hover {\n    --transform-skew-y: 1deg;\n  }\n\n  .sm\\:hover\\:skew-y-2:hover {\n    --transform-skew-y: 2deg;\n  }\n\n  .sm\\:hover\\:skew-y-3:hover {\n    --transform-skew-y: 3deg;\n  }\n\n  .sm\\:hover\\:skew-y-6:hover {\n    --transform-skew-y: 6deg;\n  }\n\n  .sm\\:hover\\:skew-y-12:hover {\n    --transform-skew-y: 12deg;\n  }\n\n  .sm\\:hover\\:-skew-y-12:hover {\n    --transform-skew-y: -12deg;\n  }\n\n  .sm\\:hover\\:-skew-y-6:hover {\n    --transform-skew-y: -6deg;\n  }\n\n  .sm\\:hover\\:-skew-y-3:hover {\n    --transform-skew-y: -3deg;\n  }\n\n  .sm\\:hover\\:-skew-y-2:hover {\n    --transform-skew-y: -2deg;\n  }\n\n  .sm\\:hover\\:-skew-y-1:hover {\n    --transform-skew-y: -1deg;\n  }\n\n  .sm\\:focus\\:skew-x-0:focus {\n    --transform-skew-x: 0;\n  }\n\n  .sm\\:focus\\:skew-x-1:focus {\n    --transform-skew-x: 1deg;\n  }\n\n  .sm\\:focus\\:skew-x-2:focus {\n    --transform-skew-x: 2deg;\n  }\n\n  .sm\\:focus\\:skew-x-3:focus {\n    --transform-skew-x: 3deg;\n  }\n\n  .sm\\:focus\\:skew-x-6:focus {\n    --transform-skew-x: 6deg;\n  }\n\n  .sm\\:focus\\:skew-x-12:focus {\n    --transform-skew-x: 12deg;\n  }\n\n  .sm\\:focus\\:-skew-x-12:focus {\n    --transform-skew-x: -12deg;\n  }\n\n  .sm\\:focus\\:-skew-x-6:focus {\n    --transform-skew-x: -6deg;\n  }\n\n  .sm\\:focus\\:-skew-x-3:focus {\n    --transform-skew-x: -3deg;\n  }\n\n  .sm\\:focus\\:-skew-x-2:focus {\n    --transform-skew-x: -2deg;\n  }\n\n  .sm\\:focus\\:-skew-x-1:focus {\n    --transform-skew-x: -1deg;\n  }\n\n  .sm\\:focus\\:skew-y-0:focus {\n    --transform-skew-y: 0;\n  }\n\n  .sm\\:focus\\:skew-y-1:focus {\n    --transform-skew-y: 1deg;\n  }\n\n  .sm\\:focus\\:skew-y-2:focus {\n    --transform-skew-y: 2deg;\n  }\n\n  .sm\\:focus\\:skew-y-3:focus {\n    --transform-skew-y: 3deg;\n  }\n\n  .sm\\:focus\\:skew-y-6:focus {\n    --transform-skew-y: 6deg;\n  }\n\n  .sm\\:focus\\:skew-y-12:focus {\n    --transform-skew-y: 12deg;\n  }\n\n  .sm\\:focus\\:-skew-y-12:focus {\n    --transform-skew-y: -12deg;\n  }\n\n  .sm\\:focus\\:-skew-y-6:focus {\n    --transform-skew-y: -6deg;\n  }\n\n  .sm\\:focus\\:-skew-y-3:focus {\n    --transform-skew-y: -3deg;\n  }\n\n  .sm\\:focus\\:-skew-y-2:focus {\n    --transform-skew-y: -2deg;\n  }\n\n  .sm\\:focus\\:-skew-y-1:focus {\n    --transform-skew-y: -1deg;\n  }\n\n  .sm\\:transition-none {\n    transition-property: none;\n  }\n\n  .sm\\:transition-all {\n    transition-property: all;\n  }\n\n  .sm\\:transition {\n    transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform;\n  }\n\n  .sm\\:transition-colors {\n    transition-property: background-color, border-color, color, fill, stroke;\n  }\n\n  .sm\\:transition-opacity {\n    transition-property: opacity;\n  }\n\n  .sm\\:transition-shadow {\n    transition-property: box-shadow;\n  }\n\n  .sm\\:transition-transform {\n    transition-property: transform;\n  }\n\n  .sm\\:ease-linear {\n    transition-timing-function: linear;\n  }\n\n  .sm\\:ease-in {\n    transition-timing-function: cubic-bezier(0.4, 0, 1, 1);\n  }\n\n  .sm\\:ease-out {\n    transition-timing-function: cubic-bezier(0, 0, 0.2, 1);\n  }\n\n  .sm\\:ease-in-out {\n    transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);\n  }\n\n  .sm\\:duration-75 {\n    transition-duration: 75ms;\n  }\n\n  .sm\\:duration-100 {\n    transition-duration: 100ms;\n  }\n\n  .sm\\:duration-150 {\n    transition-duration: 150ms;\n  }\n\n  .sm\\:duration-200 {\n    transition-duration: 200ms;\n  }\n\n  .sm\\:duration-300 {\n    transition-duration: 300ms;\n  }\n\n  .sm\\:duration-500 {\n    transition-duration: 500ms;\n  }\n\n  .sm\\:duration-700 {\n    transition-duration: 700ms;\n  }\n\n  .sm\\:duration-1000 {\n    transition-duration: 1000ms;\n  }\n\n  .sm\\:delay-75 {\n    transition-delay: 75ms;\n  }\n\n  .sm\\:delay-100 {\n    transition-delay: 100ms;\n  }\n\n  .sm\\:delay-150 {\n    transition-delay: 150ms;\n  }\n\n  .sm\\:delay-200 {\n    transition-delay: 200ms;\n  }\n\n  .sm\\:delay-300 {\n    transition-delay: 300ms;\n  }\n\n  .sm\\:delay-500 {\n    transition-delay: 500ms;\n  }\n\n  .sm\\:delay-700 {\n    transition-delay: 700ms;\n  }\n\n  .sm\\:delay-1000 {\n    transition-delay: 1000ms;\n  }\n\n  .sm\\:animate-none {\n    -webkit-animation: none;\n            animation: none;\n  }\n\n  .sm\\:animate-spin {\n    -webkit-animation: spin 1s linear infinite;\n            animation: spin 1s linear infinite;\n  }\n\n  .sm\\:animate-ping {\n    -webkit-animation: ping 1s cubic-bezier(0, 0, 0.2, 1) infinite;\n            animation: ping 1s cubic-bezier(0, 0, 0.2, 1) infinite;\n  }\n\n  .sm\\:animate-pulse {\n    -webkit-animation: pulse 2s cubic-bezier(0.4, 0, 0.6, 1) infinite;\n            animation: pulse 2s cubic-bezier(0.4, 0, 0.6, 1) infinite;\n  }\n\n  .sm\\:animate-bounce {\n    -webkit-animation: bounce 1s infinite;\n            animation: bounce 1s infinite;\n  }\n}\n\n@media (min-width: 768px) {\n  .md\\:container {\n    width: 100%;\n  }\n\n  @media (min-width: 640px) {\n    .md\\:container {\n      max-width: 640px;\n    }\n  }\n\n  @media (min-width: 768px) {\n    .md\\:container {\n      max-width: 768px;\n    }\n  }\n\n  @media (min-width: 1024px) {\n    .md\\:container {\n      max-width: 1024px;\n    }\n  }\n\n  @media (min-width: 1280px) {\n    .md\\:container {\n      max-width: 1280px;\n    }\n  }\n\n  .md\\:space-y-0 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(0px * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(0px * var(--space-y-reverse));\n  }\n\n  .md\\:space-x-0 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(0px * var(--space-x-reverse));\n    margin-left: calc(0px * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:space-y-1 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(0.25rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(0.25rem * var(--space-y-reverse));\n  }\n\n  .md\\:space-x-1 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(0.25rem * var(--space-x-reverse));\n    margin-left: calc(0.25rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:space-y-2 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(0.5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(0.5rem * var(--space-y-reverse));\n  }\n\n  .md\\:space-x-2 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(0.5rem * var(--space-x-reverse));\n    margin-left: calc(0.5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:space-y-3 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(0.75rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(0.75rem * var(--space-y-reverse));\n  }\n\n  .md\\:space-x-3 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(0.75rem * var(--space-x-reverse));\n    margin-left: calc(0.75rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:space-y-4 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(1rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(1rem * var(--space-y-reverse));\n  }\n\n  .md\\:space-x-4 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(1rem * var(--space-x-reverse));\n    margin-left: calc(1rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:space-y-5 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(1.25rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(1.25rem * var(--space-y-reverse));\n  }\n\n  .md\\:space-x-5 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(1.25rem * var(--space-x-reverse));\n    margin-left: calc(1.25rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:space-y-6 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(1.5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(1.5rem * var(--space-y-reverse));\n  }\n\n  .md\\:space-x-6 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(1.5rem * var(--space-x-reverse));\n    margin-left: calc(1.5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:space-y-8 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(2rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(2rem * var(--space-y-reverse));\n  }\n\n  .md\\:space-x-8 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(2rem * var(--space-x-reverse));\n    margin-left: calc(2rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:space-y-10 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(2.5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(2.5rem * var(--space-y-reverse));\n  }\n\n  .md\\:space-x-10 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(2.5rem * var(--space-x-reverse));\n    margin-left: calc(2.5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:space-y-12 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(3rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(3rem * var(--space-y-reverse));\n  }\n\n  .md\\:space-x-12 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(3rem * var(--space-x-reverse));\n    margin-left: calc(3rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:space-y-16 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(4rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(4rem * var(--space-y-reverse));\n  }\n\n  .md\\:space-x-16 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(4rem * var(--space-x-reverse));\n    margin-left: calc(4rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:space-y-20 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(5rem * var(--space-y-reverse));\n  }\n\n  .md\\:space-x-20 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(5rem * var(--space-x-reverse));\n    margin-left: calc(5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:space-y-24 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(6rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(6rem * var(--space-y-reverse));\n  }\n\n  .md\\:space-x-24 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(6rem * var(--space-x-reverse));\n    margin-left: calc(6rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:space-y-32 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(8rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(8rem * var(--space-y-reverse));\n  }\n\n  .md\\:space-x-32 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(8rem * var(--space-x-reverse));\n    margin-left: calc(8rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:space-y-40 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(10rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(10rem * var(--space-y-reverse));\n  }\n\n  .md\\:space-x-40 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(10rem * var(--space-x-reverse));\n    margin-left: calc(10rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:space-y-48 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(12rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(12rem * var(--space-y-reverse));\n  }\n\n  .md\\:space-x-48 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(12rem * var(--space-x-reverse));\n    margin-left: calc(12rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:space-y-56 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(14rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(14rem * var(--space-y-reverse));\n  }\n\n  .md\\:space-x-56 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(14rem * var(--space-x-reverse));\n    margin-left: calc(14rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:space-y-64 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(16rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(16rem * var(--space-y-reverse));\n  }\n\n  .md\\:space-x-64 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(16rem * var(--space-x-reverse));\n    margin-left: calc(16rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:space-y-px > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(1px * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(1px * var(--space-y-reverse));\n  }\n\n  .md\\:space-x-px > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(1px * var(--space-x-reverse));\n    margin-left: calc(1px * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:-space-y-1 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-0.25rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-0.25rem * var(--space-y-reverse));\n  }\n\n  .md\\:-space-x-1 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-0.25rem * var(--space-x-reverse));\n    margin-left: calc(-0.25rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:-space-y-2 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-0.5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-0.5rem * var(--space-y-reverse));\n  }\n\n  .md\\:-space-x-2 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-0.5rem * var(--space-x-reverse));\n    margin-left: calc(-0.5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:-space-y-3 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-0.75rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-0.75rem * var(--space-y-reverse));\n  }\n\n  .md\\:-space-x-3 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-0.75rem * var(--space-x-reverse));\n    margin-left: calc(-0.75rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:-space-y-4 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-1rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-1rem * var(--space-y-reverse));\n  }\n\n  .md\\:-space-x-4 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-1rem * var(--space-x-reverse));\n    margin-left: calc(-1rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:-space-y-5 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-1.25rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-1.25rem * var(--space-y-reverse));\n  }\n\n  .md\\:-space-x-5 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-1.25rem * var(--space-x-reverse));\n    margin-left: calc(-1.25rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:-space-y-6 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-1.5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-1.5rem * var(--space-y-reverse));\n  }\n\n  .md\\:-space-x-6 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-1.5rem * var(--space-x-reverse));\n    margin-left: calc(-1.5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:-space-y-8 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-2rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-2rem * var(--space-y-reverse));\n  }\n\n  .md\\:-space-x-8 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-2rem * var(--space-x-reverse));\n    margin-left: calc(-2rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:-space-y-10 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-2.5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-2.5rem * var(--space-y-reverse));\n  }\n\n  .md\\:-space-x-10 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-2.5rem * var(--space-x-reverse));\n    margin-left: calc(-2.5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:-space-y-12 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-3rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-3rem * var(--space-y-reverse));\n  }\n\n  .md\\:-space-x-12 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-3rem * var(--space-x-reverse));\n    margin-left: calc(-3rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:-space-y-16 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-4rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-4rem * var(--space-y-reverse));\n  }\n\n  .md\\:-space-x-16 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-4rem * var(--space-x-reverse));\n    margin-left: calc(-4rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:-space-y-20 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-5rem * var(--space-y-reverse));\n  }\n\n  .md\\:-space-x-20 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-5rem * var(--space-x-reverse));\n    margin-left: calc(-5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:-space-y-24 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-6rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-6rem * var(--space-y-reverse));\n  }\n\n  .md\\:-space-x-24 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-6rem * var(--space-x-reverse));\n    margin-left: calc(-6rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:-space-y-32 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-8rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-8rem * var(--space-y-reverse));\n  }\n\n  .md\\:-space-x-32 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-8rem * var(--space-x-reverse));\n    margin-left: calc(-8rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:-space-y-40 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-10rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-10rem * var(--space-y-reverse));\n  }\n\n  .md\\:-space-x-40 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-10rem * var(--space-x-reverse));\n    margin-left: calc(-10rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:-space-y-48 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-12rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-12rem * var(--space-y-reverse));\n  }\n\n  .md\\:-space-x-48 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-12rem * var(--space-x-reverse));\n    margin-left: calc(-12rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:-space-y-56 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-14rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-14rem * var(--space-y-reverse));\n  }\n\n  .md\\:-space-x-56 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-14rem * var(--space-x-reverse));\n    margin-left: calc(-14rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:-space-y-64 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-16rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-16rem * var(--space-y-reverse));\n  }\n\n  .md\\:-space-x-64 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-16rem * var(--space-x-reverse));\n    margin-left: calc(-16rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:-space-y-px > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-1px * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-1px * var(--space-y-reverse));\n  }\n\n  .md\\:-space-x-px > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-1px * var(--space-x-reverse));\n    margin-left: calc(-1px * calc(1 - var(--space-x-reverse)));\n  }\n\n  .md\\:space-y-reverse > :not(template) ~ :not(template) {\n    --space-y-reverse: 1;\n  }\n\n  .md\\:space-x-reverse > :not(template) ~ :not(template) {\n    --space-x-reverse: 1;\n  }\n\n  .md\\:divide-y-0 > :not(template) ~ :not(template) {\n    --divide-y-reverse: 0;\n    border-top-width: calc(0px * calc(1 - var(--divide-y-reverse)));\n    border-bottom-width: calc(0px * var(--divide-y-reverse));\n  }\n\n  .md\\:divide-x-0 > :not(template) ~ :not(template) {\n    --divide-x-reverse: 0;\n    border-right-width: calc(0px * var(--divide-x-reverse));\n    border-left-width: calc(0px * calc(1 - var(--divide-x-reverse)));\n  }\n\n  .md\\:divide-y-2 > :not(template) ~ :not(template) {\n    --divide-y-reverse: 0;\n    border-top-width: calc(2px * calc(1 - var(--divide-y-reverse)));\n    border-bottom-width: calc(2px * var(--divide-y-reverse));\n  }\n\n  .md\\:divide-x-2 > :not(template) ~ :not(template) {\n    --divide-x-reverse: 0;\n    border-right-width: calc(2px * var(--divide-x-reverse));\n    border-left-width: calc(2px * calc(1 - var(--divide-x-reverse)));\n  }\n\n  .md\\:divide-y-4 > :not(template) ~ :not(template) {\n    --divide-y-reverse: 0;\n    border-top-width: calc(4px * calc(1 - var(--divide-y-reverse)));\n    border-bottom-width: calc(4px * var(--divide-y-reverse));\n  }\n\n  .md\\:divide-x-4 > :not(template) ~ :not(template) {\n    --divide-x-reverse: 0;\n    border-right-width: calc(4px * var(--divide-x-reverse));\n    border-left-width: calc(4px * calc(1 - var(--divide-x-reverse)));\n  }\n\n  .md\\:divide-y-8 > :not(template) ~ :not(template) {\n    --divide-y-reverse: 0;\n    border-top-width: calc(8px * calc(1 - var(--divide-y-reverse)));\n    border-bottom-width: calc(8px * var(--divide-y-reverse));\n  }\n\n  .md\\:divide-x-8 > :not(template) ~ :not(template) {\n    --divide-x-reverse: 0;\n    border-right-width: calc(8px * var(--divide-x-reverse));\n    border-left-width: calc(8px * calc(1 - var(--divide-x-reverse)));\n  }\n\n  .md\\:divide-y > :not(template) ~ :not(template) {\n    --divide-y-reverse: 0;\n    border-top-width: calc(1px * calc(1 - var(--divide-y-reverse)));\n    border-bottom-width: calc(1px * var(--divide-y-reverse));\n  }\n\n  .md\\:divide-x > :not(template) ~ :not(template) {\n    --divide-x-reverse: 0;\n    border-right-width: calc(1px * var(--divide-x-reverse));\n    border-left-width: calc(1px * calc(1 - var(--divide-x-reverse)));\n  }\n\n  .md\\:divide-y-reverse > :not(template) ~ :not(template) {\n    --divide-y-reverse: 1;\n  }\n\n  .md\\:divide-x-reverse > :not(template) ~ :not(template) {\n    --divide-x-reverse: 1;\n  }\n\n  .md\\:divide-transparent > :not(template) ~ :not(template) {\n    border-color: transparent;\n  }\n\n  .md\\:divide-current > :not(template) ~ :not(template) {\n    border-color: currentColor;\n  }\n\n  .md\\:divide-black > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #000;\n    border-color: rgba(0, 0, 0, var(--divide-opacity));\n  }\n\n  .md\\:divide-white > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fff;\n    border-color: rgba(255, 255, 255, var(--divide-opacity));\n  }\n\n  .md\\:divide-gray-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #f7fafc;\n    border-color: rgba(247, 250, 252, var(--divide-opacity));\n  }\n\n  .md\\:divide-gray-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #edf2f7;\n    border-color: rgba(237, 242, 247, var(--divide-opacity));\n  }\n\n  .md\\:divide-gray-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #e2e8f0;\n    border-color: rgba(226, 232, 240, var(--divide-opacity));\n  }\n\n  .md\\:divide-gray-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #cbd5e0;\n    border-color: rgba(203, 213, 224, var(--divide-opacity));\n  }\n\n  .md\\:divide-gray-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #a0aec0;\n    border-color: rgba(160, 174, 192, var(--divide-opacity));\n  }\n\n  .md\\:divide-gray-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #718096;\n    border-color: rgba(113, 128, 150, var(--divide-opacity));\n  }\n\n  .md\\:divide-gray-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #4a5568;\n    border-color: rgba(74, 85, 104, var(--divide-opacity));\n  }\n\n  .md\\:divide-gray-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #2d3748;\n    border-color: rgba(45, 55, 72, var(--divide-opacity));\n  }\n\n  .md\\:divide-gray-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #1a202c;\n    border-color: rgba(26, 32, 44, var(--divide-opacity));\n  }\n\n  .md\\:divide-red-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fff5f5;\n    border-color: rgba(255, 245, 245, var(--divide-opacity));\n  }\n\n  .md\\:divide-red-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fed7d7;\n    border-color: rgba(254, 215, 215, var(--divide-opacity));\n  }\n\n  .md\\:divide-red-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #feb2b2;\n    border-color: rgba(254, 178, 178, var(--divide-opacity));\n  }\n\n  .md\\:divide-red-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fc8181;\n    border-color: rgba(252, 129, 129, var(--divide-opacity));\n  }\n\n  .md\\:divide-red-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #f56565;\n    border-color: rgba(245, 101, 101, var(--divide-opacity));\n  }\n\n  .md\\:divide-red-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #e53e3e;\n    border-color: rgba(229, 62, 62, var(--divide-opacity));\n  }\n\n  .md\\:divide-red-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #c53030;\n    border-color: rgba(197, 48, 48, var(--divide-opacity));\n  }\n\n  .md\\:divide-red-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #9b2c2c;\n    border-color: rgba(155, 44, 44, var(--divide-opacity));\n  }\n\n  .md\\:divide-red-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #742a2a;\n    border-color: rgba(116, 42, 42, var(--divide-opacity));\n  }\n\n  .md\\:divide-orange-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fffaf0;\n    border-color: rgba(255, 250, 240, var(--divide-opacity));\n  }\n\n  .md\\:divide-orange-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #feebc8;\n    border-color: rgba(254, 235, 200, var(--divide-opacity));\n  }\n\n  .md\\:divide-orange-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fbd38d;\n    border-color: rgba(251, 211, 141, var(--divide-opacity));\n  }\n\n  .md\\:divide-orange-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #f6ad55;\n    border-color: rgba(246, 173, 85, var(--divide-opacity));\n  }\n\n  .md\\:divide-orange-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #ed8936;\n    border-color: rgba(237, 137, 54, var(--divide-opacity));\n  }\n\n  .md\\:divide-orange-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #dd6b20;\n    border-color: rgba(221, 107, 32, var(--divide-opacity));\n  }\n\n  .md\\:divide-orange-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #c05621;\n    border-color: rgba(192, 86, 33, var(--divide-opacity));\n  }\n\n  .md\\:divide-orange-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #9c4221;\n    border-color: rgba(156, 66, 33, var(--divide-opacity));\n  }\n\n  .md\\:divide-orange-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #7b341e;\n    border-color: rgba(123, 52, 30, var(--divide-opacity));\n  }\n\n  .md\\:divide-yellow-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fffff0;\n    border-color: rgba(255, 255, 240, var(--divide-opacity));\n  }\n\n  .md\\:divide-yellow-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fefcbf;\n    border-color: rgba(254, 252, 191, var(--divide-opacity));\n  }\n\n  .md\\:divide-yellow-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #faf089;\n    border-color: rgba(250, 240, 137, var(--divide-opacity));\n  }\n\n  .md\\:divide-yellow-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #f6e05e;\n    border-color: rgba(246, 224, 94, var(--divide-opacity));\n  }\n\n  .md\\:divide-yellow-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #ecc94b;\n    border-color: rgba(236, 201, 75, var(--divide-opacity));\n  }\n\n  .md\\:divide-yellow-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #d69e2e;\n    border-color: rgba(214, 158, 46, var(--divide-opacity));\n  }\n\n  .md\\:divide-yellow-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #b7791f;\n    border-color: rgba(183, 121, 31, var(--divide-opacity));\n  }\n\n  .md\\:divide-yellow-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #975a16;\n    border-color: rgba(151, 90, 22, var(--divide-opacity));\n  }\n\n  .md\\:divide-yellow-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #744210;\n    border-color: rgba(116, 66, 16, var(--divide-opacity));\n  }\n\n  .md\\:divide-green-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #f0fff4;\n    border-color: rgba(240, 255, 244, var(--divide-opacity));\n  }\n\n  .md\\:divide-green-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #c6f6d5;\n    border-color: rgba(198, 246, 213, var(--divide-opacity));\n  }\n\n  .md\\:divide-green-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #9ae6b4;\n    border-color: rgba(154, 230, 180, var(--divide-opacity));\n  }\n\n  .md\\:divide-green-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #68d391;\n    border-color: rgba(104, 211, 145, var(--divide-opacity));\n  }\n\n  .md\\:divide-green-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #48bb78;\n    border-color: rgba(72, 187, 120, var(--divide-opacity));\n  }\n\n  .md\\:divide-green-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #38a169;\n    border-color: rgba(56, 161, 105, var(--divide-opacity));\n  }\n\n  .md\\:divide-green-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #2f855a;\n    border-color: rgba(47, 133, 90, var(--divide-opacity));\n  }\n\n  .md\\:divide-green-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #276749;\n    border-color: rgba(39, 103, 73, var(--divide-opacity));\n  }\n\n  .md\\:divide-green-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #22543d;\n    border-color: rgba(34, 84, 61, var(--divide-opacity));\n  }\n\n  .md\\:divide-teal-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #e6fffa;\n    border-color: rgba(230, 255, 250, var(--divide-opacity));\n  }\n\n  .md\\:divide-teal-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #b2f5ea;\n    border-color: rgba(178, 245, 234, var(--divide-opacity));\n  }\n\n  .md\\:divide-teal-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #81e6d9;\n    border-color: rgba(129, 230, 217, var(--divide-opacity));\n  }\n\n  .md\\:divide-teal-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #4fd1c5;\n    border-color: rgba(79, 209, 197, var(--divide-opacity));\n  }\n\n  .md\\:divide-teal-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #38b2ac;\n    border-color: rgba(56, 178, 172, var(--divide-opacity));\n  }\n\n  .md\\:divide-teal-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #319795;\n    border-color: rgba(49, 151, 149, var(--divide-opacity));\n  }\n\n  .md\\:divide-teal-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #2c7a7b;\n    border-color: rgba(44, 122, 123, var(--divide-opacity));\n  }\n\n  .md\\:divide-teal-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #285e61;\n    border-color: rgba(40, 94, 97, var(--divide-opacity));\n  }\n\n  .md\\:divide-teal-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #234e52;\n    border-color: rgba(35, 78, 82, var(--divide-opacity));\n  }\n\n  .md\\:divide-blue-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #ebf8ff;\n    border-color: rgba(235, 248, 255, var(--divide-opacity));\n  }\n\n  .md\\:divide-blue-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #bee3f8;\n    border-color: rgba(190, 227, 248, var(--divide-opacity));\n  }\n\n  .md\\:divide-blue-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #90cdf4;\n    border-color: rgba(144, 205, 244, var(--divide-opacity));\n  }\n\n  .md\\:divide-blue-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #63b3ed;\n    border-color: rgba(99, 179, 237, var(--divide-opacity));\n  }\n\n  .md\\:divide-blue-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #4299e1;\n    border-color: rgba(66, 153, 225, var(--divide-opacity));\n  }\n\n  .md\\:divide-blue-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #3182ce;\n    border-color: rgba(49, 130, 206, var(--divide-opacity));\n  }\n\n  .md\\:divide-blue-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #2b6cb0;\n    border-color: rgba(43, 108, 176, var(--divide-opacity));\n  }\n\n  .md\\:divide-blue-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #2c5282;\n    border-color: rgba(44, 82, 130, var(--divide-opacity));\n  }\n\n  .md\\:divide-blue-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #2a4365;\n    border-color: rgba(42, 67, 101, var(--divide-opacity));\n  }\n\n  .md\\:divide-indigo-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #ebf4ff;\n    border-color: rgba(235, 244, 255, var(--divide-opacity));\n  }\n\n  .md\\:divide-indigo-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #c3dafe;\n    border-color: rgba(195, 218, 254, var(--divide-opacity));\n  }\n\n  .md\\:divide-indigo-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #a3bffa;\n    border-color: rgba(163, 191, 250, var(--divide-opacity));\n  }\n\n  .md\\:divide-indigo-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #7f9cf5;\n    border-color: rgba(127, 156, 245, var(--divide-opacity));\n  }\n\n  .md\\:divide-indigo-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #667eea;\n    border-color: rgba(102, 126, 234, var(--divide-opacity));\n  }\n\n  .md\\:divide-indigo-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #5a67d8;\n    border-color: rgba(90, 103, 216, var(--divide-opacity));\n  }\n\n  .md\\:divide-indigo-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #4c51bf;\n    border-color: rgba(76, 81, 191, var(--divide-opacity));\n  }\n\n  .md\\:divide-indigo-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #434190;\n    border-color: rgba(67, 65, 144, var(--divide-opacity));\n  }\n\n  .md\\:divide-indigo-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #3c366b;\n    border-color: rgba(60, 54, 107, var(--divide-opacity));\n  }\n\n  .md\\:divide-purple-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #faf5ff;\n    border-color: rgba(250, 245, 255, var(--divide-opacity));\n  }\n\n  .md\\:divide-purple-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #e9d8fd;\n    border-color: rgba(233, 216, 253, var(--divide-opacity));\n  }\n\n  .md\\:divide-purple-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #d6bcfa;\n    border-color: rgba(214, 188, 250, var(--divide-opacity));\n  }\n\n  .md\\:divide-purple-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #b794f4;\n    border-color: rgba(183, 148, 244, var(--divide-opacity));\n  }\n\n  .md\\:divide-purple-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #9f7aea;\n    border-color: rgba(159, 122, 234, var(--divide-opacity));\n  }\n\n  .md\\:divide-purple-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #805ad5;\n    border-color: rgba(128, 90, 213, var(--divide-opacity));\n  }\n\n  .md\\:divide-purple-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #6b46c1;\n    border-color: rgba(107, 70, 193, var(--divide-opacity));\n  }\n\n  .md\\:divide-purple-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #553c9a;\n    border-color: rgba(85, 60, 154, var(--divide-opacity));\n  }\n\n  .md\\:divide-purple-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #44337a;\n    border-color: rgba(68, 51, 122, var(--divide-opacity));\n  }\n\n  .md\\:divide-pink-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fff5f7;\n    border-color: rgba(255, 245, 247, var(--divide-opacity));\n  }\n\n  .md\\:divide-pink-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fed7e2;\n    border-color: rgba(254, 215, 226, var(--divide-opacity));\n  }\n\n  .md\\:divide-pink-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fbb6ce;\n    border-color: rgba(251, 182, 206, var(--divide-opacity));\n  }\n\n  .md\\:divide-pink-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #f687b3;\n    border-color: rgba(246, 135, 179, var(--divide-opacity));\n  }\n\n  .md\\:divide-pink-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #ed64a6;\n    border-color: rgba(237, 100, 166, var(--divide-opacity));\n  }\n\n  .md\\:divide-pink-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #d53f8c;\n    border-color: rgba(213, 63, 140, var(--divide-opacity));\n  }\n\n  .md\\:divide-pink-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #b83280;\n    border-color: rgba(184, 50, 128, var(--divide-opacity));\n  }\n\n  .md\\:divide-pink-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #97266d;\n    border-color: rgba(151, 38, 109, var(--divide-opacity));\n  }\n\n  .md\\:divide-pink-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #702459;\n    border-color: rgba(112, 36, 89, var(--divide-opacity));\n  }\n\n  .md\\:divide-grayscale-80 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 8%);\n    border-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--divide-opacity));\n  }\n\n  .md\\:divide-grayscale-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 10%);\n    border-color: rgba(25.5, 25.5, 25.5, var(--divide-opacity));\n  }\n\n  .md\\:divide-grayscale-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 20%);\n    border-color: rgba(51, 51, 51, var(--divide-opacity));\n  }\n\n  .md\\:divide-grayscale-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 30%);\n    border-color: rgba(76.5, 76.5, 76.5, var(--divide-opacity));\n  }\n\n  .md\\:divide-grayscale-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 40%);\n    border-color: rgba(102, 102, 102, var(--divide-opacity));\n  }\n\n  .md\\:divide-grayscale-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 50%);\n    border-color: rgba(127.5, 127.5, 127.5, var(--divide-opacity));\n  }\n\n  .md\\:divide-grayscale-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 60%);\n    border-color: rgba(153, 153, 153, var(--divide-opacity));\n  }\n\n  .md\\:divide-grayscale-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 70%);\n    border-color: rgba(178.5, 178.5, 178.5, var(--divide-opacity));\n  }\n\n  .md\\:divide-grayscale-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 80%);\n    border-color: rgba(204, 204, 204, var(--divide-opacity));\n  }\n\n  .md\\:divide-grayscale-840 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 84%);\n    border-color: rgba(214.2, 214.2, 214.2, var(--divide-opacity));\n  }\n\n  .md\\:divide-grayscale-870 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 87%);\n    border-color: rgba(221.85, 221.85, 221.85, var(--divide-opacity));\n  }\n\n  .md\\:divide-grayscale-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 90%);\n    border-color: rgba(229.5, 229.5, 229.5, var(--divide-opacity));\n  }\n\n  .md\\:divide-grayscale-930 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 93%);\n    border-color: rgba(237.15, 237.15, 237.15, var(--divide-opacity));\n  }\n\n  .md\\:divide-primary > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(210, 100%, 52%);\n    border-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--divide-opacity));\n  }\n\n  .md\\:divide-background-main > :not(template) ~ :not(template) {\n    border-color: var(--main-background);\n  }\n\n  .md\\:divide-background-secondary > :not(template) ~ :not(template) {\n    border-color: var(--secondary-background);\n  }\n\n  .md\\:divide-foreground > :not(template) ~ :not(template) {\n    border-color: var(--foreground);\n  }\n\n  .md\\:divide-panels-bg > :not(template) ~ :not(template) {\n    border-color: var(--panels-background);\n  }\n\n  .md\\:divide-solid > :not(template) ~ :not(template) {\n    border-style: solid;\n  }\n\n  .md\\:divide-dashed > :not(template) ~ :not(template) {\n    border-style: dashed;\n  }\n\n  .md\\:divide-dotted > :not(template) ~ :not(template) {\n    border-style: dotted;\n  }\n\n  .md\\:divide-double > :not(template) ~ :not(template) {\n    border-style: double;\n  }\n\n  .md\\:divide-none > :not(template) ~ :not(template) {\n    border-style: none;\n  }\n\n  .md\\:divide-opacity-0 > :not(template) ~ :not(template) {\n    --divide-opacity: 0;\n  }\n\n  .md\\:divide-opacity-25 > :not(template) ~ :not(template) {\n    --divide-opacity: 0.25;\n  }\n\n  .md\\:divide-opacity-50 > :not(template) ~ :not(template) {\n    --divide-opacity: 0.5;\n  }\n\n  .md\\:divide-opacity-75 > :not(template) ~ :not(template) {\n    --divide-opacity: 0.75;\n  }\n\n  .md\\:divide-opacity-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n  }\n\n  .md\\:sr-only {\n    position: absolute;\n    width: 1px;\n    height: 1px;\n    padding: 0;\n    margin: -1px;\n    overflow: hidden;\n    clip: rect(0, 0, 0, 0);\n    white-space: nowrap;\n    border-width: 0;\n  }\n\n  .md\\:not-sr-only {\n    position: static;\n    width: auto;\n    height: auto;\n    padding: 0;\n    margin: 0;\n    overflow: visible;\n    clip: auto;\n    white-space: normal;\n  }\n\n  .md\\:focus\\:sr-only:focus {\n    position: absolute;\n    width: 1px;\n    height: 1px;\n    padding: 0;\n    margin: -1px;\n    overflow: hidden;\n    clip: rect(0, 0, 0, 0);\n    white-space: nowrap;\n    border-width: 0;\n  }\n\n  .md\\:focus\\:not-sr-only:focus {\n    position: static;\n    width: auto;\n    height: auto;\n    padding: 0;\n    margin: 0;\n    overflow: visible;\n    clip: auto;\n    white-space: normal;\n  }\n\n  .md\\:appearance-none {\n    -webkit-appearance: none;\n       -moz-appearance: none;\n            appearance: none;\n  }\n\n  .md\\:bg-fixed {\n    background-attachment: fixed;\n  }\n\n  .md\\:bg-local {\n    background-attachment: local;\n  }\n\n  .md\\:bg-scroll {\n    background-attachment: scroll;\n  }\n\n  .md\\:bg-clip-border {\n    background-clip: border-box;\n  }\n\n  .md\\:bg-clip-padding {\n    background-clip: padding-box;\n  }\n\n  .md\\:bg-clip-content {\n    background-clip: content-box;\n  }\n\n  .md\\:bg-clip-text {\n    -webkit-background-clip: text;\n            background-clip: text;\n  }\n\n  .md\\:bg-transparent {\n    background-color: transparent;\n  }\n\n  .md\\:bg-current {\n    background-color: currentColor;\n  }\n\n  .md\\:bg-black {\n    --bg-opacity: 1;\n    background-color: #000;\n    background-color: rgba(0, 0, 0, var(--bg-opacity));\n  }\n\n  .md\\:bg-white {\n    --bg-opacity: 1;\n    background-color: #fff;\n    background-color: rgba(255, 255, 255, var(--bg-opacity));\n  }\n\n  .md\\:bg-gray-100 {\n    --bg-opacity: 1;\n    background-color: #f7fafc;\n    background-color: rgba(247, 250, 252, var(--bg-opacity));\n  }\n\n  .md\\:bg-gray-200 {\n    --bg-opacity: 1;\n    background-color: #edf2f7;\n    background-color: rgba(237, 242, 247, var(--bg-opacity));\n  }\n\n  .md\\:bg-gray-300 {\n    --bg-opacity: 1;\n    background-color: #e2e8f0;\n    background-color: rgba(226, 232, 240, var(--bg-opacity));\n  }\n\n  .md\\:bg-gray-400 {\n    --bg-opacity: 1;\n    background-color: #cbd5e0;\n    background-color: rgba(203, 213, 224, var(--bg-opacity));\n  }\n\n  .md\\:bg-gray-500 {\n    --bg-opacity: 1;\n    background-color: #a0aec0;\n    background-color: rgba(160, 174, 192, var(--bg-opacity));\n  }\n\n  .md\\:bg-gray-600 {\n    --bg-opacity: 1;\n    background-color: #718096;\n    background-color: rgba(113, 128, 150, var(--bg-opacity));\n  }\n\n  .md\\:bg-gray-700 {\n    --bg-opacity: 1;\n    background-color: #4a5568;\n    background-color: rgba(74, 85, 104, var(--bg-opacity));\n  }\n\n  .md\\:bg-gray-800 {\n    --bg-opacity: 1;\n    background-color: #2d3748;\n    background-color: rgba(45, 55, 72, var(--bg-opacity));\n  }\n\n  .md\\:bg-gray-900 {\n    --bg-opacity: 1;\n    background-color: #1a202c;\n    background-color: rgba(26, 32, 44, var(--bg-opacity));\n  }\n\n  .md\\:bg-red-100 {\n    --bg-opacity: 1;\n    background-color: #fff5f5;\n    background-color: rgba(255, 245, 245, var(--bg-opacity));\n  }\n\n  .md\\:bg-red-200 {\n    --bg-opacity: 1;\n    background-color: #fed7d7;\n    background-color: rgba(254, 215, 215, var(--bg-opacity));\n  }\n\n  .md\\:bg-red-300 {\n    --bg-opacity: 1;\n    background-color: #feb2b2;\n    background-color: rgba(254, 178, 178, var(--bg-opacity));\n  }\n\n  .md\\:bg-red-400 {\n    --bg-opacity: 1;\n    background-color: #fc8181;\n    background-color: rgba(252, 129, 129, var(--bg-opacity));\n  }\n\n  .md\\:bg-red-500 {\n    --bg-opacity: 1;\n    background-color: #f56565;\n    background-color: rgba(245, 101, 101, var(--bg-opacity));\n  }\n\n  .md\\:bg-red-600 {\n    --bg-opacity: 1;\n    background-color: #e53e3e;\n    background-color: rgba(229, 62, 62, var(--bg-opacity));\n  }\n\n  .md\\:bg-red-700 {\n    --bg-opacity: 1;\n    background-color: #c53030;\n    background-color: rgba(197, 48, 48, var(--bg-opacity));\n  }\n\n  .md\\:bg-red-800 {\n    --bg-opacity: 1;\n    background-color: #9b2c2c;\n    background-color: rgba(155, 44, 44, var(--bg-opacity));\n  }\n\n  .md\\:bg-red-900 {\n    --bg-opacity: 1;\n    background-color: #742a2a;\n    background-color: rgba(116, 42, 42, var(--bg-opacity));\n  }\n\n  .md\\:bg-orange-100 {\n    --bg-opacity: 1;\n    background-color: #fffaf0;\n    background-color: rgba(255, 250, 240, var(--bg-opacity));\n  }\n\n  .md\\:bg-orange-200 {\n    --bg-opacity: 1;\n    background-color: #feebc8;\n    background-color: rgba(254, 235, 200, var(--bg-opacity));\n  }\n\n  .md\\:bg-orange-300 {\n    --bg-opacity: 1;\n    background-color: #fbd38d;\n    background-color: rgba(251, 211, 141, var(--bg-opacity));\n  }\n\n  .md\\:bg-orange-400 {\n    --bg-opacity: 1;\n    background-color: #f6ad55;\n    background-color: rgba(246, 173, 85, var(--bg-opacity));\n  }\n\n  .md\\:bg-orange-500 {\n    --bg-opacity: 1;\n    background-color: #ed8936;\n    background-color: rgba(237, 137, 54, var(--bg-opacity));\n  }\n\n  .md\\:bg-orange-600 {\n    --bg-opacity: 1;\n    background-color: #dd6b20;\n    background-color: rgba(221, 107, 32, var(--bg-opacity));\n  }\n\n  .md\\:bg-orange-700 {\n    --bg-opacity: 1;\n    background-color: #c05621;\n    background-color: rgba(192, 86, 33, var(--bg-opacity));\n  }\n\n  .md\\:bg-orange-800 {\n    --bg-opacity: 1;\n    background-color: #9c4221;\n    background-color: rgba(156, 66, 33, var(--bg-opacity));\n  }\n\n  .md\\:bg-orange-900 {\n    --bg-opacity: 1;\n    background-color: #7b341e;\n    background-color: rgba(123, 52, 30, var(--bg-opacity));\n  }\n\n  .md\\:bg-yellow-100 {\n    --bg-opacity: 1;\n    background-color: #fffff0;\n    background-color: rgba(255, 255, 240, var(--bg-opacity));\n  }\n\n  .md\\:bg-yellow-200 {\n    --bg-opacity: 1;\n    background-color: #fefcbf;\n    background-color: rgba(254, 252, 191, var(--bg-opacity));\n  }\n\n  .md\\:bg-yellow-300 {\n    --bg-opacity: 1;\n    background-color: #faf089;\n    background-color: rgba(250, 240, 137, var(--bg-opacity));\n  }\n\n  .md\\:bg-yellow-400 {\n    --bg-opacity: 1;\n    background-color: #f6e05e;\n    background-color: rgba(246, 224, 94, var(--bg-opacity));\n  }\n\n  .md\\:bg-yellow-500 {\n    --bg-opacity: 1;\n    background-color: #ecc94b;\n    background-color: rgba(236, 201, 75, var(--bg-opacity));\n  }\n\n  .md\\:bg-yellow-600 {\n    --bg-opacity: 1;\n    background-color: #d69e2e;\n    background-color: rgba(214, 158, 46, var(--bg-opacity));\n  }\n\n  .md\\:bg-yellow-700 {\n    --bg-opacity: 1;\n    background-color: #b7791f;\n    background-color: rgba(183, 121, 31, var(--bg-opacity));\n  }\n\n  .md\\:bg-yellow-800 {\n    --bg-opacity: 1;\n    background-color: #975a16;\n    background-color: rgba(151, 90, 22, var(--bg-opacity));\n  }\n\n  .md\\:bg-yellow-900 {\n    --bg-opacity: 1;\n    background-color: #744210;\n    background-color: rgba(116, 66, 16, var(--bg-opacity));\n  }\n\n  .md\\:bg-green-100 {\n    --bg-opacity: 1;\n    background-color: #f0fff4;\n    background-color: rgba(240, 255, 244, var(--bg-opacity));\n  }\n\n  .md\\:bg-green-200 {\n    --bg-opacity: 1;\n    background-color: #c6f6d5;\n    background-color: rgba(198, 246, 213, var(--bg-opacity));\n  }\n\n  .md\\:bg-green-300 {\n    --bg-opacity: 1;\n    background-color: #9ae6b4;\n    background-color: rgba(154, 230, 180, var(--bg-opacity));\n  }\n\n  .md\\:bg-green-400 {\n    --bg-opacity: 1;\n    background-color: #68d391;\n    background-color: rgba(104, 211, 145, var(--bg-opacity));\n  }\n\n  .md\\:bg-green-500 {\n    --bg-opacity: 1;\n    background-color: #48bb78;\n    background-color: rgba(72, 187, 120, var(--bg-opacity));\n  }\n\n  .md\\:bg-green-600 {\n    --bg-opacity: 1;\n    background-color: #38a169;\n    background-color: rgba(56, 161, 105, var(--bg-opacity));\n  }\n\n  .md\\:bg-green-700 {\n    --bg-opacity: 1;\n    background-color: #2f855a;\n    background-color: rgba(47, 133, 90, var(--bg-opacity));\n  }\n\n  .md\\:bg-green-800 {\n    --bg-opacity: 1;\n    background-color: #276749;\n    background-color: rgba(39, 103, 73, var(--bg-opacity));\n  }\n\n  .md\\:bg-green-900 {\n    --bg-opacity: 1;\n    background-color: #22543d;\n    background-color: rgba(34, 84, 61, var(--bg-opacity));\n  }\n\n  .md\\:bg-teal-100 {\n    --bg-opacity: 1;\n    background-color: #e6fffa;\n    background-color: rgba(230, 255, 250, var(--bg-opacity));\n  }\n\n  .md\\:bg-teal-200 {\n    --bg-opacity: 1;\n    background-color: #b2f5ea;\n    background-color: rgba(178, 245, 234, var(--bg-opacity));\n  }\n\n  .md\\:bg-teal-300 {\n    --bg-opacity: 1;\n    background-color: #81e6d9;\n    background-color: rgba(129, 230, 217, var(--bg-opacity));\n  }\n\n  .md\\:bg-teal-400 {\n    --bg-opacity: 1;\n    background-color: #4fd1c5;\n    background-color: rgba(79, 209, 197, var(--bg-opacity));\n  }\n\n  .md\\:bg-teal-500 {\n    --bg-opacity: 1;\n    background-color: #38b2ac;\n    background-color: rgba(56, 178, 172, var(--bg-opacity));\n  }\n\n  .md\\:bg-teal-600 {\n    --bg-opacity: 1;\n    background-color: #319795;\n    background-color: rgba(49, 151, 149, var(--bg-opacity));\n  }\n\n  .md\\:bg-teal-700 {\n    --bg-opacity: 1;\n    background-color: #2c7a7b;\n    background-color: rgba(44, 122, 123, var(--bg-opacity));\n  }\n\n  .md\\:bg-teal-800 {\n    --bg-opacity: 1;\n    background-color: #285e61;\n    background-color: rgba(40, 94, 97, var(--bg-opacity));\n  }\n\n  .md\\:bg-teal-900 {\n    --bg-opacity: 1;\n    background-color: #234e52;\n    background-color: rgba(35, 78, 82, var(--bg-opacity));\n  }\n\n  .md\\:bg-blue-100 {\n    --bg-opacity: 1;\n    background-color: #ebf8ff;\n    background-color: rgba(235, 248, 255, var(--bg-opacity));\n  }\n\n  .md\\:bg-blue-200 {\n    --bg-opacity: 1;\n    background-color: #bee3f8;\n    background-color: rgba(190, 227, 248, var(--bg-opacity));\n  }\n\n  .md\\:bg-blue-300 {\n    --bg-opacity: 1;\n    background-color: #90cdf4;\n    background-color: rgba(144, 205, 244, var(--bg-opacity));\n  }\n\n  .md\\:bg-blue-400 {\n    --bg-opacity: 1;\n    background-color: #63b3ed;\n    background-color: rgba(99, 179, 237, var(--bg-opacity));\n  }\n\n  .md\\:bg-blue-500 {\n    --bg-opacity: 1;\n    background-color: #4299e1;\n    background-color: rgba(66, 153, 225, var(--bg-opacity));\n  }\n\n  .md\\:bg-blue-600 {\n    --bg-opacity: 1;\n    background-color: #3182ce;\n    background-color: rgba(49, 130, 206, var(--bg-opacity));\n  }\n\n  .md\\:bg-blue-700 {\n    --bg-opacity: 1;\n    background-color: #2b6cb0;\n    background-color: rgba(43, 108, 176, var(--bg-opacity));\n  }\n\n  .md\\:bg-blue-800 {\n    --bg-opacity: 1;\n    background-color: #2c5282;\n    background-color: rgba(44, 82, 130, var(--bg-opacity));\n  }\n\n  .md\\:bg-blue-900 {\n    --bg-opacity: 1;\n    background-color: #2a4365;\n    background-color: rgba(42, 67, 101, var(--bg-opacity));\n  }\n\n  .md\\:bg-indigo-100 {\n    --bg-opacity: 1;\n    background-color: #ebf4ff;\n    background-color: rgba(235, 244, 255, var(--bg-opacity));\n  }\n\n  .md\\:bg-indigo-200 {\n    --bg-opacity: 1;\n    background-color: #c3dafe;\n    background-color: rgba(195, 218, 254, var(--bg-opacity));\n  }\n\n  .md\\:bg-indigo-300 {\n    --bg-opacity: 1;\n    background-color: #a3bffa;\n    background-color: rgba(163, 191, 250, var(--bg-opacity));\n  }\n\n  .md\\:bg-indigo-400 {\n    --bg-opacity: 1;\n    background-color: #7f9cf5;\n    background-color: rgba(127, 156, 245, var(--bg-opacity));\n  }\n\n  .md\\:bg-indigo-500 {\n    --bg-opacity: 1;\n    background-color: #667eea;\n    background-color: rgba(102, 126, 234, var(--bg-opacity));\n  }\n\n  .md\\:bg-indigo-600 {\n    --bg-opacity: 1;\n    background-color: #5a67d8;\n    background-color: rgba(90, 103, 216, var(--bg-opacity));\n  }\n\n  .md\\:bg-indigo-700 {\n    --bg-opacity: 1;\n    background-color: #4c51bf;\n    background-color: rgba(76, 81, 191, var(--bg-opacity));\n  }\n\n  .md\\:bg-indigo-800 {\n    --bg-opacity: 1;\n    background-color: #434190;\n    background-color: rgba(67, 65, 144, var(--bg-opacity));\n  }\n\n  .md\\:bg-indigo-900 {\n    --bg-opacity: 1;\n    background-color: #3c366b;\n    background-color: rgba(60, 54, 107, var(--bg-opacity));\n  }\n\n  .md\\:bg-purple-100 {\n    --bg-opacity: 1;\n    background-color: #faf5ff;\n    background-color: rgba(250, 245, 255, var(--bg-opacity));\n  }\n\n  .md\\:bg-purple-200 {\n    --bg-opacity: 1;\n    background-color: #e9d8fd;\n    background-color: rgba(233, 216, 253, var(--bg-opacity));\n  }\n\n  .md\\:bg-purple-300 {\n    --bg-opacity: 1;\n    background-color: #d6bcfa;\n    background-color: rgba(214, 188, 250, var(--bg-opacity));\n  }\n\n  .md\\:bg-purple-400 {\n    --bg-opacity: 1;\n    background-color: #b794f4;\n    background-color: rgba(183, 148, 244, var(--bg-opacity));\n  }\n\n  .md\\:bg-purple-500 {\n    --bg-opacity: 1;\n    background-color: #9f7aea;\n    background-color: rgba(159, 122, 234, var(--bg-opacity));\n  }\n\n  .md\\:bg-purple-600 {\n    --bg-opacity: 1;\n    background-color: #805ad5;\n    background-color: rgba(128, 90, 213, var(--bg-opacity));\n  }\n\n  .md\\:bg-purple-700 {\n    --bg-opacity: 1;\n    background-color: #6b46c1;\n    background-color: rgba(107, 70, 193, var(--bg-opacity));\n  }\n\n  .md\\:bg-purple-800 {\n    --bg-opacity: 1;\n    background-color: #553c9a;\n    background-color: rgba(85, 60, 154, var(--bg-opacity));\n  }\n\n  .md\\:bg-purple-900 {\n    --bg-opacity: 1;\n    background-color: #44337a;\n    background-color: rgba(68, 51, 122, var(--bg-opacity));\n  }\n\n  .md\\:bg-pink-100 {\n    --bg-opacity: 1;\n    background-color: #fff5f7;\n    background-color: rgba(255, 245, 247, var(--bg-opacity));\n  }\n\n  .md\\:bg-pink-200 {\n    --bg-opacity: 1;\n    background-color: #fed7e2;\n    background-color: rgba(254, 215, 226, var(--bg-opacity));\n  }\n\n  .md\\:bg-pink-300 {\n    --bg-opacity: 1;\n    background-color: #fbb6ce;\n    background-color: rgba(251, 182, 206, var(--bg-opacity));\n  }\n\n  .md\\:bg-pink-400 {\n    --bg-opacity: 1;\n    background-color: #f687b3;\n    background-color: rgba(246, 135, 179, var(--bg-opacity));\n  }\n\n  .md\\:bg-pink-500 {\n    --bg-opacity: 1;\n    background-color: #ed64a6;\n    background-color: rgba(237, 100, 166, var(--bg-opacity));\n  }\n\n  .md\\:bg-pink-600 {\n    --bg-opacity: 1;\n    background-color: #d53f8c;\n    background-color: rgba(213, 63, 140, var(--bg-opacity));\n  }\n\n  .md\\:bg-pink-700 {\n    --bg-opacity: 1;\n    background-color: #b83280;\n    background-color: rgba(184, 50, 128, var(--bg-opacity));\n  }\n\n  .md\\:bg-pink-800 {\n    --bg-opacity: 1;\n    background-color: #97266d;\n    background-color: rgba(151, 38, 109, var(--bg-opacity));\n  }\n\n  .md\\:bg-pink-900 {\n    --bg-opacity: 1;\n    background-color: #702459;\n    background-color: rgba(112, 36, 89, var(--bg-opacity));\n  }\n\n  .md\\:bg-grayscale-80 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 8%);\n    background-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--bg-opacity));\n  }\n\n  .md\\:bg-grayscale-100 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 10%);\n    background-color: rgba(25.5, 25.5, 25.5, var(--bg-opacity));\n  }\n\n  .md\\:bg-grayscale-200 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 20%);\n    background-color: rgba(51, 51, 51, var(--bg-opacity));\n  }\n\n  .md\\:bg-grayscale-300 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 30%);\n    background-color: rgba(76.5, 76.5, 76.5, var(--bg-opacity));\n  }\n\n  .md\\:bg-grayscale-400 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 40%);\n    background-color: rgba(102, 102, 102, var(--bg-opacity));\n  }\n\n  .md\\:bg-grayscale-500 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 50%);\n    background-color: rgba(127.5, 127.5, 127.5, var(--bg-opacity));\n  }\n\n  .md\\:bg-grayscale-600 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 60%);\n    background-color: rgba(153, 153, 153, var(--bg-opacity));\n  }\n\n  .md\\:bg-grayscale-700 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 70%);\n    background-color: rgba(178.5, 178.5, 178.5, var(--bg-opacity));\n  }\n\n  .md\\:bg-grayscale-800 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 80%);\n    background-color: rgba(204, 204, 204, var(--bg-opacity));\n  }\n\n  .md\\:bg-grayscale-840 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 84%);\n    background-color: rgba(214.2, 214.2, 214.2, var(--bg-opacity));\n  }\n\n  .md\\:bg-grayscale-870 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 87%);\n    background-color: rgba(221.85, 221.85, 221.85, var(--bg-opacity));\n  }\n\n  .md\\:bg-grayscale-900 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 90%);\n    background-color: rgba(229.5, 229.5, 229.5, var(--bg-opacity));\n  }\n\n  .md\\:bg-grayscale-930 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 93%);\n    background-color: rgba(237.15, 237.15, 237.15, var(--bg-opacity));\n  }\n\n  .md\\:bg-primary {\n    --bg-opacity: 1;\n    background-color: hsl(210, 100%, 52%);\n    background-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--bg-opacity));\n  }\n\n  .md\\:bg-background-main {\n    background-color: var(--main-background);\n  }\n\n  .md\\:bg-background-secondary {\n    background-color: var(--secondary-background);\n  }\n\n  .md\\:bg-foreground {\n    background-color: var(--foreground);\n  }\n\n  .md\\:bg-panels-bg {\n    background-color: var(--panels-background);\n  }\n\n  .md\\:hover\\:bg-transparent:hover {\n    background-color: transparent;\n  }\n\n  .md\\:hover\\:bg-current:hover {\n    background-color: currentColor;\n  }\n\n  .md\\:hover\\:bg-black:hover {\n    --bg-opacity: 1;\n    background-color: #000;\n    background-color: rgba(0, 0, 0, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-white:hover {\n    --bg-opacity: 1;\n    background-color: #fff;\n    background-color: rgba(255, 255, 255, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-gray-100:hover {\n    --bg-opacity: 1;\n    background-color: #f7fafc;\n    background-color: rgba(247, 250, 252, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-gray-200:hover {\n    --bg-opacity: 1;\n    background-color: #edf2f7;\n    background-color: rgba(237, 242, 247, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-gray-300:hover {\n    --bg-opacity: 1;\n    background-color: #e2e8f0;\n    background-color: rgba(226, 232, 240, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-gray-400:hover {\n    --bg-opacity: 1;\n    background-color: #cbd5e0;\n    background-color: rgba(203, 213, 224, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-gray-500:hover {\n    --bg-opacity: 1;\n    background-color: #a0aec0;\n    background-color: rgba(160, 174, 192, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-gray-600:hover {\n    --bg-opacity: 1;\n    background-color: #718096;\n    background-color: rgba(113, 128, 150, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-gray-700:hover {\n    --bg-opacity: 1;\n    background-color: #4a5568;\n    background-color: rgba(74, 85, 104, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-gray-800:hover {\n    --bg-opacity: 1;\n    background-color: #2d3748;\n    background-color: rgba(45, 55, 72, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-gray-900:hover {\n    --bg-opacity: 1;\n    background-color: #1a202c;\n    background-color: rgba(26, 32, 44, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-red-100:hover {\n    --bg-opacity: 1;\n    background-color: #fff5f5;\n    background-color: rgba(255, 245, 245, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-red-200:hover {\n    --bg-opacity: 1;\n    background-color: #fed7d7;\n    background-color: rgba(254, 215, 215, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-red-300:hover {\n    --bg-opacity: 1;\n    background-color: #feb2b2;\n    background-color: rgba(254, 178, 178, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-red-400:hover {\n    --bg-opacity: 1;\n    background-color: #fc8181;\n    background-color: rgba(252, 129, 129, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-red-500:hover {\n    --bg-opacity: 1;\n    background-color: #f56565;\n    background-color: rgba(245, 101, 101, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-red-600:hover {\n    --bg-opacity: 1;\n    background-color: #e53e3e;\n    background-color: rgba(229, 62, 62, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-red-700:hover {\n    --bg-opacity: 1;\n    background-color: #c53030;\n    background-color: rgba(197, 48, 48, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-red-800:hover {\n    --bg-opacity: 1;\n    background-color: #9b2c2c;\n    background-color: rgba(155, 44, 44, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-red-900:hover {\n    --bg-opacity: 1;\n    background-color: #742a2a;\n    background-color: rgba(116, 42, 42, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-orange-100:hover {\n    --bg-opacity: 1;\n    background-color: #fffaf0;\n    background-color: rgba(255, 250, 240, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-orange-200:hover {\n    --bg-opacity: 1;\n    background-color: #feebc8;\n    background-color: rgba(254, 235, 200, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-orange-300:hover {\n    --bg-opacity: 1;\n    background-color: #fbd38d;\n    background-color: rgba(251, 211, 141, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-orange-400:hover {\n    --bg-opacity: 1;\n    background-color: #f6ad55;\n    background-color: rgba(246, 173, 85, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-orange-500:hover {\n    --bg-opacity: 1;\n    background-color: #ed8936;\n    background-color: rgba(237, 137, 54, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-orange-600:hover {\n    --bg-opacity: 1;\n    background-color: #dd6b20;\n    background-color: rgba(221, 107, 32, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-orange-700:hover {\n    --bg-opacity: 1;\n    background-color: #c05621;\n    background-color: rgba(192, 86, 33, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-orange-800:hover {\n    --bg-opacity: 1;\n    background-color: #9c4221;\n    background-color: rgba(156, 66, 33, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-orange-900:hover {\n    --bg-opacity: 1;\n    background-color: #7b341e;\n    background-color: rgba(123, 52, 30, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-yellow-100:hover {\n    --bg-opacity: 1;\n    background-color: #fffff0;\n    background-color: rgba(255, 255, 240, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-yellow-200:hover {\n    --bg-opacity: 1;\n    background-color: #fefcbf;\n    background-color: rgba(254, 252, 191, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-yellow-300:hover {\n    --bg-opacity: 1;\n    background-color: #faf089;\n    background-color: rgba(250, 240, 137, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-yellow-400:hover {\n    --bg-opacity: 1;\n    background-color: #f6e05e;\n    background-color: rgba(246, 224, 94, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-yellow-500:hover {\n    --bg-opacity: 1;\n    background-color: #ecc94b;\n    background-color: rgba(236, 201, 75, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-yellow-600:hover {\n    --bg-opacity: 1;\n    background-color: #d69e2e;\n    background-color: rgba(214, 158, 46, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-yellow-700:hover {\n    --bg-opacity: 1;\n    background-color: #b7791f;\n    background-color: rgba(183, 121, 31, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-yellow-800:hover {\n    --bg-opacity: 1;\n    background-color: #975a16;\n    background-color: rgba(151, 90, 22, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-yellow-900:hover {\n    --bg-opacity: 1;\n    background-color: #744210;\n    background-color: rgba(116, 66, 16, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-green-100:hover {\n    --bg-opacity: 1;\n    background-color: #f0fff4;\n    background-color: rgba(240, 255, 244, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-green-200:hover {\n    --bg-opacity: 1;\n    background-color: #c6f6d5;\n    background-color: rgba(198, 246, 213, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-green-300:hover {\n    --bg-opacity: 1;\n    background-color: #9ae6b4;\n    background-color: rgba(154, 230, 180, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-green-400:hover {\n    --bg-opacity: 1;\n    background-color: #68d391;\n    background-color: rgba(104, 211, 145, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-green-500:hover {\n    --bg-opacity: 1;\n    background-color: #48bb78;\n    background-color: rgba(72, 187, 120, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-green-600:hover {\n    --bg-opacity: 1;\n    background-color: #38a169;\n    background-color: rgba(56, 161, 105, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-green-700:hover {\n    --bg-opacity: 1;\n    background-color: #2f855a;\n    background-color: rgba(47, 133, 90, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-green-800:hover {\n    --bg-opacity: 1;\n    background-color: #276749;\n    background-color: rgba(39, 103, 73, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-green-900:hover {\n    --bg-opacity: 1;\n    background-color: #22543d;\n    background-color: rgba(34, 84, 61, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-teal-100:hover {\n    --bg-opacity: 1;\n    background-color: #e6fffa;\n    background-color: rgba(230, 255, 250, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-teal-200:hover {\n    --bg-opacity: 1;\n    background-color: #b2f5ea;\n    background-color: rgba(178, 245, 234, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-teal-300:hover {\n    --bg-opacity: 1;\n    background-color: #81e6d9;\n    background-color: rgba(129, 230, 217, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-teal-400:hover {\n    --bg-opacity: 1;\n    background-color: #4fd1c5;\n    background-color: rgba(79, 209, 197, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-teal-500:hover {\n    --bg-opacity: 1;\n    background-color: #38b2ac;\n    background-color: rgba(56, 178, 172, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-teal-600:hover {\n    --bg-opacity: 1;\n    background-color: #319795;\n    background-color: rgba(49, 151, 149, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-teal-700:hover {\n    --bg-opacity: 1;\n    background-color: #2c7a7b;\n    background-color: rgba(44, 122, 123, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-teal-800:hover {\n    --bg-opacity: 1;\n    background-color: #285e61;\n    background-color: rgba(40, 94, 97, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-teal-900:hover {\n    --bg-opacity: 1;\n    background-color: #234e52;\n    background-color: rgba(35, 78, 82, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-blue-100:hover {\n    --bg-opacity: 1;\n    background-color: #ebf8ff;\n    background-color: rgba(235, 248, 255, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-blue-200:hover {\n    --bg-opacity: 1;\n    background-color: #bee3f8;\n    background-color: rgba(190, 227, 248, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-blue-300:hover {\n    --bg-opacity: 1;\n    background-color: #90cdf4;\n    background-color: rgba(144, 205, 244, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-blue-400:hover {\n    --bg-opacity: 1;\n    background-color: #63b3ed;\n    background-color: rgba(99, 179, 237, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-blue-500:hover {\n    --bg-opacity: 1;\n    background-color: #4299e1;\n    background-color: rgba(66, 153, 225, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-blue-600:hover {\n    --bg-opacity: 1;\n    background-color: #3182ce;\n    background-color: rgba(49, 130, 206, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-blue-700:hover {\n    --bg-opacity: 1;\n    background-color: #2b6cb0;\n    background-color: rgba(43, 108, 176, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-blue-800:hover {\n    --bg-opacity: 1;\n    background-color: #2c5282;\n    background-color: rgba(44, 82, 130, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-blue-900:hover {\n    --bg-opacity: 1;\n    background-color: #2a4365;\n    background-color: rgba(42, 67, 101, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-indigo-100:hover {\n    --bg-opacity: 1;\n    background-color: #ebf4ff;\n    background-color: rgba(235, 244, 255, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-indigo-200:hover {\n    --bg-opacity: 1;\n    background-color: #c3dafe;\n    background-color: rgba(195, 218, 254, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-indigo-300:hover {\n    --bg-opacity: 1;\n    background-color: #a3bffa;\n    background-color: rgba(163, 191, 250, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-indigo-400:hover {\n    --bg-opacity: 1;\n    background-color: #7f9cf5;\n    background-color: rgba(127, 156, 245, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-indigo-500:hover {\n    --bg-opacity: 1;\n    background-color: #667eea;\n    background-color: rgba(102, 126, 234, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-indigo-600:hover {\n    --bg-opacity: 1;\n    background-color: #5a67d8;\n    background-color: rgba(90, 103, 216, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-indigo-700:hover {\n    --bg-opacity: 1;\n    background-color: #4c51bf;\n    background-color: rgba(76, 81, 191, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-indigo-800:hover {\n    --bg-opacity: 1;\n    background-color: #434190;\n    background-color: rgba(67, 65, 144, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-indigo-900:hover {\n    --bg-opacity: 1;\n    background-color: #3c366b;\n    background-color: rgba(60, 54, 107, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-purple-100:hover {\n    --bg-opacity: 1;\n    background-color: #faf5ff;\n    background-color: rgba(250, 245, 255, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-purple-200:hover {\n    --bg-opacity: 1;\n    background-color: #e9d8fd;\n    background-color: rgba(233, 216, 253, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-purple-300:hover {\n    --bg-opacity: 1;\n    background-color: #d6bcfa;\n    background-color: rgba(214, 188, 250, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-purple-400:hover {\n    --bg-opacity: 1;\n    background-color: #b794f4;\n    background-color: rgba(183, 148, 244, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-purple-500:hover {\n    --bg-opacity: 1;\n    background-color: #9f7aea;\n    background-color: rgba(159, 122, 234, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-purple-600:hover {\n    --bg-opacity: 1;\n    background-color: #805ad5;\n    background-color: rgba(128, 90, 213, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-purple-700:hover {\n    --bg-opacity: 1;\n    background-color: #6b46c1;\n    background-color: rgba(107, 70, 193, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-purple-800:hover {\n    --bg-opacity: 1;\n    background-color: #553c9a;\n    background-color: rgba(85, 60, 154, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-purple-900:hover {\n    --bg-opacity: 1;\n    background-color: #44337a;\n    background-color: rgba(68, 51, 122, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-pink-100:hover {\n    --bg-opacity: 1;\n    background-color: #fff5f7;\n    background-color: rgba(255, 245, 247, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-pink-200:hover {\n    --bg-opacity: 1;\n    background-color: #fed7e2;\n    background-color: rgba(254, 215, 226, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-pink-300:hover {\n    --bg-opacity: 1;\n    background-color: #fbb6ce;\n    background-color: rgba(251, 182, 206, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-pink-400:hover {\n    --bg-opacity: 1;\n    background-color: #f687b3;\n    background-color: rgba(246, 135, 179, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-pink-500:hover {\n    --bg-opacity: 1;\n    background-color: #ed64a6;\n    background-color: rgba(237, 100, 166, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-pink-600:hover {\n    --bg-opacity: 1;\n    background-color: #d53f8c;\n    background-color: rgba(213, 63, 140, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-pink-700:hover {\n    --bg-opacity: 1;\n    background-color: #b83280;\n    background-color: rgba(184, 50, 128, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-pink-800:hover {\n    --bg-opacity: 1;\n    background-color: #97266d;\n    background-color: rgba(151, 38, 109, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-pink-900:hover {\n    --bg-opacity: 1;\n    background-color: #702459;\n    background-color: rgba(112, 36, 89, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-grayscale-80:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 8%);\n    background-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-grayscale-100:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 10%);\n    background-color: rgba(25.5, 25.5, 25.5, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-grayscale-200:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 20%);\n    background-color: rgba(51, 51, 51, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-grayscale-300:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 30%);\n    background-color: rgba(76.5, 76.5, 76.5, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-grayscale-400:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 40%);\n    background-color: rgba(102, 102, 102, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-grayscale-500:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 50%);\n    background-color: rgba(127.5, 127.5, 127.5, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-grayscale-600:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 60%);\n    background-color: rgba(153, 153, 153, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-grayscale-700:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 70%);\n    background-color: rgba(178.5, 178.5, 178.5, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-grayscale-800:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 80%);\n    background-color: rgba(204, 204, 204, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-grayscale-840:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 84%);\n    background-color: rgba(214.2, 214.2, 214.2, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-grayscale-870:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 87%);\n    background-color: rgba(221.85, 221.85, 221.85, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-grayscale-900:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 90%);\n    background-color: rgba(229.5, 229.5, 229.5, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-grayscale-930:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 93%);\n    background-color: rgba(237.15, 237.15, 237.15, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-primary:hover {\n    --bg-opacity: 1;\n    background-color: hsl(210, 100%, 52%);\n    background-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--bg-opacity));\n  }\n\n  .md\\:hover\\:bg-background-main:hover {\n    background-color: var(--main-background);\n  }\n\n  .md\\:hover\\:bg-background-secondary:hover {\n    background-color: var(--secondary-background);\n  }\n\n  .md\\:hover\\:bg-foreground:hover {\n    background-color: var(--foreground);\n  }\n\n  .md\\:hover\\:bg-panels-bg:hover {\n    background-color: var(--panels-background);\n  }\n\n  .md\\:focus\\:bg-transparent:focus {\n    background-color: transparent;\n  }\n\n  .md\\:focus\\:bg-current:focus {\n    background-color: currentColor;\n  }\n\n  .md\\:focus\\:bg-black:focus {\n    --bg-opacity: 1;\n    background-color: #000;\n    background-color: rgba(0, 0, 0, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-white:focus {\n    --bg-opacity: 1;\n    background-color: #fff;\n    background-color: rgba(255, 255, 255, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-gray-100:focus {\n    --bg-opacity: 1;\n    background-color: #f7fafc;\n    background-color: rgba(247, 250, 252, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-gray-200:focus {\n    --bg-opacity: 1;\n    background-color: #edf2f7;\n    background-color: rgba(237, 242, 247, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-gray-300:focus {\n    --bg-opacity: 1;\n    background-color: #e2e8f0;\n    background-color: rgba(226, 232, 240, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-gray-400:focus {\n    --bg-opacity: 1;\n    background-color: #cbd5e0;\n    background-color: rgba(203, 213, 224, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-gray-500:focus {\n    --bg-opacity: 1;\n    background-color: #a0aec0;\n    background-color: rgba(160, 174, 192, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-gray-600:focus {\n    --bg-opacity: 1;\n    background-color: #718096;\n    background-color: rgba(113, 128, 150, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-gray-700:focus {\n    --bg-opacity: 1;\n    background-color: #4a5568;\n    background-color: rgba(74, 85, 104, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-gray-800:focus {\n    --bg-opacity: 1;\n    background-color: #2d3748;\n    background-color: rgba(45, 55, 72, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-gray-900:focus {\n    --bg-opacity: 1;\n    background-color: #1a202c;\n    background-color: rgba(26, 32, 44, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-red-100:focus {\n    --bg-opacity: 1;\n    background-color: #fff5f5;\n    background-color: rgba(255, 245, 245, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-red-200:focus {\n    --bg-opacity: 1;\n    background-color: #fed7d7;\n    background-color: rgba(254, 215, 215, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-red-300:focus {\n    --bg-opacity: 1;\n    background-color: #feb2b2;\n    background-color: rgba(254, 178, 178, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-red-400:focus {\n    --bg-opacity: 1;\n    background-color: #fc8181;\n    background-color: rgba(252, 129, 129, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-red-500:focus {\n    --bg-opacity: 1;\n    background-color: #f56565;\n    background-color: rgba(245, 101, 101, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-red-600:focus {\n    --bg-opacity: 1;\n    background-color: #e53e3e;\n    background-color: rgba(229, 62, 62, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-red-700:focus {\n    --bg-opacity: 1;\n    background-color: #c53030;\n    background-color: rgba(197, 48, 48, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-red-800:focus {\n    --bg-opacity: 1;\n    background-color: #9b2c2c;\n    background-color: rgba(155, 44, 44, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-red-900:focus {\n    --bg-opacity: 1;\n    background-color: #742a2a;\n    background-color: rgba(116, 42, 42, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-orange-100:focus {\n    --bg-opacity: 1;\n    background-color: #fffaf0;\n    background-color: rgba(255, 250, 240, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-orange-200:focus {\n    --bg-opacity: 1;\n    background-color: #feebc8;\n    background-color: rgba(254, 235, 200, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-orange-300:focus {\n    --bg-opacity: 1;\n    background-color: #fbd38d;\n    background-color: rgba(251, 211, 141, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-orange-400:focus {\n    --bg-opacity: 1;\n    background-color: #f6ad55;\n    background-color: rgba(246, 173, 85, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-orange-500:focus {\n    --bg-opacity: 1;\n    background-color: #ed8936;\n    background-color: rgba(237, 137, 54, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-orange-600:focus {\n    --bg-opacity: 1;\n    background-color: #dd6b20;\n    background-color: rgba(221, 107, 32, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-orange-700:focus {\n    --bg-opacity: 1;\n    background-color: #c05621;\n    background-color: rgba(192, 86, 33, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-orange-800:focus {\n    --bg-opacity: 1;\n    background-color: #9c4221;\n    background-color: rgba(156, 66, 33, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-orange-900:focus {\n    --bg-opacity: 1;\n    background-color: #7b341e;\n    background-color: rgba(123, 52, 30, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-yellow-100:focus {\n    --bg-opacity: 1;\n    background-color: #fffff0;\n    background-color: rgba(255, 255, 240, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-yellow-200:focus {\n    --bg-opacity: 1;\n    background-color: #fefcbf;\n    background-color: rgba(254, 252, 191, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-yellow-300:focus {\n    --bg-opacity: 1;\n    background-color: #faf089;\n    background-color: rgba(250, 240, 137, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-yellow-400:focus {\n    --bg-opacity: 1;\n    background-color: #f6e05e;\n    background-color: rgba(246, 224, 94, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-yellow-500:focus {\n    --bg-opacity: 1;\n    background-color: #ecc94b;\n    background-color: rgba(236, 201, 75, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-yellow-600:focus {\n    --bg-opacity: 1;\n    background-color: #d69e2e;\n    background-color: rgba(214, 158, 46, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-yellow-700:focus {\n    --bg-opacity: 1;\n    background-color: #b7791f;\n    background-color: rgba(183, 121, 31, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-yellow-800:focus {\n    --bg-opacity: 1;\n    background-color: #975a16;\n    background-color: rgba(151, 90, 22, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-yellow-900:focus {\n    --bg-opacity: 1;\n    background-color: #744210;\n    background-color: rgba(116, 66, 16, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-green-100:focus {\n    --bg-opacity: 1;\n    background-color: #f0fff4;\n    background-color: rgba(240, 255, 244, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-green-200:focus {\n    --bg-opacity: 1;\n    background-color: #c6f6d5;\n    background-color: rgba(198, 246, 213, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-green-300:focus {\n    --bg-opacity: 1;\n    background-color: #9ae6b4;\n    background-color: rgba(154, 230, 180, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-green-400:focus {\n    --bg-opacity: 1;\n    background-color: #68d391;\n    background-color: rgba(104, 211, 145, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-green-500:focus {\n    --bg-opacity: 1;\n    background-color: #48bb78;\n    background-color: rgba(72, 187, 120, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-green-600:focus {\n    --bg-opacity: 1;\n    background-color: #38a169;\n    background-color: rgba(56, 161, 105, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-green-700:focus {\n    --bg-opacity: 1;\n    background-color: #2f855a;\n    background-color: rgba(47, 133, 90, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-green-800:focus {\n    --bg-opacity: 1;\n    background-color: #276749;\n    background-color: rgba(39, 103, 73, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-green-900:focus {\n    --bg-opacity: 1;\n    background-color: #22543d;\n    background-color: rgba(34, 84, 61, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-teal-100:focus {\n    --bg-opacity: 1;\n    background-color: #e6fffa;\n    background-color: rgba(230, 255, 250, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-teal-200:focus {\n    --bg-opacity: 1;\n    background-color: #b2f5ea;\n    background-color: rgba(178, 245, 234, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-teal-300:focus {\n    --bg-opacity: 1;\n    background-color: #81e6d9;\n    background-color: rgba(129, 230, 217, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-teal-400:focus {\n    --bg-opacity: 1;\n    background-color: #4fd1c5;\n    background-color: rgba(79, 209, 197, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-teal-500:focus {\n    --bg-opacity: 1;\n    background-color: #38b2ac;\n    background-color: rgba(56, 178, 172, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-teal-600:focus {\n    --bg-opacity: 1;\n    background-color: #319795;\n    background-color: rgba(49, 151, 149, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-teal-700:focus {\n    --bg-opacity: 1;\n    background-color: #2c7a7b;\n    background-color: rgba(44, 122, 123, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-teal-800:focus {\n    --bg-opacity: 1;\n    background-color: #285e61;\n    background-color: rgba(40, 94, 97, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-teal-900:focus {\n    --bg-opacity: 1;\n    background-color: #234e52;\n    background-color: rgba(35, 78, 82, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-blue-100:focus {\n    --bg-opacity: 1;\n    background-color: #ebf8ff;\n    background-color: rgba(235, 248, 255, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-blue-200:focus {\n    --bg-opacity: 1;\n    background-color: #bee3f8;\n    background-color: rgba(190, 227, 248, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-blue-300:focus {\n    --bg-opacity: 1;\n    background-color: #90cdf4;\n    background-color: rgba(144, 205, 244, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-blue-400:focus {\n    --bg-opacity: 1;\n    background-color: #63b3ed;\n    background-color: rgba(99, 179, 237, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-blue-500:focus {\n    --bg-opacity: 1;\n    background-color: #4299e1;\n    background-color: rgba(66, 153, 225, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-blue-600:focus {\n    --bg-opacity: 1;\n    background-color: #3182ce;\n    background-color: rgba(49, 130, 206, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-blue-700:focus {\n    --bg-opacity: 1;\n    background-color: #2b6cb0;\n    background-color: rgba(43, 108, 176, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-blue-800:focus {\n    --bg-opacity: 1;\n    background-color: #2c5282;\n    background-color: rgba(44, 82, 130, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-blue-900:focus {\n    --bg-opacity: 1;\n    background-color: #2a4365;\n    background-color: rgba(42, 67, 101, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-indigo-100:focus {\n    --bg-opacity: 1;\n    background-color: #ebf4ff;\n    background-color: rgba(235, 244, 255, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-indigo-200:focus {\n    --bg-opacity: 1;\n    background-color: #c3dafe;\n    background-color: rgba(195, 218, 254, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-indigo-300:focus {\n    --bg-opacity: 1;\n    background-color: #a3bffa;\n    background-color: rgba(163, 191, 250, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-indigo-400:focus {\n    --bg-opacity: 1;\n    background-color: #7f9cf5;\n    background-color: rgba(127, 156, 245, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-indigo-500:focus {\n    --bg-opacity: 1;\n    background-color: #667eea;\n    background-color: rgba(102, 126, 234, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-indigo-600:focus {\n    --bg-opacity: 1;\n    background-color: #5a67d8;\n    background-color: rgba(90, 103, 216, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-indigo-700:focus {\n    --bg-opacity: 1;\n    background-color: #4c51bf;\n    background-color: rgba(76, 81, 191, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-indigo-800:focus {\n    --bg-opacity: 1;\n    background-color: #434190;\n    background-color: rgba(67, 65, 144, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-indigo-900:focus {\n    --bg-opacity: 1;\n    background-color: #3c366b;\n    background-color: rgba(60, 54, 107, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-purple-100:focus {\n    --bg-opacity: 1;\n    background-color: #faf5ff;\n    background-color: rgba(250, 245, 255, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-purple-200:focus {\n    --bg-opacity: 1;\n    background-color: #e9d8fd;\n    background-color: rgba(233, 216, 253, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-purple-300:focus {\n    --bg-opacity: 1;\n    background-color: #d6bcfa;\n    background-color: rgba(214, 188, 250, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-purple-400:focus {\n    --bg-opacity: 1;\n    background-color: #b794f4;\n    background-color: rgba(183, 148, 244, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-purple-500:focus {\n    --bg-opacity: 1;\n    background-color: #9f7aea;\n    background-color: rgba(159, 122, 234, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-purple-600:focus {\n    --bg-opacity: 1;\n    background-color: #805ad5;\n    background-color: rgba(128, 90, 213, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-purple-700:focus {\n    --bg-opacity: 1;\n    background-color: #6b46c1;\n    background-color: rgba(107, 70, 193, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-purple-800:focus {\n    --bg-opacity: 1;\n    background-color: #553c9a;\n    background-color: rgba(85, 60, 154, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-purple-900:focus {\n    --bg-opacity: 1;\n    background-color: #44337a;\n    background-color: rgba(68, 51, 122, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-pink-100:focus {\n    --bg-opacity: 1;\n    background-color: #fff5f7;\n    background-color: rgba(255, 245, 247, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-pink-200:focus {\n    --bg-opacity: 1;\n    background-color: #fed7e2;\n    background-color: rgba(254, 215, 226, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-pink-300:focus {\n    --bg-opacity: 1;\n    background-color: #fbb6ce;\n    background-color: rgba(251, 182, 206, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-pink-400:focus {\n    --bg-opacity: 1;\n    background-color: #f687b3;\n    background-color: rgba(246, 135, 179, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-pink-500:focus {\n    --bg-opacity: 1;\n    background-color: #ed64a6;\n    background-color: rgba(237, 100, 166, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-pink-600:focus {\n    --bg-opacity: 1;\n    background-color: #d53f8c;\n    background-color: rgba(213, 63, 140, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-pink-700:focus {\n    --bg-opacity: 1;\n    background-color: #b83280;\n    background-color: rgba(184, 50, 128, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-pink-800:focus {\n    --bg-opacity: 1;\n    background-color: #97266d;\n    background-color: rgba(151, 38, 109, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-pink-900:focus {\n    --bg-opacity: 1;\n    background-color: #702459;\n    background-color: rgba(112, 36, 89, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-grayscale-80:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 8%);\n    background-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-grayscale-100:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 10%);\n    background-color: rgba(25.5, 25.5, 25.5, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-grayscale-200:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 20%);\n    background-color: rgba(51, 51, 51, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-grayscale-300:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 30%);\n    background-color: rgba(76.5, 76.5, 76.5, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-grayscale-400:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 40%);\n    background-color: rgba(102, 102, 102, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-grayscale-500:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 50%);\n    background-color: rgba(127.5, 127.5, 127.5, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-grayscale-600:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 60%);\n    background-color: rgba(153, 153, 153, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-grayscale-700:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 70%);\n    background-color: rgba(178.5, 178.5, 178.5, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-grayscale-800:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 80%);\n    background-color: rgba(204, 204, 204, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-grayscale-840:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 84%);\n    background-color: rgba(214.2, 214.2, 214.2, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-grayscale-870:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 87%);\n    background-color: rgba(221.85, 221.85, 221.85, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-grayscale-900:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 90%);\n    background-color: rgba(229.5, 229.5, 229.5, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-grayscale-930:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 93%);\n    background-color: rgba(237.15, 237.15, 237.15, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-primary:focus {\n    --bg-opacity: 1;\n    background-color: hsl(210, 100%, 52%);\n    background-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--bg-opacity));\n  }\n\n  .md\\:focus\\:bg-background-main:focus {\n    background-color: var(--main-background);\n  }\n\n  .md\\:focus\\:bg-background-secondary:focus {\n    background-color: var(--secondary-background);\n  }\n\n  .md\\:focus\\:bg-foreground:focus {\n    background-color: var(--foreground);\n  }\n\n  .md\\:focus\\:bg-panels-bg:focus {\n    background-color: var(--panels-background);\n  }\n\n  .md\\:bg-none {\n    background-image: none;\n  }\n\n  .md\\:bg-gradient-to-t {\n    background-image: linear-gradient(to top, var(--gradient-color-stops));\n  }\n\n  .md\\:bg-gradient-to-tr {\n    background-image: linear-gradient(to top right, var(--gradient-color-stops));\n  }\n\n  .md\\:bg-gradient-to-r {\n    background-image: linear-gradient(to right, var(--gradient-color-stops));\n  }\n\n  .md\\:bg-gradient-to-br {\n    background-image: linear-gradient(to bottom right, var(--gradient-color-stops));\n  }\n\n  .md\\:bg-gradient-to-b {\n    background-image: linear-gradient(to bottom, var(--gradient-color-stops));\n  }\n\n  .md\\:bg-gradient-to-bl {\n    background-image: linear-gradient(to bottom left, var(--gradient-color-stops));\n  }\n\n  .md\\:bg-gradient-to-l {\n    background-image: linear-gradient(to left, var(--gradient-color-stops));\n  }\n\n  .md\\:bg-gradient-to-tl {\n    background-image: linear-gradient(to top left, var(--gradient-color-stops));\n  }\n\n  .md\\:from-transparent {\n    --gradient-from-color: transparent;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .md\\:from-current {\n    --gradient-from-color: currentColor;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:from-black {\n    --gradient-from-color: #000;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .md\\:from-white {\n    --gradient-from-color: #fff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:from-gray-100 {\n    --gradient-from-color: #f7fafc;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n  }\n\n  .md\\:from-gray-200 {\n    --gradient-from-color: #edf2f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n  }\n\n  .md\\:from-gray-300 {\n    --gradient-from-color: #e2e8f0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n  }\n\n  .md\\:from-gray-400 {\n    --gradient-from-color: #cbd5e0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n  }\n\n  .md\\:from-gray-500 {\n    --gradient-from-color: #a0aec0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n  }\n\n  .md\\:from-gray-600 {\n    --gradient-from-color: #718096;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n  }\n\n  .md\\:from-gray-700 {\n    --gradient-from-color: #4a5568;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n  }\n\n  .md\\:from-gray-800 {\n    --gradient-from-color: #2d3748;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n  }\n\n  .md\\:from-gray-900 {\n    --gradient-from-color: #1a202c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n  }\n\n  .md\\:from-red-100 {\n    --gradient-from-color: #fff5f5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n  }\n\n  .md\\:from-red-200 {\n    --gradient-from-color: #fed7d7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n  }\n\n  .md\\:from-red-300 {\n    --gradient-from-color: #feb2b2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n  }\n\n  .md\\:from-red-400 {\n    --gradient-from-color: #fc8181;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n  }\n\n  .md\\:from-red-500 {\n    --gradient-from-color: #f56565;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n  }\n\n  .md\\:from-red-600 {\n    --gradient-from-color: #e53e3e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n  }\n\n  .md\\:from-red-700 {\n    --gradient-from-color: #c53030;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n  }\n\n  .md\\:from-red-800 {\n    --gradient-from-color: #9b2c2c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n  }\n\n  .md\\:from-red-900 {\n    --gradient-from-color: #742a2a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n  }\n\n  .md\\:from-orange-100 {\n    --gradient-from-color: #fffaf0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n  }\n\n  .md\\:from-orange-200 {\n    --gradient-from-color: #feebc8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n  }\n\n  .md\\:from-orange-300 {\n    --gradient-from-color: #fbd38d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n  }\n\n  .md\\:from-orange-400 {\n    --gradient-from-color: #f6ad55;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n  }\n\n  .md\\:from-orange-500 {\n    --gradient-from-color: #ed8936;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n  }\n\n  .md\\:from-orange-600 {\n    --gradient-from-color: #dd6b20;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n  }\n\n  .md\\:from-orange-700 {\n    --gradient-from-color: #c05621;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n  }\n\n  .md\\:from-orange-800 {\n    --gradient-from-color: #9c4221;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n  }\n\n  .md\\:from-orange-900 {\n    --gradient-from-color: #7b341e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n  }\n\n  .md\\:from-yellow-100 {\n    --gradient-from-color: #fffff0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n  }\n\n  .md\\:from-yellow-200 {\n    --gradient-from-color: #fefcbf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n  }\n\n  .md\\:from-yellow-300 {\n    --gradient-from-color: #faf089;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n  }\n\n  .md\\:from-yellow-400 {\n    --gradient-from-color: #f6e05e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n  }\n\n  .md\\:from-yellow-500 {\n    --gradient-from-color: #ecc94b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n  }\n\n  .md\\:from-yellow-600 {\n    --gradient-from-color: #d69e2e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n  }\n\n  .md\\:from-yellow-700 {\n    --gradient-from-color: #b7791f;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n  }\n\n  .md\\:from-yellow-800 {\n    --gradient-from-color: #975a16;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n  }\n\n  .md\\:from-yellow-900 {\n    --gradient-from-color: #744210;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n  }\n\n  .md\\:from-green-100 {\n    --gradient-from-color: #f0fff4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n  }\n\n  .md\\:from-green-200 {\n    --gradient-from-color: #c6f6d5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n  }\n\n  .md\\:from-green-300 {\n    --gradient-from-color: #9ae6b4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n  }\n\n  .md\\:from-green-400 {\n    --gradient-from-color: #68d391;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n  }\n\n  .md\\:from-green-500 {\n    --gradient-from-color: #48bb78;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n  }\n\n  .md\\:from-green-600 {\n    --gradient-from-color: #38a169;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n  }\n\n  .md\\:from-green-700 {\n    --gradient-from-color: #2f855a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n  }\n\n  .md\\:from-green-800 {\n    --gradient-from-color: #276749;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n  }\n\n  .md\\:from-green-900 {\n    --gradient-from-color: #22543d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n  }\n\n  .md\\:from-teal-100 {\n    --gradient-from-color: #e6fffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n  }\n\n  .md\\:from-teal-200 {\n    --gradient-from-color: #b2f5ea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n  }\n\n  .md\\:from-teal-300 {\n    --gradient-from-color: #81e6d9;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n  }\n\n  .md\\:from-teal-400 {\n    --gradient-from-color: #4fd1c5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n  }\n\n  .md\\:from-teal-500 {\n    --gradient-from-color: #38b2ac;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n  }\n\n  .md\\:from-teal-600 {\n    --gradient-from-color: #319795;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n  }\n\n  .md\\:from-teal-700 {\n    --gradient-from-color: #2c7a7b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n  }\n\n  .md\\:from-teal-800 {\n    --gradient-from-color: #285e61;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n  }\n\n  .md\\:from-teal-900 {\n    --gradient-from-color: #234e52;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n  }\n\n  .md\\:from-blue-100 {\n    --gradient-from-color: #ebf8ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n  }\n\n  .md\\:from-blue-200 {\n    --gradient-from-color: #bee3f8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n  }\n\n  .md\\:from-blue-300 {\n    --gradient-from-color: #90cdf4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n  }\n\n  .md\\:from-blue-400 {\n    --gradient-from-color: #63b3ed;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n  }\n\n  .md\\:from-blue-500 {\n    --gradient-from-color: #4299e1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n  }\n\n  .md\\:from-blue-600 {\n    --gradient-from-color: #3182ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n  }\n\n  .md\\:from-blue-700 {\n    --gradient-from-color: #2b6cb0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n  }\n\n  .md\\:from-blue-800 {\n    --gradient-from-color: #2c5282;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n  }\n\n  .md\\:from-blue-900 {\n    --gradient-from-color: #2a4365;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n  }\n\n  .md\\:from-indigo-100 {\n    --gradient-from-color: #ebf4ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n  }\n\n  .md\\:from-indigo-200 {\n    --gradient-from-color: #c3dafe;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n  }\n\n  .md\\:from-indigo-300 {\n    --gradient-from-color: #a3bffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n  }\n\n  .md\\:from-indigo-400 {\n    --gradient-from-color: #7f9cf5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n  }\n\n  .md\\:from-indigo-500 {\n    --gradient-from-color: #667eea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n  }\n\n  .md\\:from-indigo-600 {\n    --gradient-from-color: #5a67d8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n  }\n\n  .md\\:from-indigo-700 {\n    --gradient-from-color: #4c51bf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n  }\n\n  .md\\:from-indigo-800 {\n    --gradient-from-color: #434190;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n  }\n\n  .md\\:from-indigo-900 {\n    --gradient-from-color: #3c366b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n  }\n\n  .md\\:from-purple-100 {\n    --gradient-from-color: #faf5ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n  }\n\n  .md\\:from-purple-200 {\n    --gradient-from-color: #e9d8fd;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n  }\n\n  .md\\:from-purple-300 {\n    --gradient-from-color: #d6bcfa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n  }\n\n  .md\\:from-purple-400 {\n    --gradient-from-color: #b794f4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n  }\n\n  .md\\:from-purple-500 {\n    --gradient-from-color: #9f7aea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n  }\n\n  .md\\:from-purple-600 {\n    --gradient-from-color: #805ad5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n  }\n\n  .md\\:from-purple-700 {\n    --gradient-from-color: #6b46c1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n  }\n\n  .md\\:from-purple-800 {\n    --gradient-from-color: #553c9a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n  }\n\n  .md\\:from-purple-900 {\n    --gradient-from-color: #44337a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n  }\n\n  .md\\:from-pink-100 {\n    --gradient-from-color: #fff5f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n  }\n\n  .md\\:from-pink-200 {\n    --gradient-from-color: #fed7e2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n  }\n\n  .md\\:from-pink-300 {\n    --gradient-from-color: #fbb6ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n  }\n\n  .md\\:from-pink-400 {\n    --gradient-from-color: #f687b3;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n  }\n\n  .md\\:from-pink-500 {\n    --gradient-from-color: #ed64a6;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n  }\n\n  .md\\:from-pink-600 {\n    --gradient-from-color: #d53f8c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n  }\n\n  .md\\:from-pink-700 {\n    --gradient-from-color: #b83280;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n  }\n\n  .md\\:from-pink-800 {\n    --gradient-from-color: #97266d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n  }\n\n  .md\\:from-pink-900 {\n    --gradient-from-color: #702459;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n  }\n\n  .md\\:from-grayscale-80 {\n    --gradient-from-color: hsl(0, 0%, 8%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n  }\n\n  .md\\:from-grayscale-100 {\n    --gradient-from-color: hsl(0, 0%, 10%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n  }\n\n  .md\\:from-grayscale-200 {\n    --gradient-from-color: hsl(0, 0%, 20%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n  }\n\n  .md\\:from-grayscale-300 {\n    --gradient-from-color: hsl(0, 0%, 30%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n  }\n\n  .md\\:from-grayscale-400 {\n    --gradient-from-color: hsl(0, 0%, 40%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n  }\n\n  .md\\:from-grayscale-500 {\n    --gradient-from-color: hsl(0, 0%, 50%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n  }\n\n  .md\\:from-grayscale-600 {\n    --gradient-from-color: hsl(0, 0%, 60%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n  }\n\n  .md\\:from-grayscale-700 {\n    --gradient-from-color: hsl(0, 0%, 70%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n  }\n\n  .md\\:from-grayscale-800 {\n    --gradient-from-color: hsl(0, 0%, 80%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n  }\n\n  .md\\:from-grayscale-840 {\n    --gradient-from-color: hsl(0, 0%, 84%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n  }\n\n  .md\\:from-grayscale-870 {\n    --gradient-from-color: hsl(0, 0%, 87%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n  }\n\n  .md\\:from-grayscale-900 {\n    --gradient-from-color: hsl(0, 0%, 90%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n  }\n\n  .md\\:from-grayscale-930 {\n    --gradient-from-color: hsl(0, 0%, 93%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n  }\n\n  .md\\:from-primary {\n    --gradient-from-color: hsl(210, 100%, 52%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n  }\n\n  .md\\:from-background-main {\n    --gradient-from-color: var(--main-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:from-background-secondary {\n    --gradient-from-color: var(--secondary-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:from-foreground {\n    --gradient-from-color: var(--foreground);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:from-panels-bg {\n    --gradient-from-color: var(--panels-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:via-transparent {\n    --gradient-via-color: transparent;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .md\\:via-current {\n    --gradient-via-color: currentColor;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:via-black {\n    --gradient-via-color: #000;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .md\\:via-white {\n    --gradient-via-color: #fff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:via-gray-100 {\n    --gradient-via-color: #f7fafc;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n  }\n\n  .md\\:via-gray-200 {\n    --gradient-via-color: #edf2f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n  }\n\n  .md\\:via-gray-300 {\n    --gradient-via-color: #e2e8f0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n  }\n\n  .md\\:via-gray-400 {\n    --gradient-via-color: #cbd5e0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n  }\n\n  .md\\:via-gray-500 {\n    --gradient-via-color: #a0aec0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n  }\n\n  .md\\:via-gray-600 {\n    --gradient-via-color: #718096;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n  }\n\n  .md\\:via-gray-700 {\n    --gradient-via-color: #4a5568;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n  }\n\n  .md\\:via-gray-800 {\n    --gradient-via-color: #2d3748;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n  }\n\n  .md\\:via-gray-900 {\n    --gradient-via-color: #1a202c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n  }\n\n  .md\\:via-red-100 {\n    --gradient-via-color: #fff5f5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n  }\n\n  .md\\:via-red-200 {\n    --gradient-via-color: #fed7d7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n  }\n\n  .md\\:via-red-300 {\n    --gradient-via-color: #feb2b2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n  }\n\n  .md\\:via-red-400 {\n    --gradient-via-color: #fc8181;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n  }\n\n  .md\\:via-red-500 {\n    --gradient-via-color: #f56565;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n  }\n\n  .md\\:via-red-600 {\n    --gradient-via-color: #e53e3e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n  }\n\n  .md\\:via-red-700 {\n    --gradient-via-color: #c53030;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n  }\n\n  .md\\:via-red-800 {\n    --gradient-via-color: #9b2c2c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n  }\n\n  .md\\:via-red-900 {\n    --gradient-via-color: #742a2a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n  }\n\n  .md\\:via-orange-100 {\n    --gradient-via-color: #fffaf0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n  }\n\n  .md\\:via-orange-200 {\n    --gradient-via-color: #feebc8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n  }\n\n  .md\\:via-orange-300 {\n    --gradient-via-color: #fbd38d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n  }\n\n  .md\\:via-orange-400 {\n    --gradient-via-color: #f6ad55;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n  }\n\n  .md\\:via-orange-500 {\n    --gradient-via-color: #ed8936;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n  }\n\n  .md\\:via-orange-600 {\n    --gradient-via-color: #dd6b20;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n  }\n\n  .md\\:via-orange-700 {\n    --gradient-via-color: #c05621;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n  }\n\n  .md\\:via-orange-800 {\n    --gradient-via-color: #9c4221;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n  }\n\n  .md\\:via-orange-900 {\n    --gradient-via-color: #7b341e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n  }\n\n  .md\\:via-yellow-100 {\n    --gradient-via-color: #fffff0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n  }\n\n  .md\\:via-yellow-200 {\n    --gradient-via-color: #fefcbf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n  }\n\n  .md\\:via-yellow-300 {\n    --gradient-via-color: #faf089;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n  }\n\n  .md\\:via-yellow-400 {\n    --gradient-via-color: #f6e05e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n  }\n\n  .md\\:via-yellow-500 {\n    --gradient-via-color: #ecc94b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n  }\n\n  .md\\:via-yellow-600 {\n    --gradient-via-color: #d69e2e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n  }\n\n  .md\\:via-yellow-700 {\n    --gradient-via-color: #b7791f;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n  }\n\n  .md\\:via-yellow-800 {\n    --gradient-via-color: #975a16;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n  }\n\n  .md\\:via-yellow-900 {\n    --gradient-via-color: #744210;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n  }\n\n  .md\\:via-green-100 {\n    --gradient-via-color: #f0fff4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n  }\n\n  .md\\:via-green-200 {\n    --gradient-via-color: #c6f6d5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n  }\n\n  .md\\:via-green-300 {\n    --gradient-via-color: #9ae6b4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n  }\n\n  .md\\:via-green-400 {\n    --gradient-via-color: #68d391;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n  }\n\n  .md\\:via-green-500 {\n    --gradient-via-color: #48bb78;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n  }\n\n  .md\\:via-green-600 {\n    --gradient-via-color: #38a169;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n  }\n\n  .md\\:via-green-700 {\n    --gradient-via-color: #2f855a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n  }\n\n  .md\\:via-green-800 {\n    --gradient-via-color: #276749;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n  }\n\n  .md\\:via-green-900 {\n    --gradient-via-color: #22543d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n  }\n\n  .md\\:via-teal-100 {\n    --gradient-via-color: #e6fffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n  }\n\n  .md\\:via-teal-200 {\n    --gradient-via-color: #b2f5ea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n  }\n\n  .md\\:via-teal-300 {\n    --gradient-via-color: #81e6d9;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n  }\n\n  .md\\:via-teal-400 {\n    --gradient-via-color: #4fd1c5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n  }\n\n  .md\\:via-teal-500 {\n    --gradient-via-color: #38b2ac;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n  }\n\n  .md\\:via-teal-600 {\n    --gradient-via-color: #319795;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n  }\n\n  .md\\:via-teal-700 {\n    --gradient-via-color: #2c7a7b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n  }\n\n  .md\\:via-teal-800 {\n    --gradient-via-color: #285e61;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n  }\n\n  .md\\:via-teal-900 {\n    --gradient-via-color: #234e52;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n  }\n\n  .md\\:via-blue-100 {\n    --gradient-via-color: #ebf8ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n  }\n\n  .md\\:via-blue-200 {\n    --gradient-via-color: #bee3f8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n  }\n\n  .md\\:via-blue-300 {\n    --gradient-via-color: #90cdf4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n  }\n\n  .md\\:via-blue-400 {\n    --gradient-via-color: #63b3ed;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n  }\n\n  .md\\:via-blue-500 {\n    --gradient-via-color: #4299e1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n  }\n\n  .md\\:via-blue-600 {\n    --gradient-via-color: #3182ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n  }\n\n  .md\\:via-blue-700 {\n    --gradient-via-color: #2b6cb0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n  }\n\n  .md\\:via-blue-800 {\n    --gradient-via-color: #2c5282;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n  }\n\n  .md\\:via-blue-900 {\n    --gradient-via-color: #2a4365;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n  }\n\n  .md\\:via-indigo-100 {\n    --gradient-via-color: #ebf4ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n  }\n\n  .md\\:via-indigo-200 {\n    --gradient-via-color: #c3dafe;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n  }\n\n  .md\\:via-indigo-300 {\n    --gradient-via-color: #a3bffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n  }\n\n  .md\\:via-indigo-400 {\n    --gradient-via-color: #7f9cf5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n  }\n\n  .md\\:via-indigo-500 {\n    --gradient-via-color: #667eea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n  }\n\n  .md\\:via-indigo-600 {\n    --gradient-via-color: #5a67d8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n  }\n\n  .md\\:via-indigo-700 {\n    --gradient-via-color: #4c51bf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n  }\n\n  .md\\:via-indigo-800 {\n    --gradient-via-color: #434190;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n  }\n\n  .md\\:via-indigo-900 {\n    --gradient-via-color: #3c366b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n  }\n\n  .md\\:via-purple-100 {\n    --gradient-via-color: #faf5ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n  }\n\n  .md\\:via-purple-200 {\n    --gradient-via-color: #e9d8fd;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n  }\n\n  .md\\:via-purple-300 {\n    --gradient-via-color: #d6bcfa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n  }\n\n  .md\\:via-purple-400 {\n    --gradient-via-color: #b794f4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n  }\n\n  .md\\:via-purple-500 {\n    --gradient-via-color: #9f7aea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n  }\n\n  .md\\:via-purple-600 {\n    --gradient-via-color: #805ad5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n  }\n\n  .md\\:via-purple-700 {\n    --gradient-via-color: #6b46c1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n  }\n\n  .md\\:via-purple-800 {\n    --gradient-via-color: #553c9a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n  }\n\n  .md\\:via-purple-900 {\n    --gradient-via-color: #44337a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n  }\n\n  .md\\:via-pink-100 {\n    --gradient-via-color: #fff5f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n  }\n\n  .md\\:via-pink-200 {\n    --gradient-via-color: #fed7e2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n  }\n\n  .md\\:via-pink-300 {\n    --gradient-via-color: #fbb6ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n  }\n\n  .md\\:via-pink-400 {\n    --gradient-via-color: #f687b3;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n  }\n\n  .md\\:via-pink-500 {\n    --gradient-via-color: #ed64a6;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n  }\n\n  .md\\:via-pink-600 {\n    --gradient-via-color: #d53f8c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n  }\n\n  .md\\:via-pink-700 {\n    --gradient-via-color: #b83280;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n  }\n\n  .md\\:via-pink-800 {\n    --gradient-via-color: #97266d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n  }\n\n  .md\\:via-pink-900 {\n    --gradient-via-color: #702459;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n  }\n\n  .md\\:via-grayscale-80 {\n    --gradient-via-color: hsl(0, 0%, 8%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n  }\n\n  .md\\:via-grayscale-100 {\n    --gradient-via-color: hsl(0, 0%, 10%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n  }\n\n  .md\\:via-grayscale-200 {\n    --gradient-via-color: hsl(0, 0%, 20%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n  }\n\n  .md\\:via-grayscale-300 {\n    --gradient-via-color: hsl(0, 0%, 30%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n  }\n\n  .md\\:via-grayscale-400 {\n    --gradient-via-color: hsl(0, 0%, 40%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n  }\n\n  .md\\:via-grayscale-500 {\n    --gradient-via-color: hsl(0, 0%, 50%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n  }\n\n  .md\\:via-grayscale-600 {\n    --gradient-via-color: hsl(0, 0%, 60%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n  }\n\n  .md\\:via-grayscale-700 {\n    --gradient-via-color: hsl(0, 0%, 70%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n  }\n\n  .md\\:via-grayscale-800 {\n    --gradient-via-color: hsl(0, 0%, 80%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n  }\n\n  .md\\:via-grayscale-840 {\n    --gradient-via-color: hsl(0, 0%, 84%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n  }\n\n  .md\\:via-grayscale-870 {\n    --gradient-via-color: hsl(0, 0%, 87%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n  }\n\n  .md\\:via-grayscale-900 {\n    --gradient-via-color: hsl(0, 0%, 90%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n  }\n\n  .md\\:via-grayscale-930 {\n    --gradient-via-color: hsl(0, 0%, 93%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n  }\n\n  .md\\:via-primary {\n    --gradient-via-color: hsl(210, 100%, 52%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n  }\n\n  .md\\:via-background-main {\n    --gradient-via-color: var(--main-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:via-background-secondary {\n    --gradient-via-color: var(--secondary-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:via-foreground {\n    --gradient-via-color: var(--foreground);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:via-panels-bg {\n    --gradient-via-color: var(--panels-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:to-transparent {\n    --gradient-to-color: transparent;\n  }\n\n  .md\\:to-current {\n    --gradient-to-color: currentColor;\n  }\n\n  .md\\:to-black {\n    --gradient-to-color: #000;\n  }\n\n  .md\\:to-white {\n    --gradient-to-color: #fff;\n  }\n\n  .md\\:to-gray-100 {\n    --gradient-to-color: #f7fafc;\n  }\n\n  .md\\:to-gray-200 {\n    --gradient-to-color: #edf2f7;\n  }\n\n  .md\\:to-gray-300 {\n    --gradient-to-color: #e2e8f0;\n  }\n\n  .md\\:to-gray-400 {\n    --gradient-to-color: #cbd5e0;\n  }\n\n  .md\\:to-gray-500 {\n    --gradient-to-color: #a0aec0;\n  }\n\n  .md\\:to-gray-600 {\n    --gradient-to-color: #718096;\n  }\n\n  .md\\:to-gray-700 {\n    --gradient-to-color: #4a5568;\n  }\n\n  .md\\:to-gray-800 {\n    --gradient-to-color: #2d3748;\n  }\n\n  .md\\:to-gray-900 {\n    --gradient-to-color: #1a202c;\n  }\n\n  .md\\:to-red-100 {\n    --gradient-to-color: #fff5f5;\n  }\n\n  .md\\:to-red-200 {\n    --gradient-to-color: #fed7d7;\n  }\n\n  .md\\:to-red-300 {\n    --gradient-to-color: #feb2b2;\n  }\n\n  .md\\:to-red-400 {\n    --gradient-to-color: #fc8181;\n  }\n\n  .md\\:to-red-500 {\n    --gradient-to-color: #f56565;\n  }\n\n  .md\\:to-red-600 {\n    --gradient-to-color: #e53e3e;\n  }\n\n  .md\\:to-red-700 {\n    --gradient-to-color: #c53030;\n  }\n\n  .md\\:to-red-800 {\n    --gradient-to-color: #9b2c2c;\n  }\n\n  .md\\:to-red-900 {\n    --gradient-to-color: #742a2a;\n  }\n\n  .md\\:to-orange-100 {\n    --gradient-to-color: #fffaf0;\n  }\n\n  .md\\:to-orange-200 {\n    --gradient-to-color: #feebc8;\n  }\n\n  .md\\:to-orange-300 {\n    --gradient-to-color: #fbd38d;\n  }\n\n  .md\\:to-orange-400 {\n    --gradient-to-color: #f6ad55;\n  }\n\n  .md\\:to-orange-500 {\n    --gradient-to-color: #ed8936;\n  }\n\n  .md\\:to-orange-600 {\n    --gradient-to-color: #dd6b20;\n  }\n\n  .md\\:to-orange-700 {\n    --gradient-to-color: #c05621;\n  }\n\n  .md\\:to-orange-800 {\n    --gradient-to-color: #9c4221;\n  }\n\n  .md\\:to-orange-900 {\n    --gradient-to-color: #7b341e;\n  }\n\n  .md\\:to-yellow-100 {\n    --gradient-to-color: #fffff0;\n  }\n\n  .md\\:to-yellow-200 {\n    --gradient-to-color: #fefcbf;\n  }\n\n  .md\\:to-yellow-300 {\n    --gradient-to-color: #faf089;\n  }\n\n  .md\\:to-yellow-400 {\n    --gradient-to-color: #f6e05e;\n  }\n\n  .md\\:to-yellow-500 {\n    --gradient-to-color: #ecc94b;\n  }\n\n  .md\\:to-yellow-600 {\n    --gradient-to-color: #d69e2e;\n  }\n\n  .md\\:to-yellow-700 {\n    --gradient-to-color: #b7791f;\n  }\n\n  .md\\:to-yellow-800 {\n    --gradient-to-color: #975a16;\n  }\n\n  .md\\:to-yellow-900 {\n    --gradient-to-color: #744210;\n  }\n\n  .md\\:to-green-100 {\n    --gradient-to-color: #f0fff4;\n  }\n\n  .md\\:to-green-200 {\n    --gradient-to-color: #c6f6d5;\n  }\n\n  .md\\:to-green-300 {\n    --gradient-to-color: #9ae6b4;\n  }\n\n  .md\\:to-green-400 {\n    --gradient-to-color: #68d391;\n  }\n\n  .md\\:to-green-500 {\n    --gradient-to-color: #48bb78;\n  }\n\n  .md\\:to-green-600 {\n    --gradient-to-color: #38a169;\n  }\n\n  .md\\:to-green-700 {\n    --gradient-to-color: #2f855a;\n  }\n\n  .md\\:to-green-800 {\n    --gradient-to-color: #276749;\n  }\n\n  .md\\:to-green-900 {\n    --gradient-to-color: #22543d;\n  }\n\n  .md\\:to-teal-100 {\n    --gradient-to-color: #e6fffa;\n  }\n\n  .md\\:to-teal-200 {\n    --gradient-to-color: #b2f5ea;\n  }\n\n  .md\\:to-teal-300 {\n    --gradient-to-color: #81e6d9;\n  }\n\n  .md\\:to-teal-400 {\n    --gradient-to-color: #4fd1c5;\n  }\n\n  .md\\:to-teal-500 {\n    --gradient-to-color: #38b2ac;\n  }\n\n  .md\\:to-teal-600 {\n    --gradient-to-color: #319795;\n  }\n\n  .md\\:to-teal-700 {\n    --gradient-to-color: #2c7a7b;\n  }\n\n  .md\\:to-teal-800 {\n    --gradient-to-color: #285e61;\n  }\n\n  .md\\:to-teal-900 {\n    --gradient-to-color: #234e52;\n  }\n\n  .md\\:to-blue-100 {\n    --gradient-to-color: #ebf8ff;\n  }\n\n  .md\\:to-blue-200 {\n    --gradient-to-color: #bee3f8;\n  }\n\n  .md\\:to-blue-300 {\n    --gradient-to-color: #90cdf4;\n  }\n\n  .md\\:to-blue-400 {\n    --gradient-to-color: #63b3ed;\n  }\n\n  .md\\:to-blue-500 {\n    --gradient-to-color: #4299e1;\n  }\n\n  .md\\:to-blue-600 {\n    --gradient-to-color: #3182ce;\n  }\n\n  .md\\:to-blue-700 {\n    --gradient-to-color: #2b6cb0;\n  }\n\n  .md\\:to-blue-800 {\n    --gradient-to-color: #2c5282;\n  }\n\n  .md\\:to-blue-900 {\n    --gradient-to-color: #2a4365;\n  }\n\n  .md\\:to-indigo-100 {\n    --gradient-to-color: #ebf4ff;\n  }\n\n  .md\\:to-indigo-200 {\n    --gradient-to-color: #c3dafe;\n  }\n\n  .md\\:to-indigo-300 {\n    --gradient-to-color: #a3bffa;\n  }\n\n  .md\\:to-indigo-400 {\n    --gradient-to-color: #7f9cf5;\n  }\n\n  .md\\:to-indigo-500 {\n    --gradient-to-color: #667eea;\n  }\n\n  .md\\:to-indigo-600 {\n    --gradient-to-color: #5a67d8;\n  }\n\n  .md\\:to-indigo-700 {\n    --gradient-to-color: #4c51bf;\n  }\n\n  .md\\:to-indigo-800 {\n    --gradient-to-color: #434190;\n  }\n\n  .md\\:to-indigo-900 {\n    --gradient-to-color: #3c366b;\n  }\n\n  .md\\:to-purple-100 {\n    --gradient-to-color: #faf5ff;\n  }\n\n  .md\\:to-purple-200 {\n    --gradient-to-color: #e9d8fd;\n  }\n\n  .md\\:to-purple-300 {\n    --gradient-to-color: #d6bcfa;\n  }\n\n  .md\\:to-purple-400 {\n    --gradient-to-color: #b794f4;\n  }\n\n  .md\\:to-purple-500 {\n    --gradient-to-color: #9f7aea;\n  }\n\n  .md\\:to-purple-600 {\n    --gradient-to-color: #805ad5;\n  }\n\n  .md\\:to-purple-700 {\n    --gradient-to-color: #6b46c1;\n  }\n\n  .md\\:to-purple-800 {\n    --gradient-to-color: #553c9a;\n  }\n\n  .md\\:to-purple-900 {\n    --gradient-to-color: #44337a;\n  }\n\n  .md\\:to-pink-100 {\n    --gradient-to-color: #fff5f7;\n  }\n\n  .md\\:to-pink-200 {\n    --gradient-to-color: #fed7e2;\n  }\n\n  .md\\:to-pink-300 {\n    --gradient-to-color: #fbb6ce;\n  }\n\n  .md\\:to-pink-400 {\n    --gradient-to-color: #f687b3;\n  }\n\n  .md\\:to-pink-500 {\n    --gradient-to-color: #ed64a6;\n  }\n\n  .md\\:to-pink-600 {\n    --gradient-to-color: #d53f8c;\n  }\n\n  .md\\:to-pink-700 {\n    --gradient-to-color: #b83280;\n  }\n\n  .md\\:to-pink-800 {\n    --gradient-to-color: #97266d;\n  }\n\n  .md\\:to-pink-900 {\n    --gradient-to-color: #702459;\n  }\n\n  .md\\:to-grayscale-80 {\n    --gradient-to-color: hsl(0, 0%, 8%);\n  }\n\n  .md\\:to-grayscale-100 {\n    --gradient-to-color: hsl(0, 0%, 10%);\n  }\n\n  .md\\:to-grayscale-200 {\n    --gradient-to-color: hsl(0, 0%, 20%);\n  }\n\n  .md\\:to-grayscale-300 {\n    --gradient-to-color: hsl(0, 0%, 30%);\n  }\n\n  .md\\:to-grayscale-400 {\n    --gradient-to-color: hsl(0, 0%, 40%);\n  }\n\n  .md\\:to-grayscale-500 {\n    --gradient-to-color: hsl(0, 0%, 50%);\n  }\n\n  .md\\:to-grayscale-600 {\n    --gradient-to-color: hsl(0, 0%, 60%);\n  }\n\n  .md\\:to-grayscale-700 {\n    --gradient-to-color: hsl(0, 0%, 70%);\n  }\n\n  .md\\:to-grayscale-800 {\n    --gradient-to-color: hsl(0, 0%, 80%);\n  }\n\n  .md\\:to-grayscale-840 {\n    --gradient-to-color: hsl(0, 0%, 84%);\n  }\n\n  .md\\:to-grayscale-870 {\n    --gradient-to-color: hsl(0, 0%, 87%);\n  }\n\n  .md\\:to-grayscale-900 {\n    --gradient-to-color: hsl(0, 0%, 90%);\n  }\n\n  .md\\:to-grayscale-930 {\n    --gradient-to-color: hsl(0, 0%, 93%);\n  }\n\n  .md\\:to-primary {\n    --gradient-to-color: hsl(210, 100%, 52%);\n  }\n\n  .md\\:to-background-main {\n    --gradient-to-color: var(--main-background);\n  }\n\n  .md\\:to-background-secondary {\n    --gradient-to-color: var(--secondary-background);\n  }\n\n  .md\\:to-foreground {\n    --gradient-to-color: var(--foreground);\n  }\n\n  .md\\:to-panels-bg {\n    --gradient-to-color: var(--panels-background);\n  }\n\n  .md\\:hover\\:from-transparent:hover {\n    --gradient-from-color: transparent;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .md\\:hover\\:from-current:hover {\n    --gradient-from-color: currentColor;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:hover\\:from-black:hover {\n    --gradient-from-color: #000;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .md\\:hover\\:from-white:hover {\n    --gradient-from-color: #fff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:hover\\:from-gray-100:hover {\n    --gradient-from-color: #f7fafc;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n  }\n\n  .md\\:hover\\:from-gray-200:hover {\n    --gradient-from-color: #edf2f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n  }\n\n  .md\\:hover\\:from-gray-300:hover {\n    --gradient-from-color: #e2e8f0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n  }\n\n  .md\\:hover\\:from-gray-400:hover {\n    --gradient-from-color: #cbd5e0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n  }\n\n  .md\\:hover\\:from-gray-500:hover {\n    --gradient-from-color: #a0aec0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n  }\n\n  .md\\:hover\\:from-gray-600:hover {\n    --gradient-from-color: #718096;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n  }\n\n  .md\\:hover\\:from-gray-700:hover {\n    --gradient-from-color: #4a5568;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n  }\n\n  .md\\:hover\\:from-gray-800:hover {\n    --gradient-from-color: #2d3748;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n  }\n\n  .md\\:hover\\:from-gray-900:hover {\n    --gradient-from-color: #1a202c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n  }\n\n  .md\\:hover\\:from-red-100:hover {\n    --gradient-from-color: #fff5f5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n  }\n\n  .md\\:hover\\:from-red-200:hover {\n    --gradient-from-color: #fed7d7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n  }\n\n  .md\\:hover\\:from-red-300:hover {\n    --gradient-from-color: #feb2b2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n  }\n\n  .md\\:hover\\:from-red-400:hover {\n    --gradient-from-color: #fc8181;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n  }\n\n  .md\\:hover\\:from-red-500:hover {\n    --gradient-from-color: #f56565;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n  }\n\n  .md\\:hover\\:from-red-600:hover {\n    --gradient-from-color: #e53e3e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n  }\n\n  .md\\:hover\\:from-red-700:hover {\n    --gradient-from-color: #c53030;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n  }\n\n  .md\\:hover\\:from-red-800:hover {\n    --gradient-from-color: #9b2c2c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n  }\n\n  .md\\:hover\\:from-red-900:hover {\n    --gradient-from-color: #742a2a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n  }\n\n  .md\\:hover\\:from-orange-100:hover {\n    --gradient-from-color: #fffaf0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n  }\n\n  .md\\:hover\\:from-orange-200:hover {\n    --gradient-from-color: #feebc8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n  }\n\n  .md\\:hover\\:from-orange-300:hover {\n    --gradient-from-color: #fbd38d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n  }\n\n  .md\\:hover\\:from-orange-400:hover {\n    --gradient-from-color: #f6ad55;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n  }\n\n  .md\\:hover\\:from-orange-500:hover {\n    --gradient-from-color: #ed8936;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n  }\n\n  .md\\:hover\\:from-orange-600:hover {\n    --gradient-from-color: #dd6b20;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n  }\n\n  .md\\:hover\\:from-orange-700:hover {\n    --gradient-from-color: #c05621;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n  }\n\n  .md\\:hover\\:from-orange-800:hover {\n    --gradient-from-color: #9c4221;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n  }\n\n  .md\\:hover\\:from-orange-900:hover {\n    --gradient-from-color: #7b341e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n  }\n\n  .md\\:hover\\:from-yellow-100:hover {\n    --gradient-from-color: #fffff0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n  }\n\n  .md\\:hover\\:from-yellow-200:hover {\n    --gradient-from-color: #fefcbf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n  }\n\n  .md\\:hover\\:from-yellow-300:hover {\n    --gradient-from-color: #faf089;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n  }\n\n  .md\\:hover\\:from-yellow-400:hover {\n    --gradient-from-color: #f6e05e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n  }\n\n  .md\\:hover\\:from-yellow-500:hover {\n    --gradient-from-color: #ecc94b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n  }\n\n  .md\\:hover\\:from-yellow-600:hover {\n    --gradient-from-color: #d69e2e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n  }\n\n  .md\\:hover\\:from-yellow-700:hover {\n    --gradient-from-color: #b7791f;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n  }\n\n  .md\\:hover\\:from-yellow-800:hover {\n    --gradient-from-color: #975a16;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n  }\n\n  .md\\:hover\\:from-yellow-900:hover {\n    --gradient-from-color: #744210;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n  }\n\n  .md\\:hover\\:from-green-100:hover {\n    --gradient-from-color: #f0fff4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n  }\n\n  .md\\:hover\\:from-green-200:hover {\n    --gradient-from-color: #c6f6d5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n  }\n\n  .md\\:hover\\:from-green-300:hover {\n    --gradient-from-color: #9ae6b4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n  }\n\n  .md\\:hover\\:from-green-400:hover {\n    --gradient-from-color: #68d391;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n  }\n\n  .md\\:hover\\:from-green-500:hover {\n    --gradient-from-color: #48bb78;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n  }\n\n  .md\\:hover\\:from-green-600:hover {\n    --gradient-from-color: #38a169;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n  }\n\n  .md\\:hover\\:from-green-700:hover {\n    --gradient-from-color: #2f855a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n  }\n\n  .md\\:hover\\:from-green-800:hover {\n    --gradient-from-color: #276749;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n  }\n\n  .md\\:hover\\:from-green-900:hover {\n    --gradient-from-color: #22543d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n  }\n\n  .md\\:hover\\:from-teal-100:hover {\n    --gradient-from-color: #e6fffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n  }\n\n  .md\\:hover\\:from-teal-200:hover {\n    --gradient-from-color: #b2f5ea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n  }\n\n  .md\\:hover\\:from-teal-300:hover {\n    --gradient-from-color: #81e6d9;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n  }\n\n  .md\\:hover\\:from-teal-400:hover {\n    --gradient-from-color: #4fd1c5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n  }\n\n  .md\\:hover\\:from-teal-500:hover {\n    --gradient-from-color: #38b2ac;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n  }\n\n  .md\\:hover\\:from-teal-600:hover {\n    --gradient-from-color: #319795;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n  }\n\n  .md\\:hover\\:from-teal-700:hover {\n    --gradient-from-color: #2c7a7b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n  }\n\n  .md\\:hover\\:from-teal-800:hover {\n    --gradient-from-color: #285e61;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n  }\n\n  .md\\:hover\\:from-teal-900:hover {\n    --gradient-from-color: #234e52;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n  }\n\n  .md\\:hover\\:from-blue-100:hover {\n    --gradient-from-color: #ebf8ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n  }\n\n  .md\\:hover\\:from-blue-200:hover {\n    --gradient-from-color: #bee3f8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n  }\n\n  .md\\:hover\\:from-blue-300:hover {\n    --gradient-from-color: #90cdf4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n  }\n\n  .md\\:hover\\:from-blue-400:hover {\n    --gradient-from-color: #63b3ed;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n  }\n\n  .md\\:hover\\:from-blue-500:hover {\n    --gradient-from-color: #4299e1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n  }\n\n  .md\\:hover\\:from-blue-600:hover {\n    --gradient-from-color: #3182ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n  }\n\n  .md\\:hover\\:from-blue-700:hover {\n    --gradient-from-color: #2b6cb0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n  }\n\n  .md\\:hover\\:from-blue-800:hover {\n    --gradient-from-color: #2c5282;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n  }\n\n  .md\\:hover\\:from-blue-900:hover {\n    --gradient-from-color: #2a4365;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n  }\n\n  .md\\:hover\\:from-indigo-100:hover {\n    --gradient-from-color: #ebf4ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n  }\n\n  .md\\:hover\\:from-indigo-200:hover {\n    --gradient-from-color: #c3dafe;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n  }\n\n  .md\\:hover\\:from-indigo-300:hover {\n    --gradient-from-color: #a3bffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n  }\n\n  .md\\:hover\\:from-indigo-400:hover {\n    --gradient-from-color: #7f9cf5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n  }\n\n  .md\\:hover\\:from-indigo-500:hover {\n    --gradient-from-color: #667eea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n  }\n\n  .md\\:hover\\:from-indigo-600:hover {\n    --gradient-from-color: #5a67d8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n  }\n\n  .md\\:hover\\:from-indigo-700:hover {\n    --gradient-from-color: #4c51bf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n  }\n\n  .md\\:hover\\:from-indigo-800:hover {\n    --gradient-from-color: #434190;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n  }\n\n  .md\\:hover\\:from-indigo-900:hover {\n    --gradient-from-color: #3c366b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n  }\n\n  .md\\:hover\\:from-purple-100:hover {\n    --gradient-from-color: #faf5ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n  }\n\n  .md\\:hover\\:from-purple-200:hover {\n    --gradient-from-color: #e9d8fd;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n  }\n\n  .md\\:hover\\:from-purple-300:hover {\n    --gradient-from-color: #d6bcfa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n  }\n\n  .md\\:hover\\:from-purple-400:hover {\n    --gradient-from-color: #b794f4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n  }\n\n  .md\\:hover\\:from-purple-500:hover {\n    --gradient-from-color: #9f7aea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n  }\n\n  .md\\:hover\\:from-purple-600:hover {\n    --gradient-from-color: #805ad5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n  }\n\n  .md\\:hover\\:from-purple-700:hover {\n    --gradient-from-color: #6b46c1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n  }\n\n  .md\\:hover\\:from-purple-800:hover {\n    --gradient-from-color: #553c9a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n  }\n\n  .md\\:hover\\:from-purple-900:hover {\n    --gradient-from-color: #44337a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n  }\n\n  .md\\:hover\\:from-pink-100:hover {\n    --gradient-from-color: #fff5f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n  }\n\n  .md\\:hover\\:from-pink-200:hover {\n    --gradient-from-color: #fed7e2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n  }\n\n  .md\\:hover\\:from-pink-300:hover {\n    --gradient-from-color: #fbb6ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n  }\n\n  .md\\:hover\\:from-pink-400:hover {\n    --gradient-from-color: #f687b3;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n  }\n\n  .md\\:hover\\:from-pink-500:hover {\n    --gradient-from-color: #ed64a6;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n  }\n\n  .md\\:hover\\:from-pink-600:hover {\n    --gradient-from-color: #d53f8c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n  }\n\n  .md\\:hover\\:from-pink-700:hover {\n    --gradient-from-color: #b83280;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n  }\n\n  .md\\:hover\\:from-pink-800:hover {\n    --gradient-from-color: #97266d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n  }\n\n  .md\\:hover\\:from-pink-900:hover {\n    --gradient-from-color: #702459;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n  }\n\n  .md\\:hover\\:from-grayscale-80:hover {\n    --gradient-from-color: hsl(0, 0%, 8%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n  }\n\n  .md\\:hover\\:from-grayscale-100:hover {\n    --gradient-from-color: hsl(0, 0%, 10%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n  }\n\n  .md\\:hover\\:from-grayscale-200:hover {\n    --gradient-from-color: hsl(0, 0%, 20%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n  }\n\n  .md\\:hover\\:from-grayscale-300:hover {\n    --gradient-from-color: hsl(0, 0%, 30%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n  }\n\n  .md\\:hover\\:from-grayscale-400:hover {\n    --gradient-from-color: hsl(0, 0%, 40%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n  }\n\n  .md\\:hover\\:from-grayscale-500:hover {\n    --gradient-from-color: hsl(0, 0%, 50%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n  }\n\n  .md\\:hover\\:from-grayscale-600:hover {\n    --gradient-from-color: hsl(0, 0%, 60%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n  }\n\n  .md\\:hover\\:from-grayscale-700:hover {\n    --gradient-from-color: hsl(0, 0%, 70%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n  }\n\n  .md\\:hover\\:from-grayscale-800:hover {\n    --gradient-from-color: hsl(0, 0%, 80%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n  }\n\n  .md\\:hover\\:from-grayscale-840:hover {\n    --gradient-from-color: hsl(0, 0%, 84%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n  }\n\n  .md\\:hover\\:from-grayscale-870:hover {\n    --gradient-from-color: hsl(0, 0%, 87%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n  }\n\n  .md\\:hover\\:from-grayscale-900:hover {\n    --gradient-from-color: hsl(0, 0%, 90%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n  }\n\n  .md\\:hover\\:from-grayscale-930:hover {\n    --gradient-from-color: hsl(0, 0%, 93%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n  }\n\n  .md\\:hover\\:from-primary:hover {\n    --gradient-from-color: hsl(210, 100%, 52%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n  }\n\n  .md\\:hover\\:from-background-main:hover {\n    --gradient-from-color: var(--main-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:hover\\:from-background-secondary:hover {\n    --gradient-from-color: var(--secondary-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:hover\\:from-foreground:hover {\n    --gradient-from-color: var(--foreground);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:hover\\:from-panels-bg:hover {\n    --gradient-from-color: var(--panels-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:hover\\:via-transparent:hover {\n    --gradient-via-color: transparent;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .md\\:hover\\:via-current:hover {\n    --gradient-via-color: currentColor;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:hover\\:via-black:hover {\n    --gradient-via-color: #000;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .md\\:hover\\:via-white:hover {\n    --gradient-via-color: #fff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:hover\\:via-gray-100:hover {\n    --gradient-via-color: #f7fafc;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n  }\n\n  .md\\:hover\\:via-gray-200:hover {\n    --gradient-via-color: #edf2f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n  }\n\n  .md\\:hover\\:via-gray-300:hover {\n    --gradient-via-color: #e2e8f0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n  }\n\n  .md\\:hover\\:via-gray-400:hover {\n    --gradient-via-color: #cbd5e0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n  }\n\n  .md\\:hover\\:via-gray-500:hover {\n    --gradient-via-color: #a0aec0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n  }\n\n  .md\\:hover\\:via-gray-600:hover {\n    --gradient-via-color: #718096;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n  }\n\n  .md\\:hover\\:via-gray-700:hover {\n    --gradient-via-color: #4a5568;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n  }\n\n  .md\\:hover\\:via-gray-800:hover {\n    --gradient-via-color: #2d3748;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n  }\n\n  .md\\:hover\\:via-gray-900:hover {\n    --gradient-via-color: #1a202c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n  }\n\n  .md\\:hover\\:via-red-100:hover {\n    --gradient-via-color: #fff5f5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n  }\n\n  .md\\:hover\\:via-red-200:hover {\n    --gradient-via-color: #fed7d7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n  }\n\n  .md\\:hover\\:via-red-300:hover {\n    --gradient-via-color: #feb2b2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n  }\n\n  .md\\:hover\\:via-red-400:hover {\n    --gradient-via-color: #fc8181;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n  }\n\n  .md\\:hover\\:via-red-500:hover {\n    --gradient-via-color: #f56565;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n  }\n\n  .md\\:hover\\:via-red-600:hover {\n    --gradient-via-color: #e53e3e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n  }\n\n  .md\\:hover\\:via-red-700:hover {\n    --gradient-via-color: #c53030;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n  }\n\n  .md\\:hover\\:via-red-800:hover {\n    --gradient-via-color: #9b2c2c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n  }\n\n  .md\\:hover\\:via-red-900:hover {\n    --gradient-via-color: #742a2a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n  }\n\n  .md\\:hover\\:via-orange-100:hover {\n    --gradient-via-color: #fffaf0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n  }\n\n  .md\\:hover\\:via-orange-200:hover {\n    --gradient-via-color: #feebc8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n  }\n\n  .md\\:hover\\:via-orange-300:hover {\n    --gradient-via-color: #fbd38d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n  }\n\n  .md\\:hover\\:via-orange-400:hover {\n    --gradient-via-color: #f6ad55;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n  }\n\n  .md\\:hover\\:via-orange-500:hover {\n    --gradient-via-color: #ed8936;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n  }\n\n  .md\\:hover\\:via-orange-600:hover {\n    --gradient-via-color: #dd6b20;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n  }\n\n  .md\\:hover\\:via-orange-700:hover {\n    --gradient-via-color: #c05621;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n  }\n\n  .md\\:hover\\:via-orange-800:hover {\n    --gradient-via-color: #9c4221;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n  }\n\n  .md\\:hover\\:via-orange-900:hover {\n    --gradient-via-color: #7b341e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n  }\n\n  .md\\:hover\\:via-yellow-100:hover {\n    --gradient-via-color: #fffff0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n  }\n\n  .md\\:hover\\:via-yellow-200:hover {\n    --gradient-via-color: #fefcbf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n  }\n\n  .md\\:hover\\:via-yellow-300:hover {\n    --gradient-via-color: #faf089;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n  }\n\n  .md\\:hover\\:via-yellow-400:hover {\n    --gradient-via-color: #f6e05e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n  }\n\n  .md\\:hover\\:via-yellow-500:hover {\n    --gradient-via-color: #ecc94b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n  }\n\n  .md\\:hover\\:via-yellow-600:hover {\n    --gradient-via-color: #d69e2e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n  }\n\n  .md\\:hover\\:via-yellow-700:hover {\n    --gradient-via-color: #b7791f;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n  }\n\n  .md\\:hover\\:via-yellow-800:hover {\n    --gradient-via-color: #975a16;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n  }\n\n  .md\\:hover\\:via-yellow-900:hover {\n    --gradient-via-color: #744210;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n  }\n\n  .md\\:hover\\:via-green-100:hover {\n    --gradient-via-color: #f0fff4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n  }\n\n  .md\\:hover\\:via-green-200:hover {\n    --gradient-via-color: #c6f6d5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n  }\n\n  .md\\:hover\\:via-green-300:hover {\n    --gradient-via-color: #9ae6b4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n  }\n\n  .md\\:hover\\:via-green-400:hover {\n    --gradient-via-color: #68d391;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n  }\n\n  .md\\:hover\\:via-green-500:hover {\n    --gradient-via-color: #48bb78;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n  }\n\n  .md\\:hover\\:via-green-600:hover {\n    --gradient-via-color: #38a169;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n  }\n\n  .md\\:hover\\:via-green-700:hover {\n    --gradient-via-color: #2f855a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n  }\n\n  .md\\:hover\\:via-green-800:hover {\n    --gradient-via-color: #276749;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n  }\n\n  .md\\:hover\\:via-green-900:hover {\n    --gradient-via-color: #22543d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n  }\n\n  .md\\:hover\\:via-teal-100:hover {\n    --gradient-via-color: #e6fffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n  }\n\n  .md\\:hover\\:via-teal-200:hover {\n    --gradient-via-color: #b2f5ea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n  }\n\n  .md\\:hover\\:via-teal-300:hover {\n    --gradient-via-color: #81e6d9;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n  }\n\n  .md\\:hover\\:via-teal-400:hover {\n    --gradient-via-color: #4fd1c5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n  }\n\n  .md\\:hover\\:via-teal-500:hover {\n    --gradient-via-color: #38b2ac;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n  }\n\n  .md\\:hover\\:via-teal-600:hover {\n    --gradient-via-color: #319795;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n  }\n\n  .md\\:hover\\:via-teal-700:hover {\n    --gradient-via-color: #2c7a7b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n  }\n\n  .md\\:hover\\:via-teal-800:hover {\n    --gradient-via-color: #285e61;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n  }\n\n  .md\\:hover\\:via-teal-900:hover {\n    --gradient-via-color: #234e52;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n  }\n\n  .md\\:hover\\:via-blue-100:hover {\n    --gradient-via-color: #ebf8ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n  }\n\n  .md\\:hover\\:via-blue-200:hover {\n    --gradient-via-color: #bee3f8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n  }\n\n  .md\\:hover\\:via-blue-300:hover {\n    --gradient-via-color: #90cdf4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n  }\n\n  .md\\:hover\\:via-blue-400:hover {\n    --gradient-via-color: #63b3ed;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n  }\n\n  .md\\:hover\\:via-blue-500:hover {\n    --gradient-via-color: #4299e1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n  }\n\n  .md\\:hover\\:via-blue-600:hover {\n    --gradient-via-color: #3182ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n  }\n\n  .md\\:hover\\:via-blue-700:hover {\n    --gradient-via-color: #2b6cb0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n  }\n\n  .md\\:hover\\:via-blue-800:hover {\n    --gradient-via-color: #2c5282;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n  }\n\n  .md\\:hover\\:via-blue-900:hover {\n    --gradient-via-color: #2a4365;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n  }\n\n  .md\\:hover\\:via-indigo-100:hover {\n    --gradient-via-color: #ebf4ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n  }\n\n  .md\\:hover\\:via-indigo-200:hover {\n    --gradient-via-color: #c3dafe;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n  }\n\n  .md\\:hover\\:via-indigo-300:hover {\n    --gradient-via-color: #a3bffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n  }\n\n  .md\\:hover\\:via-indigo-400:hover {\n    --gradient-via-color: #7f9cf5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n  }\n\n  .md\\:hover\\:via-indigo-500:hover {\n    --gradient-via-color: #667eea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n  }\n\n  .md\\:hover\\:via-indigo-600:hover {\n    --gradient-via-color: #5a67d8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n  }\n\n  .md\\:hover\\:via-indigo-700:hover {\n    --gradient-via-color: #4c51bf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n  }\n\n  .md\\:hover\\:via-indigo-800:hover {\n    --gradient-via-color: #434190;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n  }\n\n  .md\\:hover\\:via-indigo-900:hover {\n    --gradient-via-color: #3c366b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n  }\n\n  .md\\:hover\\:via-purple-100:hover {\n    --gradient-via-color: #faf5ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n  }\n\n  .md\\:hover\\:via-purple-200:hover {\n    --gradient-via-color: #e9d8fd;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n  }\n\n  .md\\:hover\\:via-purple-300:hover {\n    --gradient-via-color: #d6bcfa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n  }\n\n  .md\\:hover\\:via-purple-400:hover {\n    --gradient-via-color: #b794f4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n  }\n\n  .md\\:hover\\:via-purple-500:hover {\n    --gradient-via-color: #9f7aea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n  }\n\n  .md\\:hover\\:via-purple-600:hover {\n    --gradient-via-color: #805ad5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n  }\n\n  .md\\:hover\\:via-purple-700:hover {\n    --gradient-via-color: #6b46c1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n  }\n\n  .md\\:hover\\:via-purple-800:hover {\n    --gradient-via-color: #553c9a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n  }\n\n  .md\\:hover\\:via-purple-900:hover {\n    --gradient-via-color: #44337a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n  }\n\n  .md\\:hover\\:via-pink-100:hover {\n    --gradient-via-color: #fff5f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n  }\n\n  .md\\:hover\\:via-pink-200:hover {\n    --gradient-via-color: #fed7e2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n  }\n\n  .md\\:hover\\:via-pink-300:hover {\n    --gradient-via-color: #fbb6ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n  }\n\n  .md\\:hover\\:via-pink-400:hover {\n    --gradient-via-color: #f687b3;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n  }\n\n  .md\\:hover\\:via-pink-500:hover {\n    --gradient-via-color: #ed64a6;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n  }\n\n  .md\\:hover\\:via-pink-600:hover {\n    --gradient-via-color: #d53f8c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n  }\n\n  .md\\:hover\\:via-pink-700:hover {\n    --gradient-via-color: #b83280;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n  }\n\n  .md\\:hover\\:via-pink-800:hover {\n    --gradient-via-color: #97266d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n  }\n\n  .md\\:hover\\:via-pink-900:hover {\n    --gradient-via-color: #702459;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n  }\n\n  .md\\:hover\\:via-grayscale-80:hover {\n    --gradient-via-color: hsl(0, 0%, 8%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n  }\n\n  .md\\:hover\\:via-grayscale-100:hover {\n    --gradient-via-color: hsl(0, 0%, 10%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n  }\n\n  .md\\:hover\\:via-grayscale-200:hover {\n    --gradient-via-color: hsl(0, 0%, 20%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n  }\n\n  .md\\:hover\\:via-grayscale-300:hover {\n    --gradient-via-color: hsl(0, 0%, 30%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n  }\n\n  .md\\:hover\\:via-grayscale-400:hover {\n    --gradient-via-color: hsl(0, 0%, 40%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n  }\n\n  .md\\:hover\\:via-grayscale-500:hover {\n    --gradient-via-color: hsl(0, 0%, 50%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n  }\n\n  .md\\:hover\\:via-grayscale-600:hover {\n    --gradient-via-color: hsl(0, 0%, 60%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n  }\n\n  .md\\:hover\\:via-grayscale-700:hover {\n    --gradient-via-color: hsl(0, 0%, 70%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n  }\n\n  .md\\:hover\\:via-grayscale-800:hover {\n    --gradient-via-color: hsl(0, 0%, 80%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n  }\n\n  .md\\:hover\\:via-grayscale-840:hover {\n    --gradient-via-color: hsl(0, 0%, 84%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n  }\n\n  .md\\:hover\\:via-grayscale-870:hover {\n    --gradient-via-color: hsl(0, 0%, 87%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n  }\n\n  .md\\:hover\\:via-grayscale-900:hover {\n    --gradient-via-color: hsl(0, 0%, 90%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n  }\n\n  .md\\:hover\\:via-grayscale-930:hover {\n    --gradient-via-color: hsl(0, 0%, 93%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n  }\n\n  .md\\:hover\\:via-primary:hover {\n    --gradient-via-color: hsl(210, 100%, 52%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n  }\n\n  .md\\:hover\\:via-background-main:hover {\n    --gradient-via-color: var(--main-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:hover\\:via-background-secondary:hover {\n    --gradient-via-color: var(--secondary-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:hover\\:via-foreground:hover {\n    --gradient-via-color: var(--foreground);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:hover\\:via-panels-bg:hover {\n    --gradient-via-color: var(--panels-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:hover\\:to-transparent:hover {\n    --gradient-to-color: transparent;\n  }\n\n  .md\\:hover\\:to-current:hover {\n    --gradient-to-color: currentColor;\n  }\n\n  .md\\:hover\\:to-black:hover {\n    --gradient-to-color: #000;\n  }\n\n  .md\\:hover\\:to-white:hover {\n    --gradient-to-color: #fff;\n  }\n\n  .md\\:hover\\:to-gray-100:hover {\n    --gradient-to-color: #f7fafc;\n  }\n\n  .md\\:hover\\:to-gray-200:hover {\n    --gradient-to-color: #edf2f7;\n  }\n\n  .md\\:hover\\:to-gray-300:hover {\n    --gradient-to-color: #e2e8f0;\n  }\n\n  .md\\:hover\\:to-gray-400:hover {\n    --gradient-to-color: #cbd5e0;\n  }\n\n  .md\\:hover\\:to-gray-500:hover {\n    --gradient-to-color: #a0aec0;\n  }\n\n  .md\\:hover\\:to-gray-600:hover {\n    --gradient-to-color: #718096;\n  }\n\n  .md\\:hover\\:to-gray-700:hover {\n    --gradient-to-color: #4a5568;\n  }\n\n  .md\\:hover\\:to-gray-800:hover {\n    --gradient-to-color: #2d3748;\n  }\n\n  .md\\:hover\\:to-gray-900:hover {\n    --gradient-to-color: #1a202c;\n  }\n\n  .md\\:hover\\:to-red-100:hover {\n    --gradient-to-color: #fff5f5;\n  }\n\n  .md\\:hover\\:to-red-200:hover {\n    --gradient-to-color: #fed7d7;\n  }\n\n  .md\\:hover\\:to-red-300:hover {\n    --gradient-to-color: #feb2b2;\n  }\n\n  .md\\:hover\\:to-red-400:hover {\n    --gradient-to-color: #fc8181;\n  }\n\n  .md\\:hover\\:to-red-500:hover {\n    --gradient-to-color: #f56565;\n  }\n\n  .md\\:hover\\:to-red-600:hover {\n    --gradient-to-color: #e53e3e;\n  }\n\n  .md\\:hover\\:to-red-700:hover {\n    --gradient-to-color: #c53030;\n  }\n\n  .md\\:hover\\:to-red-800:hover {\n    --gradient-to-color: #9b2c2c;\n  }\n\n  .md\\:hover\\:to-red-900:hover {\n    --gradient-to-color: #742a2a;\n  }\n\n  .md\\:hover\\:to-orange-100:hover {\n    --gradient-to-color: #fffaf0;\n  }\n\n  .md\\:hover\\:to-orange-200:hover {\n    --gradient-to-color: #feebc8;\n  }\n\n  .md\\:hover\\:to-orange-300:hover {\n    --gradient-to-color: #fbd38d;\n  }\n\n  .md\\:hover\\:to-orange-400:hover {\n    --gradient-to-color: #f6ad55;\n  }\n\n  .md\\:hover\\:to-orange-500:hover {\n    --gradient-to-color: #ed8936;\n  }\n\n  .md\\:hover\\:to-orange-600:hover {\n    --gradient-to-color: #dd6b20;\n  }\n\n  .md\\:hover\\:to-orange-700:hover {\n    --gradient-to-color: #c05621;\n  }\n\n  .md\\:hover\\:to-orange-800:hover {\n    --gradient-to-color: #9c4221;\n  }\n\n  .md\\:hover\\:to-orange-900:hover {\n    --gradient-to-color: #7b341e;\n  }\n\n  .md\\:hover\\:to-yellow-100:hover {\n    --gradient-to-color: #fffff0;\n  }\n\n  .md\\:hover\\:to-yellow-200:hover {\n    --gradient-to-color: #fefcbf;\n  }\n\n  .md\\:hover\\:to-yellow-300:hover {\n    --gradient-to-color: #faf089;\n  }\n\n  .md\\:hover\\:to-yellow-400:hover {\n    --gradient-to-color: #f6e05e;\n  }\n\n  .md\\:hover\\:to-yellow-500:hover {\n    --gradient-to-color: #ecc94b;\n  }\n\n  .md\\:hover\\:to-yellow-600:hover {\n    --gradient-to-color: #d69e2e;\n  }\n\n  .md\\:hover\\:to-yellow-700:hover {\n    --gradient-to-color: #b7791f;\n  }\n\n  .md\\:hover\\:to-yellow-800:hover {\n    --gradient-to-color: #975a16;\n  }\n\n  .md\\:hover\\:to-yellow-900:hover {\n    --gradient-to-color: #744210;\n  }\n\n  .md\\:hover\\:to-green-100:hover {\n    --gradient-to-color: #f0fff4;\n  }\n\n  .md\\:hover\\:to-green-200:hover {\n    --gradient-to-color: #c6f6d5;\n  }\n\n  .md\\:hover\\:to-green-300:hover {\n    --gradient-to-color: #9ae6b4;\n  }\n\n  .md\\:hover\\:to-green-400:hover {\n    --gradient-to-color: #68d391;\n  }\n\n  .md\\:hover\\:to-green-500:hover {\n    --gradient-to-color: #48bb78;\n  }\n\n  .md\\:hover\\:to-green-600:hover {\n    --gradient-to-color: #38a169;\n  }\n\n  .md\\:hover\\:to-green-700:hover {\n    --gradient-to-color: #2f855a;\n  }\n\n  .md\\:hover\\:to-green-800:hover {\n    --gradient-to-color: #276749;\n  }\n\n  .md\\:hover\\:to-green-900:hover {\n    --gradient-to-color: #22543d;\n  }\n\n  .md\\:hover\\:to-teal-100:hover {\n    --gradient-to-color: #e6fffa;\n  }\n\n  .md\\:hover\\:to-teal-200:hover {\n    --gradient-to-color: #b2f5ea;\n  }\n\n  .md\\:hover\\:to-teal-300:hover {\n    --gradient-to-color: #81e6d9;\n  }\n\n  .md\\:hover\\:to-teal-400:hover {\n    --gradient-to-color: #4fd1c5;\n  }\n\n  .md\\:hover\\:to-teal-500:hover {\n    --gradient-to-color: #38b2ac;\n  }\n\n  .md\\:hover\\:to-teal-600:hover {\n    --gradient-to-color: #319795;\n  }\n\n  .md\\:hover\\:to-teal-700:hover {\n    --gradient-to-color: #2c7a7b;\n  }\n\n  .md\\:hover\\:to-teal-800:hover {\n    --gradient-to-color: #285e61;\n  }\n\n  .md\\:hover\\:to-teal-900:hover {\n    --gradient-to-color: #234e52;\n  }\n\n  .md\\:hover\\:to-blue-100:hover {\n    --gradient-to-color: #ebf8ff;\n  }\n\n  .md\\:hover\\:to-blue-200:hover {\n    --gradient-to-color: #bee3f8;\n  }\n\n  .md\\:hover\\:to-blue-300:hover {\n    --gradient-to-color: #90cdf4;\n  }\n\n  .md\\:hover\\:to-blue-400:hover {\n    --gradient-to-color: #63b3ed;\n  }\n\n  .md\\:hover\\:to-blue-500:hover {\n    --gradient-to-color: #4299e1;\n  }\n\n  .md\\:hover\\:to-blue-600:hover {\n    --gradient-to-color: #3182ce;\n  }\n\n  .md\\:hover\\:to-blue-700:hover {\n    --gradient-to-color: #2b6cb0;\n  }\n\n  .md\\:hover\\:to-blue-800:hover {\n    --gradient-to-color: #2c5282;\n  }\n\n  .md\\:hover\\:to-blue-900:hover {\n    --gradient-to-color: #2a4365;\n  }\n\n  .md\\:hover\\:to-indigo-100:hover {\n    --gradient-to-color: #ebf4ff;\n  }\n\n  .md\\:hover\\:to-indigo-200:hover {\n    --gradient-to-color: #c3dafe;\n  }\n\n  .md\\:hover\\:to-indigo-300:hover {\n    --gradient-to-color: #a3bffa;\n  }\n\n  .md\\:hover\\:to-indigo-400:hover {\n    --gradient-to-color: #7f9cf5;\n  }\n\n  .md\\:hover\\:to-indigo-500:hover {\n    --gradient-to-color: #667eea;\n  }\n\n  .md\\:hover\\:to-indigo-600:hover {\n    --gradient-to-color: #5a67d8;\n  }\n\n  .md\\:hover\\:to-indigo-700:hover {\n    --gradient-to-color: #4c51bf;\n  }\n\n  .md\\:hover\\:to-indigo-800:hover {\n    --gradient-to-color: #434190;\n  }\n\n  .md\\:hover\\:to-indigo-900:hover {\n    --gradient-to-color: #3c366b;\n  }\n\n  .md\\:hover\\:to-purple-100:hover {\n    --gradient-to-color: #faf5ff;\n  }\n\n  .md\\:hover\\:to-purple-200:hover {\n    --gradient-to-color: #e9d8fd;\n  }\n\n  .md\\:hover\\:to-purple-300:hover {\n    --gradient-to-color: #d6bcfa;\n  }\n\n  .md\\:hover\\:to-purple-400:hover {\n    --gradient-to-color: #b794f4;\n  }\n\n  .md\\:hover\\:to-purple-500:hover {\n    --gradient-to-color: #9f7aea;\n  }\n\n  .md\\:hover\\:to-purple-600:hover {\n    --gradient-to-color: #805ad5;\n  }\n\n  .md\\:hover\\:to-purple-700:hover {\n    --gradient-to-color: #6b46c1;\n  }\n\n  .md\\:hover\\:to-purple-800:hover {\n    --gradient-to-color: #553c9a;\n  }\n\n  .md\\:hover\\:to-purple-900:hover {\n    --gradient-to-color: #44337a;\n  }\n\n  .md\\:hover\\:to-pink-100:hover {\n    --gradient-to-color: #fff5f7;\n  }\n\n  .md\\:hover\\:to-pink-200:hover {\n    --gradient-to-color: #fed7e2;\n  }\n\n  .md\\:hover\\:to-pink-300:hover {\n    --gradient-to-color: #fbb6ce;\n  }\n\n  .md\\:hover\\:to-pink-400:hover {\n    --gradient-to-color: #f687b3;\n  }\n\n  .md\\:hover\\:to-pink-500:hover {\n    --gradient-to-color: #ed64a6;\n  }\n\n  .md\\:hover\\:to-pink-600:hover {\n    --gradient-to-color: #d53f8c;\n  }\n\n  .md\\:hover\\:to-pink-700:hover {\n    --gradient-to-color: #b83280;\n  }\n\n  .md\\:hover\\:to-pink-800:hover {\n    --gradient-to-color: #97266d;\n  }\n\n  .md\\:hover\\:to-pink-900:hover {\n    --gradient-to-color: #702459;\n  }\n\n  .md\\:hover\\:to-grayscale-80:hover {\n    --gradient-to-color: hsl(0, 0%, 8%);\n  }\n\n  .md\\:hover\\:to-grayscale-100:hover {\n    --gradient-to-color: hsl(0, 0%, 10%);\n  }\n\n  .md\\:hover\\:to-grayscale-200:hover {\n    --gradient-to-color: hsl(0, 0%, 20%);\n  }\n\n  .md\\:hover\\:to-grayscale-300:hover {\n    --gradient-to-color: hsl(0, 0%, 30%);\n  }\n\n  .md\\:hover\\:to-grayscale-400:hover {\n    --gradient-to-color: hsl(0, 0%, 40%);\n  }\n\n  .md\\:hover\\:to-grayscale-500:hover {\n    --gradient-to-color: hsl(0, 0%, 50%);\n  }\n\n  .md\\:hover\\:to-grayscale-600:hover {\n    --gradient-to-color: hsl(0, 0%, 60%);\n  }\n\n  .md\\:hover\\:to-grayscale-700:hover {\n    --gradient-to-color: hsl(0, 0%, 70%);\n  }\n\n  .md\\:hover\\:to-grayscale-800:hover {\n    --gradient-to-color: hsl(0, 0%, 80%);\n  }\n\n  .md\\:hover\\:to-grayscale-840:hover {\n    --gradient-to-color: hsl(0, 0%, 84%);\n  }\n\n  .md\\:hover\\:to-grayscale-870:hover {\n    --gradient-to-color: hsl(0, 0%, 87%);\n  }\n\n  .md\\:hover\\:to-grayscale-900:hover {\n    --gradient-to-color: hsl(0, 0%, 90%);\n  }\n\n  .md\\:hover\\:to-grayscale-930:hover {\n    --gradient-to-color: hsl(0, 0%, 93%);\n  }\n\n  .md\\:hover\\:to-primary:hover {\n    --gradient-to-color: hsl(210, 100%, 52%);\n  }\n\n  .md\\:hover\\:to-background-main:hover {\n    --gradient-to-color: var(--main-background);\n  }\n\n  .md\\:hover\\:to-background-secondary:hover {\n    --gradient-to-color: var(--secondary-background);\n  }\n\n  .md\\:hover\\:to-foreground:hover {\n    --gradient-to-color: var(--foreground);\n  }\n\n  .md\\:hover\\:to-panels-bg:hover {\n    --gradient-to-color: var(--panels-background);\n  }\n\n  .md\\:focus\\:from-transparent:focus {\n    --gradient-from-color: transparent;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .md\\:focus\\:from-current:focus {\n    --gradient-from-color: currentColor;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:focus\\:from-black:focus {\n    --gradient-from-color: #000;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .md\\:focus\\:from-white:focus {\n    --gradient-from-color: #fff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:focus\\:from-gray-100:focus {\n    --gradient-from-color: #f7fafc;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n  }\n\n  .md\\:focus\\:from-gray-200:focus {\n    --gradient-from-color: #edf2f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n  }\n\n  .md\\:focus\\:from-gray-300:focus {\n    --gradient-from-color: #e2e8f0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n  }\n\n  .md\\:focus\\:from-gray-400:focus {\n    --gradient-from-color: #cbd5e0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n  }\n\n  .md\\:focus\\:from-gray-500:focus {\n    --gradient-from-color: #a0aec0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n  }\n\n  .md\\:focus\\:from-gray-600:focus {\n    --gradient-from-color: #718096;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n  }\n\n  .md\\:focus\\:from-gray-700:focus {\n    --gradient-from-color: #4a5568;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n  }\n\n  .md\\:focus\\:from-gray-800:focus {\n    --gradient-from-color: #2d3748;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n  }\n\n  .md\\:focus\\:from-gray-900:focus {\n    --gradient-from-color: #1a202c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n  }\n\n  .md\\:focus\\:from-red-100:focus {\n    --gradient-from-color: #fff5f5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n  }\n\n  .md\\:focus\\:from-red-200:focus {\n    --gradient-from-color: #fed7d7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n  }\n\n  .md\\:focus\\:from-red-300:focus {\n    --gradient-from-color: #feb2b2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n  }\n\n  .md\\:focus\\:from-red-400:focus {\n    --gradient-from-color: #fc8181;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n  }\n\n  .md\\:focus\\:from-red-500:focus {\n    --gradient-from-color: #f56565;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n  }\n\n  .md\\:focus\\:from-red-600:focus {\n    --gradient-from-color: #e53e3e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n  }\n\n  .md\\:focus\\:from-red-700:focus {\n    --gradient-from-color: #c53030;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n  }\n\n  .md\\:focus\\:from-red-800:focus {\n    --gradient-from-color: #9b2c2c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n  }\n\n  .md\\:focus\\:from-red-900:focus {\n    --gradient-from-color: #742a2a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n  }\n\n  .md\\:focus\\:from-orange-100:focus {\n    --gradient-from-color: #fffaf0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n  }\n\n  .md\\:focus\\:from-orange-200:focus {\n    --gradient-from-color: #feebc8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n  }\n\n  .md\\:focus\\:from-orange-300:focus {\n    --gradient-from-color: #fbd38d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n  }\n\n  .md\\:focus\\:from-orange-400:focus {\n    --gradient-from-color: #f6ad55;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n  }\n\n  .md\\:focus\\:from-orange-500:focus {\n    --gradient-from-color: #ed8936;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n  }\n\n  .md\\:focus\\:from-orange-600:focus {\n    --gradient-from-color: #dd6b20;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n  }\n\n  .md\\:focus\\:from-orange-700:focus {\n    --gradient-from-color: #c05621;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n  }\n\n  .md\\:focus\\:from-orange-800:focus {\n    --gradient-from-color: #9c4221;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n  }\n\n  .md\\:focus\\:from-orange-900:focus {\n    --gradient-from-color: #7b341e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n  }\n\n  .md\\:focus\\:from-yellow-100:focus {\n    --gradient-from-color: #fffff0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n  }\n\n  .md\\:focus\\:from-yellow-200:focus {\n    --gradient-from-color: #fefcbf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n  }\n\n  .md\\:focus\\:from-yellow-300:focus {\n    --gradient-from-color: #faf089;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n  }\n\n  .md\\:focus\\:from-yellow-400:focus {\n    --gradient-from-color: #f6e05e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n  }\n\n  .md\\:focus\\:from-yellow-500:focus {\n    --gradient-from-color: #ecc94b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n  }\n\n  .md\\:focus\\:from-yellow-600:focus {\n    --gradient-from-color: #d69e2e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n  }\n\n  .md\\:focus\\:from-yellow-700:focus {\n    --gradient-from-color: #b7791f;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n  }\n\n  .md\\:focus\\:from-yellow-800:focus {\n    --gradient-from-color: #975a16;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n  }\n\n  .md\\:focus\\:from-yellow-900:focus {\n    --gradient-from-color: #744210;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n  }\n\n  .md\\:focus\\:from-green-100:focus {\n    --gradient-from-color: #f0fff4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n  }\n\n  .md\\:focus\\:from-green-200:focus {\n    --gradient-from-color: #c6f6d5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n  }\n\n  .md\\:focus\\:from-green-300:focus {\n    --gradient-from-color: #9ae6b4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n  }\n\n  .md\\:focus\\:from-green-400:focus {\n    --gradient-from-color: #68d391;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n  }\n\n  .md\\:focus\\:from-green-500:focus {\n    --gradient-from-color: #48bb78;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n  }\n\n  .md\\:focus\\:from-green-600:focus {\n    --gradient-from-color: #38a169;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n  }\n\n  .md\\:focus\\:from-green-700:focus {\n    --gradient-from-color: #2f855a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n  }\n\n  .md\\:focus\\:from-green-800:focus {\n    --gradient-from-color: #276749;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n  }\n\n  .md\\:focus\\:from-green-900:focus {\n    --gradient-from-color: #22543d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n  }\n\n  .md\\:focus\\:from-teal-100:focus {\n    --gradient-from-color: #e6fffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n  }\n\n  .md\\:focus\\:from-teal-200:focus {\n    --gradient-from-color: #b2f5ea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n  }\n\n  .md\\:focus\\:from-teal-300:focus {\n    --gradient-from-color: #81e6d9;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n  }\n\n  .md\\:focus\\:from-teal-400:focus {\n    --gradient-from-color: #4fd1c5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n  }\n\n  .md\\:focus\\:from-teal-500:focus {\n    --gradient-from-color: #38b2ac;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n  }\n\n  .md\\:focus\\:from-teal-600:focus {\n    --gradient-from-color: #319795;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n  }\n\n  .md\\:focus\\:from-teal-700:focus {\n    --gradient-from-color: #2c7a7b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n  }\n\n  .md\\:focus\\:from-teal-800:focus {\n    --gradient-from-color: #285e61;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n  }\n\n  .md\\:focus\\:from-teal-900:focus {\n    --gradient-from-color: #234e52;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n  }\n\n  .md\\:focus\\:from-blue-100:focus {\n    --gradient-from-color: #ebf8ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n  }\n\n  .md\\:focus\\:from-blue-200:focus {\n    --gradient-from-color: #bee3f8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n  }\n\n  .md\\:focus\\:from-blue-300:focus {\n    --gradient-from-color: #90cdf4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n  }\n\n  .md\\:focus\\:from-blue-400:focus {\n    --gradient-from-color: #63b3ed;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n  }\n\n  .md\\:focus\\:from-blue-500:focus {\n    --gradient-from-color: #4299e1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n  }\n\n  .md\\:focus\\:from-blue-600:focus {\n    --gradient-from-color: #3182ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n  }\n\n  .md\\:focus\\:from-blue-700:focus {\n    --gradient-from-color: #2b6cb0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n  }\n\n  .md\\:focus\\:from-blue-800:focus {\n    --gradient-from-color: #2c5282;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n  }\n\n  .md\\:focus\\:from-blue-900:focus {\n    --gradient-from-color: #2a4365;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n  }\n\n  .md\\:focus\\:from-indigo-100:focus {\n    --gradient-from-color: #ebf4ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n  }\n\n  .md\\:focus\\:from-indigo-200:focus {\n    --gradient-from-color: #c3dafe;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n  }\n\n  .md\\:focus\\:from-indigo-300:focus {\n    --gradient-from-color: #a3bffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n  }\n\n  .md\\:focus\\:from-indigo-400:focus {\n    --gradient-from-color: #7f9cf5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n  }\n\n  .md\\:focus\\:from-indigo-500:focus {\n    --gradient-from-color: #667eea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n  }\n\n  .md\\:focus\\:from-indigo-600:focus {\n    --gradient-from-color: #5a67d8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n  }\n\n  .md\\:focus\\:from-indigo-700:focus {\n    --gradient-from-color: #4c51bf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n  }\n\n  .md\\:focus\\:from-indigo-800:focus {\n    --gradient-from-color: #434190;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n  }\n\n  .md\\:focus\\:from-indigo-900:focus {\n    --gradient-from-color: #3c366b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n  }\n\n  .md\\:focus\\:from-purple-100:focus {\n    --gradient-from-color: #faf5ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n  }\n\n  .md\\:focus\\:from-purple-200:focus {\n    --gradient-from-color: #e9d8fd;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n  }\n\n  .md\\:focus\\:from-purple-300:focus {\n    --gradient-from-color: #d6bcfa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n  }\n\n  .md\\:focus\\:from-purple-400:focus {\n    --gradient-from-color: #b794f4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n  }\n\n  .md\\:focus\\:from-purple-500:focus {\n    --gradient-from-color: #9f7aea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n  }\n\n  .md\\:focus\\:from-purple-600:focus {\n    --gradient-from-color: #805ad5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n  }\n\n  .md\\:focus\\:from-purple-700:focus {\n    --gradient-from-color: #6b46c1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n  }\n\n  .md\\:focus\\:from-purple-800:focus {\n    --gradient-from-color: #553c9a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n  }\n\n  .md\\:focus\\:from-purple-900:focus {\n    --gradient-from-color: #44337a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n  }\n\n  .md\\:focus\\:from-pink-100:focus {\n    --gradient-from-color: #fff5f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n  }\n\n  .md\\:focus\\:from-pink-200:focus {\n    --gradient-from-color: #fed7e2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n  }\n\n  .md\\:focus\\:from-pink-300:focus {\n    --gradient-from-color: #fbb6ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n  }\n\n  .md\\:focus\\:from-pink-400:focus {\n    --gradient-from-color: #f687b3;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n  }\n\n  .md\\:focus\\:from-pink-500:focus {\n    --gradient-from-color: #ed64a6;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n  }\n\n  .md\\:focus\\:from-pink-600:focus {\n    --gradient-from-color: #d53f8c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n  }\n\n  .md\\:focus\\:from-pink-700:focus {\n    --gradient-from-color: #b83280;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n  }\n\n  .md\\:focus\\:from-pink-800:focus {\n    --gradient-from-color: #97266d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n  }\n\n  .md\\:focus\\:from-pink-900:focus {\n    --gradient-from-color: #702459;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n  }\n\n  .md\\:focus\\:from-grayscale-80:focus {\n    --gradient-from-color: hsl(0, 0%, 8%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n  }\n\n  .md\\:focus\\:from-grayscale-100:focus {\n    --gradient-from-color: hsl(0, 0%, 10%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n  }\n\n  .md\\:focus\\:from-grayscale-200:focus {\n    --gradient-from-color: hsl(0, 0%, 20%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n  }\n\n  .md\\:focus\\:from-grayscale-300:focus {\n    --gradient-from-color: hsl(0, 0%, 30%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n  }\n\n  .md\\:focus\\:from-grayscale-400:focus {\n    --gradient-from-color: hsl(0, 0%, 40%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n  }\n\n  .md\\:focus\\:from-grayscale-500:focus {\n    --gradient-from-color: hsl(0, 0%, 50%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n  }\n\n  .md\\:focus\\:from-grayscale-600:focus {\n    --gradient-from-color: hsl(0, 0%, 60%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n  }\n\n  .md\\:focus\\:from-grayscale-700:focus {\n    --gradient-from-color: hsl(0, 0%, 70%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n  }\n\n  .md\\:focus\\:from-grayscale-800:focus {\n    --gradient-from-color: hsl(0, 0%, 80%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n  }\n\n  .md\\:focus\\:from-grayscale-840:focus {\n    --gradient-from-color: hsl(0, 0%, 84%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n  }\n\n  .md\\:focus\\:from-grayscale-870:focus {\n    --gradient-from-color: hsl(0, 0%, 87%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n  }\n\n  .md\\:focus\\:from-grayscale-900:focus {\n    --gradient-from-color: hsl(0, 0%, 90%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n  }\n\n  .md\\:focus\\:from-grayscale-930:focus {\n    --gradient-from-color: hsl(0, 0%, 93%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n  }\n\n  .md\\:focus\\:from-primary:focus {\n    --gradient-from-color: hsl(210, 100%, 52%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n  }\n\n  .md\\:focus\\:from-background-main:focus {\n    --gradient-from-color: var(--main-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:focus\\:from-background-secondary:focus {\n    --gradient-from-color: var(--secondary-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:focus\\:from-foreground:focus {\n    --gradient-from-color: var(--foreground);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:focus\\:from-panels-bg:focus {\n    --gradient-from-color: var(--panels-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:focus\\:via-transparent:focus {\n    --gradient-via-color: transparent;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .md\\:focus\\:via-current:focus {\n    --gradient-via-color: currentColor;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:focus\\:via-black:focus {\n    --gradient-via-color: #000;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .md\\:focus\\:via-white:focus {\n    --gradient-via-color: #fff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:focus\\:via-gray-100:focus {\n    --gradient-via-color: #f7fafc;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n  }\n\n  .md\\:focus\\:via-gray-200:focus {\n    --gradient-via-color: #edf2f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n  }\n\n  .md\\:focus\\:via-gray-300:focus {\n    --gradient-via-color: #e2e8f0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n  }\n\n  .md\\:focus\\:via-gray-400:focus {\n    --gradient-via-color: #cbd5e0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n  }\n\n  .md\\:focus\\:via-gray-500:focus {\n    --gradient-via-color: #a0aec0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n  }\n\n  .md\\:focus\\:via-gray-600:focus {\n    --gradient-via-color: #718096;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n  }\n\n  .md\\:focus\\:via-gray-700:focus {\n    --gradient-via-color: #4a5568;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n  }\n\n  .md\\:focus\\:via-gray-800:focus {\n    --gradient-via-color: #2d3748;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n  }\n\n  .md\\:focus\\:via-gray-900:focus {\n    --gradient-via-color: #1a202c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n  }\n\n  .md\\:focus\\:via-red-100:focus {\n    --gradient-via-color: #fff5f5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n  }\n\n  .md\\:focus\\:via-red-200:focus {\n    --gradient-via-color: #fed7d7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n  }\n\n  .md\\:focus\\:via-red-300:focus {\n    --gradient-via-color: #feb2b2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n  }\n\n  .md\\:focus\\:via-red-400:focus {\n    --gradient-via-color: #fc8181;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n  }\n\n  .md\\:focus\\:via-red-500:focus {\n    --gradient-via-color: #f56565;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n  }\n\n  .md\\:focus\\:via-red-600:focus {\n    --gradient-via-color: #e53e3e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n  }\n\n  .md\\:focus\\:via-red-700:focus {\n    --gradient-via-color: #c53030;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n  }\n\n  .md\\:focus\\:via-red-800:focus {\n    --gradient-via-color: #9b2c2c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n  }\n\n  .md\\:focus\\:via-red-900:focus {\n    --gradient-via-color: #742a2a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n  }\n\n  .md\\:focus\\:via-orange-100:focus {\n    --gradient-via-color: #fffaf0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n  }\n\n  .md\\:focus\\:via-orange-200:focus {\n    --gradient-via-color: #feebc8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n  }\n\n  .md\\:focus\\:via-orange-300:focus {\n    --gradient-via-color: #fbd38d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n  }\n\n  .md\\:focus\\:via-orange-400:focus {\n    --gradient-via-color: #f6ad55;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n  }\n\n  .md\\:focus\\:via-orange-500:focus {\n    --gradient-via-color: #ed8936;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n  }\n\n  .md\\:focus\\:via-orange-600:focus {\n    --gradient-via-color: #dd6b20;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n  }\n\n  .md\\:focus\\:via-orange-700:focus {\n    --gradient-via-color: #c05621;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n  }\n\n  .md\\:focus\\:via-orange-800:focus {\n    --gradient-via-color: #9c4221;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n  }\n\n  .md\\:focus\\:via-orange-900:focus {\n    --gradient-via-color: #7b341e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n  }\n\n  .md\\:focus\\:via-yellow-100:focus {\n    --gradient-via-color: #fffff0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n  }\n\n  .md\\:focus\\:via-yellow-200:focus {\n    --gradient-via-color: #fefcbf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n  }\n\n  .md\\:focus\\:via-yellow-300:focus {\n    --gradient-via-color: #faf089;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n  }\n\n  .md\\:focus\\:via-yellow-400:focus {\n    --gradient-via-color: #f6e05e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n  }\n\n  .md\\:focus\\:via-yellow-500:focus {\n    --gradient-via-color: #ecc94b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n  }\n\n  .md\\:focus\\:via-yellow-600:focus {\n    --gradient-via-color: #d69e2e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n  }\n\n  .md\\:focus\\:via-yellow-700:focus {\n    --gradient-via-color: #b7791f;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n  }\n\n  .md\\:focus\\:via-yellow-800:focus {\n    --gradient-via-color: #975a16;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n  }\n\n  .md\\:focus\\:via-yellow-900:focus {\n    --gradient-via-color: #744210;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n  }\n\n  .md\\:focus\\:via-green-100:focus {\n    --gradient-via-color: #f0fff4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n  }\n\n  .md\\:focus\\:via-green-200:focus {\n    --gradient-via-color: #c6f6d5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n  }\n\n  .md\\:focus\\:via-green-300:focus {\n    --gradient-via-color: #9ae6b4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n  }\n\n  .md\\:focus\\:via-green-400:focus {\n    --gradient-via-color: #68d391;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n  }\n\n  .md\\:focus\\:via-green-500:focus {\n    --gradient-via-color: #48bb78;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n  }\n\n  .md\\:focus\\:via-green-600:focus {\n    --gradient-via-color: #38a169;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n  }\n\n  .md\\:focus\\:via-green-700:focus {\n    --gradient-via-color: #2f855a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n  }\n\n  .md\\:focus\\:via-green-800:focus {\n    --gradient-via-color: #276749;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n  }\n\n  .md\\:focus\\:via-green-900:focus {\n    --gradient-via-color: #22543d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n  }\n\n  .md\\:focus\\:via-teal-100:focus {\n    --gradient-via-color: #e6fffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n  }\n\n  .md\\:focus\\:via-teal-200:focus {\n    --gradient-via-color: #b2f5ea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n  }\n\n  .md\\:focus\\:via-teal-300:focus {\n    --gradient-via-color: #81e6d9;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n  }\n\n  .md\\:focus\\:via-teal-400:focus {\n    --gradient-via-color: #4fd1c5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n  }\n\n  .md\\:focus\\:via-teal-500:focus {\n    --gradient-via-color: #38b2ac;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n  }\n\n  .md\\:focus\\:via-teal-600:focus {\n    --gradient-via-color: #319795;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n  }\n\n  .md\\:focus\\:via-teal-700:focus {\n    --gradient-via-color: #2c7a7b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n  }\n\n  .md\\:focus\\:via-teal-800:focus {\n    --gradient-via-color: #285e61;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n  }\n\n  .md\\:focus\\:via-teal-900:focus {\n    --gradient-via-color: #234e52;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n  }\n\n  .md\\:focus\\:via-blue-100:focus {\n    --gradient-via-color: #ebf8ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n  }\n\n  .md\\:focus\\:via-blue-200:focus {\n    --gradient-via-color: #bee3f8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n  }\n\n  .md\\:focus\\:via-blue-300:focus {\n    --gradient-via-color: #90cdf4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n  }\n\n  .md\\:focus\\:via-blue-400:focus {\n    --gradient-via-color: #63b3ed;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n  }\n\n  .md\\:focus\\:via-blue-500:focus {\n    --gradient-via-color: #4299e1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n  }\n\n  .md\\:focus\\:via-blue-600:focus {\n    --gradient-via-color: #3182ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n  }\n\n  .md\\:focus\\:via-blue-700:focus {\n    --gradient-via-color: #2b6cb0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n  }\n\n  .md\\:focus\\:via-blue-800:focus {\n    --gradient-via-color: #2c5282;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n  }\n\n  .md\\:focus\\:via-blue-900:focus {\n    --gradient-via-color: #2a4365;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n  }\n\n  .md\\:focus\\:via-indigo-100:focus {\n    --gradient-via-color: #ebf4ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n  }\n\n  .md\\:focus\\:via-indigo-200:focus {\n    --gradient-via-color: #c3dafe;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n  }\n\n  .md\\:focus\\:via-indigo-300:focus {\n    --gradient-via-color: #a3bffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n  }\n\n  .md\\:focus\\:via-indigo-400:focus {\n    --gradient-via-color: #7f9cf5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n  }\n\n  .md\\:focus\\:via-indigo-500:focus {\n    --gradient-via-color: #667eea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n  }\n\n  .md\\:focus\\:via-indigo-600:focus {\n    --gradient-via-color: #5a67d8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n  }\n\n  .md\\:focus\\:via-indigo-700:focus {\n    --gradient-via-color: #4c51bf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n  }\n\n  .md\\:focus\\:via-indigo-800:focus {\n    --gradient-via-color: #434190;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n  }\n\n  .md\\:focus\\:via-indigo-900:focus {\n    --gradient-via-color: #3c366b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n  }\n\n  .md\\:focus\\:via-purple-100:focus {\n    --gradient-via-color: #faf5ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n  }\n\n  .md\\:focus\\:via-purple-200:focus {\n    --gradient-via-color: #e9d8fd;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n  }\n\n  .md\\:focus\\:via-purple-300:focus {\n    --gradient-via-color: #d6bcfa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n  }\n\n  .md\\:focus\\:via-purple-400:focus {\n    --gradient-via-color: #b794f4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n  }\n\n  .md\\:focus\\:via-purple-500:focus {\n    --gradient-via-color: #9f7aea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n  }\n\n  .md\\:focus\\:via-purple-600:focus {\n    --gradient-via-color: #805ad5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n  }\n\n  .md\\:focus\\:via-purple-700:focus {\n    --gradient-via-color: #6b46c1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n  }\n\n  .md\\:focus\\:via-purple-800:focus {\n    --gradient-via-color: #553c9a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n  }\n\n  .md\\:focus\\:via-purple-900:focus {\n    --gradient-via-color: #44337a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n  }\n\n  .md\\:focus\\:via-pink-100:focus {\n    --gradient-via-color: #fff5f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n  }\n\n  .md\\:focus\\:via-pink-200:focus {\n    --gradient-via-color: #fed7e2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n  }\n\n  .md\\:focus\\:via-pink-300:focus {\n    --gradient-via-color: #fbb6ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n  }\n\n  .md\\:focus\\:via-pink-400:focus {\n    --gradient-via-color: #f687b3;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n  }\n\n  .md\\:focus\\:via-pink-500:focus {\n    --gradient-via-color: #ed64a6;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n  }\n\n  .md\\:focus\\:via-pink-600:focus {\n    --gradient-via-color: #d53f8c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n  }\n\n  .md\\:focus\\:via-pink-700:focus {\n    --gradient-via-color: #b83280;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n  }\n\n  .md\\:focus\\:via-pink-800:focus {\n    --gradient-via-color: #97266d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n  }\n\n  .md\\:focus\\:via-pink-900:focus {\n    --gradient-via-color: #702459;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n  }\n\n  .md\\:focus\\:via-grayscale-80:focus {\n    --gradient-via-color: hsl(0, 0%, 8%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n  }\n\n  .md\\:focus\\:via-grayscale-100:focus {\n    --gradient-via-color: hsl(0, 0%, 10%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n  }\n\n  .md\\:focus\\:via-grayscale-200:focus {\n    --gradient-via-color: hsl(0, 0%, 20%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n  }\n\n  .md\\:focus\\:via-grayscale-300:focus {\n    --gradient-via-color: hsl(0, 0%, 30%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n  }\n\n  .md\\:focus\\:via-grayscale-400:focus {\n    --gradient-via-color: hsl(0, 0%, 40%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n  }\n\n  .md\\:focus\\:via-grayscale-500:focus {\n    --gradient-via-color: hsl(0, 0%, 50%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n  }\n\n  .md\\:focus\\:via-grayscale-600:focus {\n    --gradient-via-color: hsl(0, 0%, 60%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n  }\n\n  .md\\:focus\\:via-grayscale-700:focus {\n    --gradient-via-color: hsl(0, 0%, 70%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n  }\n\n  .md\\:focus\\:via-grayscale-800:focus {\n    --gradient-via-color: hsl(0, 0%, 80%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n  }\n\n  .md\\:focus\\:via-grayscale-840:focus {\n    --gradient-via-color: hsl(0, 0%, 84%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n  }\n\n  .md\\:focus\\:via-grayscale-870:focus {\n    --gradient-via-color: hsl(0, 0%, 87%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n  }\n\n  .md\\:focus\\:via-grayscale-900:focus {\n    --gradient-via-color: hsl(0, 0%, 90%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n  }\n\n  .md\\:focus\\:via-grayscale-930:focus {\n    --gradient-via-color: hsl(0, 0%, 93%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n  }\n\n  .md\\:focus\\:via-primary:focus {\n    --gradient-via-color: hsl(210, 100%, 52%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n  }\n\n  .md\\:focus\\:via-background-main:focus {\n    --gradient-via-color: var(--main-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:focus\\:via-background-secondary:focus {\n    --gradient-via-color: var(--secondary-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:focus\\:via-foreground:focus {\n    --gradient-via-color: var(--foreground);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:focus\\:via-panels-bg:focus {\n    --gradient-via-color: var(--panels-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .md\\:focus\\:to-transparent:focus {\n    --gradient-to-color: transparent;\n  }\n\n  .md\\:focus\\:to-current:focus {\n    --gradient-to-color: currentColor;\n  }\n\n  .md\\:focus\\:to-black:focus {\n    --gradient-to-color: #000;\n  }\n\n  .md\\:focus\\:to-white:focus {\n    --gradient-to-color: #fff;\n  }\n\n  .md\\:focus\\:to-gray-100:focus {\n    --gradient-to-color: #f7fafc;\n  }\n\n  .md\\:focus\\:to-gray-200:focus {\n    --gradient-to-color: #edf2f7;\n  }\n\n  .md\\:focus\\:to-gray-300:focus {\n    --gradient-to-color: #e2e8f0;\n  }\n\n  .md\\:focus\\:to-gray-400:focus {\n    --gradient-to-color: #cbd5e0;\n  }\n\n  .md\\:focus\\:to-gray-500:focus {\n    --gradient-to-color: #a0aec0;\n  }\n\n  .md\\:focus\\:to-gray-600:focus {\n    --gradient-to-color: #718096;\n  }\n\n  .md\\:focus\\:to-gray-700:focus {\n    --gradient-to-color: #4a5568;\n  }\n\n  .md\\:focus\\:to-gray-800:focus {\n    --gradient-to-color: #2d3748;\n  }\n\n  .md\\:focus\\:to-gray-900:focus {\n    --gradient-to-color: #1a202c;\n  }\n\n  .md\\:focus\\:to-red-100:focus {\n    --gradient-to-color: #fff5f5;\n  }\n\n  .md\\:focus\\:to-red-200:focus {\n    --gradient-to-color: #fed7d7;\n  }\n\n  .md\\:focus\\:to-red-300:focus {\n    --gradient-to-color: #feb2b2;\n  }\n\n  .md\\:focus\\:to-red-400:focus {\n    --gradient-to-color: #fc8181;\n  }\n\n  .md\\:focus\\:to-red-500:focus {\n    --gradient-to-color: #f56565;\n  }\n\n  .md\\:focus\\:to-red-600:focus {\n    --gradient-to-color: #e53e3e;\n  }\n\n  .md\\:focus\\:to-red-700:focus {\n    --gradient-to-color: #c53030;\n  }\n\n  .md\\:focus\\:to-red-800:focus {\n    --gradient-to-color: #9b2c2c;\n  }\n\n  .md\\:focus\\:to-red-900:focus {\n    --gradient-to-color: #742a2a;\n  }\n\n  .md\\:focus\\:to-orange-100:focus {\n    --gradient-to-color: #fffaf0;\n  }\n\n  .md\\:focus\\:to-orange-200:focus {\n    --gradient-to-color: #feebc8;\n  }\n\n  .md\\:focus\\:to-orange-300:focus {\n    --gradient-to-color: #fbd38d;\n  }\n\n  .md\\:focus\\:to-orange-400:focus {\n    --gradient-to-color: #f6ad55;\n  }\n\n  .md\\:focus\\:to-orange-500:focus {\n    --gradient-to-color: #ed8936;\n  }\n\n  .md\\:focus\\:to-orange-600:focus {\n    --gradient-to-color: #dd6b20;\n  }\n\n  .md\\:focus\\:to-orange-700:focus {\n    --gradient-to-color: #c05621;\n  }\n\n  .md\\:focus\\:to-orange-800:focus {\n    --gradient-to-color: #9c4221;\n  }\n\n  .md\\:focus\\:to-orange-900:focus {\n    --gradient-to-color: #7b341e;\n  }\n\n  .md\\:focus\\:to-yellow-100:focus {\n    --gradient-to-color: #fffff0;\n  }\n\n  .md\\:focus\\:to-yellow-200:focus {\n    --gradient-to-color: #fefcbf;\n  }\n\n  .md\\:focus\\:to-yellow-300:focus {\n    --gradient-to-color: #faf089;\n  }\n\n  .md\\:focus\\:to-yellow-400:focus {\n    --gradient-to-color: #f6e05e;\n  }\n\n  .md\\:focus\\:to-yellow-500:focus {\n    --gradient-to-color: #ecc94b;\n  }\n\n  .md\\:focus\\:to-yellow-600:focus {\n    --gradient-to-color: #d69e2e;\n  }\n\n  .md\\:focus\\:to-yellow-700:focus {\n    --gradient-to-color: #b7791f;\n  }\n\n  .md\\:focus\\:to-yellow-800:focus {\n    --gradient-to-color: #975a16;\n  }\n\n  .md\\:focus\\:to-yellow-900:focus {\n    --gradient-to-color: #744210;\n  }\n\n  .md\\:focus\\:to-green-100:focus {\n    --gradient-to-color: #f0fff4;\n  }\n\n  .md\\:focus\\:to-green-200:focus {\n    --gradient-to-color: #c6f6d5;\n  }\n\n  .md\\:focus\\:to-green-300:focus {\n    --gradient-to-color: #9ae6b4;\n  }\n\n  .md\\:focus\\:to-green-400:focus {\n    --gradient-to-color: #68d391;\n  }\n\n  .md\\:focus\\:to-green-500:focus {\n    --gradient-to-color: #48bb78;\n  }\n\n  .md\\:focus\\:to-green-600:focus {\n    --gradient-to-color: #38a169;\n  }\n\n  .md\\:focus\\:to-green-700:focus {\n    --gradient-to-color: #2f855a;\n  }\n\n  .md\\:focus\\:to-green-800:focus {\n    --gradient-to-color: #276749;\n  }\n\n  .md\\:focus\\:to-green-900:focus {\n    --gradient-to-color: #22543d;\n  }\n\n  .md\\:focus\\:to-teal-100:focus {\n    --gradient-to-color: #e6fffa;\n  }\n\n  .md\\:focus\\:to-teal-200:focus {\n    --gradient-to-color: #b2f5ea;\n  }\n\n  .md\\:focus\\:to-teal-300:focus {\n    --gradient-to-color: #81e6d9;\n  }\n\n  .md\\:focus\\:to-teal-400:focus {\n    --gradient-to-color: #4fd1c5;\n  }\n\n  .md\\:focus\\:to-teal-500:focus {\n    --gradient-to-color: #38b2ac;\n  }\n\n  .md\\:focus\\:to-teal-600:focus {\n    --gradient-to-color: #319795;\n  }\n\n  .md\\:focus\\:to-teal-700:focus {\n    --gradient-to-color: #2c7a7b;\n  }\n\n  .md\\:focus\\:to-teal-800:focus {\n    --gradient-to-color: #285e61;\n  }\n\n  .md\\:focus\\:to-teal-900:focus {\n    --gradient-to-color: #234e52;\n  }\n\n  .md\\:focus\\:to-blue-100:focus {\n    --gradient-to-color: #ebf8ff;\n  }\n\n  .md\\:focus\\:to-blue-200:focus {\n    --gradient-to-color: #bee3f8;\n  }\n\n  .md\\:focus\\:to-blue-300:focus {\n    --gradient-to-color: #90cdf4;\n  }\n\n  .md\\:focus\\:to-blue-400:focus {\n    --gradient-to-color: #63b3ed;\n  }\n\n  .md\\:focus\\:to-blue-500:focus {\n    --gradient-to-color: #4299e1;\n  }\n\n  .md\\:focus\\:to-blue-600:focus {\n    --gradient-to-color: #3182ce;\n  }\n\n  .md\\:focus\\:to-blue-700:focus {\n    --gradient-to-color: #2b6cb0;\n  }\n\n  .md\\:focus\\:to-blue-800:focus {\n    --gradient-to-color: #2c5282;\n  }\n\n  .md\\:focus\\:to-blue-900:focus {\n    --gradient-to-color: #2a4365;\n  }\n\n  .md\\:focus\\:to-indigo-100:focus {\n    --gradient-to-color: #ebf4ff;\n  }\n\n  .md\\:focus\\:to-indigo-200:focus {\n    --gradient-to-color: #c3dafe;\n  }\n\n  .md\\:focus\\:to-indigo-300:focus {\n    --gradient-to-color: #a3bffa;\n  }\n\n  .md\\:focus\\:to-indigo-400:focus {\n    --gradient-to-color: #7f9cf5;\n  }\n\n  .md\\:focus\\:to-indigo-500:focus {\n    --gradient-to-color: #667eea;\n  }\n\n  .md\\:focus\\:to-indigo-600:focus {\n    --gradient-to-color: #5a67d8;\n  }\n\n  .md\\:focus\\:to-indigo-700:focus {\n    --gradient-to-color: #4c51bf;\n  }\n\n  .md\\:focus\\:to-indigo-800:focus {\n    --gradient-to-color: #434190;\n  }\n\n  .md\\:focus\\:to-indigo-900:focus {\n    --gradient-to-color: #3c366b;\n  }\n\n  .md\\:focus\\:to-purple-100:focus {\n    --gradient-to-color: #faf5ff;\n  }\n\n  .md\\:focus\\:to-purple-200:focus {\n    --gradient-to-color: #e9d8fd;\n  }\n\n  .md\\:focus\\:to-purple-300:focus {\n    --gradient-to-color: #d6bcfa;\n  }\n\n  .md\\:focus\\:to-purple-400:focus {\n    --gradient-to-color: #b794f4;\n  }\n\n  .md\\:focus\\:to-purple-500:focus {\n    --gradient-to-color: #9f7aea;\n  }\n\n  .md\\:focus\\:to-purple-600:focus {\n    --gradient-to-color: #805ad5;\n  }\n\n  .md\\:focus\\:to-purple-700:focus {\n    --gradient-to-color: #6b46c1;\n  }\n\n  .md\\:focus\\:to-purple-800:focus {\n    --gradient-to-color: #553c9a;\n  }\n\n  .md\\:focus\\:to-purple-900:focus {\n    --gradient-to-color: #44337a;\n  }\n\n  .md\\:focus\\:to-pink-100:focus {\n    --gradient-to-color: #fff5f7;\n  }\n\n  .md\\:focus\\:to-pink-200:focus {\n    --gradient-to-color: #fed7e2;\n  }\n\n  .md\\:focus\\:to-pink-300:focus {\n    --gradient-to-color: #fbb6ce;\n  }\n\n  .md\\:focus\\:to-pink-400:focus {\n    --gradient-to-color: #f687b3;\n  }\n\n  .md\\:focus\\:to-pink-500:focus {\n    --gradient-to-color: #ed64a6;\n  }\n\n  .md\\:focus\\:to-pink-600:focus {\n    --gradient-to-color: #d53f8c;\n  }\n\n  .md\\:focus\\:to-pink-700:focus {\n    --gradient-to-color: #b83280;\n  }\n\n  .md\\:focus\\:to-pink-800:focus {\n    --gradient-to-color: #97266d;\n  }\n\n  .md\\:focus\\:to-pink-900:focus {\n    --gradient-to-color: #702459;\n  }\n\n  .md\\:focus\\:to-grayscale-80:focus {\n    --gradient-to-color: hsl(0, 0%, 8%);\n  }\n\n  .md\\:focus\\:to-grayscale-100:focus {\n    --gradient-to-color: hsl(0, 0%, 10%);\n  }\n\n  .md\\:focus\\:to-grayscale-200:focus {\n    --gradient-to-color: hsl(0, 0%, 20%);\n  }\n\n  .md\\:focus\\:to-grayscale-300:focus {\n    --gradient-to-color: hsl(0, 0%, 30%);\n  }\n\n  .md\\:focus\\:to-grayscale-400:focus {\n    --gradient-to-color: hsl(0, 0%, 40%);\n  }\n\n  .md\\:focus\\:to-grayscale-500:focus {\n    --gradient-to-color: hsl(0, 0%, 50%);\n  }\n\n  .md\\:focus\\:to-grayscale-600:focus {\n    --gradient-to-color: hsl(0, 0%, 60%);\n  }\n\n  .md\\:focus\\:to-grayscale-700:focus {\n    --gradient-to-color: hsl(0, 0%, 70%);\n  }\n\n  .md\\:focus\\:to-grayscale-800:focus {\n    --gradient-to-color: hsl(0, 0%, 80%);\n  }\n\n  .md\\:focus\\:to-grayscale-840:focus {\n    --gradient-to-color: hsl(0, 0%, 84%);\n  }\n\n  .md\\:focus\\:to-grayscale-870:focus {\n    --gradient-to-color: hsl(0, 0%, 87%);\n  }\n\n  .md\\:focus\\:to-grayscale-900:focus {\n    --gradient-to-color: hsl(0, 0%, 90%);\n  }\n\n  .md\\:focus\\:to-grayscale-930:focus {\n    --gradient-to-color: hsl(0, 0%, 93%);\n  }\n\n  .md\\:focus\\:to-primary:focus {\n    --gradient-to-color: hsl(210, 100%, 52%);\n  }\n\n  .md\\:focus\\:to-background-main:focus {\n    --gradient-to-color: var(--main-background);\n  }\n\n  .md\\:focus\\:to-background-secondary:focus {\n    --gradient-to-color: var(--secondary-background);\n  }\n\n  .md\\:focus\\:to-foreground:focus {\n    --gradient-to-color: var(--foreground);\n  }\n\n  .md\\:focus\\:to-panels-bg:focus {\n    --gradient-to-color: var(--panels-background);\n  }\n\n  .md\\:bg-opacity-0 {\n    --bg-opacity: 0;\n  }\n\n  .md\\:bg-opacity-25 {\n    --bg-opacity: 0.25;\n  }\n\n  .md\\:bg-opacity-50 {\n    --bg-opacity: 0.5;\n  }\n\n  .md\\:bg-opacity-75 {\n    --bg-opacity: 0.75;\n  }\n\n  .md\\:bg-opacity-100 {\n    --bg-opacity: 1;\n  }\n\n  .md\\:hover\\:bg-opacity-0:hover {\n    --bg-opacity: 0;\n  }\n\n  .md\\:hover\\:bg-opacity-25:hover {\n    --bg-opacity: 0.25;\n  }\n\n  .md\\:hover\\:bg-opacity-50:hover {\n    --bg-opacity: 0.5;\n  }\n\n  .md\\:hover\\:bg-opacity-75:hover {\n    --bg-opacity: 0.75;\n  }\n\n  .md\\:hover\\:bg-opacity-100:hover {\n    --bg-opacity: 1;\n  }\n\n  .md\\:focus\\:bg-opacity-0:focus {\n    --bg-opacity: 0;\n  }\n\n  .md\\:focus\\:bg-opacity-25:focus {\n    --bg-opacity: 0.25;\n  }\n\n  .md\\:focus\\:bg-opacity-50:focus {\n    --bg-opacity: 0.5;\n  }\n\n  .md\\:focus\\:bg-opacity-75:focus {\n    --bg-opacity: 0.75;\n  }\n\n  .md\\:focus\\:bg-opacity-100:focus {\n    --bg-opacity: 1;\n  }\n\n  .md\\:bg-bottom {\n    background-position: bottom;\n  }\n\n  .md\\:bg-center {\n    background-position: center;\n  }\n\n  .md\\:bg-left {\n    background-position: left;\n  }\n\n  .md\\:bg-left-bottom {\n    background-position: left bottom;\n  }\n\n  .md\\:bg-left-top {\n    background-position: left top;\n  }\n\n  .md\\:bg-right {\n    background-position: right;\n  }\n\n  .md\\:bg-right-bottom {\n    background-position: right bottom;\n  }\n\n  .md\\:bg-right-top {\n    background-position: right top;\n  }\n\n  .md\\:bg-top {\n    background-position: top;\n  }\n\n  .md\\:bg-repeat {\n    background-repeat: repeat;\n  }\n\n  .md\\:bg-no-repeat {\n    background-repeat: no-repeat;\n  }\n\n  .md\\:bg-repeat-x {\n    background-repeat: repeat-x;\n  }\n\n  .md\\:bg-repeat-y {\n    background-repeat: repeat-y;\n  }\n\n  .md\\:bg-repeat-round {\n    background-repeat: round;\n  }\n\n  .md\\:bg-repeat-space {\n    background-repeat: space;\n  }\n\n  .md\\:bg-auto {\n    background-size: auto;\n  }\n\n  .md\\:bg-cover {\n    background-size: cover;\n  }\n\n  .md\\:bg-contain {\n    background-size: contain;\n  }\n\n  .md\\:border-collapse {\n    border-collapse: collapse;\n  }\n\n  .md\\:border-separate {\n    border-collapse: separate;\n  }\n\n  .md\\:border-transparent {\n    border-color: transparent;\n  }\n\n  .md\\:border-current {\n    border-color: currentColor;\n  }\n\n  .md\\:border-black {\n    --border-opacity: 1;\n    border-color: #000;\n    border-color: rgba(0, 0, 0, var(--border-opacity));\n  }\n\n  .md\\:border-white {\n    --border-opacity: 1;\n    border-color: #fff;\n    border-color: rgba(255, 255, 255, var(--border-opacity));\n  }\n\n  .md\\:border-gray-100 {\n    --border-opacity: 1;\n    border-color: #f7fafc;\n    border-color: rgba(247, 250, 252, var(--border-opacity));\n  }\n\n  .md\\:border-gray-200 {\n    --border-opacity: 1;\n    border-color: #edf2f7;\n    border-color: rgba(237, 242, 247, var(--border-opacity));\n  }\n\n  .md\\:border-gray-300 {\n    --border-opacity: 1;\n    border-color: #e2e8f0;\n    border-color: rgba(226, 232, 240, var(--border-opacity));\n  }\n\n  .md\\:border-gray-400 {\n    --border-opacity: 1;\n    border-color: #cbd5e0;\n    border-color: rgba(203, 213, 224, var(--border-opacity));\n  }\n\n  .md\\:border-gray-500 {\n    --border-opacity: 1;\n    border-color: #a0aec0;\n    border-color: rgba(160, 174, 192, var(--border-opacity));\n  }\n\n  .md\\:border-gray-600 {\n    --border-opacity: 1;\n    border-color: #718096;\n    border-color: rgba(113, 128, 150, var(--border-opacity));\n  }\n\n  .md\\:border-gray-700 {\n    --border-opacity: 1;\n    border-color: #4a5568;\n    border-color: rgba(74, 85, 104, var(--border-opacity));\n  }\n\n  .md\\:border-gray-800 {\n    --border-opacity: 1;\n    border-color: #2d3748;\n    border-color: rgba(45, 55, 72, var(--border-opacity));\n  }\n\n  .md\\:border-gray-900 {\n    --border-opacity: 1;\n    border-color: #1a202c;\n    border-color: rgba(26, 32, 44, var(--border-opacity));\n  }\n\n  .md\\:border-red-100 {\n    --border-opacity: 1;\n    border-color: #fff5f5;\n    border-color: rgba(255, 245, 245, var(--border-opacity));\n  }\n\n  .md\\:border-red-200 {\n    --border-opacity: 1;\n    border-color: #fed7d7;\n    border-color: rgba(254, 215, 215, var(--border-opacity));\n  }\n\n  .md\\:border-red-300 {\n    --border-opacity: 1;\n    border-color: #feb2b2;\n    border-color: rgba(254, 178, 178, var(--border-opacity));\n  }\n\n  .md\\:border-red-400 {\n    --border-opacity: 1;\n    border-color: #fc8181;\n    border-color: rgba(252, 129, 129, var(--border-opacity));\n  }\n\n  .md\\:border-red-500 {\n    --border-opacity: 1;\n    border-color: #f56565;\n    border-color: rgba(245, 101, 101, var(--border-opacity));\n  }\n\n  .md\\:border-red-600 {\n    --border-opacity: 1;\n    border-color: #e53e3e;\n    border-color: rgba(229, 62, 62, var(--border-opacity));\n  }\n\n  .md\\:border-red-700 {\n    --border-opacity: 1;\n    border-color: #c53030;\n    border-color: rgba(197, 48, 48, var(--border-opacity));\n  }\n\n  .md\\:border-red-800 {\n    --border-opacity: 1;\n    border-color: #9b2c2c;\n    border-color: rgba(155, 44, 44, var(--border-opacity));\n  }\n\n  .md\\:border-red-900 {\n    --border-opacity: 1;\n    border-color: #742a2a;\n    border-color: rgba(116, 42, 42, var(--border-opacity));\n  }\n\n  .md\\:border-orange-100 {\n    --border-opacity: 1;\n    border-color: #fffaf0;\n    border-color: rgba(255, 250, 240, var(--border-opacity));\n  }\n\n  .md\\:border-orange-200 {\n    --border-opacity: 1;\n    border-color: #feebc8;\n    border-color: rgba(254, 235, 200, var(--border-opacity));\n  }\n\n  .md\\:border-orange-300 {\n    --border-opacity: 1;\n    border-color: #fbd38d;\n    border-color: rgba(251, 211, 141, var(--border-opacity));\n  }\n\n  .md\\:border-orange-400 {\n    --border-opacity: 1;\n    border-color: #f6ad55;\n    border-color: rgba(246, 173, 85, var(--border-opacity));\n  }\n\n  .md\\:border-orange-500 {\n    --border-opacity: 1;\n    border-color: #ed8936;\n    border-color: rgba(237, 137, 54, var(--border-opacity));\n  }\n\n  .md\\:border-orange-600 {\n    --border-opacity: 1;\n    border-color: #dd6b20;\n    border-color: rgba(221, 107, 32, var(--border-opacity));\n  }\n\n  .md\\:border-orange-700 {\n    --border-opacity: 1;\n    border-color: #c05621;\n    border-color: rgba(192, 86, 33, var(--border-opacity));\n  }\n\n  .md\\:border-orange-800 {\n    --border-opacity: 1;\n    border-color: #9c4221;\n    border-color: rgba(156, 66, 33, var(--border-opacity));\n  }\n\n  .md\\:border-orange-900 {\n    --border-opacity: 1;\n    border-color: #7b341e;\n    border-color: rgba(123, 52, 30, var(--border-opacity));\n  }\n\n  .md\\:border-yellow-100 {\n    --border-opacity: 1;\n    border-color: #fffff0;\n    border-color: rgba(255, 255, 240, var(--border-opacity));\n  }\n\n  .md\\:border-yellow-200 {\n    --border-opacity: 1;\n    border-color: #fefcbf;\n    border-color: rgba(254, 252, 191, var(--border-opacity));\n  }\n\n  .md\\:border-yellow-300 {\n    --border-opacity: 1;\n    border-color: #faf089;\n    border-color: rgba(250, 240, 137, var(--border-opacity));\n  }\n\n  .md\\:border-yellow-400 {\n    --border-opacity: 1;\n    border-color: #f6e05e;\n    border-color: rgba(246, 224, 94, var(--border-opacity));\n  }\n\n  .md\\:border-yellow-500 {\n    --border-opacity: 1;\n    border-color: #ecc94b;\n    border-color: rgba(236, 201, 75, var(--border-opacity));\n  }\n\n  .md\\:border-yellow-600 {\n    --border-opacity: 1;\n    border-color: #d69e2e;\n    border-color: rgba(214, 158, 46, var(--border-opacity));\n  }\n\n  .md\\:border-yellow-700 {\n    --border-opacity: 1;\n    border-color: #b7791f;\n    border-color: rgba(183, 121, 31, var(--border-opacity));\n  }\n\n  .md\\:border-yellow-800 {\n    --border-opacity: 1;\n    border-color: #975a16;\n    border-color: rgba(151, 90, 22, var(--border-opacity));\n  }\n\n  .md\\:border-yellow-900 {\n    --border-opacity: 1;\n    border-color: #744210;\n    border-color: rgba(116, 66, 16, var(--border-opacity));\n  }\n\n  .md\\:border-green-100 {\n    --border-opacity: 1;\n    border-color: #f0fff4;\n    border-color: rgba(240, 255, 244, var(--border-opacity));\n  }\n\n  .md\\:border-green-200 {\n    --border-opacity: 1;\n    border-color: #c6f6d5;\n    border-color: rgba(198, 246, 213, var(--border-opacity));\n  }\n\n  .md\\:border-green-300 {\n    --border-opacity: 1;\n    border-color: #9ae6b4;\n    border-color: rgba(154, 230, 180, var(--border-opacity));\n  }\n\n  .md\\:border-green-400 {\n    --border-opacity: 1;\n    border-color: #68d391;\n    border-color: rgba(104, 211, 145, var(--border-opacity));\n  }\n\n  .md\\:border-green-500 {\n    --border-opacity: 1;\n    border-color: #48bb78;\n    border-color: rgba(72, 187, 120, var(--border-opacity));\n  }\n\n  .md\\:border-green-600 {\n    --border-opacity: 1;\n    border-color: #38a169;\n    border-color: rgba(56, 161, 105, var(--border-opacity));\n  }\n\n  .md\\:border-green-700 {\n    --border-opacity: 1;\n    border-color: #2f855a;\n    border-color: rgba(47, 133, 90, var(--border-opacity));\n  }\n\n  .md\\:border-green-800 {\n    --border-opacity: 1;\n    border-color: #276749;\n    border-color: rgba(39, 103, 73, var(--border-opacity));\n  }\n\n  .md\\:border-green-900 {\n    --border-opacity: 1;\n    border-color: #22543d;\n    border-color: rgba(34, 84, 61, var(--border-opacity));\n  }\n\n  .md\\:border-teal-100 {\n    --border-opacity: 1;\n    border-color: #e6fffa;\n    border-color: rgba(230, 255, 250, var(--border-opacity));\n  }\n\n  .md\\:border-teal-200 {\n    --border-opacity: 1;\n    border-color: #b2f5ea;\n    border-color: rgba(178, 245, 234, var(--border-opacity));\n  }\n\n  .md\\:border-teal-300 {\n    --border-opacity: 1;\n    border-color: #81e6d9;\n    border-color: rgba(129, 230, 217, var(--border-opacity));\n  }\n\n  .md\\:border-teal-400 {\n    --border-opacity: 1;\n    border-color: #4fd1c5;\n    border-color: rgba(79, 209, 197, var(--border-opacity));\n  }\n\n  .md\\:border-teal-500 {\n    --border-opacity: 1;\n    border-color: #38b2ac;\n    border-color: rgba(56, 178, 172, var(--border-opacity));\n  }\n\n  .md\\:border-teal-600 {\n    --border-opacity: 1;\n    border-color: #319795;\n    border-color: rgba(49, 151, 149, var(--border-opacity));\n  }\n\n  .md\\:border-teal-700 {\n    --border-opacity: 1;\n    border-color: #2c7a7b;\n    border-color: rgba(44, 122, 123, var(--border-opacity));\n  }\n\n  .md\\:border-teal-800 {\n    --border-opacity: 1;\n    border-color: #285e61;\n    border-color: rgba(40, 94, 97, var(--border-opacity));\n  }\n\n  .md\\:border-teal-900 {\n    --border-opacity: 1;\n    border-color: #234e52;\n    border-color: rgba(35, 78, 82, var(--border-opacity));\n  }\n\n  .md\\:border-blue-100 {\n    --border-opacity: 1;\n    border-color: #ebf8ff;\n    border-color: rgba(235, 248, 255, var(--border-opacity));\n  }\n\n  .md\\:border-blue-200 {\n    --border-opacity: 1;\n    border-color: #bee3f8;\n    border-color: rgba(190, 227, 248, var(--border-opacity));\n  }\n\n  .md\\:border-blue-300 {\n    --border-opacity: 1;\n    border-color: #90cdf4;\n    border-color: rgba(144, 205, 244, var(--border-opacity));\n  }\n\n  .md\\:border-blue-400 {\n    --border-opacity: 1;\n    border-color: #63b3ed;\n    border-color: rgba(99, 179, 237, var(--border-opacity));\n  }\n\n  .md\\:border-blue-500 {\n    --border-opacity: 1;\n    border-color: #4299e1;\n    border-color: rgba(66, 153, 225, var(--border-opacity));\n  }\n\n  .md\\:border-blue-600 {\n    --border-opacity: 1;\n    border-color: #3182ce;\n    border-color: rgba(49, 130, 206, var(--border-opacity));\n  }\n\n  .md\\:border-blue-700 {\n    --border-opacity: 1;\n    border-color: #2b6cb0;\n    border-color: rgba(43, 108, 176, var(--border-opacity));\n  }\n\n  .md\\:border-blue-800 {\n    --border-opacity: 1;\n    border-color: #2c5282;\n    border-color: rgba(44, 82, 130, var(--border-opacity));\n  }\n\n  .md\\:border-blue-900 {\n    --border-opacity: 1;\n    border-color: #2a4365;\n    border-color: rgba(42, 67, 101, var(--border-opacity));\n  }\n\n  .md\\:border-indigo-100 {\n    --border-opacity: 1;\n    border-color: #ebf4ff;\n    border-color: rgba(235, 244, 255, var(--border-opacity));\n  }\n\n  .md\\:border-indigo-200 {\n    --border-opacity: 1;\n    border-color: #c3dafe;\n    border-color: rgba(195, 218, 254, var(--border-opacity));\n  }\n\n  .md\\:border-indigo-300 {\n    --border-opacity: 1;\n    border-color: #a3bffa;\n    border-color: rgba(163, 191, 250, var(--border-opacity));\n  }\n\n  .md\\:border-indigo-400 {\n    --border-opacity: 1;\n    border-color: #7f9cf5;\n    border-color: rgba(127, 156, 245, var(--border-opacity));\n  }\n\n  .md\\:border-indigo-500 {\n    --border-opacity: 1;\n    border-color: #667eea;\n    border-color: rgba(102, 126, 234, var(--border-opacity));\n  }\n\n  .md\\:border-indigo-600 {\n    --border-opacity: 1;\n    border-color: #5a67d8;\n    border-color: rgba(90, 103, 216, var(--border-opacity));\n  }\n\n  .md\\:border-indigo-700 {\n    --border-opacity: 1;\n    border-color: #4c51bf;\n    border-color: rgba(76, 81, 191, var(--border-opacity));\n  }\n\n  .md\\:border-indigo-800 {\n    --border-opacity: 1;\n    border-color: #434190;\n    border-color: rgba(67, 65, 144, var(--border-opacity));\n  }\n\n  .md\\:border-indigo-900 {\n    --border-opacity: 1;\n    border-color: #3c366b;\n    border-color: rgba(60, 54, 107, var(--border-opacity));\n  }\n\n  .md\\:border-purple-100 {\n    --border-opacity: 1;\n    border-color: #faf5ff;\n    border-color: rgba(250, 245, 255, var(--border-opacity));\n  }\n\n  .md\\:border-purple-200 {\n    --border-opacity: 1;\n    border-color: #e9d8fd;\n    border-color: rgba(233, 216, 253, var(--border-opacity));\n  }\n\n  .md\\:border-purple-300 {\n    --border-opacity: 1;\n    border-color: #d6bcfa;\n    border-color: rgba(214, 188, 250, var(--border-opacity));\n  }\n\n  .md\\:border-purple-400 {\n    --border-opacity: 1;\n    border-color: #b794f4;\n    border-color: rgba(183, 148, 244, var(--border-opacity));\n  }\n\n  .md\\:border-purple-500 {\n    --border-opacity: 1;\n    border-color: #9f7aea;\n    border-color: rgba(159, 122, 234, var(--border-opacity));\n  }\n\n  .md\\:border-purple-600 {\n    --border-opacity: 1;\n    border-color: #805ad5;\n    border-color: rgba(128, 90, 213, var(--border-opacity));\n  }\n\n  .md\\:border-purple-700 {\n    --border-opacity: 1;\n    border-color: #6b46c1;\n    border-color: rgba(107, 70, 193, var(--border-opacity));\n  }\n\n  .md\\:border-purple-800 {\n    --border-opacity: 1;\n    border-color: #553c9a;\n    border-color: rgba(85, 60, 154, var(--border-opacity));\n  }\n\n  .md\\:border-purple-900 {\n    --border-opacity: 1;\n    border-color: #44337a;\n    border-color: rgba(68, 51, 122, var(--border-opacity));\n  }\n\n  .md\\:border-pink-100 {\n    --border-opacity: 1;\n    border-color: #fff5f7;\n    border-color: rgba(255, 245, 247, var(--border-opacity));\n  }\n\n  .md\\:border-pink-200 {\n    --border-opacity: 1;\n    border-color: #fed7e2;\n    border-color: rgba(254, 215, 226, var(--border-opacity));\n  }\n\n  .md\\:border-pink-300 {\n    --border-opacity: 1;\n    border-color: #fbb6ce;\n    border-color: rgba(251, 182, 206, var(--border-opacity));\n  }\n\n  .md\\:border-pink-400 {\n    --border-opacity: 1;\n    border-color: #f687b3;\n    border-color: rgba(246, 135, 179, var(--border-opacity));\n  }\n\n  .md\\:border-pink-500 {\n    --border-opacity: 1;\n    border-color: #ed64a6;\n    border-color: rgba(237, 100, 166, var(--border-opacity));\n  }\n\n  .md\\:border-pink-600 {\n    --border-opacity: 1;\n    border-color: #d53f8c;\n    border-color: rgba(213, 63, 140, var(--border-opacity));\n  }\n\n  .md\\:border-pink-700 {\n    --border-opacity: 1;\n    border-color: #b83280;\n    border-color: rgba(184, 50, 128, var(--border-opacity));\n  }\n\n  .md\\:border-pink-800 {\n    --border-opacity: 1;\n    border-color: #97266d;\n    border-color: rgba(151, 38, 109, var(--border-opacity));\n  }\n\n  .md\\:border-pink-900 {\n    --border-opacity: 1;\n    border-color: #702459;\n    border-color: rgba(112, 36, 89, var(--border-opacity));\n  }\n\n  .md\\:border-grayscale-80 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 8%);\n    border-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--border-opacity));\n  }\n\n  .md\\:border-grayscale-100 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 10%);\n    border-color: rgba(25.5, 25.5, 25.5, var(--border-opacity));\n  }\n\n  .md\\:border-grayscale-200 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 20%);\n    border-color: rgba(51, 51, 51, var(--border-opacity));\n  }\n\n  .md\\:border-grayscale-300 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 30%);\n    border-color: rgba(76.5, 76.5, 76.5, var(--border-opacity));\n  }\n\n  .md\\:border-grayscale-400 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 40%);\n    border-color: rgba(102, 102, 102, var(--border-opacity));\n  }\n\n  .md\\:border-grayscale-500 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 50%);\n    border-color: rgba(127.5, 127.5, 127.5, var(--border-opacity));\n  }\n\n  .md\\:border-grayscale-600 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 60%);\n    border-color: rgba(153, 153, 153, var(--border-opacity));\n  }\n\n  .md\\:border-grayscale-700 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 70%);\n    border-color: rgba(178.5, 178.5, 178.5, var(--border-opacity));\n  }\n\n  .md\\:border-grayscale-800 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 80%);\n    border-color: rgba(204, 204, 204, var(--border-opacity));\n  }\n\n  .md\\:border-grayscale-840 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 84%);\n    border-color: rgba(214.2, 214.2, 214.2, var(--border-opacity));\n  }\n\n  .md\\:border-grayscale-870 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 87%);\n    border-color: rgba(221.85, 221.85, 221.85, var(--border-opacity));\n  }\n\n  .md\\:border-grayscale-900 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 90%);\n    border-color: rgba(229.5, 229.5, 229.5, var(--border-opacity));\n  }\n\n  .md\\:border-grayscale-930 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 93%);\n    border-color: rgba(237.15, 237.15, 237.15, var(--border-opacity));\n  }\n\n  .md\\:border-primary {\n    --border-opacity: 1;\n    border-color: hsl(210, 100%, 52%);\n    border-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--border-opacity));\n  }\n\n  .md\\:border-background-main {\n    border-color: var(--main-background);\n  }\n\n  .md\\:border-background-secondary {\n    border-color: var(--secondary-background);\n  }\n\n  .md\\:border-foreground {\n    border-color: var(--foreground);\n  }\n\n  .md\\:border-panels-bg {\n    border-color: var(--panels-background);\n  }\n\n  .md\\:hover\\:border-transparent:hover {\n    border-color: transparent;\n  }\n\n  .md\\:hover\\:border-current:hover {\n    border-color: currentColor;\n  }\n\n  .md\\:hover\\:border-black:hover {\n    --border-opacity: 1;\n    border-color: #000;\n    border-color: rgba(0, 0, 0, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-white:hover {\n    --border-opacity: 1;\n    border-color: #fff;\n    border-color: rgba(255, 255, 255, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-gray-100:hover {\n    --border-opacity: 1;\n    border-color: #f7fafc;\n    border-color: rgba(247, 250, 252, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-gray-200:hover {\n    --border-opacity: 1;\n    border-color: #edf2f7;\n    border-color: rgba(237, 242, 247, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-gray-300:hover {\n    --border-opacity: 1;\n    border-color: #e2e8f0;\n    border-color: rgba(226, 232, 240, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-gray-400:hover {\n    --border-opacity: 1;\n    border-color: #cbd5e0;\n    border-color: rgba(203, 213, 224, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-gray-500:hover {\n    --border-opacity: 1;\n    border-color: #a0aec0;\n    border-color: rgba(160, 174, 192, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-gray-600:hover {\n    --border-opacity: 1;\n    border-color: #718096;\n    border-color: rgba(113, 128, 150, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-gray-700:hover {\n    --border-opacity: 1;\n    border-color: #4a5568;\n    border-color: rgba(74, 85, 104, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-gray-800:hover {\n    --border-opacity: 1;\n    border-color: #2d3748;\n    border-color: rgba(45, 55, 72, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-gray-900:hover {\n    --border-opacity: 1;\n    border-color: #1a202c;\n    border-color: rgba(26, 32, 44, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-red-100:hover {\n    --border-opacity: 1;\n    border-color: #fff5f5;\n    border-color: rgba(255, 245, 245, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-red-200:hover {\n    --border-opacity: 1;\n    border-color: #fed7d7;\n    border-color: rgba(254, 215, 215, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-red-300:hover {\n    --border-opacity: 1;\n    border-color: #feb2b2;\n    border-color: rgba(254, 178, 178, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-red-400:hover {\n    --border-opacity: 1;\n    border-color: #fc8181;\n    border-color: rgba(252, 129, 129, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-red-500:hover {\n    --border-opacity: 1;\n    border-color: #f56565;\n    border-color: rgba(245, 101, 101, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-red-600:hover {\n    --border-opacity: 1;\n    border-color: #e53e3e;\n    border-color: rgba(229, 62, 62, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-red-700:hover {\n    --border-opacity: 1;\n    border-color: #c53030;\n    border-color: rgba(197, 48, 48, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-red-800:hover {\n    --border-opacity: 1;\n    border-color: #9b2c2c;\n    border-color: rgba(155, 44, 44, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-red-900:hover {\n    --border-opacity: 1;\n    border-color: #742a2a;\n    border-color: rgba(116, 42, 42, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-orange-100:hover {\n    --border-opacity: 1;\n    border-color: #fffaf0;\n    border-color: rgba(255, 250, 240, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-orange-200:hover {\n    --border-opacity: 1;\n    border-color: #feebc8;\n    border-color: rgba(254, 235, 200, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-orange-300:hover {\n    --border-opacity: 1;\n    border-color: #fbd38d;\n    border-color: rgba(251, 211, 141, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-orange-400:hover {\n    --border-opacity: 1;\n    border-color: #f6ad55;\n    border-color: rgba(246, 173, 85, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-orange-500:hover {\n    --border-opacity: 1;\n    border-color: #ed8936;\n    border-color: rgba(237, 137, 54, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-orange-600:hover {\n    --border-opacity: 1;\n    border-color: #dd6b20;\n    border-color: rgba(221, 107, 32, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-orange-700:hover {\n    --border-opacity: 1;\n    border-color: #c05621;\n    border-color: rgba(192, 86, 33, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-orange-800:hover {\n    --border-opacity: 1;\n    border-color: #9c4221;\n    border-color: rgba(156, 66, 33, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-orange-900:hover {\n    --border-opacity: 1;\n    border-color: #7b341e;\n    border-color: rgba(123, 52, 30, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-yellow-100:hover {\n    --border-opacity: 1;\n    border-color: #fffff0;\n    border-color: rgba(255, 255, 240, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-yellow-200:hover {\n    --border-opacity: 1;\n    border-color: #fefcbf;\n    border-color: rgba(254, 252, 191, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-yellow-300:hover {\n    --border-opacity: 1;\n    border-color: #faf089;\n    border-color: rgba(250, 240, 137, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-yellow-400:hover {\n    --border-opacity: 1;\n    border-color: #f6e05e;\n    border-color: rgba(246, 224, 94, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-yellow-500:hover {\n    --border-opacity: 1;\n    border-color: #ecc94b;\n    border-color: rgba(236, 201, 75, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-yellow-600:hover {\n    --border-opacity: 1;\n    border-color: #d69e2e;\n    border-color: rgba(214, 158, 46, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-yellow-700:hover {\n    --border-opacity: 1;\n    border-color: #b7791f;\n    border-color: rgba(183, 121, 31, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-yellow-800:hover {\n    --border-opacity: 1;\n    border-color: #975a16;\n    border-color: rgba(151, 90, 22, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-yellow-900:hover {\n    --border-opacity: 1;\n    border-color: #744210;\n    border-color: rgba(116, 66, 16, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-green-100:hover {\n    --border-opacity: 1;\n    border-color: #f0fff4;\n    border-color: rgba(240, 255, 244, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-green-200:hover {\n    --border-opacity: 1;\n    border-color: #c6f6d5;\n    border-color: rgba(198, 246, 213, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-green-300:hover {\n    --border-opacity: 1;\n    border-color: #9ae6b4;\n    border-color: rgba(154, 230, 180, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-green-400:hover {\n    --border-opacity: 1;\n    border-color: #68d391;\n    border-color: rgba(104, 211, 145, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-green-500:hover {\n    --border-opacity: 1;\n    border-color: #48bb78;\n    border-color: rgba(72, 187, 120, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-green-600:hover {\n    --border-opacity: 1;\n    border-color: #38a169;\n    border-color: rgba(56, 161, 105, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-green-700:hover {\n    --border-opacity: 1;\n    border-color: #2f855a;\n    border-color: rgba(47, 133, 90, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-green-800:hover {\n    --border-opacity: 1;\n    border-color: #276749;\n    border-color: rgba(39, 103, 73, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-green-900:hover {\n    --border-opacity: 1;\n    border-color: #22543d;\n    border-color: rgba(34, 84, 61, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-teal-100:hover {\n    --border-opacity: 1;\n    border-color: #e6fffa;\n    border-color: rgba(230, 255, 250, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-teal-200:hover {\n    --border-opacity: 1;\n    border-color: #b2f5ea;\n    border-color: rgba(178, 245, 234, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-teal-300:hover {\n    --border-opacity: 1;\n    border-color: #81e6d9;\n    border-color: rgba(129, 230, 217, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-teal-400:hover {\n    --border-opacity: 1;\n    border-color: #4fd1c5;\n    border-color: rgba(79, 209, 197, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-teal-500:hover {\n    --border-opacity: 1;\n    border-color: #38b2ac;\n    border-color: rgba(56, 178, 172, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-teal-600:hover {\n    --border-opacity: 1;\n    border-color: #319795;\n    border-color: rgba(49, 151, 149, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-teal-700:hover {\n    --border-opacity: 1;\n    border-color: #2c7a7b;\n    border-color: rgba(44, 122, 123, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-teal-800:hover {\n    --border-opacity: 1;\n    border-color: #285e61;\n    border-color: rgba(40, 94, 97, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-teal-900:hover {\n    --border-opacity: 1;\n    border-color: #234e52;\n    border-color: rgba(35, 78, 82, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-blue-100:hover {\n    --border-opacity: 1;\n    border-color: #ebf8ff;\n    border-color: rgba(235, 248, 255, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-blue-200:hover {\n    --border-opacity: 1;\n    border-color: #bee3f8;\n    border-color: rgba(190, 227, 248, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-blue-300:hover {\n    --border-opacity: 1;\n    border-color: #90cdf4;\n    border-color: rgba(144, 205, 244, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-blue-400:hover {\n    --border-opacity: 1;\n    border-color: #63b3ed;\n    border-color: rgba(99, 179, 237, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-blue-500:hover {\n    --border-opacity: 1;\n    border-color: #4299e1;\n    border-color: rgba(66, 153, 225, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-blue-600:hover {\n    --border-opacity: 1;\n    border-color: #3182ce;\n    border-color: rgba(49, 130, 206, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-blue-700:hover {\n    --border-opacity: 1;\n    border-color: #2b6cb0;\n    border-color: rgba(43, 108, 176, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-blue-800:hover {\n    --border-opacity: 1;\n    border-color: #2c5282;\n    border-color: rgba(44, 82, 130, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-blue-900:hover {\n    --border-opacity: 1;\n    border-color: #2a4365;\n    border-color: rgba(42, 67, 101, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-indigo-100:hover {\n    --border-opacity: 1;\n    border-color: #ebf4ff;\n    border-color: rgba(235, 244, 255, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-indigo-200:hover {\n    --border-opacity: 1;\n    border-color: #c3dafe;\n    border-color: rgba(195, 218, 254, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-indigo-300:hover {\n    --border-opacity: 1;\n    border-color: #a3bffa;\n    border-color: rgba(163, 191, 250, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-indigo-400:hover {\n    --border-opacity: 1;\n    border-color: #7f9cf5;\n    border-color: rgba(127, 156, 245, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-indigo-500:hover {\n    --border-opacity: 1;\n    border-color: #667eea;\n    border-color: rgba(102, 126, 234, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-indigo-600:hover {\n    --border-opacity: 1;\n    border-color: #5a67d8;\n    border-color: rgba(90, 103, 216, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-indigo-700:hover {\n    --border-opacity: 1;\n    border-color: #4c51bf;\n    border-color: rgba(76, 81, 191, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-indigo-800:hover {\n    --border-opacity: 1;\n    border-color: #434190;\n    border-color: rgba(67, 65, 144, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-indigo-900:hover {\n    --border-opacity: 1;\n    border-color: #3c366b;\n    border-color: rgba(60, 54, 107, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-purple-100:hover {\n    --border-opacity: 1;\n    border-color: #faf5ff;\n    border-color: rgba(250, 245, 255, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-purple-200:hover {\n    --border-opacity: 1;\n    border-color: #e9d8fd;\n    border-color: rgba(233, 216, 253, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-purple-300:hover {\n    --border-opacity: 1;\n    border-color: #d6bcfa;\n    border-color: rgba(214, 188, 250, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-purple-400:hover {\n    --border-opacity: 1;\n    border-color: #b794f4;\n    border-color: rgba(183, 148, 244, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-purple-500:hover {\n    --border-opacity: 1;\n    border-color: #9f7aea;\n    border-color: rgba(159, 122, 234, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-purple-600:hover {\n    --border-opacity: 1;\n    border-color: #805ad5;\n    border-color: rgba(128, 90, 213, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-purple-700:hover {\n    --border-opacity: 1;\n    border-color: #6b46c1;\n    border-color: rgba(107, 70, 193, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-purple-800:hover {\n    --border-opacity: 1;\n    border-color: #553c9a;\n    border-color: rgba(85, 60, 154, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-purple-900:hover {\n    --border-opacity: 1;\n    border-color: #44337a;\n    border-color: rgba(68, 51, 122, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-pink-100:hover {\n    --border-opacity: 1;\n    border-color: #fff5f7;\n    border-color: rgba(255, 245, 247, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-pink-200:hover {\n    --border-opacity: 1;\n    border-color: #fed7e2;\n    border-color: rgba(254, 215, 226, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-pink-300:hover {\n    --border-opacity: 1;\n    border-color: #fbb6ce;\n    border-color: rgba(251, 182, 206, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-pink-400:hover {\n    --border-opacity: 1;\n    border-color: #f687b3;\n    border-color: rgba(246, 135, 179, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-pink-500:hover {\n    --border-opacity: 1;\n    border-color: #ed64a6;\n    border-color: rgba(237, 100, 166, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-pink-600:hover {\n    --border-opacity: 1;\n    border-color: #d53f8c;\n    border-color: rgba(213, 63, 140, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-pink-700:hover {\n    --border-opacity: 1;\n    border-color: #b83280;\n    border-color: rgba(184, 50, 128, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-pink-800:hover {\n    --border-opacity: 1;\n    border-color: #97266d;\n    border-color: rgba(151, 38, 109, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-pink-900:hover {\n    --border-opacity: 1;\n    border-color: #702459;\n    border-color: rgba(112, 36, 89, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-grayscale-80:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 8%);\n    border-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-grayscale-100:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 10%);\n    border-color: rgba(25.5, 25.5, 25.5, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-grayscale-200:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 20%);\n    border-color: rgba(51, 51, 51, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-grayscale-300:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 30%);\n    border-color: rgba(76.5, 76.5, 76.5, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-grayscale-400:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 40%);\n    border-color: rgba(102, 102, 102, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-grayscale-500:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 50%);\n    border-color: rgba(127.5, 127.5, 127.5, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-grayscale-600:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 60%);\n    border-color: rgba(153, 153, 153, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-grayscale-700:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 70%);\n    border-color: rgba(178.5, 178.5, 178.5, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-grayscale-800:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 80%);\n    border-color: rgba(204, 204, 204, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-grayscale-840:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 84%);\n    border-color: rgba(214.2, 214.2, 214.2, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-grayscale-870:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 87%);\n    border-color: rgba(221.85, 221.85, 221.85, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-grayscale-900:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 90%);\n    border-color: rgba(229.5, 229.5, 229.5, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-grayscale-930:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 93%);\n    border-color: rgba(237.15, 237.15, 237.15, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-primary:hover {\n    --border-opacity: 1;\n    border-color: hsl(210, 100%, 52%);\n    border-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--border-opacity));\n  }\n\n  .md\\:hover\\:border-background-main:hover {\n    border-color: var(--main-background);\n  }\n\n  .md\\:hover\\:border-background-secondary:hover {\n    border-color: var(--secondary-background);\n  }\n\n  .md\\:hover\\:border-foreground:hover {\n    border-color: var(--foreground);\n  }\n\n  .md\\:hover\\:border-panels-bg:hover {\n    border-color: var(--panels-background);\n  }\n\n  .md\\:focus\\:border-transparent:focus {\n    border-color: transparent;\n  }\n\n  .md\\:focus\\:border-current:focus {\n    border-color: currentColor;\n  }\n\n  .md\\:focus\\:border-black:focus {\n    --border-opacity: 1;\n    border-color: #000;\n    border-color: rgba(0, 0, 0, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-white:focus {\n    --border-opacity: 1;\n    border-color: #fff;\n    border-color: rgba(255, 255, 255, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-gray-100:focus {\n    --border-opacity: 1;\n    border-color: #f7fafc;\n    border-color: rgba(247, 250, 252, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-gray-200:focus {\n    --border-opacity: 1;\n    border-color: #edf2f7;\n    border-color: rgba(237, 242, 247, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-gray-300:focus {\n    --border-opacity: 1;\n    border-color: #e2e8f0;\n    border-color: rgba(226, 232, 240, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-gray-400:focus {\n    --border-opacity: 1;\n    border-color: #cbd5e0;\n    border-color: rgba(203, 213, 224, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-gray-500:focus {\n    --border-opacity: 1;\n    border-color: #a0aec0;\n    border-color: rgba(160, 174, 192, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-gray-600:focus {\n    --border-opacity: 1;\n    border-color: #718096;\n    border-color: rgba(113, 128, 150, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-gray-700:focus {\n    --border-opacity: 1;\n    border-color: #4a5568;\n    border-color: rgba(74, 85, 104, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-gray-800:focus {\n    --border-opacity: 1;\n    border-color: #2d3748;\n    border-color: rgba(45, 55, 72, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-gray-900:focus {\n    --border-opacity: 1;\n    border-color: #1a202c;\n    border-color: rgba(26, 32, 44, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-red-100:focus {\n    --border-opacity: 1;\n    border-color: #fff5f5;\n    border-color: rgba(255, 245, 245, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-red-200:focus {\n    --border-opacity: 1;\n    border-color: #fed7d7;\n    border-color: rgba(254, 215, 215, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-red-300:focus {\n    --border-opacity: 1;\n    border-color: #feb2b2;\n    border-color: rgba(254, 178, 178, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-red-400:focus {\n    --border-opacity: 1;\n    border-color: #fc8181;\n    border-color: rgba(252, 129, 129, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-red-500:focus {\n    --border-opacity: 1;\n    border-color: #f56565;\n    border-color: rgba(245, 101, 101, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-red-600:focus {\n    --border-opacity: 1;\n    border-color: #e53e3e;\n    border-color: rgba(229, 62, 62, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-red-700:focus {\n    --border-opacity: 1;\n    border-color: #c53030;\n    border-color: rgba(197, 48, 48, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-red-800:focus {\n    --border-opacity: 1;\n    border-color: #9b2c2c;\n    border-color: rgba(155, 44, 44, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-red-900:focus {\n    --border-opacity: 1;\n    border-color: #742a2a;\n    border-color: rgba(116, 42, 42, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-orange-100:focus {\n    --border-opacity: 1;\n    border-color: #fffaf0;\n    border-color: rgba(255, 250, 240, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-orange-200:focus {\n    --border-opacity: 1;\n    border-color: #feebc8;\n    border-color: rgba(254, 235, 200, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-orange-300:focus {\n    --border-opacity: 1;\n    border-color: #fbd38d;\n    border-color: rgba(251, 211, 141, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-orange-400:focus {\n    --border-opacity: 1;\n    border-color: #f6ad55;\n    border-color: rgba(246, 173, 85, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-orange-500:focus {\n    --border-opacity: 1;\n    border-color: #ed8936;\n    border-color: rgba(237, 137, 54, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-orange-600:focus {\n    --border-opacity: 1;\n    border-color: #dd6b20;\n    border-color: rgba(221, 107, 32, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-orange-700:focus {\n    --border-opacity: 1;\n    border-color: #c05621;\n    border-color: rgba(192, 86, 33, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-orange-800:focus {\n    --border-opacity: 1;\n    border-color: #9c4221;\n    border-color: rgba(156, 66, 33, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-orange-900:focus {\n    --border-opacity: 1;\n    border-color: #7b341e;\n    border-color: rgba(123, 52, 30, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-yellow-100:focus {\n    --border-opacity: 1;\n    border-color: #fffff0;\n    border-color: rgba(255, 255, 240, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-yellow-200:focus {\n    --border-opacity: 1;\n    border-color: #fefcbf;\n    border-color: rgba(254, 252, 191, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-yellow-300:focus {\n    --border-opacity: 1;\n    border-color: #faf089;\n    border-color: rgba(250, 240, 137, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-yellow-400:focus {\n    --border-opacity: 1;\n    border-color: #f6e05e;\n    border-color: rgba(246, 224, 94, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-yellow-500:focus {\n    --border-opacity: 1;\n    border-color: #ecc94b;\n    border-color: rgba(236, 201, 75, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-yellow-600:focus {\n    --border-opacity: 1;\n    border-color: #d69e2e;\n    border-color: rgba(214, 158, 46, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-yellow-700:focus {\n    --border-opacity: 1;\n    border-color: #b7791f;\n    border-color: rgba(183, 121, 31, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-yellow-800:focus {\n    --border-opacity: 1;\n    border-color: #975a16;\n    border-color: rgba(151, 90, 22, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-yellow-900:focus {\n    --border-opacity: 1;\n    border-color: #744210;\n    border-color: rgba(116, 66, 16, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-green-100:focus {\n    --border-opacity: 1;\n    border-color: #f0fff4;\n    border-color: rgba(240, 255, 244, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-green-200:focus {\n    --border-opacity: 1;\n    border-color: #c6f6d5;\n    border-color: rgba(198, 246, 213, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-green-300:focus {\n    --border-opacity: 1;\n    border-color: #9ae6b4;\n    border-color: rgba(154, 230, 180, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-green-400:focus {\n    --border-opacity: 1;\n    border-color: #68d391;\n    border-color: rgba(104, 211, 145, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-green-500:focus {\n    --border-opacity: 1;\n    border-color: #48bb78;\n    border-color: rgba(72, 187, 120, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-green-600:focus {\n    --border-opacity: 1;\n    border-color: #38a169;\n    border-color: rgba(56, 161, 105, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-green-700:focus {\n    --border-opacity: 1;\n    border-color: #2f855a;\n    border-color: rgba(47, 133, 90, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-green-800:focus {\n    --border-opacity: 1;\n    border-color: #276749;\n    border-color: rgba(39, 103, 73, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-green-900:focus {\n    --border-opacity: 1;\n    border-color: #22543d;\n    border-color: rgba(34, 84, 61, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-teal-100:focus {\n    --border-opacity: 1;\n    border-color: #e6fffa;\n    border-color: rgba(230, 255, 250, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-teal-200:focus {\n    --border-opacity: 1;\n    border-color: #b2f5ea;\n    border-color: rgba(178, 245, 234, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-teal-300:focus {\n    --border-opacity: 1;\n    border-color: #81e6d9;\n    border-color: rgba(129, 230, 217, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-teal-400:focus {\n    --border-opacity: 1;\n    border-color: #4fd1c5;\n    border-color: rgba(79, 209, 197, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-teal-500:focus {\n    --border-opacity: 1;\n    border-color: #38b2ac;\n    border-color: rgba(56, 178, 172, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-teal-600:focus {\n    --border-opacity: 1;\n    border-color: #319795;\n    border-color: rgba(49, 151, 149, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-teal-700:focus {\n    --border-opacity: 1;\n    border-color: #2c7a7b;\n    border-color: rgba(44, 122, 123, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-teal-800:focus {\n    --border-opacity: 1;\n    border-color: #285e61;\n    border-color: rgba(40, 94, 97, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-teal-900:focus {\n    --border-opacity: 1;\n    border-color: #234e52;\n    border-color: rgba(35, 78, 82, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-blue-100:focus {\n    --border-opacity: 1;\n    border-color: #ebf8ff;\n    border-color: rgba(235, 248, 255, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-blue-200:focus {\n    --border-opacity: 1;\n    border-color: #bee3f8;\n    border-color: rgba(190, 227, 248, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-blue-300:focus {\n    --border-opacity: 1;\n    border-color: #90cdf4;\n    border-color: rgba(144, 205, 244, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-blue-400:focus {\n    --border-opacity: 1;\n    border-color: #63b3ed;\n    border-color: rgba(99, 179, 237, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-blue-500:focus {\n    --border-opacity: 1;\n    border-color: #4299e1;\n    border-color: rgba(66, 153, 225, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-blue-600:focus {\n    --border-opacity: 1;\n    border-color: #3182ce;\n    border-color: rgba(49, 130, 206, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-blue-700:focus {\n    --border-opacity: 1;\n    border-color: #2b6cb0;\n    border-color: rgba(43, 108, 176, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-blue-800:focus {\n    --border-opacity: 1;\n    border-color: #2c5282;\n    border-color: rgba(44, 82, 130, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-blue-900:focus {\n    --border-opacity: 1;\n    border-color: #2a4365;\n    border-color: rgba(42, 67, 101, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-indigo-100:focus {\n    --border-opacity: 1;\n    border-color: #ebf4ff;\n    border-color: rgba(235, 244, 255, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-indigo-200:focus {\n    --border-opacity: 1;\n    border-color: #c3dafe;\n    border-color: rgba(195, 218, 254, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-indigo-300:focus {\n    --border-opacity: 1;\n    border-color: #a3bffa;\n    border-color: rgba(163, 191, 250, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-indigo-400:focus {\n    --border-opacity: 1;\n    border-color: #7f9cf5;\n    border-color: rgba(127, 156, 245, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-indigo-500:focus {\n    --border-opacity: 1;\n    border-color: #667eea;\n    border-color: rgba(102, 126, 234, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-indigo-600:focus {\n    --border-opacity: 1;\n    border-color: #5a67d8;\n    border-color: rgba(90, 103, 216, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-indigo-700:focus {\n    --border-opacity: 1;\n    border-color: #4c51bf;\n    border-color: rgba(76, 81, 191, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-indigo-800:focus {\n    --border-opacity: 1;\n    border-color: #434190;\n    border-color: rgba(67, 65, 144, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-indigo-900:focus {\n    --border-opacity: 1;\n    border-color: #3c366b;\n    border-color: rgba(60, 54, 107, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-purple-100:focus {\n    --border-opacity: 1;\n    border-color: #faf5ff;\n    border-color: rgba(250, 245, 255, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-purple-200:focus {\n    --border-opacity: 1;\n    border-color: #e9d8fd;\n    border-color: rgba(233, 216, 253, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-purple-300:focus {\n    --border-opacity: 1;\n    border-color: #d6bcfa;\n    border-color: rgba(214, 188, 250, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-purple-400:focus {\n    --border-opacity: 1;\n    border-color: #b794f4;\n    border-color: rgba(183, 148, 244, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-purple-500:focus {\n    --border-opacity: 1;\n    border-color: #9f7aea;\n    border-color: rgba(159, 122, 234, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-purple-600:focus {\n    --border-opacity: 1;\n    border-color: #805ad5;\n    border-color: rgba(128, 90, 213, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-purple-700:focus {\n    --border-opacity: 1;\n    border-color: #6b46c1;\n    border-color: rgba(107, 70, 193, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-purple-800:focus {\n    --border-opacity: 1;\n    border-color: #553c9a;\n    border-color: rgba(85, 60, 154, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-purple-900:focus {\n    --border-opacity: 1;\n    border-color: #44337a;\n    border-color: rgba(68, 51, 122, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-pink-100:focus {\n    --border-opacity: 1;\n    border-color: #fff5f7;\n    border-color: rgba(255, 245, 247, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-pink-200:focus {\n    --border-opacity: 1;\n    border-color: #fed7e2;\n    border-color: rgba(254, 215, 226, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-pink-300:focus {\n    --border-opacity: 1;\n    border-color: #fbb6ce;\n    border-color: rgba(251, 182, 206, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-pink-400:focus {\n    --border-opacity: 1;\n    border-color: #f687b3;\n    border-color: rgba(246, 135, 179, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-pink-500:focus {\n    --border-opacity: 1;\n    border-color: #ed64a6;\n    border-color: rgba(237, 100, 166, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-pink-600:focus {\n    --border-opacity: 1;\n    border-color: #d53f8c;\n    border-color: rgba(213, 63, 140, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-pink-700:focus {\n    --border-opacity: 1;\n    border-color: #b83280;\n    border-color: rgba(184, 50, 128, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-pink-800:focus {\n    --border-opacity: 1;\n    border-color: #97266d;\n    border-color: rgba(151, 38, 109, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-pink-900:focus {\n    --border-opacity: 1;\n    border-color: #702459;\n    border-color: rgba(112, 36, 89, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-grayscale-80:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 8%);\n    border-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-grayscale-100:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 10%);\n    border-color: rgba(25.5, 25.5, 25.5, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-grayscale-200:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 20%);\n    border-color: rgba(51, 51, 51, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-grayscale-300:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 30%);\n    border-color: rgba(76.5, 76.5, 76.5, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-grayscale-400:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 40%);\n    border-color: rgba(102, 102, 102, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-grayscale-500:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 50%);\n    border-color: rgba(127.5, 127.5, 127.5, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-grayscale-600:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 60%);\n    border-color: rgba(153, 153, 153, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-grayscale-700:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 70%);\n    border-color: rgba(178.5, 178.5, 178.5, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-grayscale-800:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 80%);\n    border-color: rgba(204, 204, 204, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-grayscale-840:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 84%);\n    border-color: rgba(214.2, 214.2, 214.2, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-grayscale-870:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 87%);\n    border-color: rgba(221.85, 221.85, 221.85, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-grayscale-900:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 90%);\n    border-color: rgba(229.5, 229.5, 229.5, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-grayscale-930:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 93%);\n    border-color: rgba(237.15, 237.15, 237.15, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-primary:focus {\n    --border-opacity: 1;\n    border-color: hsl(210, 100%, 52%);\n    border-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--border-opacity));\n  }\n\n  .md\\:focus\\:border-background-main:focus {\n    border-color: var(--main-background);\n  }\n\n  .md\\:focus\\:border-background-secondary:focus {\n    border-color: var(--secondary-background);\n  }\n\n  .md\\:focus\\:border-foreground:focus {\n    border-color: var(--foreground);\n  }\n\n  .md\\:focus\\:border-panels-bg:focus {\n    border-color: var(--panels-background);\n  }\n\n  .md\\:border-opacity-0 {\n    --border-opacity: 0;\n  }\n\n  .md\\:border-opacity-25 {\n    --border-opacity: 0.25;\n  }\n\n  .md\\:border-opacity-50 {\n    --border-opacity: 0.5;\n  }\n\n  .md\\:border-opacity-75 {\n    --border-opacity: 0.75;\n  }\n\n  .md\\:border-opacity-100 {\n    --border-opacity: 1;\n  }\n\n  .md\\:hover\\:border-opacity-0:hover {\n    --border-opacity: 0;\n  }\n\n  .md\\:hover\\:border-opacity-25:hover {\n    --border-opacity: 0.25;\n  }\n\n  .md\\:hover\\:border-opacity-50:hover {\n    --border-opacity: 0.5;\n  }\n\n  .md\\:hover\\:border-opacity-75:hover {\n    --border-opacity: 0.75;\n  }\n\n  .md\\:hover\\:border-opacity-100:hover {\n    --border-opacity: 1;\n  }\n\n  .md\\:focus\\:border-opacity-0:focus {\n    --border-opacity: 0;\n  }\n\n  .md\\:focus\\:border-opacity-25:focus {\n    --border-opacity: 0.25;\n  }\n\n  .md\\:focus\\:border-opacity-50:focus {\n    --border-opacity: 0.5;\n  }\n\n  .md\\:focus\\:border-opacity-75:focus {\n    --border-opacity: 0.75;\n  }\n\n  .md\\:focus\\:border-opacity-100:focus {\n    --border-opacity: 1;\n  }\n\n  .md\\:rounded-none {\n    border-radius: 0;\n  }\n\n  .md\\:rounded-sm {\n    border-radius: 0.125rem;\n  }\n\n  .md\\:rounded {\n    border-radius: 0.25rem;\n  }\n\n  .md\\:rounded-md {\n    border-radius: 0.375rem;\n  }\n\n  .md\\:rounded-lg {\n    border-radius: 0.5rem;\n  }\n\n  .md\\:rounded-xl {\n    border-radius: 0.75rem;\n  }\n\n  .md\\:rounded-2xl {\n    border-radius: 1rem;\n  }\n\n  .md\\:rounded-3xl {\n    border-radius: 1.5rem;\n  }\n\n  .md\\:rounded-full {\n    border-radius: 9999px;\n  }\n\n  .md\\:rounded-t-none {\n    border-top-left-radius: 0;\n    border-top-right-radius: 0;\n  }\n\n  .md\\:rounded-r-none {\n    border-top-right-radius: 0;\n    border-bottom-right-radius: 0;\n  }\n\n  .md\\:rounded-b-none {\n    border-bottom-right-radius: 0;\n    border-bottom-left-radius: 0;\n  }\n\n  .md\\:rounded-l-none {\n    border-top-left-radius: 0;\n    border-bottom-left-radius: 0;\n  }\n\n  .md\\:rounded-t-sm {\n    border-top-left-radius: 0.125rem;\n    border-top-right-radius: 0.125rem;\n  }\n\n  .md\\:rounded-r-sm {\n    border-top-right-radius: 0.125rem;\n    border-bottom-right-radius: 0.125rem;\n  }\n\n  .md\\:rounded-b-sm {\n    border-bottom-right-radius: 0.125rem;\n    border-bottom-left-radius: 0.125rem;\n  }\n\n  .md\\:rounded-l-sm {\n    border-top-left-radius: 0.125rem;\n    border-bottom-left-radius: 0.125rem;\n  }\n\n  .md\\:rounded-t {\n    border-top-left-radius: 0.25rem;\n    border-top-right-radius: 0.25rem;\n  }\n\n  .md\\:rounded-r {\n    border-top-right-radius: 0.25rem;\n    border-bottom-right-radius: 0.25rem;\n  }\n\n  .md\\:rounded-b {\n    border-bottom-right-radius: 0.25rem;\n    border-bottom-left-radius: 0.25rem;\n  }\n\n  .md\\:rounded-l {\n    border-top-left-radius: 0.25rem;\n    border-bottom-left-radius: 0.25rem;\n  }\n\n  .md\\:rounded-t-md {\n    border-top-left-radius: 0.375rem;\n    border-top-right-radius: 0.375rem;\n  }\n\n  .md\\:rounded-r-md {\n    border-top-right-radius: 0.375rem;\n    border-bottom-right-radius: 0.375rem;\n  }\n\n  .md\\:rounded-b-md {\n    border-bottom-right-radius: 0.375rem;\n    border-bottom-left-radius: 0.375rem;\n  }\n\n  .md\\:rounded-l-md {\n    border-top-left-radius: 0.375rem;\n    border-bottom-left-radius: 0.375rem;\n  }\n\n  .md\\:rounded-t-lg {\n    border-top-left-radius: 0.5rem;\n    border-top-right-radius: 0.5rem;\n  }\n\n  .md\\:rounded-r-lg {\n    border-top-right-radius: 0.5rem;\n    border-bottom-right-radius: 0.5rem;\n  }\n\n  .md\\:rounded-b-lg {\n    border-bottom-right-radius: 0.5rem;\n    border-bottom-left-radius: 0.5rem;\n  }\n\n  .md\\:rounded-l-lg {\n    border-top-left-radius: 0.5rem;\n    border-bottom-left-radius: 0.5rem;\n  }\n\n  .md\\:rounded-t-xl {\n    border-top-left-radius: 0.75rem;\n    border-top-right-radius: 0.75rem;\n  }\n\n  .md\\:rounded-r-xl {\n    border-top-right-radius: 0.75rem;\n    border-bottom-right-radius: 0.75rem;\n  }\n\n  .md\\:rounded-b-xl {\n    border-bottom-right-radius: 0.75rem;\n    border-bottom-left-radius: 0.75rem;\n  }\n\n  .md\\:rounded-l-xl {\n    border-top-left-radius: 0.75rem;\n    border-bottom-left-radius: 0.75rem;\n  }\n\n  .md\\:rounded-t-2xl {\n    border-top-left-radius: 1rem;\n    border-top-right-radius: 1rem;\n  }\n\n  .md\\:rounded-r-2xl {\n    border-top-right-radius: 1rem;\n    border-bottom-right-radius: 1rem;\n  }\n\n  .md\\:rounded-b-2xl {\n    border-bottom-right-radius: 1rem;\n    border-bottom-left-radius: 1rem;\n  }\n\n  .md\\:rounded-l-2xl {\n    border-top-left-radius: 1rem;\n    border-bottom-left-radius: 1rem;\n  }\n\n  .md\\:rounded-t-3xl {\n    border-top-left-radius: 1.5rem;\n    border-top-right-radius: 1.5rem;\n  }\n\n  .md\\:rounded-r-3xl {\n    border-top-right-radius: 1.5rem;\n    border-bottom-right-radius: 1.5rem;\n  }\n\n  .md\\:rounded-b-3xl {\n    border-bottom-right-radius: 1.5rem;\n    border-bottom-left-radius: 1.5rem;\n  }\n\n  .md\\:rounded-l-3xl {\n    border-top-left-radius: 1.5rem;\n    border-bottom-left-radius: 1.5rem;\n  }\n\n  .md\\:rounded-t-full {\n    border-top-left-radius: 9999px;\n    border-top-right-radius: 9999px;\n  }\n\n  .md\\:rounded-r-full {\n    border-top-right-radius: 9999px;\n    border-bottom-right-radius: 9999px;\n  }\n\n  .md\\:rounded-b-full {\n    border-bottom-right-radius: 9999px;\n    border-bottom-left-radius: 9999px;\n  }\n\n  .md\\:rounded-l-full {\n    border-top-left-radius: 9999px;\n    border-bottom-left-radius: 9999px;\n  }\n\n  .md\\:rounded-tl-none {\n    border-top-left-radius: 0;\n  }\n\n  .md\\:rounded-tr-none {\n    border-top-right-radius: 0;\n  }\n\n  .md\\:rounded-br-none {\n    border-bottom-right-radius: 0;\n  }\n\n  .md\\:rounded-bl-none {\n    border-bottom-left-radius: 0;\n  }\n\n  .md\\:rounded-tl-sm {\n    border-top-left-radius: 0.125rem;\n  }\n\n  .md\\:rounded-tr-sm {\n    border-top-right-radius: 0.125rem;\n  }\n\n  .md\\:rounded-br-sm {\n    border-bottom-right-radius: 0.125rem;\n  }\n\n  .md\\:rounded-bl-sm {\n    border-bottom-left-radius: 0.125rem;\n  }\n\n  .md\\:rounded-tl {\n    border-top-left-radius: 0.25rem;\n  }\n\n  .md\\:rounded-tr {\n    border-top-right-radius: 0.25rem;\n  }\n\n  .md\\:rounded-br {\n    border-bottom-right-radius: 0.25rem;\n  }\n\n  .md\\:rounded-bl {\n    border-bottom-left-radius: 0.25rem;\n  }\n\n  .md\\:rounded-tl-md {\n    border-top-left-radius: 0.375rem;\n  }\n\n  .md\\:rounded-tr-md {\n    border-top-right-radius: 0.375rem;\n  }\n\n  .md\\:rounded-br-md {\n    border-bottom-right-radius: 0.375rem;\n  }\n\n  .md\\:rounded-bl-md {\n    border-bottom-left-radius: 0.375rem;\n  }\n\n  .md\\:rounded-tl-lg {\n    border-top-left-radius: 0.5rem;\n  }\n\n  .md\\:rounded-tr-lg {\n    border-top-right-radius: 0.5rem;\n  }\n\n  .md\\:rounded-br-lg {\n    border-bottom-right-radius: 0.5rem;\n  }\n\n  .md\\:rounded-bl-lg {\n    border-bottom-left-radius: 0.5rem;\n  }\n\n  .md\\:rounded-tl-xl {\n    border-top-left-radius: 0.75rem;\n  }\n\n  .md\\:rounded-tr-xl {\n    border-top-right-radius: 0.75rem;\n  }\n\n  .md\\:rounded-br-xl {\n    border-bottom-right-radius: 0.75rem;\n  }\n\n  .md\\:rounded-bl-xl {\n    border-bottom-left-radius: 0.75rem;\n  }\n\n  .md\\:rounded-tl-2xl {\n    border-top-left-radius: 1rem;\n  }\n\n  .md\\:rounded-tr-2xl {\n    border-top-right-radius: 1rem;\n  }\n\n  .md\\:rounded-br-2xl {\n    border-bottom-right-radius: 1rem;\n  }\n\n  .md\\:rounded-bl-2xl {\n    border-bottom-left-radius: 1rem;\n  }\n\n  .md\\:rounded-tl-3xl {\n    border-top-left-radius: 1.5rem;\n  }\n\n  .md\\:rounded-tr-3xl {\n    border-top-right-radius: 1.5rem;\n  }\n\n  .md\\:rounded-br-3xl {\n    border-bottom-right-radius: 1.5rem;\n  }\n\n  .md\\:rounded-bl-3xl {\n    border-bottom-left-radius: 1.5rem;\n  }\n\n  .md\\:rounded-tl-full {\n    border-top-left-radius: 9999px;\n  }\n\n  .md\\:rounded-tr-full {\n    border-top-right-radius: 9999px;\n  }\n\n  .md\\:rounded-br-full {\n    border-bottom-right-radius: 9999px;\n  }\n\n  .md\\:rounded-bl-full {\n    border-bottom-left-radius: 9999px;\n  }\n\n  .md\\:border-solid {\n    border-style: solid;\n  }\n\n  .md\\:border-dashed {\n    border-style: dashed;\n  }\n\n  .md\\:border-dotted {\n    border-style: dotted;\n  }\n\n  .md\\:border-double {\n    border-style: double;\n  }\n\n  .md\\:border-none {\n    border-style: none;\n  }\n\n  .md\\:border-0 {\n    border-width: 0;\n  }\n\n  .md\\:border-2 {\n    border-width: 2px;\n  }\n\n  .md\\:border-4 {\n    border-width: 4px;\n  }\n\n  .md\\:border-8 {\n    border-width: 8px;\n  }\n\n  .md\\:border {\n    border-width: 1px;\n  }\n\n  .md\\:border-t-0 {\n    border-top-width: 0;\n  }\n\n  .md\\:border-r-0 {\n    border-right-width: 0;\n  }\n\n  .md\\:border-b-0 {\n    border-bottom-width: 0;\n  }\n\n  .md\\:border-l-0 {\n    border-left-width: 0;\n  }\n\n  .md\\:border-t-2 {\n    border-top-width: 2px;\n  }\n\n  .md\\:border-r-2 {\n    border-right-width: 2px;\n  }\n\n  .md\\:border-b-2 {\n    border-bottom-width: 2px;\n  }\n\n  .md\\:border-l-2 {\n    border-left-width: 2px;\n  }\n\n  .md\\:border-t-4 {\n    border-top-width: 4px;\n  }\n\n  .md\\:border-r-4 {\n    border-right-width: 4px;\n  }\n\n  .md\\:border-b-4 {\n    border-bottom-width: 4px;\n  }\n\n  .md\\:border-l-4 {\n    border-left-width: 4px;\n  }\n\n  .md\\:border-t-8 {\n    border-top-width: 8px;\n  }\n\n  .md\\:border-r-8 {\n    border-right-width: 8px;\n  }\n\n  .md\\:border-b-8 {\n    border-bottom-width: 8px;\n  }\n\n  .md\\:border-l-8 {\n    border-left-width: 8px;\n  }\n\n  .md\\:border-t {\n    border-top-width: 1px;\n  }\n\n  .md\\:border-r {\n    border-right-width: 1px;\n  }\n\n  .md\\:border-b {\n    border-bottom-width: 1px;\n  }\n\n  .md\\:border-l {\n    border-left-width: 1px;\n  }\n\n  .md\\:box-border {\n    box-sizing: border-box;\n  }\n\n  .md\\:box-content {\n    box-sizing: content-box;\n  }\n\n  .md\\:cursor-auto {\n    cursor: auto;\n  }\n\n  .md\\:cursor-default {\n    cursor: default;\n  }\n\n  .md\\:cursor-pointer {\n    cursor: pointer;\n  }\n\n  .md\\:cursor-wait {\n    cursor: wait;\n  }\n\n  .md\\:cursor-text {\n    cursor: text;\n  }\n\n  .md\\:cursor-move {\n    cursor: move;\n  }\n\n  .md\\:cursor-not-allowed {\n    cursor: not-allowed;\n  }\n\n  .md\\:block {\n    display: block;\n  }\n\n  .md\\:inline-block {\n    display: inline-block;\n  }\n\n  .md\\:inline {\n    display: inline;\n  }\n\n  .md\\:flex {\n    display: flex;\n  }\n\n  .md\\:inline-flex {\n    display: inline-flex;\n  }\n\n  .md\\:table {\n    display: table;\n  }\n\n  .md\\:table-caption {\n    display: table-caption;\n  }\n\n  .md\\:table-cell {\n    display: table-cell;\n  }\n\n  .md\\:table-column {\n    display: table-column;\n  }\n\n  .md\\:table-column-group {\n    display: table-column-group;\n  }\n\n  .md\\:table-footer-group {\n    display: table-footer-group;\n  }\n\n  .md\\:table-header-group {\n    display: table-header-group;\n  }\n\n  .md\\:table-row-group {\n    display: table-row-group;\n  }\n\n  .md\\:table-row {\n    display: table-row;\n  }\n\n  .md\\:flow-root {\n    display: flow-root;\n  }\n\n  .md\\:grid {\n    display: grid;\n  }\n\n  .md\\:inline-grid {\n    display: inline-grid;\n  }\n\n  .md\\:contents {\n    display: contents;\n  }\n\n  .md\\:hidden {\n    display: none;\n  }\n\n  .md\\:flex-row {\n    flex-direction: row;\n  }\n\n  .md\\:flex-row-reverse {\n    flex-direction: row-reverse;\n  }\n\n  .md\\:flex-col {\n    flex-direction: column;\n  }\n\n  .md\\:flex-col-reverse {\n    flex-direction: column-reverse;\n  }\n\n  .md\\:flex-wrap {\n    flex-wrap: wrap;\n  }\n\n  .md\\:flex-wrap-reverse {\n    flex-wrap: wrap-reverse;\n  }\n\n  .md\\:flex-no-wrap {\n    flex-wrap: nowrap;\n  }\n\n  .md\\:place-items-auto {\n    place-items: auto;\n  }\n\n  .md\\:place-items-start {\n    place-items: start;\n  }\n\n  .md\\:place-items-end {\n    place-items: end;\n  }\n\n  .md\\:place-items-center {\n    place-items: center;\n  }\n\n  .md\\:place-items-stretch {\n    place-items: stretch;\n  }\n\n  .md\\:place-content-center {\n    place-content: center;\n  }\n\n  .md\\:place-content-start {\n    place-content: start;\n  }\n\n  .md\\:place-content-end {\n    place-content: end;\n  }\n\n  .md\\:place-content-between {\n    place-content: space-between;\n  }\n\n  .md\\:place-content-around {\n    place-content: space-around;\n  }\n\n  .md\\:place-content-evenly {\n    place-content: space-evenly;\n  }\n\n  .md\\:place-content-stretch {\n    place-content: stretch;\n  }\n\n  .md\\:place-self-auto {\n    place-self: auto;\n  }\n\n  .md\\:place-self-start {\n    place-self: start;\n  }\n\n  .md\\:place-self-end {\n    place-self: end;\n  }\n\n  .md\\:place-self-center {\n    place-self: center;\n  }\n\n  .md\\:place-self-stretch {\n    place-self: stretch;\n  }\n\n  .md\\:items-start {\n    align-items: flex-start;\n  }\n\n  .md\\:items-end {\n    align-items: flex-end;\n  }\n\n  .md\\:items-center {\n    align-items: center;\n  }\n\n  .md\\:items-baseline {\n    align-items: baseline;\n  }\n\n  .md\\:items-stretch {\n    align-items: stretch;\n  }\n\n  .md\\:content-center {\n    align-content: center;\n  }\n\n  .md\\:content-start {\n    align-content: flex-start;\n  }\n\n  .md\\:content-end {\n    align-content: flex-end;\n  }\n\n  .md\\:content-between {\n    align-content: space-between;\n  }\n\n  .md\\:content-around {\n    align-content: space-around;\n  }\n\n  .md\\:content-evenly {\n    align-content: space-evenly;\n  }\n\n  .md\\:self-auto {\n    align-self: auto;\n  }\n\n  .md\\:self-start {\n    align-self: flex-start;\n  }\n\n  .md\\:self-end {\n    align-self: flex-end;\n  }\n\n  .md\\:self-center {\n    align-self: center;\n  }\n\n  .md\\:self-stretch {\n    align-self: stretch;\n  }\n\n  .md\\:justify-items-auto {\n    justify-items: auto;\n  }\n\n  .md\\:justify-items-start {\n    justify-items: start;\n  }\n\n  .md\\:justify-items-end {\n    justify-items: end;\n  }\n\n  .md\\:justify-items-center {\n    justify-items: center;\n  }\n\n  .md\\:justify-items-stretch {\n    justify-items: stretch;\n  }\n\n  .md\\:justify-start {\n    justify-content: flex-start;\n  }\n\n  .md\\:justify-end {\n    justify-content: flex-end;\n  }\n\n  .md\\:justify-center {\n    justify-content: center;\n  }\n\n  .md\\:justify-between {\n    justify-content: space-between;\n  }\n\n  .md\\:justify-around {\n    justify-content: space-around;\n  }\n\n  .md\\:justify-evenly {\n    justify-content: space-evenly;\n  }\n\n  .md\\:justify-self-auto {\n    justify-self: auto;\n  }\n\n  .md\\:justify-self-start {\n    justify-self: start;\n  }\n\n  .md\\:justify-self-end {\n    justify-self: end;\n  }\n\n  .md\\:justify-self-center {\n    justify-self: center;\n  }\n\n  .md\\:justify-self-stretch {\n    justify-self: stretch;\n  }\n\n  .md\\:flex-1 {\n    flex: 1 1 0%;\n  }\n\n  .md\\:flex-auto {\n    flex: 1 1 auto;\n  }\n\n  .md\\:flex-initial {\n    flex: 0 1 auto;\n  }\n\n  .md\\:flex-none {\n    flex: none;\n  }\n\n  .md\\:flex-grow-0 {\n    flex-grow: 0;\n  }\n\n  .md\\:flex-grow {\n    flex-grow: 1;\n  }\n\n  .md\\:flex-shrink-0 {\n    flex-shrink: 0;\n  }\n\n  .md\\:flex-shrink {\n    flex-shrink: 1;\n  }\n\n  .md\\:order-1 {\n    order: 1;\n  }\n\n  .md\\:order-2 {\n    order: 2;\n  }\n\n  .md\\:order-3 {\n    order: 3;\n  }\n\n  .md\\:order-4 {\n    order: 4;\n  }\n\n  .md\\:order-5 {\n    order: 5;\n  }\n\n  .md\\:order-6 {\n    order: 6;\n  }\n\n  .md\\:order-7 {\n    order: 7;\n  }\n\n  .md\\:order-8 {\n    order: 8;\n  }\n\n  .md\\:order-9 {\n    order: 9;\n  }\n\n  .md\\:order-10 {\n    order: 10;\n  }\n\n  .md\\:order-11 {\n    order: 11;\n  }\n\n  .md\\:order-12 {\n    order: 12;\n  }\n\n  .md\\:order-first {\n    order: -9999;\n  }\n\n  .md\\:order-last {\n    order: 9999;\n  }\n\n  .md\\:order-none {\n    order: 0;\n  }\n\n  .md\\:float-right {\n    float: right;\n  }\n\n  .md\\:float-left {\n    float: left;\n  }\n\n  .md\\:float-none {\n    float: none;\n  }\n\n  .md\\:clearfix:after {\n    content: \"\";\n    display: table;\n    clear: both;\n  }\n\n  .md\\:clear-left {\n    clear: left;\n  }\n\n  .md\\:clear-right {\n    clear: right;\n  }\n\n  .md\\:clear-both {\n    clear: both;\n  }\n\n  .md\\:clear-none {\n    clear: none;\n  }\n\n  .md\\:font-sans {\n    font-family: system-ui, -apple-system, BlinkMacSystemFont, \"Segoe UI\", Roboto, \"Helvetica Neue\", Arial, \"Noto Sans\", sans-serif, \"Apple Color Emoji\", \"Segoe UI Emoji\", \"Segoe UI Symbol\", \"Noto Color Emoji\";\n  }\n\n  .md\\:font-serif {\n    font-family: Georgia, Cambria, \"Times New Roman\", Times, serif;\n  }\n\n  .md\\:font-mono {\n    font-family: Menlo, Monaco, Consolas, \"Liberation Mono\", \"Courier New\", monospace;\n  }\n\n  .md\\:font-hairline {\n    font-weight: 100;\n  }\n\n  .md\\:font-thin {\n    font-weight: 200;\n  }\n\n  .md\\:font-light {\n    font-weight: 300;\n  }\n\n  .md\\:font-normal {\n    font-weight: 400;\n  }\n\n  .md\\:font-medium {\n    font-weight: 500;\n  }\n\n  .md\\:font-semibold {\n    font-weight: 600;\n  }\n\n  .md\\:font-bold {\n    font-weight: 700;\n  }\n\n  .md\\:font-extrabold {\n    font-weight: 800;\n  }\n\n  .md\\:font-black {\n    font-weight: 900;\n  }\n\n  .md\\:hover\\:font-hairline:hover {\n    font-weight: 100;\n  }\n\n  .md\\:hover\\:font-thin:hover {\n    font-weight: 200;\n  }\n\n  .md\\:hover\\:font-light:hover {\n    font-weight: 300;\n  }\n\n  .md\\:hover\\:font-normal:hover {\n    font-weight: 400;\n  }\n\n  .md\\:hover\\:font-medium:hover {\n    font-weight: 500;\n  }\n\n  .md\\:hover\\:font-semibold:hover {\n    font-weight: 600;\n  }\n\n  .md\\:hover\\:font-bold:hover {\n    font-weight: 700;\n  }\n\n  .md\\:hover\\:font-extrabold:hover {\n    font-weight: 800;\n  }\n\n  .md\\:hover\\:font-black:hover {\n    font-weight: 900;\n  }\n\n  .md\\:focus\\:font-hairline:focus {\n    font-weight: 100;\n  }\n\n  .md\\:focus\\:font-thin:focus {\n    font-weight: 200;\n  }\n\n  .md\\:focus\\:font-light:focus {\n    font-weight: 300;\n  }\n\n  .md\\:focus\\:font-normal:focus {\n    font-weight: 400;\n  }\n\n  .md\\:focus\\:font-medium:focus {\n    font-weight: 500;\n  }\n\n  .md\\:focus\\:font-semibold:focus {\n    font-weight: 600;\n  }\n\n  .md\\:focus\\:font-bold:focus {\n    font-weight: 700;\n  }\n\n  .md\\:focus\\:font-extrabold:focus {\n    font-weight: 800;\n  }\n\n  .md\\:focus\\:font-black:focus {\n    font-weight: 900;\n  }\n\n  .md\\:h-0 {\n    height: 0;\n  }\n\n  .md\\:h-1 {\n    height: 0.25rem;\n  }\n\n  .md\\:h-2 {\n    height: 0.5rem;\n  }\n\n  .md\\:h-3 {\n    height: 0.75rem;\n  }\n\n  .md\\:h-4 {\n    height: 1rem;\n  }\n\n  .md\\:h-5 {\n    height: 1.25rem;\n  }\n\n  .md\\:h-6 {\n    height: 1.5rem;\n  }\n\n  .md\\:h-8 {\n    height: 2rem;\n  }\n\n  .md\\:h-10 {\n    height: 2.5rem;\n  }\n\n  .md\\:h-12 {\n    height: 3rem;\n  }\n\n  .md\\:h-16 {\n    height: 4rem;\n  }\n\n  .md\\:h-20 {\n    height: 5rem;\n  }\n\n  .md\\:h-24 {\n    height: 6rem;\n  }\n\n  .md\\:h-32 {\n    height: 8rem;\n  }\n\n  .md\\:h-40 {\n    height: 10rem;\n  }\n\n  .md\\:h-48 {\n    height: 12rem;\n  }\n\n  .md\\:h-56 {\n    height: 14rem;\n  }\n\n  .md\\:h-64 {\n    height: 16rem;\n  }\n\n  .md\\:h-auto {\n    height: auto;\n  }\n\n  .md\\:h-px {\n    height: 1px;\n  }\n\n  .md\\:h-full {\n    height: 100%;\n  }\n\n  .md\\:h-screen {\n    height: 100vh;\n  }\n\n  .md\\:text-xs {\n    font-size: 0.75rem;\n  }\n\n  .md\\:text-sm {\n    font-size: 0.875rem;\n  }\n\n  .md\\:text-base {\n    font-size: 1rem;\n  }\n\n  .md\\:text-lg {\n    font-size: 1.125rem;\n  }\n\n  .md\\:text-xl {\n    font-size: 1.25rem;\n  }\n\n  .md\\:text-2xl {\n    font-size: 1.5rem;\n  }\n\n  .md\\:text-3xl {\n    font-size: 1.875rem;\n  }\n\n  .md\\:text-4xl {\n    font-size: 2.25rem;\n  }\n\n  .md\\:text-5xl {\n    font-size: 3rem;\n  }\n\n  .md\\:text-6xl {\n    font-size: 4rem;\n  }\n\n  .md\\:leading-3 {\n    line-height: .75rem;\n  }\n\n  .md\\:leading-4 {\n    line-height: 1rem;\n  }\n\n  .md\\:leading-5 {\n    line-height: 1.25rem;\n  }\n\n  .md\\:leading-6 {\n    line-height: 1.5rem;\n  }\n\n  .md\\:leading-7 {\n    line-height: 1.75rem;\n  }\n\n  .md\\:leading-8 {\n    line-height: 2rem;\n  }\n\n  .md\\:leading-9 {\n    line-height: 2.25rem;\n  }\n\n  .md\\:leading-10 {\n    line-height: 2.5rem;\n  }\n\n  .md\\:leading-none {\n    line-height: 1;\n  }\n\n  .md\\:leading-tight {\n    line-height: 1.25;\n  }\n\n  .md\\:leading-snug {\n    line-height: 1.375;\n  }\n\n  .md\\:leading-normal {\n    line-height: 1.5;\n  }\n\n  .md\\:leading-relaxed {\n    line-height: 1.625;\n  }\n\n  .md\\:leading-loose {\n    line-height: 2;\n  }\n\n  .md\\:list-inside {\n    list-style-position: inside;\n  }\n\n  .md\\:list-outside {\n    list-style-position: outside;\n  }\n\n  .md\\:list-none {\n    list-style-type: none;\n  }\n\n  .md\\:list-disc {\n    list-style-type: disc;\n  }\n\n  .md\\:list-decimal {\n    list-style-type: decimal;\n  }\n\n  .md\\:m-0 {\n    margin: 0;\n  }\n\n  .md\\:m-1 {\n    margin: 0.25rem;\n  }\n\n  .md\\:m-2 {\n    margin: 0.5rem;\n  }\n\n  .md\\:m-3 {\n    margin: 0.75rem;\n  }\n\n  .md\\:m-4 {\n    margin: 1rem;\n  }\n\n  .md\\:m-5 {\n    margin: 1.25rem;\n  }\n\n  .md\\:m-6 {\n    margin: 1.5rem;\n  }\n\n  .md\\:m-8 {\n    margin: 2rem;\n  }\n\n  .md\\:m-10 {\n    margin: 2.5rem;\n  }\n\n  .md\\:m-12 {\n    margin: 3rem;\n  }\n\n  .md\\:m-16 {\n    margin: 4rem;\n  }\n\n  .md\\:m-20 {\n    margin: 5rem;\n  }\n\n  .md\\:m-24 {\n    margin: 6rem;\n  }\n\n  .md\\:m-32 {\n    margin: 8rem;\n  }\n\n  .md\\:m-40 {\n    margin: 10rem;\n  }\n\n  .md\\:m-48 {\n    margin: 12rem;\n  }\n\n  .md\\:m-56 {\n    margin: 14rem;\n  }\n\n  .md\\:m-64 {\n    margin: 16rem;\n  }\n\n  .md\\:m-auto {\n    margin: auto;\n  }\n\n  .md\\:m-px {\n    margin: 1px;\n  }\n\n  .md\\:-m-1 {\n    margin: -0.25rem;\n  }\n\n  .md\\:-m-2 {\n    margin: -0.5rem;\n  }\n\n  .md\\:-m-3 {\n    margin: -0.75rem;\n  }\n\n  .md\\:-m-4 {\n    margin: -1rem;\n  }\n\n  .md\\:-m-5 {\n    margin: -1.25rem;\n  }\n\n  .md\\:-m-6 {\n    margin: -1.5rem;\n  }\n\n  .md\\:-m-8 {\n    margin: -2rem;\n  }\n\n  .md\\:-m-10 {\n    margin: -2.5rem;\n  }\n\n  .md\\:-m-12 {\n    margin: -3rem;\n  }\n\n  .md\\:-m-16 {\n    margin: -4rem;\n  }\n\n  .md\\:-m-20 {\n    margin: -5rem;\n  }\n\n  .md\\:-m-24 {\n    margin: -6rem;\n  }\n\n  .md\\:-m-32 {\n    margin: -8rem;\n  }\n\n  .md\\:-m-40 {\n    margin: -10rem;\n  }\n\n  .md\\:-m-48 {\n    margin: -12rem;\n  }\n\n  .md\\:-m-56 {\n    margin: -14rem;\n  }\n\n  .md\\:-m-64 {\n    margin: -16rem;\n  }\n\n  .md\\:-m-px {\n    margin: -1px;\n  }\n\n  .md\\:my-0 {\n    margin-top: 0;\n    margin-bottom: 0;\n  }\n\n  .md\\:mx-0 {\n    margin-left: 0;\n    margin-right: 0;\n  }\n\n  .md\\:my-1 {\n    margin-top: 0.25rem;\n    margin-bottom: 0.25rem;\n  }\n\n  .md\\:mx-1 {\n    margin-left: 0.25rem;\n    margin-right: 0.25rem;\n  }\n\n  .md\\:my-2 {\n    margin-top: 0.5rem;\n    margin-bottom: 0.5rem;\n  }\n\n  .md\\:mx-2 {\n    margin-left: 0.5rem;\n    margin-right: 0.5rem;\n  }\n\n  .md\\:my-3 {\n    margin-top: 0.75rem;\n    margin-bottom: 0.75rem;\n  }\n\n  .md\\:mx-3 {\n    margin-left: 0.75rem;\n    margin-right: 0.75rem;\n  }\n\n  .md\\:my-4 {\n    margin-top: 1rem;\n    margin-bottom: 1rem;\n  }\n\n  .md\\:mx-4 {\n    margin-left: 1rem;\n    margin-right: 1rem;\n  }\n\n  .md\\:my-5 {\n    margin-top: 1.25rem;\n    margin-bottom: 1.25rem;\n  }\n\n  .md\\:mx-5 {\n    margin-left: 1.25rem;\n    margin-right: 1.25rem;\n  }\n\n  .md\\:my-6 {\n    margin-top: 1.5rem;\n    margin-bottom: 1.5rem;\n  }\n\n  .md\\:mx-6 {\n    margin-left: 1.5rem;\n    margin-right: 1.5rem;\n  }\n\n  .md\\:my-8 {\n    margin-top: 2rem;\n    margin-bottom: 2rem;\n  }\n\n  .md\\:mx-8 {\n    margin-left: 2rem;\n    margin-right: 2rem;\n  }\n\n  .md\\:my-10 {\n    margin-top: 2.5rem;\n    margin-bottom: 2.5rem;\n  }\n\n  .md\\:mx-10 {\n    margin-left: 2.5rem;\n    margin-right: 2.5rem;\n  }\n\n  .md\\:my-12 {\n    margin-top: 3rem;\n    margin-bottom: 3rem;\n  }\n\n  .md\\:mx-12 {\n    margin-left: 3rem;\n    margin-right: 3rem;\n  }\n\n  .md\\:my-16 {\n    margin-top: 4rem;\n    margin-bottom: 4rem;\n  }\n\n  .md\\:mx-16 {\n    margin-left: 4rem;\n    margin-right: 4rem;\n  }\n\n  .md\\:my-20 {\n    margin-top: 5rem;\n    margin-bottom: 5rem;\n  }\n\n  .md\\:mx-20 {\n    margin-left: 5rem;\n    margin-right: 5rem;\n  }\n\n  .md\\:my-24 {\n    margin-top: 6rem;\n    margin-bottom: 6rem;\n  }\n\n  .md\\:mx-24 {\n    margin-left: 6rem;\n    margin-right: 6rem;\n  }\n\n  .md\\:my-32 {\n    margin-top: 8rem;\n    margin-bottom: 8rem;\n  }\n\n  .md\\:mx-32 {\n    margin-left: 8rem;\n    margin-right: 8rem;\n  }\n\n  .md\\:my-40 {\n    margin-top: 10rem;\n    margin-bottom: 10rem;\n  }\n\n  .md\\:mx-40 {\n    margin-left: 10rem;\n    margin-right: 10rem;\n  }\n\n  .md\\:my-48 {\n    margin-top: 12rem;\n    margin-bottom: 12rem;\n  }\n\n  .md\\:mx-48 {\n    margin-left: 12rem;\n    margin-right: 12rem;\n  }\n\n  .md\\:my-56 {\n    margin-top: 14rem;\n    margin-bottom: 14rem;\n  }\n\n  .md\\:mx-56 {\n    margin-left: 14rem;\n    margin-right: 14rem;\n  }\n\n  .md\\:my-64 {\n    margin-top: 16rem;\n    margin-bottom: 16rem;\n  }\n\n  .md\\:mx-64 {\n    margin-left: 16rem;\n    margin-right: 16rem;\n  }\n\n  .md\\:my-auto {\n    margin-top: auto;\n    margin-bottom: auto;\n  }\n\n  .md\\:mx-auto {\n    margin-left: auto;\n    margin-right: auto;\n  }\n\n  .md\\:my-px {\n    margin-top: 1px;\n    margin-bottom: 1px;\n  }\n\n  .md\\:mx-px {\n    margin-left: 1px;\n    margin-right: 1px;\n  }\n\n  .md\\:-my-1 {\n    margin-top: -0.25rem;\n    margin-bottom: -0.25rem;\n  }\n\n  .md\\:-mx-1 {\n    margin-left: -0.25rem;\n    margin-right: -0.25rem;\n  }\n\n  .md\\:-my-2 {\n    margin-top: -0.5rem;\n    margin-bottom: -0.5rem;\n  }\n\n  .md\\:-mx-2 {\n    margin-left: -0.5rem;\n    margin-right: -0.5rem;\n  }\n\n  .md\\:-my-3 {\n    margin-top: -0.75rem;\n    margin-bottom: -0.75rem;\n  }\n\n  .md\\:-mx-3 {\n    margin-left: -0.75rem;\n    margin-right: -0.75rem;\n  }\n\n  .md\\:-my-4 {\n    margin-top: -1rem;\n    margin-bottom: -1rem;\n  }\n\n  .md\\:-mx-4 {\n    margin-left: -1rem;\n    margin-right: -1rem;\n  }\n\n  .md\\:-my-5 {\n    margin-top: -1.25rem;\n    margin-bottom: -1.25rem;\n  }\n\n  .md\\:-mx-5 {\n    margin-left: -1.25rem;\n    margin-right: -1.25rem;\n  }\n\n  .md\\:-my-6 {\n    margin-top: -1.5rem;\n    margin-bottom: -1.5rem;\n  }\n\n  .md\\:-mx-6 {\n    margin-left: -1.5rem;\n    margin-right: -1.5rem;\n  }\n\n  .md\\:-my-8 {\n    margin-top: -2rem;\n    margin-bottom: -2rem;\n  }\n\n  .md\\:-mx-8 {\n    margin-left: -2rem;\n    margin-right: -2rem;\n  }\n\n  .md\\:-my-10 {\n    margin-top: -2.5rem;\n    margin-bottom: -2.5rem;\n  }\n\n  .md\\:-mx-10 {\n    margin-left: -2.5rem;\n    margin-right: -2.5rem;\n  }\n\n  .md\\:-my-12 {\n    margin-top: -3rem;\n    margin-bottom: -3rem;\n  }\n\n  .md\\:-mx-12 {\n    margin-left: -3rem;\n    margin-right: -3rem;\n  }\n\n  .md\\:-my-16 {\n    margin-top: -4rem;\n    margin-bottom: -4rem;\n  }\n\n  .md\\:-mx-16 {\n    margin-left: -4rem;\n    margin-right: -4rem;\n  }\n\n  .md\\:-my-20 {\n    margin-top: -5rem;\n    margin-bottom: -5rem;\n  }\n\n  .md\\:-mx-20 {\n    margin-left: -5rem;\n    margin-right: -5rem;\n  }\n\n  .md\\:-my-24 {\n    margin-top: -6rem;\n    margin-bottom: -6rem;\n  }\n\n  .md\\:-mx-24 {\n    margin-left: -6rem;\n    margin-right: -6rem;\n  }\n\n  .md\\:-my-32 {\n    margin-top: -8rem;\n    margin-bottom: -8rem;\n  }\n\n  .md\\:-mx-32 {\n    margin-left: -8rem;\n    margin-right: -8rem;\n  }\n\n  .md\\:-my-40 {\n    margin-top: -10rem;\n    margin-bottom: -10rem;\n  }\n\n  .md\\:-mx-40 {\n    margin-left: -10rem;\n    margin-right: -10rem;\n  }\n\n  .md\\:-my-48 {\n    margin-top: -12rem;\n    margin-bottom: -12rem;\n  }\n\n  .md\\:-mx-48 {\n    margin-left: -12rem;\n    margin-right: -12rem;\n  }\n\n  .md\\:-my-56 {\n    margin-top: -14rem;\n    margin-bottom: -14rem;\n  }\n\n  .md\\:-mx-56 {\n    margin-left: -14rem;\n    margin-right: -14rem;\n  }\n\n  .md\\:-my-64 {\n    margin-top: -16rem;\n    margin-bottom: -16rem;\n  }\n\n  .md\\:-mx-64 {\n    margin-left: -16rem;\n    margin-right: -16rem;\n  }\n\n  .md\\:-my-px {\n    margin-top: -1px;\n    margin-bottom: -1px;\n  }\n\n  .md\\:-mx-px {\n    margin-left: -1px;\n    margin-right: -1px;\n  }\n\n  .md\\:mt-0 {\n    margin-top: 0;\n  }\n\n  .md\\:mr-0 {\n    margin-right: 0;\n  }\n\n  .md\\:mb-0 {\n    margin-bottom: 0;\n  }\n\n  .md\\:ml-0 {\n    margin-left: 0;\n  }\n\n  .md\\:mt-1 {\n    margin-top: 0.25rem;\n  }\n\n  .md\\:mr-1 {\n    margin-right: 0.25rem;\n  }\n\n  .md\\:mb-1 {\n    margin-bottom: 0.25rem;\n  }\n\n  .md\\:ml-1 {\n    margin-left: 0.25rem;\n  }\n\n  .md\\:mt-2 {\n    margin-top: 0.5rem;\n  }\n\n  .md\\:mr-2 {\n    margin-right: 0.5rem;\n  }\n\n  .md\\:mb-2 {\n    margin-bottom: 0.5rem;\n  }\n\n  .md\\:ml-2 {\n    margin-left: 0.5rem;\n  }\n\n  .md\\:mt-3 {\n    margin-top: 0.75rem;\n  }\n\n  .md\\:mr-3 {\n    margin-right: 0.75rem;\n  }\n\n  .md\\:mb-3 {\n    margin-bottom: 0.75rem;\n  }\n\n  .md\\:ml-3 {\n    margin-left: 0.75rem;\n  }\n\n  .md\\:mt-4 {\n    margin-top: 1rem;\n  }\n\n  .md\\:mr-4 {\n    margin-right: 1rem;\n  }\n\n  .md\\:mb-4 {\n    margin-bottom: 1rem;\n  }\n\n  .md\\:ml-4 {\n    margin-left: 1rem;\n  }\n\n  .md\\:mt-5 {\n    margin-top: 1.25rem;\n  }\n\n  .md\\:mr-5 {\n    margin-right: 1.25rem;\n  }\n\n  .md\\:mb-5 {\n    margin-bottom: 1.25rem;\n  }\n\n  .md\\:ml-5 {\n    margin-left: 1.25rem;\n  }\n\n  .md\\:mt-6 {\n    margin-top: 1.5rem;\n  }\n\n  .md\\:mr-6 {\n    margin-right: 1.5rem;\n  }\n\n  .md\\:mb-6 {\n    margin-bottom: 1.5rem;\n  }\n\n  .md\\:ml-6 {\n    margin-left: 1.5rem;\n  }\n\n  .md\\:mt-8 {\n    margin-top: 2rem;\n  }\n\n  .md\\:mr-8 {\n    margin-right: 2rem;\n  }\n\n  .md\\:mb-8 {\n    margin-bottom: 2rem;\n  }\n\n  .md\\:ml-8 {\n    margin-left: 2rem;\n  }\n\n  .md\\:mt-10 {\n    margin-top: 2.5rem;\n  }\n\n  .md\\:mr-10 {\n    margin-right: 2.5rem;\n  }\n\n  .md\\:mb-10 {\n    margin-bottom: 2.5rem;\n  }\n\n  .md\\:ml-10 {\n    margin-left: 2.5rem;\n  }\n\n  .md\\:mt-12 {\n    margin-top: 3rem;\n  }\n\n  .md\\:mr-12 {\n    margin-right: 3rem;\n  }\n\n  .md\\:mb-12 {\n    margin-bottom: 3rem;\n  }\n\n  .md\\:ml-12 {\n    margin-left: 3rem;\n  }\n\n  .md\\:mt-16 {\n    margin-top: 4rem;\n  }\n\n  .md\\:mr-16 {\n    margin-right: 4rem;\n  }\n\n  .md\\:mb-16 {\n    margin-bottom: 4rem;\n  }\n\n  .md\\:ml-16 {\n    margin-left: 4rem;\n  }\n\n  .md\\:mt-20 {\n    margin-top: 5rem;\n  }\n\n  .md\\:mr-20 {\n    margin-right: 5rem;\n  }\n\n  .md\\:mb-20 {\n    margin-bottom: 5rem;\n  }\n\n  .md\\:ml-20 {\n    margin-left: 5rem;\n  }\n\n  .md\\:mt-24 {\n    margin-top: 6rem;\n  }\n\n  .md\\:mr-24 {\n    margin-right: 6rem;\n  }\n\n  .md\\:mb-24 {\n    margin-bottom: 6rem;\n  }\n\n  .md\\:ml-24 {\n    margin-left: 6rem;\n  }\n\n  .md\\:mt-32 {\n    margin-top: 8rem;\n  }\n\n  .md\\:mr-32 {\n    margin-right: 8rem;\n  }\n\n  .md\\:mb-32 {\n    margin-bottom: 8rem;\n  }\n\n  .md\\:ml-32 {\n    margin-left: 8rem;\n  }\n\n  .md\\:mt-40 {\n    margin-top: 10rem;\n  }\n\n  .md\\:mr-40 {\n    margin-right: 10rem;\n  }\n\n  .md\\:mb-40 {\n    margin-bottom: 10rem;\n  }\n\n  .md\\:ml-40 {\n    margin-left: 10rem;\n  }\n\n  .md\\:mt-48 {\n    margin-top: 12rem;\n  }\n\n  .md\\:mr-48 {\n    margin-right: 12rem;\n  }\n\n  .md\\:mb-48 {\n    margin-bottom: 12rem;\n  }\n\n  .md\\:ml-48 {\n    margin-left: 12rem;\n  }\n\n  .md\\:mt-56 {\n    margin-top: 14rem;\n  }\n\n  .md\\:mr-56 {\n    margin-right: 14rem;\n  }\n\n  .md\\:mb-56 {\n    margin-bottom: 14rem;\n  }\n\n  .md\\:ml-56 {\n    margin-left: 14rem;\n  }\n\n  .md\\:mt-64 {\n    margin-top: 16rem;\n  }\n\n  .md\\:mr-64 {\n    margin-right: 16rem;\n  }\n\n  .md\\:mb-64 {\n    margin-bottom: 16rem;\n  }\n\n  .md\\:ml-64 {\n    margin-left: 16rem;\n  }\n\n  .md\\:mt-auto {\n    margin-top: auto;\n  }\n\n  .md\\:mr-auto {\n    margin-right: auto;\n  }\n\n  .md\\:mb-auto {\n    margin-bottom: auto;\n  }\n\n  .md\\:ml-auto {\n    margin-left: auto;\n  }\n\n  .md\\:mt-px {\n    margin-top: 1px;\n  }\n\n  .md\\:mr-px {\n    margin-right: 1px;\n  }\n\n  .md\\:mb-px {\n    margin-bottom: 1px;\n  }\n\n  .md\\:ml-px {\n    margin-left: 1px;\n  }\n\n  .md\\:-mt-1 {\n    margin-top: -0.25rem;\n  }\n\n  .md\\:-mr-1 {\n    margin-right: -0.25rem;\n  }\n\n  .md\\:-mb-1 {\n    margin-bottom: -0.25rem;\n  }\n\n  .md\\:-ml-1 {\n    margin-left: -0.25rem;\n  }\n\n  .md\\:-mt-2 {\n    margin-top: -0.5rem;\n  }\n\n  .md\\:-mr-2 {\n    margin-right: -0.5rem;\n  }\n\n  .md\\:-mb-2 {\n    margin-bottom: -0.5rem;\n  }\n\n  .md\\:-ml-2 {\n    margin-left: -0.5rem;\n  }\n\n  .md\\:-mt-3 {\n    margin-top: -0.75rem;\n  }\n\n  .md\\:-mr-3 {\n    margin-right: -0.75rem;\n  }\n\n  .md\\:-mb-3 {\n    margin-bottom: -0.75rem;\n  }\n\n  .md\\:-ml-3 {\n    margin-left: -0.75rem;\n  }\n\n  .md\\:-mt-4 {\n    margin-top: -1rem;\n  }\n\n  .md\\:-mr-4 {\n    margin-right: -1rem;\n  }\n\n  .md\\:-mb-4 {\n    margin-bottom: -1rem;\n  }\n\n  .md\\:-ml-4 {\n    margin-left: -1rem;\n  }\n\n  .md\\:-mt-5 {\n    margin-top: -1.25rem;\n  }\n\n  .md\\:-mr-5 {\n    margin-right: -1.25rem;\n  }\n\n  .md\\:-mb-5 {\n    margin-bottom: -1.25rem;\n  }\n\n  .md\\:-ml-5 {\n    margin-left: -1.25rem;\n  }\n\n  .md\\:-mt-6 {\n    margin-top: -1.5rem;\n  }\n\n  .md\\:-mr-6 {\n    margin-right: -1.5rem;\n  }\n\n  .md\\:-mb-6 {\n    margin-bottom: -1.5rem;\n  }\n\n  .md\\:-ml-6 {\n    margin-left: -1.5rem;\n  }\n\n  .md\\:-mt-8 {\n    margin-top: -2rem;\n  }\n\n  .md\\:-mr-8 {\n    margin-right: -2rem;\n  }\n\n  .md\\:-mb-8 {\n    margin-bottom: -2rem;\n  }\n\n  .md\\:-ml-8 {\n    margin-left: -2rem;\n  }\n\n  .md\\:-mt-10 {\n    margin-top: -2.5rem;\n  }\n\n  .md\\:-mr-10 {\n    margin-right: -2.5rem;\n  }\n\n  .md\\:-mb-10 {\n    margin-bottom: -2.5rem;\n  }\n\n  .md\\:-ml-10 {\n    margin-left: -2.5rem;\n  }\n\n  .md\\:-mt-12 {\n    margin-top: -3rem;\n  }\n\n  .md\\:-mr-12 {\n    margin-right: -3rem;\n  }\n\n  .md\\:-mb-12 {\n    margin-bottom: -3rem;\n  }\n\n  .md\\:-ml-12 {\n    margin-left: -3rem;\n  }\n\n  .md\\:-mt-16 {\n    margin-top: -4rem;\n  }\n\n  .md\\:-mr-16 {\n    margin-right: -4rem;\n  }\n\n  .md\\:-mb-16 {\n    margin-bottom: -4rem;\n  }\n\n  .md\\:-ml-16 {\n    margin-left: -4rem;\n  }\n\n  .md\\:-mt-20 {\n    margin-top: -5rem;\n  }\n\n  .md\\:-mr-20 {\n    margin-right: -5rem;\n  }\n\n  .md\\:-mb-20 {\n    margin-bottom: -5rem;\n  }\n\n  .md\\:-ml-20 {\n    margin-left: -5rem;\n  }\n\n  .md\\:-mt-24 {\n    margin-top: -6rem;\n  }\n\n  .md\\:-mr-24 {\n    margin-right: -6rem;\n  }\n\n  .md\\:-mb-24 {\n    margin-bottom: -6rem;\n  }\n\n  .md\\:-ml-24 {\n    margin-left: -6rem;\n  }\n\n  .md\\:-mt-32 {\n    margin-top: -8rem;\n  }\n\n  .md\\:-mr-32 {\n    margin-right: -8rem;\n  }\n\n  .md\\:-mb-32 {\n    margin-bottom: -8rem;\n  }\n\n  .md\\:-ml-32 {\n    margin-left: -8rem;\n  }\n\n  .md\\:-mt-40 {\n    margin-top: -10rem;\n  }\n\n  .md\\:-mr-40 {\n    margin-right: -10rem;\n  }\n\n  .md\\:-mb-40 {\n    margin-bottom: -10rem;\n  }\n\n  .md\\:-ml-40 {\n    margin-left: -10rem;\n  }\n\n  .md\\:-mt-48 {\n    margin-top: -12rem;\n  }\n\n  .md\\:-mr-48 {\n    margin-right: -12rem;\n  }\n\n  .md\\:-mb-48 {\n    margin-bottom: -12rem;\n  }\n\n  .md\\:-ml-48 {\n    margin-left: -12rem;\n  }\n\n  .md\\:-mt-56 {\n    margin-top: -14rem;\n  }\n\n  .md\\:-mr-56 {\n    margin-right: -14rem;\n  }\n\n  .md\\:-mb-56 {\n    margin-bottom: -14rem;\n  }\n\n  .md\\:-ml-56 {\n    margin-left: -14rem;\n  }\n\n  .md\\:-mt-64 {\n    margin-top: -16rem;\n  }\n\n  .md\\:-mr-64 {\n    margin-right: -16rem;\n  }\n\n  .md\\:-mb-64 {\n    margin-bottom: -16rem;\n  }\n\n  .md\\:-ml-64 {\n    margin-left: -16rem;\n  }\n\n  .md\\:-mt-px {\n    margin-top: -1px;\n  }\n\n  .md\\:-mr-px {\n    margin-right: -1px;\n  }\n\n  .md\\:-mb-px {\n    margin-bottom: -1px;\n  }\n\n  .md\\:-ml-px {\n    margin-left: -1px;\n  }\n\n  .md\\:max-h-full {\n    max-height: 100%;\n  }\n\n  .md\\:max-h-screen {\n    max-height: 100vh;\n  }\n\n  .md\\:max-w-none {\n    max-width: none;\n  }\n\n  .md\\:max-w-xs {\n    max-width: 20rem;\n  }\n\n  .md\\:max-w-sm {\n    max-width: 24rem;\n  }\n\n  .md\\:max-w-md {\n    max-width: 28rem;\n  }\n\n  .md\\:max-w-lg {\n    max-width: 32rem;\n  }\n\n  .md\\:max-w-xl {\n    max-width: 36rem;\n  }\n\n  .md\\:max-w-2xl {\n    max-width: 42rem;\n  }\n\n  .md\\:max-w-3xl {\n    max-width: 48rem;\n  }\n\n  .md\\:max-w-4xl {\n    max-width: 56rem;\n  }\n\n  .md\\:max-w-5xl {\n    max-width: 64rem;\n  }\n\n  .md\\:max-w-6xl {\n    max-width: 72rem;\n  }\n\n  .md\\:max-w-full {\n    max-width: 100%;\n  }\n\n  .md\\:max-w-screen-sm {\n    max-width: 640px;\n  }\n\n  .md\\:max-w-screen-md {\n    max-width: 768px;\n  }\n\n  .md\\:max-w-screen-lg {\n    max-width: 1024px;\n  }\n\n  .md\\:max-w-screen-xl {\n    max-width: 1280px;\n  }\n\n  .md\\:min-h-0 {\n    min-height: 0;\n  }\n\n  .md\\:min-h-full {\n    min-height: 100%;\n  }\n\n  .md\\:min-h-screen {\n    min-height: 100vh;\n  }\n\n  .md\\:min-w-0 {\n    min-width: 0;\n  }\n\n  .md\\:min-w-full {\n    min-width: 100%;\n  }\n\n  .md\\:object-contain {\n    -o-object-fit: contain;\n       object-fit: contain;\n  }\n\n  .md\\:object-cover {\n    -o-object-fit: cover;\n       object-fit: cover;\n  }\n\n  .md\\:object-fill {\n    -o-object-fit: fill;\n       object-fit: fill;\n  }\n\n  .md\\:object-none {\n    -o-object-fit: none;\n       object-fit: none;\n  }\n\n  .md\\:object-scale-down {\n    -o-object-fit: scale-down;\n       object-fit: scale-down;\n  }\n\n  .md\\:object-bottom {\n    -o-object-position: bottom;\n       object-position: bottom;\n  }\n\n  .md\\:object-center {\n    -o-object-position: center;\n       object-position: center;\n  }\n\n  .md\\:object-left {\n    -o-object-position: left;\n       object-position: left;\n  }\n\n  .md\\:object-left-bottom {\n    -o-object-position: left bottom;\n       object-position: left bottom;\n  }\n\n  .md\\:object-left-top {\n    -o-object-position: left top;\n       object-position: left top;\n  }\n\n  .md\\:object-right {\n    -o-object-position: right;\n       object-position: right;\n  }\n\n  .md\\:object-right-bottom {\n    -o-object-position: right bottom;\n       object-position: right bottom;\n  }\n\n  .md\\:object-right-top {\n    -o-object-position: right top;\n       object-position: right top;\n  }\n\n  .md\\:object-top {\n    -o-object-position: top;\n       object-position: top;\n  }\n\n  .md\\:opacity-0 {\n    opacity: 0;\n  }\n\n  .md\\:opacity-25 {\n    opacity: 0.25;\n  }\n\n  .md\\:opacity-50 {\n    opacity: 0.5;\n  }\n\n  .md\\:opacity-75 {\n    opacity: 0.75;\n  }\n\n  .md\\:opacity-100 {\n    opacity: 1;\n  }\n\n  .md\\:hover\\:opacity-0:hover {\n    opacity: 0;\n  }\n\n  .md\\:hover\\:opacity-25:hover {\n    opacity: 0.25;\n  }\n\n  .md\\:hover\\:opacity-50:hover {\n    opacity: 0.5;\n  }\n\n  .md\\:hover\\:opacity-75:hover {\n    opacity: 0.75;\n  }\n\n  .md\\:hover\\:opacity-100:hover {\n    opacity: 1;\n  }\n\n  .md\\:focus\\:opacity-0:focus {\n    opacity: 0;\n  }\n\n  .md\\:focus\\:opacity-25:focus {\n    opacity: 0.25;\n  }\n\n  .md\\:focus\\:opacity-50:focus {\n    opacity: 0.5;\n  }\n\n  .md\\:focus\\:opacity-75:focus {\n    opacity: 0.75;\n  }\n\n  .md\\:focus\\:opacity-100:focus {\n    opacity: 1;\n  }\n\n  .md\\:outline-none {\n    outline: 2px solid transparent;\n    outline-offset: 2px;\n  }\n\n  .md\\:outline-white {\n    outline: 2px dotted white;\n    outline-offset: 2px;\n  }\n\n  .md\\:outline-black {\n    outline: 2px dotted black;\n    outline-offset: 2px;\n  }\n\n  .md\\:focus\\:outline-none:focus {\n    outline: 2px solid transparent;\n    outline-offset: 2px;\n  }\n\n  .md\\:focus\\:outline-white:focus {\n    outline: 2px dotted white;\n    outline-offset: 2px;\n  }\n\n  .md\\:focus\\:outline-black:focus {\n    outline: 2px dotted black;\n    outline-offset: 2px;\n  }\n\n  .md\\:overflow-auto {\n    overflow: auto;\n  }\n\n  .md\\:overflow-hidden {\n    overflow: hidden;\n  }\n\n  .md\\:overflow-visible {\n    overflow: visible;\n  }\n\n  .md\\:overflow-scroll {\n    overflow: scroll;\n  }\n\n  .md\\:overflow-x-auto {\n    overflow-x: auto;\n  }\n\n  .md\\:overflow-y-auto {\n    overflow-y: auto;\n  }\n\n  .md\\:overflow-x-hidden {\n    overflow-x: hidden;\n  }\n\n  .md\\:overflow-y-hidden {\n    overflow-y: hidden;\n  }\n\n  .md\\:overflow-x-visible {\n    overflow-x: visible;\n  }\n\n  .md\\:overflow-y-visible {\n    overflow-y: visible;\n  }\n\n  .md\\:overflow-x-scroll {\n    overflow-x: scroll;\n  }\n\n  .md\\:overflow-y-scroll {\n    overflow-y: scroll;\n  }\n\n  .md\\:scrolling-touch {\n    -webkit-overflow-scrolling: touch;\n  }\n\n  .md\\:scrolling-auto {\n    -webkit-overflow-scrolling: auto;\n  }\n\n  .md\\:overscroll-auto {\n    -ms-scroll-chaining: chained;\n        overscroll-behavior: auto;\n  }\n\n  .md\\:overscroll-contain {\n    -ms-scroll-chaining: none;\n        overscroll-behavior: contain;\n  }\n\n  .md\\:overscroll-none {\n    -ms-scroll-chaining: none;\n        overscroll-behavior: none;\n  }\n\n  .md\\:overscroll-y-auto {\n    overscroll-behavior-y: auto;\n  }\n\n  .md\\:overscroll-y-contain {\n    overscroll-behavior-y: contain;\n  }\n\n  .md\\:overscroll-y-none {\n    overscroll-behavior-y: none;\n  }\n\n  .md\\:overscroll-x-auto {\n    overscroll-behavior-x: auto;\n  }\n\n  .md\\:overscroll-x-contain {\n    overscroll-behavior-x: contain;\n  }\n\n  .md\\:overscroll-x-none {\n    overscroll-behavior-x: none;\n  }\n\n  .md\\:p-0 {\n    padding: 0;\n  }\n\n  .md\\:p-1 {\n    padding: 0.25rem;\n  }\n\n  .md\\:p-2 {\n    padding: 0.5rem;\n  }\n\n  .md\\:p-3 {\n    padding: 0.75rem;\n  }\n\n  .md\\:p-4 {\n    padding: 1rem;\n  }\n\n  .md\\:p-5 {\n    padding: 1.25rem;\n  }\n\n  .md\\:p-6 {\n    padding: 1.5rem;\n  }\n\n  .md\\:p-8 {\n    padding: 2rem;\n  }\n\n  .md\\:p-10 {\n    padding: 2.5rem;\n  }\n\n  .md\\:p-12 {\n    padding: 3rem;\n  }\n\n  .md\\:p-16 {\n    padding: 4rem;\n  }\n\n  .md\\:p-20 {\n    padding: 5rem;\n  }\n\n  .md\\:p-24 {\n    padding: 6rem;\n  }\n\n  .md\\:p-32 {\n    padding: 8rem;\n  }\n\n  .md\\:p-40 {\n    padding: 10rem;\n  }\n\n  .md\\:p-48 {\n    padding: 12rem;\n  }\n\n  .md\\:p-56 {\n    padding: 14rem;\n  }\n\n  .md\\:p-64 {\n    padding: 16rem;\n  }\n\n  .md\\:p-px {\n    padding: 1px;\n  }\n\n  .md\\:py-0 {\n    padding-top: 0;\n    padding-bottom: 0;\n  }\n\n  .md\\:px-0 {\n    padding-left: 0;\n    padding-right: 0;\n  }\n\n  .md\\:py-1 {\n    padding-top: 0.25rem;\n    padding-bottom: 0.25rem;\n  }\n\n  .md\\:px-1 {\n    padding-left: 0.25rem;\n    padding-right: 0.25rem;\n  }\n\n  .md\\:py-2 {\n    padding-top: 0.5rem;\n    padding-bottom: 0.5rem;\n  }\n\n  .md\\:px-2 {\n    padding-left: 0.5rem;\n    padding-right: 0.5rem;\n  }\n\n  .md\\:py-3 {\n    padding-top: 0.75rem;\n    padding-bottom: 0.75rem;\n  }\n\n  .md\\:px-3 {\n    padding-left: 0.75rem;\n    padding-right: 0.75rem;\n  }\n\n  .md\\:py-4 {\n    padding-top: 1rem;\n    padding-bottom: 1rem;\n  }\n\n  .md\\:px-4 {\n    padding-left: 1rem;\n    padding-right: 1rem;\n  }\n\n  .md\\:py-5 {\n    padding-top: 1.25rem;\n    padding-bottom: 1.25rem;\n  }\n\n  .md\\:px-5 {\n    padding-left: 1.25rem;\n    padding-right: 1.25rem;\n  }\n\n  .md\\:py-6 {\n    padding-top: 1.5rem;\n    padding-bottom: 1.5rem;\n  }\n\n  .md\\:px-6 {\n    padding-left: 1.5rem;\n    padding-right: 1.5rem;\n  }\n\n  .md\\:py-8 {\n    padding-top: 2rem;\n    padding-bottom: 2rem;\n  }\n\n  .md\\:px-8 {\n    padding-left: 2rem;\n    padding-right: 2rem;\n  }\n\n  .md\\:py-10 {\n    padding-top: 2.5rem;\n    padding-bottom: 2.5rem;\n  }\n\n  .md\\:px-10 {\n    padding-left: 2.5rem;\n    padding-right: 2.5rem;\n  }\n\n  .md\\:py-12 {\n    padding-top: 3rem;\n    padding-bottom: 3rem;\n  }\n\n  .md\\:px-12 {\n    padding-left: 3rem;\n    padding-right: 3rem;\n  }\n\n  .md\\:py-16 {\n    padding-top: 4rem;\n    padding-bottom: 4rem;\n  }\n\n  .md\\:px-16 {\n    padding-left: 4rem;\n    padding-right: 4rem;\n  }\n\n  .md\\:py-20 {\n    padding-top: 5rem;\n    padding-bottom: 5rem;\n  }\n\n  .md\\:px-20 {\n    padding-left: 5rem;\n    padding-right: 5rem;\n  }\n\n  .md\\:py-24 {\n    padding-top: 6rem;\n    padding-bottom: 6rem;\n  }\n\n  .md\\:px-24 {\n    padding-left: 6rem;\n    padding-right: 6rem;\n  }\n\n  .md\\:py-32 {\n    padding-top: 8rem;\n    padding-bottom: 8rem;\n  }\n\n  .md\\:px-32 {\n    padding-left: 8rem;\n    padding-right: 8rem;\n  }\n\n  .md\\:py-40 {\n    padding-top: 10rem;\n    padding-bottom: 10rem;\n  }\n\n  .md\\:px-40 {\n    padding-left: 10rem;\n    padding-right: 10rem;\n  }\n\n  .md\\:py-48 {\n    padding-top: 12rem;\n    padding-bottom: 12rem;\n  }\n\n  .md\\:px-48 {\n    padding-left: 12rem;\n    padding-right: 12rem;\n  }\n\n  .md\\:py-56 {\n    padding-top: 14rem;\n    padding-bottom: 14rem;\n  }\n\n  .md\\:px-56 {\n    padding-left: 14rem;\n    padding-right: 14rem;\n  }\n\n  .md\\:py-64 {\n    padding-top: 16rem;\n    padding-bottom: 16rem;\n  }\n\n  .md\\:px-64 {\n    padding-left: 16rem;\n    padding-right: 16rem;\n  }\n\n  .md\\:py-px {\n    padding-top: 1px;\n    padding-bottom: 1px;\n  }\n\n  .md\\:px-px {\n    padding-left: 1px;\n    padding-right: 1px;\n  }\n\n  .md\\:pt-0 {\n    padding-top: 0;\n  }\n\n  .md\\:pr-0 {\n    padding-right: 0;\n  }\n\n  .md\\:pb-0 {\n    padding-bottom: 0;\n  }\n\n  .md\\:pl-0 {\n    padding-left: 0;\n  }\n\n  .md\\:pt-1 {\n    padding-top: 0.25rem;\n  }\n\n  .md\\:pr-1 {\n    padding-right: 0.25rem;\n  }\n\n  .md\\:pb-1 {\n    padding-bottom: 0.25rem;\n  }\n\n  .md\\:pl-1 {\n    padding-left: 0.25rem;\n  }\n\n  .md\\:pt-2 {\n    padding-top: 0.5rem;\n  }\n\n  .md\\:pr-2 {\n    padding-right: 0.5rem;\n  }\n\n  .md\\:pb-2 {\n    padding-bottom: 0.5rem;\n  }\n\n  .md\\:pl-2 {\n    padding-left: 0.5rem;\n  }\n\n  .md\\:pt-3 {\n    padding-top: 0.75rem;\n  }\n\n  .md\\:pr-3 {\n    padding-right: 0.75rem;\n  }\n\n  .md\\:pb-3 {\n    padding-bottom: 0.75rem;\n  }\n\n  .md\\:pl-3 {\n    padding-left: 0.75rem;\n  }\n\n  .md\\:pt-4 {\n    padding-top: 1rem;\n  }\n\n  .md\\:pr-4 {\n    padding-right: 1rem;\n  }\n\n  .md\\:pb-4 {\n    padding-bottom: 1rem;\n  }\n\n  .md\\:pl-4 {\n    padding-left: 1rem;\n  }\n\n  .md\\:pt-5 {\n    padding-top: 1.25rem;\n  }\n\n  .md\\:pr-5 {\n    padding-right: 1.25rem;\n  }\n\n  .md\\:pb-5 {\n    padding-bottom: 1.25rem;\n  }\n\n  .md\\:pl-5 {\n    padding-left: 1.25rem;\n  }\n\n  .md\\:pt-6 {\n    padding-top: 1.5rem;\n  }\n\n  .md\\:pr-6 {\n    padding-right: 1.5rem;\n  }\n\n  .md\\:pb-6 {\n    padding-bottom: 1.5rem;\n  }\n\n  .md\\:pl-6 {\n    padding-left: 1.5rem;\n  }\n\n  .md\\:pt-8 {\n    padding-top: 2rem;\n  }\n\n  .md\\:pr-8 {\n    padding-right: 2rem;\n  }\n\n  .md\\:pb-8 {\n    padding-bottom: 2rem;\n  }\n\n  .md\\:pl-8 {\n    padding-left: 2rem;\n  }\n\n  .md\\:pt-10 {\n    padding-top: 2.5rem;\n  }\n\n  .md\\:pr-10 {\n    padding-right: 2.5rem;\n  }\n\n  .md\\:pb-10 {\n    padding-bottom: 2.5rem;\n  }\n\n  .md\\:pl-10 {\n    padding-left: 2.5rem;\n  }\n\n  .md\\:pt-12 {\n    padding-top: 3rem;\n  }\n\n  .md\\:pr-12 {\n    padding-right: 3rem;\n  }\n\n  .md\\:pb-12 {\n    padding-bottom: 3rem;\n  }\n\n  .md\\:pl-12 {\n    padding-left: 3rem;\n  }\n\n  .md\\:pt-16 {\n    padding-top: 4rem;\n  }\n\n  .md\\:pr-16 {\n    padding-right: 4rem;\n  }\n\n  .md\\:pb-16 {\n    padding-bottom: 4rem;\n  }\n\n  .md\\:pl-16 {\n    padding-left: 4rem;\n  }\n\n  .md\\:pt-20 {\n    padding-top: 5rem;\n  }\n\n  .md\\:pr-20 {\n    padding-right: 5rem;\n  }\n\n  .md\\:pb-20 {\n    padding-bottom: 5rem;\n  }\n\n  .md\\:pl-20 {\n    padding-left: 5rem;\n  }\n\n  .md\\:pt-24 {\n    padding-top: 6rem;\n  }\n\n  .md\\:pr-24 {\n    padding-right: 6rem;\n  }\n\n  .md\\:pb-24 {\n    padding-bottom: 6rem;\n  }\n\n  .md\\:pl-24 {\n    padding-left: 6rem;\n  }\n\n  .md\\:pt-32 {\n    padding-top: 8rem;\n  }\n\n  .md\\:pr-32 {\n    padding-right: 8rem;\n  }\n\n  .md\\:pb-32 {\n    padding-bottom: 8rem;\n  }\n\n  .md\\:pl-32 {\n    padding-left: 8rem;\n  }\n\n  .md\\:pt-40 {\n    padding-top: 10rem;\n  }\n\n  .md\\:pr-40 {\n    padding-right: 10rem;\n  }\n\n  .md\\:pb-40 {\n    padding-bottom: 10rem;\n  }\n\n  .md\\:pl-40 {\n    padding-left: 10rem;\n  }\n\n  .md\\:pt-48 {\n    padding-top: 12rem;\n  }\n\n  .md\\:pr-48 {\n    padding-right: 12rem;\n  }\n\n  .md\\:pb-48 {\n    padding-bottom: 12rem;\n  }\n\n  .md\\:pl-48 {\n    padding-left: 12rem;\n  }\n\n  .md\\:pt-56 {\n    padding-top: 14rem;\n  }\n\n  .md\\:pr-56 {\n    padding-right: 14rem;\n  }\n\n  .md\\:pb-56 {\n    padding-bottom: 14rem;\n  }\n\n  .md\\:pl-56 {\n    padding-left: 14rem;\n  }\n\n  .md\\:pt-64 {\n    padding-top: 16rem;\n  }\n\n  .md\\:pr-64 {\n    padding-right: 16rem;\n  }\n\n  .md\\:pb-64 {\n    padding-bottom: 16rem;\n  }\n\n  .md\\:pl-64 {\n    padding-left: 16rem;\n  }\n\n  .md\\:pt-px {\n    padding-top: 1px;\n  }\n\n  .md\\:pr-px {\n    padding-right: 1px;\n  }\n\n  .md\\:pb-px {\n    padding-bottom: 1px;\n  }\n\n  .md\\:pl-px {\n    padding-left: 1px;\n  }\n\n  .md\\:placeholder-transparent::-moz-placeholder {\n    color: transparent;\n  }\n\n  .md\\:placeholder-transparent:-ms-input-placeholder {\n    color: transparent;\n  }\n\n  .md\\:placeholder-transparent::placeholder {\n    color: transparent;\n  }\n\n  .md\\:placeholder-current::-moz-placeholder {\n    color: currentColor;\n  }\n\n  .md\\:placeholder-current:-ms-input-placeholder {\n    color: currentColor;\n  }\n\n  .md\\:placeholder-current::placeholder {\n    color: currentColor;\n  }\n\n  .md\\:placeholder-black::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-black:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-black::placeholder {\n    --placeholder-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-white::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-white:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-white::placeholder {\n    --placeholder-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-gray-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-red-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-orange-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-yellow-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-green-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-teal-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-blue-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-indigo-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-purple-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-pink-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-80::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-80:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-80::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-100::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-200::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-300::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-400::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-500::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-600::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-700::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-800::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-840::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-840:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-840::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-870::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-870:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-870::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-900::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-930::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-930:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-grayscale-930::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-primary::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-primary:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-primary::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:placeholder-background-main::-moz-placeholder {\n    color: var(--main-background);\n  }\n\n  .md\\:placeholder-background-main:-ms-input-placeholder {\n    color: var(--main-background);\n  }\n\n  .md\\:placeholder-background-main::placeholder {\n    color: var(--main-background);\n  }\n\n  .md\\:placeholder-background-secondary::-moz-placeholder {\n    color: var(--secondary-background);\n  }\n\n  .md\\:placeholder-background-secondary:-ms-input-placeholder {\n    color: var(--secondary-background);\n  }\n\n  .md\\:placeholder-background-secondary::placeholder {\n    color: var(--secondary-background);\n  }\n\n  .md\\:placeholder-foreground::-moz-placeholder {\n    color: var(--foreground);\n  }\n\n  .md\\:placeholder-foreground:-ms-input-placeholder {\n    color: var(--foreground);\n  }\n\n  .md\\:placeholder-foreground::placeholder {\n    color: var(--foreground);\n  }\n\n  .md\\:placeholder-panels-bg::-moz-placeholder {\n    color: var(--panels-background);\n  }\n\n  .md\\:placeholder-panels-bg:-ms-input-placeholder {\n    color: var(--panels-background);\n  }\n\n  .md\\:placeholder-panels-bg::placeholder {\n    color: var(--panels-background);\n  }\n\n  .md\\:focus\\:placeholder-transparent:focus::-moz-placeholder {\n    color: transparent;\n  }\n\n  .md\\:focus\\:placeholder-transparent:focus:-ms-input-placeholder {\n    color: transparent;\n  }\n\n  .md\\:focus\\:placeholder-transparent:focus::placeholder {\n    color: transparent;\n  }\n\n  .md\\:focus\\:placeholder-current:focus::-moz-placeholder {\n    color: currentColor;\n  }\n\n  .md\\:focus\\:placeholder-current:focus:-ms-input-placeholder {\n    color: currentColor;\n  }\n\n  .md\\:focus\\:placeholder-current:focus::placeholder {\n    color: currentColor;\n  }\n\n  .md\\:focus\\:placeholder-black:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-black:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-black:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-white:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-white:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-white:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-gray-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-red-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-orange-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-yellow-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-green-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-teal-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-blue-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-indigo-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-purple-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-pink-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-80:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-80:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-80:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-840:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-840:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-840:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-870:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-870:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-870:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-930:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-930:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-grayscale-930:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-primary:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-primary:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-primary:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n  }\n\n  .md\\:focus\\:placeholder-background-main:focus::-moz-placeholder {\n    color: var(--main-background);\n  }\n\n  .md\\:focus\\:placeholder-background-main:focus:-ms-input-placeholder {\n    color: var(--main-background);\n  }\n\n  .md\\:focus\\:placeholder-background-main:focus::placeholder {\n    color: var(--main-background);\n  }\n\n  .md\\:focus\\:placeholder-background-secondary:focus::-moz-placeholder {\n    color: var(--secondary-background);\n  }\n\n  .md\\:focus\\:placeholder-background-secondary:focus:-ms-input-placeholder {\n    color: var(--secondary-background);\n  }\n\n  .md\\:focus\\:placeholder-background-secondary:focus::placeholder {\n    color: var(--secondary-background);\n  }\n\n  .md\\:focus\\:placeholder-foreground:focus::-moz-placeholder {\n    color: var(--foreground);\n  }\n\n  .md\\:focus\\:placeholder-foreground:focus:-ms-input-placeholder {\n    color: var(--foreground);\n  }\n\n  .md\\:focus\\:placeholder-foreground:focus::placeholder {\n    color: var(--foreground);\n  }\n\n  .md\\:focus\\:placeholder-panels-bg:focus::-moz-placeholder {\n    color: var(--panels-background);\n  }\n\n  .md\\:focus\\:placeholder-panels-bg:focus:-ms-input-placeholder {\n    color: var(--panels-background);\n  }\n\n  .md\\:focus\\:placeholder-panels-bg:focus::placeholder {\n    color: var(--panels-background);\n  }\n\n  .md\\:placeholder-opacity-0::-moz-placeholder {\n    --placeholder-opacity: 0;\n  }\n\n  .md\\:placeholder-opacity-0:-ms-input-placeholder {\n    --placeholder-opacity: 0;\n  }\n\n  .md\\:placeholder-opacity-0::placeholder {\n    --placeholder-opacity: 0;\n  }\n\n  .md\\:placeholder-opacity-25::-moz-placeholder {\n    --placeholder-opacity: 0.25;\n  }\n\n  .md\\:placeholder-opacity-25:-ms-input-placeholder {\n    --placeholder-opacity: 0.25;\n  }\n\n  .md\\:placeholder-opacity-25::placeholder {\n    --placeholder-opacity: 0.25;\n  }\n\n  .md\\:placeholder-opacity-50::-moz-placeholder {\n    --placeholder-opacity: 0.5;\n  }\n\n  .md\\:placeholder-opacity-50:-ms-input-placeholder {\n    --placeholder-opacity: 0.5;\n  }\n\n  .md\\:placeholder-opacity-50::placeholder {\n    --placeholder-opacity: 0.5;\n  }\n\n  .md\\:placeholder-opacity-75::-moz-placeholder {\n    --placeholder-opacity: 0.75;\n  }\n\n  .md\\:placeholder-opacity-75:-ms-input-placeholder {\n    --placeholder-opacity: 0.75;\n  }\n\n  .md\\:placeholder-opacity-75::placeholder {\n    --placeholder-opacity: 0.75;\n  }\n\n  .md\\:placeholder-opacity-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n  }\n\n  .md\\:placeholder-opacity-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n  }\n\n  .md\\:placeholder-opacity-100::placeholder {\n    --placeholder-opacity: 1;\n  }\n\n  .md\\:focus\\:placeholder-opacity-0:focus::-moz-placeholder {\n    --placeholder-opacity: 0;\n  }\n\n  .md\\:focus\\:placeholder-opacity-0:focus:-ms-input-placeholder {\n    --placeholder-opacity: 0;\n  }\n\n  .md\\:focus\\:placeholder-opacity-0:focus::placeholder {\n    --placeholder-opacity: 0;\n  }\n\n  .md\\:focus\\:placeholder-opacity-25:focus::-moz-placeholder {\n    --placeholder-opacity: 0.25;\n  }\n\n  .md\\:focus\\:placeholder-opacity-25:focus:-ms-input-placeholder {\n    --placeholder-opacity: 0.25;\n  }\n\n  .md\\:focus\\:placeholder-opacity-25:focus::placeholder {\n    --placeholder-opacity: 0.25;\n  }\n\n  .md\\:focus\\:placeholder-opacity-50:focus::-moz-placeholder {\n    --placeholder-opacity: 0.5;\n  }\n\n  .md\\:focus\\:placeholder-opacity-50:focus:-ms-input-placeholder {\n    --placeholder-opacity: 0.5;\n  }\n\n  .md\\:focus\\:placeholder-opacity-50:focus::placeholder {\n    --placeholder-opacity: 0.5;\n  }\n\n  .md\\:focus\\:placeholder-opacity-75:focus::-moz-placeholder {\n    --placeholder-opacity: 0.75;\n  }\n\n  .md\\:focus\\:placeholder-opacity-75:focus:-ms-input-placeholder {\n    --placeholder-opacity: 0.75;\n  }\n\n  .md\\:focus\\:placeholder-opacity-75:focus::placeholder {\n    --placeholder-opacity: 0.75;\n  }\n\n  .md\\:focus\\:placeholder-opacity-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n  }\n\n  .md\\:focus\\:placeholder-opacity-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n  }\n\n  .md\\:focus\\:placeholder-opacity-100:focus::placeholder {\n    --placeholder-opacity: 1;\n  }\n\n  .md\\:pointer-events-none {\n    pointer-events: none;\n  }\n\n  .md\\:pointer-events-auto {\n    pointer-events: auto;\n  }\n\n  .md\\:static {\n    position: static;\n  }\n\n  .md\\:fixed {\n    position: fixed;\n  }\n\n  .md\\:absolute {\n    position: absolute;\n  }\n\n  .md\\:relative {\n    position: relative;\n  }\n\n  .md\\:sticky {\n    position: -webkit-sticky;\n    position: sticky;\n  }\n\n  .md\\:inset-0 {\n    top: 0;\n    right: 0;\n    bottom: 0;\n    left: 0;\n  }\n\n  .md\\:inset-auto {\n    top: auto;\n    right: auto;\n    bottom: auto;\n    left: auto;\n  }\n\n  .md\\:inset-y-0 {\n    top: 0;\n    bottom: 0;\n  }\n\n  .md\\:inset-x-0 {\n    right: 0;\n    left: 0;\n  }\n\n  .md\\:inset-y-auto {\n    top: auto;\n    bottom: auto;\n  }\n\n  .md\\:inset-x-auto {\n    right: auto;\n    left: auto;\n  }\n\n  .md\\:top-0 {\n    top: 0;\n  }\n\n  .md\\:right-0 {\n    right: 0;\n  }\n\n  .md\\:bottom-0 {\n    bottom: 0;\n  }\n\n  .md\\:left-0 {\n    left: 0;\n  }\n\n  .md\\:top-auto {\n    top: auto;\n  }\n\n  .md\\:right-auto {\n    right: auto;\n  }\n\n  .md\\:bottom-auto {\n    bottom: auto;\n  }\n\n  .md\\:left-auto {\n    left: auto;\n  }\n\n  .md\\:resize-none {\n    resize: none;\n  }\n\n  .md\\:resize-y {\n    resize: vertical;\n  }\n\n  .md\\:resize-x {\n    resize: horizontal;\n  }\n\n  .md\\:resize {\n    resize: both;\n  }\n\n  .md\\:shadow-xs {\n    box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.05);\n  }\n\n  .md\\:shadow-sm {\n    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);\n  }\n\n  .md\\:shadow {\n    box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);\n  }\n\n  .md\\:shadow-md {\n    box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);\n  }\n\n  .md\\:shadow-lg {\n    box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);\n  }\n\n  .md\\:shadow-xl {\n    box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04);\n  }\n\n  .md\\:shadow-2xl {\n    box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);\n  }\n\n  .md\\:shadow-inner {\n    box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);\n  }\n\n  .md\\:shadow-outline {\n    box-shadow: 0 0 0 3px rgba(66, 153, 225, 0.5);\n  }\n\n  .md\\:shadow-none {\n    box-shadow: none;\n  }\n\n  .md\\:hover\\:shadow-xs:hover {\n    box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.05);\n  }\n\n  .md\\:hover\\:shadow-sm:hover {\n    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);\n  }\n\n  .md\\:hover\\:shadow:hover {\n    box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);\n  }\n\n  .md\\:hover\\:shadow-md:hover {\n    box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);\n  }\n\n  .md\\:hover\\:shadow-lg:hover {\n    box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);\n  }\n\n  .md\\:hover\\:shadow-xl:hover {\n    box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04);\n  }\n\n  .md\\:hover\\:shadow-2xl:hover {\n    box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);\n  }\n\n  .md\\:hover\\:shadow-inner:hover {\n    box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);\n  }\n\n  .md\\:hover\\:shadow-outline:hover {\n    box-shadow: 0 0 0 3px rgba(66, 153, 225, 0.5);\n  }\n\n  .md\\:hover\\:shadow-none:hover {\n    box-shadow: none;\n  }\n\n  .md\\:focus\\:shadow-xs:focus {\n    box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.05);\n  }\n\n  .md\\:focus\\:shadow-sm:focus {\n    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);\n  }\n\n  .md\\:focus\\:shadow:focus {\n    box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);\n  }\n\n  .md\\:focus\\:shadow-md:focus {\n    box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);\n  }\n\n  .md\\:focus\\:shadow-lg:focus {\n    box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);\n  }\n\n  .md\\:focus\\:shadow-xl:focus {\n    box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04);\n  }\n\n  .md\\:focus\\:shadow-2xl:focus {\n    box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);\n  }\n\n  .md\\:focus\\:shadow-inner:focus {\n    box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);\n  }\n\n  .md\\:focus\\:shadow-outline:focus {\n    box-shadow: 0 0 0 3px rgba(66, 153, 225, 0.5);\n  }\n\n  .md\\:focus\\:shadow-none:focus {\n    box-shadow: none;\n  }\n\n  .md\\:fill-current {\n    fill: currentColor;\n  }\n\n  .md\\:stroke-current {\n    stroke: currentColor;\n  }\n\n  .md\\:stroke-0 {\n    stroke-width: 0;\n  }\n\n  .md\\:stroke-1 {\n    stroke-width: 1;\n  }\n\n  .md\\:stroke-2 {\n    stroke-width: 2;\n  }\n\n  .md\\:table-auto {\n    table-layout: auto;\n  }\n\n  .md\\:table-fixed {\n    table-layout: fixed;\n  }\n\n  .md\\:text-left {\n    text-align: left;\n  }\n\n  .md\\:text-center {\n    text-align: center;\n  }\n\n  .md\\:text-right {\n    text-align: right;\n  }\n\n  .md\\:text-justify {\n    text-align: justify;\n  }\n\n  .md\\:text-transparent {\n    color: transparent;\n  }\n\n  .md\\:text-current {\n    color: currentColor;\n  }\n\n  .md\\:text-black {\n    --text-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--text-opacity));\n  }\n\n  .md\\:text-white {\n    --text-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--text-opacity));\n  }\n\n  .md\\:text-gray-100 {\n    --text-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--text-opacity));\n  }\n\n  .md\\:text-gray-200 {\n    --text-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--text-opacity));\n  }\n\n  .md\\:text-gray-300 {\n    --text-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--text-opacity));\n  }\n\n  .md\\:text-gray-400 {\n    --text-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--text-opacity));\n  }\n\n  .md\\:text-gray-500 {\n    --text-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--text-opacity));\n  }\n\n  .md\\:text-gray-600 {\n    --text-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--text-opacity));\n  }\n\n  .md\\:text-gray-700 {\n    --text-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--text-opacity));\n  }\n\n  .md\\:text-gray-800 {\n    --text-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--text-opacity));\n  }\n\n  .md\\:text-gray-900 {\n    --text-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--text-opacity));\n  }\n\n  .md\\:text-red-100 {\n    --text-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--text-opacity));\n  }\n\n  .md\\:text-red-200 {\n    --text-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--text-opacity));\n  }\n\n  .md\\:text-red-300 {\n    --text-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--text-opacity));\n  }\n\n  .md\\:text-red-400 {\n    --text-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--text-opacity));\n  }\n\n  .md\\:text-red-500 {\n    --text-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--text-opacity));\n  }\n\n  .md\\:text-red-600 {\n    --text-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--text-opacity));\n  }\n\n  .md\\:text-red-700 {\n    --text-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--text-opacity));\n  }\n\n  .md\\:text-red-800 {\n    --text-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--text-opacity));\n  }\n\n  .md\\:text-red-900 {\n    --text-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--text-opacity));\n  }\n\n  .md\\:text-orange-100 {\n    --text-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--text-opacity));\n  }\n\n  .md\\:text-orange-200 {\n    --text-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--text-opacity));\n  }\n\n  .md\\:text-orange-300 {\n    --text-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--text-opacity));\n  }\n\n  .md\\:text-orange-400 {\n    --text-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--text-opacity));\n  }\n\n  .md\\:text-orange-500 {\n    --text-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--text-opacity));\n  }\n\n  .md\\:text-orange-600 {\n    --text-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--text-opacity));\n  }\n\n  .md\\:text-orange-700 {\n    --text-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--text-opacity));\n  }\n\n  .md\\:text-orange-800 {\n    --text-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--text-opacity));\n  }\n\n  .md\\:text-orange-900 {\n    --text-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--text-opacity));\n  }\n\n  .md\\:text-yellow-100 {\n    --text-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--text-opacity));\n  }\n\n  .md\\:text-yellow-200 {\n    --text-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--text-opacity));\n  }\n\n  .md\\:text-yellow-300 {\n    --text-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--text-opacity));\n  }\n\n  .md\\:text-yellow-400 {\n    --text-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--text-opacity));\n  }\n\n  .md\\:text-yellow-500 {\n    --text-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--text-opacity));\n  }\n\n  .md\\:text-yellow-600 {\n    --text-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--text-opacity));\n  }\n\n  .md\\:text-yellow-700 {\n    --text-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--text-opacity));\n  }\n\n  .md\\:text-yellow-800 {\n    --text-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--text-opacity));\n  }\n\n  .md\\:text-yellow-900 {\n    --text-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--text-opacity));\n  }\n\n  .md\\:text-green-100 {\n    --text-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--text-opacity));\n  }\n\n  .md\\:text-green-200 {\n    --text-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--text-opacity));\n  }\n\n  .md\\:text-green-300 {\n    --text-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--text-opacity));\n  }\n\n  .md\\:text-green-400 {\n    --text-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--text-opacity));\n  }\n\n  .md\\:text-green-500 {\n    --text-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--text-opacity));\n  }\n\n  .md\\:text-green-600 {\n    --text-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--text-opacity));\n  }\n\n  .md\\:text-green-700 {\n    --text-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--text-opacity));\n  }\n\n  .md\\:text-green-800 {\n    --text-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--text-opacity));\n  }\n\n  .md\\:text-green-900 {\n    --text-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--text-opacity));\n  }\n\n  .md\\:text-teal-100 {\n    --text-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--text-opacity));\n  }\n\n  .md\\:text-teal-200 {\n    --text-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--text-opacity));\n  }\n\n  .md\\:text-teal-300 {\n    --text-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--text-opacity));\n  }\n\n  .md\\:text-teal-400 {\n    --text-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--text-opacity));\n  }\n\n  .md\\:text-teal-500 {\n    --text-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--text-opacity));\n  }\n\n  .md\\:text-teal-600 {\n    --text-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--text-opacity));\n  }\n\n  .md\\:text-teal-700 {\n    --text-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--text-opacity));\n  }\n\n  .md\\:text-teal-800 {\n    --text-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--text-opacity));\n  }\n\n  .md\\:text-teal-900 {\n    --text-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--text-opacity));\n  }\n\n  .md\\:text-blue-100 {\n    --text-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--text-opacity));\n  }\n\n  .md\\:text-blue-200 {\n    --text-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--text-opacity));\n  }\n\n  .md\\:text-blue-300 {\n    --text-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--text-opacity));\n  }\n\n  .md\\:text-blue-400 {\n    --text-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--text-opacity));\n  }\n\n  .md\\:text-blue-500 {\n    --text-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--text-opacity));\n  }\n\n  .md\\:text-blue-600 {\n    --text-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--text-opacity));\n  }\n\n  .md\\:text-blue-700 {\n    --text-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--text-opacity));\n  }\n\n  .md\\:text-blue-800 {\n    --text-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--text-opacity));\n  }\n\n  .md\\:text-blue-900 {\n    --text-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--text-opacity));\n  }\n\n  .md\\:text-indigo-100 {\n    --text-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--text-opacity));\n  }\n\n  .md\\:text-indigo-200 {\n    --text-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--text-opacity));\n  }\n\n  .md\\:text-indigo-300 {\n    --text-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--text-opacity));\n  }\n\n  .md\\:text-indigo-400 {\n    --text-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--text-opacity));\n  }\n\n  .md\\:text-indigo-500 {\n    --text-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--text-opacity));\n  }\n\n  .md\\:text-indigo-600 {\n    --text-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--text-opacity));\n  }\n\n  .md\\:text-indigo-700 {\n    --text-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--text-opacity));\n  }\n\n  .md\\:text-indigo-800 {\n    --text-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--text-opacity));\n  }\n\n  .md\\:text-indigo-900 {\n    --text-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--text-opacity));\n  }\n\n  .md\\:text-purple-100 {\n    --text-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--text-opacity));\n  }\n\n  .md\\:text-purple-200 {\n    --text-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--text-opacity));\n  }\n\n  .md\\:text-purple-300 {\n    --text-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--text-opacity));\n  }\n\n  .md\\:text-purple-400 {\n    --text-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--text-opacity));\n  }\n\n  .md\\:text-purple-500 {\n    --text-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--text-opacity));\n  }\n\n  .md\\:text-purple-600 {\n    --text-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--text-opacity));\n  }\n\n  .md\\:text-purple-700 {\n    --text-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--text-opacity));\n  }\n\n  .md\\:text-purple-800 {\n    --text-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--text-opacity));\n  }\n\n  .md\\:text-purple-900 {\n    --text-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--text-opacity));\n  }\n\n  .md\\:text-pink-100 {\n    --text-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--text-opacity));\n  }\n\n  .md\\:text-pink-200 {\n    --text-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--text-opacity));\n  }\n\n  .md\\:text-pink-300 {\n    --text-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--text-opacity));\n  }\n\n  .md\\:text-pink-400 {\n    --text-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--text-opacity));\n  }\n\n  .md\\:text-pink-500 {\n    --text-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--text-opacity));\n  }\n\n  .md\\:text-pink-600 {\n    --text-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--text-opacity));\n  }\n\n  .md\\:text-pink-700 {\n    --text-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--text-opacity));\n  }\n\n  .md\\:text-pink-800 {\n    --text-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--text-opacity));\n  }\n\n  .md\\:text-pink-900 {\n    --text-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--text-opacity));\n  }\n\n  .md\\:text-grayscale-80 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--text-opacity));\n  }\n\n  .md\\:text-grayscale-100 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--text-opacity));\n  }\n\n  .md\\:text-grayscale-200 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--text-opacity));\n  }\n\n  .md\\:text-grayscale-300 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--text-opacity));\n  }\n\n  .md\\:text-grayscale-400 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--text-opacity));\n  }\n\n  .md\\:text-grayscale-500 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--text-opacity));\n  }\n\n  .md\\:text-grayscale-600 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--text-opacity));\n  }\n\n  .md\\:text-grayscale-700 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--text-opacity));\n  }\n\n  .md\\:text-grayscale-800 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--text-opacity));\n  }\n\n  .md\\:text-grayscale-840 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--text-opacity));\n  }\n\n  .md\\:text-grayscale-870 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--text-opacity));\n  }\n\n  .md\\:text-grayscale-900 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--text-opacity));\n  }\n\n  .md\\:text-grayscale-930 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--text-opacity));\n  }\n\n  .md\\:text-primary {\n    --text-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--text-opacity));\n  }\n\n  .md\\:text-background-main {\n    color: var(--main-background);\n  }\n\n  .md\\:text-background-secondary {\n    color: var(--secondary-background);\n  }\n\n  .md\\:text-foreground {\n    color: var(--foreground);\n  }\n\n  .md\\:text-panels-bg {\n    color: var(--panels-background);\n  }\n\n  .md\\:hover\\:text-transparent:hover {\n    color: transparent;\n  }\n\n  .md\\:hover\\:text-current:hover {\n    color: currentColor;\n  }\n\n  .md\\:hover\\:text-black:hover {\n    --text-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-white:hover {\n    --text-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-gray-100:hover {\n    --text-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-gray-200:hover {\n    --text-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-gray-300:hover {\n    --text-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-gray-400:hover {\n    --text-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-gray-500:hover {\n    --text-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-gray-600:hover {\n    --text-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-gray-700:hover {\n    --text-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-gray-800:hover {\n    --text-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-gray-900:hover {\n    --text-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-red-100:hover {\n    --text-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-red-200:hover {\n    --text-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-red-300:hover {\n    --text-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-red-400:hover {\n    --text-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-red-500:hover {\n    --text-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-red-600:hover {\n    --text-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-red-700:hover {\n    --text-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-red-800:hover {\n    --text-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-red-900:hover {\n    --text-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-orange-100:hover {\n    --text-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-orange-200:hover {\n    --text-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-orange-300:hover {\n    --text-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-orange-400:hover {\n    --text-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-orange-500:hover {\n    --text-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-orange-600:hover {\n    --text-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-orange-700:hover {\n    --text-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-orange-800:hover {\n    --text-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-orange-900:hover {\n    --text-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-yellow-100:hover {\n    --text-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-yellow-200:hover {\n    --text-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-yellow-300:hover {\n    --text-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-yellow-400:hover {\n    --text-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-yellow-500:hover {\n    --text-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-yellow-600:hover {\n    --text-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-yellow-700:hover {\n    --text-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-yellow-800:hover {\n    --text-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-yellow-900:hover {\n    --text-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-green-100:hover {\n    --text-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-green-200:hover {\n    --text-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-green-300:hover {\n    --text-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-green-400:hover {\n    --text-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-green-500:hover {\n    --text-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-green-600:hover {\n    --text-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-green-700:hover {\n    --text-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-green-800:hover {\n    --text-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-green-900:hover {\n    --text-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-teal-100:hover {\n    --text-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-teal-200:hover {\n    --text-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-teal-300:hover {\n    --text-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-teal-400:hover {\n    --text-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-teal-500:hover {\n    --text-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-teal-600:hover {\n    --text-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-teal-700:hover {\n    --text-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-teal-800:hover {\n    --text-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-teal-900:hover {\n    --text-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-blue-100:hover {\n    --text-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-blue-200:hover {\n    --text-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-blue-300:hover {\n    --text-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-blue-400:hover {\n    --text-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-blue-500:hover {\n    --text-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-blue-600:hover {\n    --text-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-blue-700:hover {\n    --text-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-blue-800:hover {\n    --text-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-blue-900:hover {\n    --text-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-indigo-100:hover {\n    --text-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-indigo-200:hover {\n    --text-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-indigo-300:hover {\n    --text-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-indigo-400:hover {\n    --text-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-indigo-500:hover {\n    --text-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-indigo-600:hover {\n    --text-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-indigo-700:hover {\n    --text-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-indigo-800:hover {\n    --text-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-indigo-900:hover {\n    --text-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-purple-100:hover {\n    --text-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-purple-200:hover {\n    --text-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-purple-300:hover {\n    --text-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-purple-400:hover {\n    --text-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-purple-500:hover {\n    --text-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-purple-600:hover {\n    --text-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-purple-700:hover {\n    --text-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-purple-800:hover {\n    --text-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-purple-900:hover {\n    --text-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-pink-100:hover {\n    --text-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-pink-200:hover {\n    --text-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-pink-300:hover {\n    --text-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-pink-400:hover {\n    --text-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-pink-500:hover {\n    --text-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-pink-600:hover {\n    --text-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-pink-700:hover {\n    --text-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-pink-800:hover {\n    --text-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-pink-900:hover {\n    --text-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-grayscale-80:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-grayscale-100:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-grayscale-200:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-grayscale-300:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-grayscale-400:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-grayscale-500:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-grayscale-600:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-grayscale-700:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-grayscale-800:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-grayscale-840:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-grayscale-870:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-grayscale-900:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-grayscale-930:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-primary:hover {\n    --text-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--text-opacity));\n  }\n\n  .md\\:hover\\:text-background-main:hover {\n    color: var(--main-background);\n  }\n\n  .md\\:hover\\:text-background-secondary:hover {\n    color: var(--secondary-background);\n  }\n\n  .md\\:hover\\:text-foreground:hover {\n    color: var(--foreground);\n  }\n\n  .md\\:hover\\:text-panels-bg:hover {\n    color: var(--panels-background);\n  }\n\n  .md\\:focus\\:text-transparent:focus {\n    color: transparent;\n  }\n\n  .md\\:focus\\:text-current:focus {\n    color: currentColor;\n  }\n\n  .md\\:focus\\:text-black:focus {\n    --text-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-white:focus {\n    --text-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-gray-100:focus {\n    --text-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-gray-200:focus {\n    --text-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-gray-300:focus {\n    --text-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-gray-400:focus {\n    --text-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-gray-500:focus {\n    --text-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-gray-600:focus {\n    --text-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-gray-700:focus {\n    --text-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-gray-800:focus {\n    --text-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-gray-900:focus {\n    --text-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-red-100:focus {\n    --text-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-red-200:focus {\n    --text-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-red-300:focus {\n    --text-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-red-400:focus {\n    --text-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-red-500:focus {\n    --text-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-red-600:focus {\n    --text-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-red-700:focus {\n    --text-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-red-800:focus {\n    --text-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-red-900:focus {\n    --text-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-orange-100:focus {\n    --text-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-orange-200:focus {\n    --text-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-orange-300:focus {\n    --text-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-orange-400:focus {\n    --text-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-orange-500:focus {\n    --text-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-orange-600:focus {\n    --text-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-orange-700:focus {\n    --text-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-orange-800:focus {\n    --text-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-orange-900:focus {\n    --text-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-yellow-100:focus {\n    --text-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-yellow-200:focus {\n    --text-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-yellow-300:focus {\n    --text-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-yellow-400:focus {\n    --text-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-yellow-500:focus {\n    --text-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-yellow-600:focus {\n    --text-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-yellow-700:focus {\n    --text-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-yellow-800:focus {\n    --text-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-yellow-900:focus {\n    --text-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-green-100:focus {\n    --text-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-green-200:focus {\n    --text-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-green-300:focus {\n    --text-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-green-400:focus {\n    --text-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-green-500:focus {\n    --text-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-green-600:focus {\n    --text-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-green-700:focus {\n    --text-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-green-800:focus {\n    --text-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-green-900:focus {\n    --text-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-teal-100:focus {\n    --text-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-teal-200:focus {\n    --text-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-teal-300:focus {\n    --text-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-teal-400:focus {\n    --text-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-teal-500:focus {\n    --text-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-teal-600:focus {\n    --text-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-teal-700:focus {\n    --text-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-teal-800:focus {\n    --text-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-teal-900:focus {\n    --text-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-blue-100:focus {\n    --text-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-blue-200:focus {\n    --text-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-blue-300:focus {\n    --text-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-blue-400:focus {\n    --text-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-blue-500:focus {\n    --text-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-blue-600:focus {\n    --text-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-blue-700:focus {\n    --text-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-blue-800:focus {\n    --text-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-blue-900:focus {\n    --text-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-indigo-100:focus {\n    --text-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-indigo-200:focus {\n    --text-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-indigo-300:focus {\n    --text-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-indigo-400:focus {\n    --text-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-indigo-500:focus {\n    --text-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-indigo-600:focus {\n    --text-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-indigo-700:focus {\n    --text-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-indigo-800:focus {\n    --text-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-indigo-900:focus {\n    --text-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-purple-100:focus {\n    --text-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-purple-200:focus {\n    --text-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-purple-300:focus {\n    --text-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-purple-400:focus {\n    --text-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-purple-500:focus {\n    --text-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-purple-600:focus {\n    --text-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-purple-700:focus {\n    --text-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-purple-800:focus {\n    --text-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-purple-900:focus {\n    --text-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-pink-100:focus {\n    --text-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-pink-200:focus {\n    --text-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-pink-300:focus {\n    --text-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-pink-400:focus {\n    --text-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-pink-500:focus {\n    --text-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-pink-600:focus {\n    --text-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-pink-700:focus {\n    --text-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-pink-800:focus {\n    --text-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-pink-900:focus {\n    --text-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-grayscale-80:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-grayscale-100:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-grayscale-200:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-grayscale-300:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-grayscale-400:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-grayscale-500:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-grayscale-600:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-grayscale-700:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-grayscale-800:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-grayscale-840:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-grayscale-870:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-grayscale-900:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-grayscale-930:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-primary:focus {\n    --text-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--text-opacity));\n  }\n\n  .md\\:focus\\:text-background-main:focus {\n    color: var(--main-background);\n  }\n\n  .md\\:focus\\:text-background-secondary:focus {\n    color: var(--secondary-background);\n  }\n\n  .md\\:focus\\:text-foreground:focus {\n    color: var(--foreground);\n  }\n\n  .md\\:focus\\:text-panels-bg:focus {\n    color: var(--panels-background);\n  }\n\n  .group:hover .md\\:group-hover\\:text-transparent {\n    color: transparent;\n  }\n\n  .group:hover .md\\:group-hover\\:text-current {\n    color: currentColor;\n  }\n\n  .group:hover .md\\:group-hover\\:text-black {\n    --text-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-white {\n    --text-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-gray-100 {\n    --text-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-gray-200 {\n    --text-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-gray-300 {\n    --text-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-gray-400 {\n    --text-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-gray-500 {\n    --text-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-gray-600 {\n    --text-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-gray-700 {\n    --text-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-gray-800 {\n    --text-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-gray-900 {\n    --text-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-red-100 {\n    --text-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-red-200 {\n    --text-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-red-300 {\n    --text-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-red-400 {\n    --text-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-red-500 {\n    --text-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-red-600 {\n    --text-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-red-700 {\n    --text-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-red-800 {\n    --text-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-red-900 {\n    --text-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-orange-100 {\n    --text-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-orange-200 {\n    --text-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-orange-300 {\n    --text-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-orange-400 {\n    --text-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-orange-500 {\n    --text-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-orange-600 {\n    --text-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-orange-700 {\n    --text-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-orange-800 {\n    --text-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-orange-900 {\n    --text-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-yellow-100 {\n    --text-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-yellow-200 {\n    --text-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-yellow-300 {\n    --text-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-yellow-400 {\n    --text-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-yellow-500 {\n    --text-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-yellow-600 {\n    --text-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-yellow-700 {\n    --text-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-yellow-800 {\n    --text-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-yellow-900 {\n    --text-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-green-100 {\n    --text-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-green-200 {\n    --text-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-green-300 {\n    --text-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-green-400 {\n    --text-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-green-500 {\n    --text-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-green-600 {\n    --text-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-green-700 {\n    --text-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-green-800 {\n    --text-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-green-900 {\n    --text-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-teal-100 {\n    --text-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-teal-200 {\n    --text-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-teal-300 {\n    --text-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-teal-400 {\n    --text-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-teal-500 {\n    --text-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-teal-600 {\n    --text-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-teal-700 {\n    --text-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-teal-800 {\n    --text-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-teal-900 {\n    --text-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-blue-100 {\n    --text-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-blue-200 {\n    --text-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-blue-300 {\n    --text-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-blue-400 {\n    --text-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-blue-500 {\n    --text-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-blue-600 {\n    --text-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-blue-700 {\n    --text-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-blue-800 {\n    --text-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-blue-900 {\n    --text-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-indigo-100 {\n    --text-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-indigo-200 {\n    --text-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-indigo-300 {\n    --text-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-indigo-400 {\n    --text-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-indigo-500 {\n    --text-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-indigo-600 {\n    --text-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-indigo-700 {\n    --text-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-indigo-800 {\n    --text-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-indigo-900 {\n    --text-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-purple-100 {\n    --text-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-purple-200 {\n    --text-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-purple-300 {\n    --text-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-purple-400 {\n    --text-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-purple-500 {\n    --text-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-purple-600 {\n    --text-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-purple-700 {\n    --text-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-purple-800 {\n    --text-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-purple-900 {\n    --text-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-pink-100 {\n    --text-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-pink-200 {\n    --text-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-pink-300 {\n    --text-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-pink-400 {\n    --text-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-pink-500 {\n    --text-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-pink-600 {\n    --text-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-pink-700 {\n    --text-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-pink-800 {\n    --text-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-pink-900 {\n    --text-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-grayscale-80 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-grayscale-100 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-grayscale-200 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-grayscale-300 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-grayscale-400 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-grayscale-500 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-grayscale-600 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-grayscale-700 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-grayscale-800 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-grayscale-840 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-grayscale-870 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-grayscale-900 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-grayscale-930 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-primary {\n    --text-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--text-opacity));\n  }\n\n  .group:hover .md\\:group-hover\\:text-background-main {\n    color: var(--main-background);\n  }\n\n  .group:hover .md\\:group-hover\\:text-background-secondary {\n    color: var(--secondary-background);\n  }\n\n  .group:hover .md\\:group-hover\\:text-foreground {\n    color: var(--foreground);\n  }\n\n  .group:hover .md\\:group-hover\\:text-panels-bg {\n    color: var(--panels-background);\n  }\n\n  .md\\:text-opacity-0 {\n    --text-opacity: 0;\n  }\n\n  .md\\:text-opacity-25 {\n    --text-opacity: 0.25;\n  }\n\n  .md\\:text-opacity-50 {\n    --text-opacity: 0.5;\n  }\n\n  .md\\:text-opacity-75 {\n    --text-opacity: 0.75;\n  }\n\n  .md\\:text-opacity-100 {\n    --text-opacity: 1;\n  }\n\n  .md\\:hover\\:text-opacity-0:hover {\n    --text-opacity: 0;\n  }\n\n  .md\\:hover\\:text-opacity-25:hover {\n    --text-opacity: 0.25;\n  }\n\n  .md\\:hover\\:text-opacity-50:hover {\n    --text-opacity: 0.5;\n  }\n\n  .md\\:hover\\:text-opacity-75:hover {\n    --text-opacity: 0.75;\n  }\n\n  .md\\:hover\\:text-opacity-100:hover {\n    --text-opacity: 1;\n  }\n\n  .md\\:focus\\:text-opacity-0:focus {\n    --text-opacity: 0;\n  }\n\n  .md\\:focus\\:text-opacity-25:focus {\n    --text-opacity: 0.25;\n  }\n\n  .md\\:focus\\:text-opacity-50:focus {\n    --text-opacity: 0.5;\n  }\n\n  .md\\:focus\\:text-opacity-75:focus {\n    --text-opacity: 0.75;\n  }\n\n  .md\\:focus\\:text-opacity-100:focus {\n    --text-opacity: 1;\n  }\n\n  .md\\:italic {\n    font-style: italic;\n  }\n\n  .md\\:not-italic {\n    font-style: normal;\n  }\n\n  .md\\:uppercase {\n    text-transform: uppercase;\n  }\n\n  .md\\:lowercase {\n    text-transform: lowercase;\n  }\n\n  .md\\:capitalize {\n    text-transform: capitalize;\n  }\n\n  .md\\:normal-case {\n    text-transform: none;\n  }\n\n  .md\\:underline {\n    text-decoration: underline;\n  }\n\n  .md\\:line-through {\n    text-decoration: line-through;\n  }\n\n  .md\\:no-underline {\n    text-decoration: none;\n  }\n\n  .md\\:hover\\:underline:hover {\n    text-decoration: underline;\n  }\n\n  .md\\:hover\\:line-through:hover {\n    text-decoration: line-through;\n  }\n\n  .md\\:hover\\:no-underline:hover {\n    text-decoration: none;\n  }\n\n  .md\\:focus\\:underline:focus {\n    text-decoration: underline;\n  }\n\n  .md\\:focus\\:line-through:focus {\n    text-decoration: line-through;\n  }\n\n  .md\\:focus\\:no-underline:focus {\n    text-decoration: none;\n  }\n\n  .md\\:antialiased {\n    -webkit-font-smoothing: antialiased;\n    -moz-osx-font-smoothing: grayscale;\n  }\n\n  .md\\:subpixel-antialiased {\n    -webkit-font-smoothing: auto;\n    -moz-osx-font-smoothing: auto;\n  }\n\n  .md\\:ordinal, .md\\:slashed-zero, .md\\:lining-nums, .md\\:oldstyle-nums, .md\\:proportional-nums, .md\\:tabular-nums, .md\\:diagonal-fractions, .md\\:stacked-fractions {\n    --font-variant-numeric-ordinal: var(--tailwind-empty,/*!*/ /*!*/);\n    --font-variant-numeric-slashed-zero: var(--tailwind-empty,/*!*/ /*!*/);\n    --font-variant-numeric-figure: var(--tailwind-empty,/*!*/ /*!*/);\n    --font-variant-numeric-spacing: var(--tailwind-empty,/*!*/ /*!*/);\n    --font-variant-numeric-fraction: var(--tailwind-empty,/*!*/ /*!*/);\n    font-variant-numeric: var(--font-variant-numeric-ordinal) var(--font-variant-numeric-slashed-zero) var(--font-variant-numeric-figure) var(--font-variant-numeric-spacing) var(--font-variant-numeric-fraction);\n  }\n\n  .md\\:normal-nums {\n    font-variant-numeric: normal;\n  }\n\n  .md\\:ordinal {\n    --font-variant-numeric-ordinal: ordinal;\n  }\n\n  .md\\:slashed-zero {\n    --font-variant-numeric-slashed-zero: slashed-zero;\n  }\n\n  .md\\:lining-nums {\n    --font-variant-numeric-figure: lining-nums;\n  }\n\n  .md\\:oldstyle-nums {\n    --font-variant-numeric-figure: oldstyle-nums;\n  }\n\n  .md\\:proportional-nums {\n    --font-variant-numeric-spacing: proportional-nums;\n  }\n\n  .md\\:tabular-nums {\n    --font-variant-numeric-spacing: tabular-nums;\n  }\n\n  .md\\:diagonal-fractions {\n    --font-variant-numeric-fraction: diagonal-fractions;\n  }\n\n  .md\\:stacked-fractions {\n    --font-variant-numeric-fraction: stacked-fractions;\n  }\n\n  .md\\:tracking-tighter {\n    letter-spacing: -0.05em;\n  }\n\n  .md\\:tracking-tight {\n    letter-spacing: -0.025em;\n  }\n\n  .md\\:tracking-normal {\n    letter-spacing: 0;\n  }\n\n  .md\\:tracking-wide {\n    letter-spacing: 0.025em;\n  }\n\n  .md\\:tracking-wider {\n    letter-spacing: 0.05em;\n  }\n\n  .md\\:tracking-widest {\n    letter-spacing: 0.1em;\n  }\n\n  .md\\:select-none {\n    -webkit-user-select: none;\n       -moz-user-select: none;\n        -ms-user-select: none;\n            user-select: none;\n  }\n\n  .md\\:select-text {\n    -webkit-user-select: text;\n       -moz-user-select: text;\n        -ms-user-select: text;\n            user-select: text;\n  }\n\n  .md\\:select-all {\n    -webkit-user-select: all;\n       -moz-user-select: all;\n        -ms-user-select: all;\n            user-select: all;\n  }\n\n  .md\\:select-auto {\n    -webkit-user-select: auto;\n       -moz-user-select: auto;\n        -ms-user-select: auto;\n            user-select: auto;\n  }\n\n  .md\\:align-baseline {\n    vertical-align: baseline;\n  }\n\n  .md\\:align-top {\n    vertical-align: top;\n  }\n\n  .md\\:align-middle {\n    vertical-align: middle;\n  }\n\n  .md\\:align-bottom {\n    vertical-align: bottom;\n  }\n\n  .md\\:align-text-top {\n    vertical-align: text-top;\n  }\n\n  .md\\:align-text-bottom {\n    vertical-align: text-bottom;\n  }\n\n  .md\\:visible {\n    visibility: visible;\n  }\n\n  .md\\:invisible {\n    visibility: hidden;\n  }\n\n  .md\\:whitespace-normal {\n    white-space: normal;\n  }\n\n  .md\\:whitespace-no-wrap {\n    white-space: nowrap;\n  }\n\n  .md\\:whitespace-pre {\n    white-space: pre;\n  }\n\n  .md\\:whitespace-pre-line {\n    white-space: pre-line;\n  }\n\n  .md\\:whitespace-pre-wrap {\n    white-space: pre-wrap;\n  }\n\n  .md\\:break-normal {\n    word-wrap: normal;\n    overflow-wrap: normal;\n    word-break: normal;\n  }\n\n  .md\\:break-words {\n    word-wrap: break-word;\n    overflow-wrap: break-word;\n  }\n\n  .md\\:break-all {\n    word-break: break-all;\n  }\n\n  .md\\:truncate {\n    overflow: hidden;\n    text-overflow: ellipsis;\n    white-space: nowrap;\n  }\n\n  .md\\:w-0 {\n    width: 0;\n  }\n\n  .md\\:w-1 {\n    width: 0.25rem;\n  }\n\n  .md\\:w-2 {\n    width: 0.5rem;\n  }\n\n  .md\\:w-3 {\n    width: 0.75rem;\n  }\n\n  .md\\:w-4 {\n    width: 1rem;\n  }\n\n  .md\\:w-5 {\n    width: 1.25rem;\n  }\n\n  .md\\:w-6 {\n    width: 1.5rem;\n  }\n\n  .md\\:w-8 {\n    width: 2rem;\n  }\n\n  .md\\:w-10 {\n    width: 2.5rem;\n  }\n\n  .md\\:w-12 {\n    width: 3rem;\n  }\n\n  .md\\:w-16 {\n    width: 4rem;\n  }\n\n  .md\\:w-20 {\n    width: 5rem;\n  }\n\n  .md\\:w-24 {\n    width: 6rem;\n  }\n\n  .md\\:w-32 {\n    width: 8rem;\n  }\n\n  .md\\:w-40 {\n    width: 10rem;\n  }\n\n  .md\\:w-48 {\n    width: 12rem;\n  }\n\n  .md\\:w-56 {\n    width: 14rem;\n  }\n\n  .md\\:w-64 {\n    width: 16rem;\n  }\n\n  .md\\:w-auto {\n    width: auto;\n  }\n\n  .md\\:w-px {\n    width: 1px;\n  }\n\n  .md\\:w-1\\/2 {\n    width: 50%;\n  }\n\n  .md\\:w-1\\/3 {\n    width: 33.333333%;\n  }\n\n  .md\\:w-2\\/3 {\n    width: 66.666667%;\n  }\n\n  .md\\:w-1\\/4 {\n    width: 25%;\n  }\n\n  .md\\:w-2\\/4 {\n    width: 50%;\n  }\n\n  .md\\:w-3\\/4 {\n    width: 75%;\n  }\n\n  .md\\:w-1\\/5 {\n    width: 20%;\n  }\n\n  .md\\:w-2\\/5 {\n    width: 40%;\n  }\n\n  .md\\:w-3\\/5 {\n    width: 60%;\n  }\n\n  .md\\:w-4\\/5 {\n    width: 80%;\n  }\n\n  .md\\:w-1\\/6 {\n    width: 16.666667%;\n  }\n\n  .md\\:w-2\\/6 {\n    width: 33.333333%;\n  }\n\n  .md\\:w-3\\/6 {\n    width: 50%;\n  }\n\n  .md\\:w-4\\/6 {\n    width: 66.666667%;\n  }\n\n  .md\\:w-5\\/6 {\n    width: 83.333333%;\n  }\n\n  .md\\:w-1\\/12 {\n    width: 8.333333%;\n  }\n\n  .md\\:w-2\\/12 {\n    width: 16.666667%;\n  }\n\n  .md\\:w-3\\/12 {\n    width: 25%;\n  }\n\n  .md\\:w-4\\/12 {\n    width: 33.333333%;\n  }\n\n  .md\\:w-5\\/12 {\n    width: 41.666667%;\n  }\n\n  .md\\:w-6\\/12 {\n    width: 50%;\n  }\n\n  .md\\:w-7\\/12 {\n    width: 58.333333%;\n  }\n\n  .md\\:w-8\\/12 {\n    width: 66.666667%;\n  }\n\n  .md\\:w-9\\/12 {\n    width: 75%;\n  }\n\n  .md\\:w-10\\/12 {\n    width: 83.333333%;\n  }\n\n  .md\\:w-11\\/12 {\n    width: 91.666667%;\n  }\n\n  .md\\:w-full {\n    width: 100%;\n  }\n\n  .md\\:w-screen {\n    width: 100vw;\n  }\n\n  .md\\:z-0 {\n    z-index: 0;\n  }\n\n  .md\\:z-10 {\n    z-index: 10;\n  }\n\n  .md\\:z-20 {\n    z-index: 20;\n  }\n\n  .md\\:z-30 {\n    z-index: 30;\n  }\n\n  .md\\:z-40 {\n    z-index: 40;\n  }\n\n  .md\\:z-50 {\n    z-index: 50;\n  }\n\n  .md\\:z-auto {\n    z-index: auto;\n  }\n\n  .md\\:gap-0 {\n    grid-gap: 0;\n    gap: 0;\n  }\n\n  .md\\:gap-1 {\n    grid-gap: 0.25rem;\n    gap: 0.25rem;\n  }\n\n  .md\\:gap-2 {\n    grid-gap: 0.5rem;\n    gap: 0.5rem;\n  }\n\n  .md\\:gap-3 {\n    grid-gap: 0.75rem;\n    gap: 0.75rem;\n  }\n\n  .md\\:gap-4 {\n    grid-gap: 1rem;\n    gap: 1rem;\n  }\n\n  .md\\:gap-5 {\n    grid-gap: 1.25rem;\n    gap: 1.25rem;\n  }\n\n  .md\\:gap-6 {\n    grid-gap: 1.5rem;\n    gap: 1.5rem;\n  }\n\n  .md\\:gap-8 {\n    grid-gap: 2rem;\n    gap: 2rem;\n  }\n\n  .md\\:gap-10 {\n    grid-gap: 2.5rem;\n    gap: 2.5rem;\n  }\n\n  .md\\:gap-12 {\n    grid-gap: 3rem;\n    gap: 3rem;\n  }\n\n  .md\\:gap-16 {\n    grid-gap: 4rem;\n    gap: 4rem;\n  }\n\n  .md\\:gap-20 {\n    grid-gap: 5rem;\n    gap: 5rem;\n  }\n\n  .md\\:gap-24 {\n    grid-gap: 6rem;\n    gap: 6rem;\n  }\n\n  .md\\:gap-32 {\n    grid-gap: 8rem;\n    gap: 8rem;\n  }\n\n  .md\\:gap-40 {\n    grid-gap: 10rem;\n    gap: 10rem;\n  }\n\n  .md\\:gap-48 {\n    grid-gap: 12rem;\n    gap: 12rem;\n  }\n\n  .md\\:gap-56 {\n    grid-gap: 14rem;\n    gap: 14rem;\n  }\n\n  .md\\:gap-64 {\n    grid-gap: 16rem;\n    gap: 16rem;\n  }\n\n  .md\\:gap-px {\n    grid-gap: 1px;\n    gap: 1px;\n  }\n\n  .md\\:gap-x-0 {\n    grid-column-gap: 0;\n    -moz-column-gap: 0;\n         column-gap: 0;\n  }\n\n  .md\\:gap-x-1 {\n    grid-column-gap: 0.25rem;\n    -moz-column-gap: 0.25rem;\n         column-gap: 0.25rem;\n  }\n\n  .md\\:gap-x-2 {\n    grid-column-gap: 0.5rem;\n    -moz-column-gap: 0.5rem;\n         column-gap: 0.5rem;\n  }\n\n  .md\\:gap-x-3 {\n    grid-column-gap: 0.75rem;\n    -moz-column-gap: 0.75rem;\n         column-gap: 0.75rem;\n  }\n\n  .md\\:gap-x-4 {\n    grid-column-gap: 1rem;\n    -moz-column-gap: 1rem;\n         column-gap: 1rem;\n  }\n\n  .md\\:gap-x-5 {\n    grid-column-gap: 1.25rem;\n    -moz-column-gap: 1.25rem;\n         column-gap: 1.25rem;\n  }\n\n  .md\\:gap-x-6 {\n    grid-column-gap: 1.5rem;\n    -moz-column-gap: 1.5rem;\n         column-gap: 1.5rem;\n  }\n\n  .md\\:gap-x-8 {\n    grid-column-gap: 2rem;\n    -moz-column-gap: 2rem;\n         column-gap: 2rem;\n  }\n\n  .md\\:gap-x-10 {\n    grid-column-gap: 2.5rem;\n    -moz-column-gap: 2.5rem;\n         column-gap: 2.5rem;\n  }\n\n  .md\\:gap-x-12 {\n    grid-column-gap: 3rem;\n    -moz-column-gap: 3rem;\n         column-gap: 3rem;\n  }\n\n  .md\\:gap-x-16 {\n    grid-column-gap: 4rem;\n    -moz-column-gap: 4rem;\n         column-gap: 4rem;\n  }\n\n  .md\\:gap-x-20 {\n    grid-column-gap: 5rem;\n    -moz-column-gap: 5rem;\n         column-gap: 5rem;\n  }\n\n  .md\\:gap-x-24 {\n    grid-column-gap: 6rem;\n    -moz-column-gap: 6rem;\n         column-gap: 6rem;\n  }\n\n  .md\\:gap-x-32 {\n    grid-column-gap: 8rem;\n    -moz-column-gap: 8rem;\n         column-gap: 8rem;\n  }\n\n  .md\\:gap-x-40 {\n    grid-column-gap: 10rem;\n    -moz-column-gap: 10rem;\n         column-gap: 10rem;\n  }\n\n  .md\\:gap-x-48 {\n    grid-column-gap: 12rem;\n    -moz-column-gap: 12rem;\n         column-gap: 12rem;\n  }\n\n  .md\\:gap-x-56 {\n    grid-column-gap: 14rem;\n    -moz-column-gap: 14rem;\n         column-gap: 14rem;\n  }\n\n  .md\\:gap-x-64 {\n    grid-column-gap: 16rem;\n    -moz-column-gap: 16rem;\n         column-gap: 16rem;\n  }\n\n  .md\\:gap-x-px {\n    grid-column-gap: 1px;\n    -moz-column-gap: 1px;\n         column-gap: 1px;\n  }\n\n  .md\\:gap-y-0 {\n    grid-row-gap: 0;\n    row-gap: 0;\n  }\n\n  .md\\:gap-y-1 {\n    grid-row-gap: 0.25rem;\n    row-gap: 0.25rem;\n  }\n\n  .md\\:gap-y-2 {\n    grid-row-gap: 0.5rem;\n    row-gap: 0.5rem;\n  }\n\n  .md\\:gap-y-3 {\n    grid-row-gap: 0.75rem;\n    row-gap: 0.75rem;\n  }\n\n  .md\\:gap-y-4 {\n    grid-row-gap: 1rem;\n    row-gap: 1rem;\n  }\n\n  .md\\:gap-y-5 {\n    grid-row-gap: 1.25rem;\n    row-gap: 1.25rem;\n  }\n\n  .md\\:gap-y-6 {\n    grid-row-gap: 1.5rem;\n    row-gap: 1.5rem;\n  }\n\n  .md\\:gap-y-8 {\n    grid-row-gap: 2rem;\n    row-gap: 2rem;\n  }\n\n  .md\\:gap-y-10 {\n    grid-row-gap: 2.5rem;\n    row-gap: 2.5rem;\n  }\n\n  .md\\:gap-y-12 {\n    grid-row-gap: 3rem;\n    row-gap: 3rem;\n  }\n\n  .md\\:gap-y-16 {\n    grid-row-gap: 4rem;\n    row-gap: 4rem;\n  }\n\n  .md\\:gap-y-20 {\n    grid-row-gap: 5rem;\n    row-gap: 5rem;\n  }\n\n  .md\\:gap-y-24 {\n    grid-row-gap: 6rem;\n    row-gap: 6rem;\n  }\n\n  .md\\:gap-y-32 {\n    grid-row-gap: 8rem;\n    row-gap: 8rem;\n  }\n\n  .md\\:gap-y-40 {\n    grid-row-gap: 10rem;\n    row-gap: 10rem;\n  }\n\n  .md\\:gap-y-48 {\n    grid-row-gap: 12rem;\n    row-gap: 12rem;\n  }\n\n  .md\\:gap-y-56 {\n    grid-row-gap: 14rem;\n    row-gap: 14rem;\n  }\n\n  .md\\:gap-y-64 {\n    grid-row-gap: 16rem;\n    row-gap: 16rem;\n  }\n\n  .md\\:gap-y-px {\n    grid-row-gap: 1px;\n    row-gap: 1px;\n  }\n\n  .md\\:grid-flow-row {\n    grid-auto-flow: row;\n  }\n\n  .md\\:grid-flow-col {\n    grid-auto-flow: column;\n  }\n\n  .md\\:grid-flow-row-dense {\n    grid-auto-flow: row dense;\n  }\n\n  .md\\:grid-flow-col-dense {\n    grid-auto-flow: column dense;\n  }\n\n  .md\\:grid-cols-1 {\n    grid-template-columns: repeat(1, minmax(0, 1fr));\n  }\n\n  .md\\:grid-cols-2 {\n    grid-template-columns: repeat(2, minmax(0, 1fr));\n  }\n\n  .md\\:grid-cols-3 {\n    grid-template-columns: repeat(3, minmax(0, 1fr));\n  }\n\n  .md\\:grid-cols-4 {\n    grid-template-columns: repeat(4, minmax(0, 1fr));\n  }\n\n  .md\\:grid-cols-5 {\n    grid-template-columns: repeat(5, minmax(0, 1fr));\n  }\n\n  .md\\:grid-cols-6 {\n    grid-template-columns: repeat(6, minmax(0, 1fr));\n  }\n\n  .md\\:grid-cols-7 {\n    grid-template-columns: repeat(7, minmax(0, 1fr));\n  }\n\n  .md\\:grid-cols-8 {\n    grid-template-columns: repeat(8, minmax(0, 1fr));\n  }\n\n  .md\\:grid-cols-9 {\n    grid-template-columns: repeat(9, minmax(0, 1fr));\n  }\n\n  .md\\:grid-cols-10 {\n    grid-template-columns: repeat(10, minmax(0, 1fr));\n  }\n\n  .md\\:grid-cols-11 {\n    grid-template-columns: repeat(11, minmax(0, 1fr));\n  }\n\n  .md\\:grid-cols-12 {\n    grid-template-columns: repeat(12, minmax(0, 1fr));\n  }\n\n  .md\\:grid-cols-none {\n    grid-template-columns: none;\n  }\n\n  .md\\:auto-cols-auto {\n    grid-auto-columns: auto;\n  }\n\n  .md\\:auto-cols-min {\n    grid-auto-columns: -webkit-min-content;\n    grid-auto-columns: min-content;\n  }\n\n  .md\\:auto-cols-max {\n    grid-auto-columns: -webkit-max-content;\n    grid-auto-columns: max-content;\n  }\n\n  .md\\:auto-cols-fr {\n    grid-auto-columns: minmax(0, 1fr);\n  }\n\n  .md\\:col-auto {\n    grid-column: auto;\n  }\n\n  .md\\:col-span-1 {\n    grid-column: span 1 / span 1;\n  }\n\n  .md\\:col-span-2 {\n    grid-column: span 2 / span 2;\n  }\n\n  .md\\:col-span-3 {\n    grid-column: span 3 / span 3;\n  }\n\n  .md\\:col-span-4 {\n    grid-column: span 4 / span 4;\n  }\n\n  .md\\:col-span-5 {\n    grid-column: span 5 / span 5;\n  }\n\n  .md\\:col-span-6 {\n    grid-column: span 6 / span 6;\n  }\n\n  .md\\:col-span-7 {\n    grid-column: span 7 / span 7;\n  }\n\n  .md\\:col-span-8 {\n    grid-column: span 8 / span 8;\n  }\n\n  .md\\:col-span-9 {\n    grid-column: span 9 / span 9;\n  }\n\n  .md\\:col-span-10 {\n    grid-column: span 10 / span 10;\n  }\n\n  .md\\:col-span-11 {\n    grid-column: span 11 / span 11;\n  }\n\n  .md\\:col-span-12 {\n    grid-column: span 12 / span 12;\n  }\n\n  .md\\:col-span-full {\n    grid-column: 1 / -1;\n  }\n\n  .md\\:col-start-1 {\n    grid-column-start: 1;\n  }\n\n  .md\\:col-start-2 {\n    grid-column-start: 2;\n  }\n\n  .md\\:col-start-3 {\n    grid-column-start: 3;\n  }\n\n  .md\\:col-start-4 {\n    grid-column-start: 4;\n  }\n\n  .md\\:col-start-5 {\n    grid-column-start: 5;\n  }\n\n  .md\\:col-start-6 {\n    grid-column-start: 6;\n  }\n\n  .md\\:col-start-7 {\n    grid-column-start: 7;\n  }\n\n  .md\\:col-start-8 {\n    grid-column-start: 8;\n  }\n\n  .md\\:col-start-9 {\n    grid-column-start: 9;\n  }\n\n  .md\\:col-start-10 {\n    grid-column-start: 10;\n  }\n\n  .md\\:col-start-11 {\n    grid-column-start: 11;\n  }\n\n  .md\\:col-start-12 {\n    grid-column-start: 12;\n  }\n\n  .md\\:col-start-13 {\n    grid-column-start: 13;\n  }\n\n  .md\\:col-start-auto {\n    grid-column-start: auto;\n  }\n\n  .md\\:col-end-1 {\n    grid-column-end: 1;\n  }\n\n  .md\\:col-end-2 {\n    grid-column-end: 2;\n  }\n\n  .md\\:col-end-3 {\n    grid-column-end: 3;\n  }\n\n  .md\\:col-end-4 {\n    grid-column-end: 4;\n  }\n\n  .md\\:col-end-5 {\n    grid-column-end: 5;\n  }\n\n  .md\\:col-end-6 {\n    grid-column-end: 6;\n  }\n\n  .md\\:col-end-7 {\n    grid-column-end: 7;\n  }\n\n  .md\\:col-end-8 {\n    grid-column-end: 8;\n  }\n\n  .md\\:col-end-9 {\n    grid-column-end: 9;\n  }\n\n  .md\\:col-end-10 {\n    grid-column-end: 10;\n  }\n\n  .md\\:col-end-11 {\n    grid-column-end: 11;\n  }\n\n  .md\\:col-end-12 {\n    grid-column-end: 12;\n  }\n\n  .md\\:col-end-13 {\n    grid-column-end: 13;\n  }\n\n  .md\\:col-end-auto {\n    grid-column-end: auto;\n  }\n\n  .md\\:grid-rows-1 {\n    grid-template-rows: repeat(1, minmax(0, 1fr));\n  }\n\n  .md\\:grid-rows-2 {\n    grid-template-rows: repeat(2, minmax(0, 1fr));\n  }\n\n  .md\\:grid-rows-3 {\n    grid-template-rows: repeat(3, minmax(0, 1fr));\n  }\n\n  .md\\:grid-rows-4 {\n    grid-template-rows: repeat(4, minmax(0, 1fr));\n  }\n\n  .md\\:grid-rows-5 {\n    grid-template-rows: repeat(5, minmax(0, 1fr));\n  }\n\n  .md\\:grid-rows-6 {\n    grid-template-rows: repeat(6, minmax(0, 1fr));\n  }\n\n  .md\\:grid-rows-none {\n    grid-template-rows: none;\n  }\n\n  .md\\:auto-rows-auto {\n    grid-auto-rows: auto;\n  }\n\n  .md\\:auto-rows-min {\n    grid-auto-rows: -webkit-min-content;\n    grid-auto-rows: min-content;\n  }\n\n  .md\\:auto-rows-max {\n    grid-auto-rows: -webkit-max-content;\n    grid-auto-rows: max-content;\n  }\n\n  .md\\:auto-rows-fr {\n    grid-auto-rows: minmax(0, 1fr);\n  }\n\n  .md\\:row-auto {\n    grid-row: auto;\n  }\n\n  .md\\:row-span-1 {\n    grid-row: span 1 / span 1;\n  }\n\n  .md\\:row-span-2 {\n    grid-row: span 2 / span 2;\n  }\n\n  .md\\:row-span-3 {\n    grid-row: span 3 / span 3;\n  }\n\n  .md\\:row-span-4 {\n    grid-row: span 4 / span 4;\n  }\n\n  .md\\:row-span-5 {\n    grid-row: span 5 / span 5;\n  }\n\n  .md\\:row-span-6 {\n    grid-row: span 6 / span 6;\n  }\n\n  .md\\:row-span-full {\n    grid-row: 1 / -1;\n  }\n\n  .md\\:row-start-1 {\n    grid-row-start: 1;\n  }\n\n  .md\\:row-start-2 {\n    grid-row-start: 2;\n  }\n\n  .md\\:row-start-3 {\n    grid-row-start: 3;\n  }\n\n  .md\\:row-start-4 {\n    grid-row-start: 4;\n  }\n\n  .md\\:row-start-5 {\n    grid-row-start: 5;\n  }\n\n  .md\\:row-start-6 {\n    grid-row-start: 6;\n  }\n\n  .md\\:row-start-7 {\n    grid-row-start: 7;\n  }\n\n  .md\\:row-start-auto {\n    grid-row-start: auto;\n  }\n\n  .md\\:row-end-1 {\n    grid-row-end: 1;\n  }\n\n  .md\\:row-end-2 {\n    grid-row-end: 2;\n  }\n\n  .md\\:row-end-3 {\n    grid-row-end: 3;\n  }\n\n  .md\\:row-end-4 {\n    grid-row-end: 4;\n  }\n\n  .md\\:row-end-5 {\n    grid-row-end: 5;\n  }\n\n  .md\\:row-end-6 {\n    grid-row-end: 6;\n  }\n\n  .md\\:row-end-7 {\n    grid-row-end: 7;\n  }\n\n  .md\\:row-end-auto {\n    grid-row-end: auto;\n  }\n\n  .md\\:transform {\n    --transform-translate-x: 0;\n    --transform-translate-y: 0;\n    --transform-rotate: 0;\n    --transform-skew-x: 0;\n    --transform-skew-y: 0;\n    --transform-scale-x: 1;\n    --transform-scale-y: 1;\n    transform: translateX(var(--transform-translate-x)) translateY(var(--transform-translate-y)) rotate(var(--transform-rotate)) skewX(var(--transform-skew-x)) skewY(var(--transform-skew-y)) scaleX(var(--transform-scale-x)) scaleY(var(--transform-scale-y));\n  }\n\n  .md\\:transform-none {\n    transform: none;\n  }\n\n  .md\\:origin-center {\n    transform-origin: center;\n  }\n\n  .md\\:origin-top {\n    transform-origin: top;\n  }\n\n  .md\\:origin-top-right {\n    transform-origin: top right;\n  }\n\n  .md\\:origin-right {\n    transform-origin: right;\n  }\n\n  .md\\:origin-bottom-right {\n    transform-origin: bottom right;\n  }\n\n  .md\\:origin-bottom {\n    transform-origin: bottom;\n  }\n\n  .md\\:origin-bottom-left {\n    transform-origin: bottom left;\n  }\n\n  .md\\:origin-left {\n    transform-origin: left;\n  }\n\n  .md\\:origin-top-left {\n    transform-origin: top left;\n  }\n\n  .md\\:scale-0 {\n    --transform-scale-x: 0;\n    --transform-scale-y: 0;\n  }\n\n  .md\\:scale-50 {\n    --transform-scale-x: .5;\n    --transform-scale-y: .5;\n  }\n\n  .md\\:scale-75 {\n    --transform-scale-x: .75;\n    --transform-scale-y: .75;\n  }\n\n  .md\\:scale-90 {\n    --transform-scale-x: .9;\n    --transform-scale-y: .9;\n  }\n\n  .md\\:scale-95 {\n    --transform-scale-x: .95;\n    --transform-scale-y: .95;\n  }\n\n  .md\\:scale-100 {\n    --transform-scale-x: 1;\n    --transform-scale-y: 1;\n  }\n\n  .md\\:scale-105 {\n    --transform-scale-x: 1.05;\n    --transform-scale-y: 1.05;\n  }\n\n  .md\\:scale-110 {\n    --transform-scale-x: 1.1;\n    --transform-scale-y: 1.1;\n  }\n\n  .md\\:scale-125 {\n    --transform-scale-x: 1.25;\n    --transform-scale-y: 1.25;\n  }\n\n  .md\\:scale-150 {\n    --transform-scale-x: 1.5;\n    --transform-scale-y: 1.5;\n  }\n\n  .md\\:scale-x-0 {\n    --transform-scale-x: 0;\n  }\n\n  .md\\:scale-x-50 {\n    --transform-scale-x: .5;\n  }\n\n  .md\\:scale-x-75 {\n    --transform-scale-x: .75;\n  }\n\n  .md\\:scale-x-90 {\n    --transform-scale-x: .9;\n  }\n\n  .md\\:scale-x-95 {\n    --transform-scale-x: .95;\n  }\n\n  .md\\:scale-x-100 {\n    --transform-scale-x: 1;\n  }\n\n  .md\\:scale-x-105 {\n    --transform-scale-x: 1.05;\n  }\n\n  .md\\:scale-x-110 {\n    --transform-scale-x: 1.1;\n  }\n\n  .md\\:scale-x-125 {\n    --transform-scale-x: 1.25;\n  }\n\n  .md\\:scale-x-150 {\n    --transform-scale-x: 1.5;\n  }\n\n  .md\\:scale-y-0 {\n    --transform-scale-y: 0;\n  }\n\n  .md\\:scale-y-50 {\n    --transform-scale-y: .5;\n  }\n\n  .md\\:scale-y-75 {\n    --transform-scale-y: .75;\n  }\n\n  .md\\:scale-y-90 {\n    --transform-scale-y: .9;\n  }\n\n  .md\\:scale-y-95 {\n    --transform-scale-y: .95;\n  }\n\n  .md\\:scale-y-100 {\n    --transform-scale-y: 1;\n  }\n\n  .md\\:scale-y-105 {\n    --transform-scale-y: 1.05;\n  }\n\n  .md\\:scale-y-110 {\n    --transform-scale-y: 1.1;\n  }\n\n  .md\\:scale-y-125 {\n    --transform-scale-y: 1.25;\n  }\n\n  .md\\:scale-y-150 {\n    --transform-scale-y: 1.5;\n  }\n\n  .md\\:hover\\:scale-0:hover {\n    --transform-scale-x: 0;\n    --transform-scale-y: 0;\n  }\n\n  .md\\:hover\\:scale-50:hover {\n    --transform-scale-x: .5;\n    --transform-scale-y: .5;\n  }\n\n  .md\\:hover\\:scale-75:hover {\n    --transform-scale-x: .75;\n    --transform-scale-y: .75;\n  }\n\n  .md\\:hover\\:scale-90:hover {\n    --transform-scale-x: .9;\n    --transform-scale-y: .9;\n  }\n\n  .md\\:hover\\:scale-95:hover {\n    --transform-scale-x: .95;\n    --transform-scale-y: .95;\n  }\n\n  .md\\:hover\\:scale-100:hover {\n    --transform-scale-x: 1;\n    --transform-scale-y: 1;\n  }\n\n  .md\\:hover\\:scale-105:hover {\n    --transform-scale-x: 1.05;\n    --transform-scale-y: 1.05;\n  }\n\n  .md\\:hover\\:scale-110:hover {\n    --transform-scale-x: 1.1;\n    --transform-scale-y: 1.1;\n  }\n\n  .md\\:hover\\:scale-125:hover {\n    --transform-scale-x: 1.25;\n    --transform-scale-y: 1.25;\n  }\n\n  .md\\:hover\\:scale-150:hover {\n    --transform-scale-x: 1.5;\n    --transform-scale-y: 1.5;\n  }\n\n  .md\\:hover\\:scale-x-0:hover {\n    --transform-scale-x: 0;\n  }\n\n  .md\\:hover\\:scale-x-50:hover {\n    --transform-scale-x: .5;\n  }\n\n  .md\\:hover\\:scale-x-75:hover {\n    --transform-scale-x: .75;\n  }\n\n  .md\\:hover\\:scale-x-90:hover {\n    --transform-scale-x: .9;\n  }\n\n  .md\\:hover\\:scale-x-95:hover {\n    --transform-scale-x: .95;\n  }\n\n  .md\\:hover\\:scale-x-100:hover {\n    --transform-scale-x: 1;\n  }\n\n  .md\\:hover\\:scale-x-105:hover {\n    --transform-scale-x: 1.05;\n  }\n\n  .md\\:hover\\:scale-x-110:hover {\n    --transform-scale-x: 1.1;\n  }\n\n  .md\\:hover\\:scale-x-125:hover {\n    --transform-scale-x: 1.25;\n  }\n\n  .md\\:hover\\:scale-x-150:hover {\n    --transform-scale-x: 1.5;\n  }\n\n  .md\\:hover\\:scale-y-0:hover {\n    --transform-scale-y: 0;\n  }\n\n  .md\\:hover\\:scale-y-50:hover {\n    --transform-scale-y: .5;\n  }\n\n  .md\\:hover\\:scale-y-75:hover {\n    --transform-scale-y: .75;\n  }\n\n  .md\\:hover\\:scale-y-90:hover {\n    --transform-scale-y: .9;\n  }\n\n  .md\\:hover\\:scale-y-95:hover {\n    --transform-scale-y: .95;\n  }\n\n  .md\\:hover\\:scale-y-100:hover {\n    --transform-scale-y: 1;\n  }\n\n  .md\\:hover\\:scale-y-105:hover {\n    --transform-scale-y: 1.05;\n  }\n\n  .md\\:hover\\:scale-y-110:hover {\n    --transform-scale-y: 1.1;\n  }\n\n  .md\\:hover\\:scale-y-125:hover {\n    --transform-scale-y: 1.25;\n  }\n\n  .md\\:hover\\:scale-y-150:hover {\n    --transform-scale-y: 1.5;\n  }\n\n  .md\\:focus\\:scale-0:focus {\n    --transform-scale-x: 0;\n    --transform-scale-y: 0;\n  }\n\n  .md\\:focus\\:scale-50:focus {\n    --transform-scale-x: .5;\n    --transform-scale-y: .5;\n  }\n\n  .md\\:focus\\:scale-75:focus {\n    --transform-scale-x: .75;\n    --transform-scale-y: .75;\n  }\n\n  .md\\:focus\\:scale-90:focus {\n    --transform-scale-x: .9;\n    --transform-scale-y: .9;\n  }\n\n  .md\\:focus\\:scale-95:focus {\n    --transform-scale-x: .95;\n    --transform-scale-y: .95;\n  }\n\n  .md\\:focus\\:scale-100:focus {\n    --transform-scale-x: 1;\n    --transform-scale-y: 1;\n  }\n\n  .md\\:focus\\:scale-105:focus {\n    --transform-scale-x: 1.05;\n    --transform-scale-y: 1.05;\n  }\n\n  .md\\:focus\\:scale-110:focus {\n    --transform-scale-x: 1.1;\n    --transform-scale-y: 1.1;\n  }\n\n  .md\\:focus\\:scale-125:focus {\n    --transform-scale-x: 1.25;\n    --transform-scale-y: 1.25;\n  }\n\n  .md\\:focus\\:scale-150:focus {\n    --transform-scale-x: 1.5;\n    --transform-scale-y: 1.5;\n  }\n\n  .md\\:focus\\:scale-x-0:focus {\n    --transform-scale-x: 0;\n  }\n\n  .md\\:focus\\:scale-x-50:focus {\n    --transform-scale-x: .5;\n  }\n\n  .md\\:focus\\:scale-x-75:focus {\n    --transform-scale-x: .75;\n  }\n\n  .md\\:focus\\:scale-x-90:focus {\n    --transform-scale-x: .9;\n  }\n\n  .md\\:focus\\:scale-x-95:focus {\n    --transform-scale-x: .95;\n  }\n\n  .md\\:focus\\:scale-x-100:focus {\n    --transform-scale-x: 1;\n  }\n\n  .md\\:focus\\:scale-x-105:focus {\n    --transform-scale-x: 1.05;\n  }\n\n  .md\\:focus\\:scale-x-110:focus {\n    --transform-scale-x: 1.1;\n  }\n\n  .md\\:focus\\:scale-x-125:focus {\n    --transform-scale-x: 1.25;\n  }\n\n  .md\\:focus\\:scale-x-150:focus {\n    --transform-scale-x: 1.5;\n  }\n\n  .md\\:focus\\:scale-y-0:focus {\n    --transform-scale-y: 0;\n  }\n\n  .md\\:focus\\:scale-y-50:focus {\n    --transform-scale-y: .5;\n  }\n\n  .md\\:focus\\:scale-y-75:focus {\n    --transform-scale-y: .75;\n  }\n\n  .md\\:focus\\:scale-y-90:focus {\n    --transform-scale-y: .9;\n  }\n\n  .md\\:focus\\:scale-y-95:focus {\n    --transform-scale-y: .95;\n  }\n\n  .md\\:focus\\:scale-y-100:focus {\n    --transform-scale-y: 1;\n  }\n\n  .md\\:focus\\:scale-y-105:focus {\n    --transform-scale-y: 1.05;\n  }\n\n  .md\\:focus\\:scale-y-110:focus {\n    --transform-scale-y: 1.1;\n  }\n\n  .md\\:focus\\:scale-y-125:focus {\n    --transform-scale-y: 1.25;\n  }\n\n  .md\\:focus\\:scale-y-150:focus {\n    --transform-scale-y: 1.5;\n  }\n\n  .md\\:rotate-0 {\n    --transform-rotate: 0;\n  }\n\n  .md\\:rotate-1 {\n    --transform-rotate: 1deg;\n  }\n\n  .md\\:rotate-2 {\n    --transform-rotate: 2deg;\n  }\n\n  .md\\:rotate-3 {\n    --transform-rotate: 3deg;\n  }\n\n  .md\\:rotate-6 {\n    --transform-rotate: 6deg;\n  }\n\n  .md\\:rotate-12 {\n    --transform-rotate: 12deg;\n  }\n\n  .md\\:rotate-45 {\n    --transform-rotate: 45deg;\n  }\n\n  .md\\:rotate-90 {\n    --transform-rotate: 90deg;\n  }\n\n  .md\\:rotate-180 {\n    --transform-rotate: 180deg;\n  }\n\n  .md\\:-rotate-180 {\n    --transform-rotate: -180deg;\n  }\n\n  .md\\:-rotate-90 {\n    --transform-rotate: -90deg;\n  }\n\n  .md\\:-rotate-45 {\n    --transform-rotate: -45deg;\n  }\n\n  .md\\:-rotate-12 {\n    --transform-rotate: -12deg;\n  }\n\n  .md\\:-rotate-6 {\n    --transform-rotate: -6deg;\n  }\n\n  .md\\:-rotate-3 {\n    --transform-rotate: -3deg;\n  }\n\n  .md\\:-rotate-2 {\n    --transform-rotate: -2deg;\n  }\n\n  .md\\:-rotate-1 {\n    --transform-rotate: -1deg;\n  }\n\n  .md\\:hover\\:rotate-0:hover {\n    --transform-rotate: 0;\n  }\n\n  .md\\:hover\\:rotate-1:hover {\n    --transform-rotate: 1deg;\n  }\n\n  .md\\:hover\\:rotate-2:hover {\n    --transform-rotate: 2deg;\n  }\n\n  .md\\:hover\\:rotate-3:hover {\n    --transform-rotate: 3deg;\n  }\n\n  .md\\:hover\\:rotate-6:hover {\n    --transform-rotate: 6deg;\n  }\n\n  .md\\:hover\\:rotate-12:hover {\n    --transform-rotate: 12deg;\n  }\n\n  .md\\:hover\\:rotate-45:hover {\n    --transform-rotate: 45deg;\n  }\n\n  .md\\:hover\\:rotate-90:hover {\n    --transform-rotate: 90deg;\n  }\n\n  .md\\:hover\\:rotate-180:hover {\n    --transform-rotate: 180deg;\n  }\n\n  .md\\:hover\\:-rotate-180:hover {\n    --transform-rotate: -180deg;\n  }\n\n  .md\\:hover\\:-rotate-90:hover {\n    --transform-rotate: -90deg;\n  }\n\n  .md\\:hover\\:-rotate-45:hover {\n    --transform-rotate: -45deg;\n  }\n\n  .md\\:hover\\:-rotate-12:hover {\n    --transform-rotate: -12deg;\n  }\n\n  .md\\:hover\\:-rotate-6:hover {\n    --transform-rotate: -6deg;\n  }\n\n  .md\\:hover\\:-rotate-3:hover {\n    --transform-rotate: -3deg;\n  }\n\n  .md\\:hover\\:-rotate-2:hover {\n    --transform-rotate: -2deg;\n  }\n\n  .md\\:hover\\:-rotate-1:hover {\n    --transform-rotate: -1deg;\n  }\n\n  .md\\:focus\\:rotate-0:focus {\n    --transform-rotate: 0;\n  }\n\n  .md\\:focus\\:rotate-1:focus {\n    --transform-rotate: 1deg;\n  }\n\n  .md\\:focus\\:rotate-2:focus {\n    --transform-rotate: 2deg;\n  }\n\n  .md\\:focus\\:rotate-3:focus {\n    --transform-rotate: 3deg;\n  }\n\n  .md\\:focus\\:rotate-6:focus {\n    --transform-rotate: 6deg;\n  }\n\n  .md\\:focus\\:rotate-12:focus {\n    --transform-rotate: 12deg;\n  }\n\n  .md\\:focus\\:rotate-45:focus {\n    --transform-rotate: 45deg;\n  }\n\n  .md\\:focus\\:rotate-90:focus {\n    --transform-rotate: 90deg;\n  }\n\n  .md\\:focus\\:rotate-180:focus {\n    --transform-rotate: 180deg;\n  }\n\n  .md\\:focus\\:-rotate-180:focus {\n    --transform-rotate: -180deg;\n  }\n\n  .md\\:focus\\:-rotate-90:focus {\n    --transform-rotate: -90deg;\n  }\n\n  .md\\:focus\\:-rotate-45:focus {\n    --transform-rotate: -45deg;\n  }\n\n  .md\\:focus\\:-rotate-12:focus {\n    --transform-rotate: -12deg;\n  }\n\n  .md\\:focus\\:-rotate-6:focus {\n    --transform-rotate: -6deg;\n  }\n\n  .md\\:focus\\:-rotate-3:focus {\n    --transform-rotate: -3deg;\n  }\n\n  .md\\:focus\\:-rotate-2:focus {\n    --transform-rotate: -2deg;\n  }\n\n  .md\\:focus\\:-rotate-1:focus {\n    --transform-rotate: -1deg;\n  }\n\n  .md\\:translate-x-0 {\n    --transform-translate-x: 0;\n  }\n\n  .md\\:translate-x-1 {\n    --transform-translate-x: 0.25rem;\n  }\n\n  .md\\:translate-x-2 {\n    --transform-translate-x: 0.5rem;\n  }\n\n  .md\\:translate-x-3 {\n    --transform-translate-x: 0.75rem;\n  }\n\n  .md\\:translate-x-4 {\n    --transform-translate-x: 1rem;\n  }\n\n  .md\\:translate-x-5 {\n    --transform-translate-x: 1.25rem;\n  }\n\n  .md\\:translate-x-6 {\n    --transform-translate-x: 1.5rem;\n  }\n\n  .md\\:translate-x-8 {\n    --transform-translate-x: 2rem;\n  }\n\n  .md\\:translate-x-10 {\n    --transform-translate-x: 2.5rem;\n  }\n\n  .md\\:translate-x-12 {\n    --transform-translate-x: 3rem;\n  }\n\n  .md\\:translate-x-16 {\n    --transform-translate-x: 4rem;\n  }\n\n  .md\\:translate-x-20 {\n    --transform-translate-x: 5rem;\n  }\n\n  .md\\:translate-x-24 {\n    --transform-translate-x: 6rem;\n  }\n\n  .md\\:translate-x-32 {\n    --transform-translate-x: 8rem;\n  }\n\n  .md\\:translate-x-40 {\n    --transform-translate-x: 10rem;\n  }\n\n  .md\\:translate-x-48 {\n    --transform-translate-x: 12rem;\n  }\n\n  .md\\:translate-x-56 {\n    --transform-translate-x: 14rem;\n  }\n\n  .md\\:translate-x-64 {\n    --transform-translate-x: 16rem;\n  }\n\n  .md\\:translate-x-px {\n    --transform-translate-x: 1px;\n  }\n\n  .md\\:-translate-x-1 {\n    --transform-translate-x: -0.25rem;\n  }\n\n  .md\\:-translate-x-2 {\n    --transform-translate-x: -0.5rem;\n  }\n\n  .md\\:-translate-x-3 {\n    --transform-translate-x: -0.75rem;\n  }\n\n  .md\\:-translate-x-4 {\n    --transform-translate-x: -1rem;\n  }\n\n  .md\\:-translate-x-5 {\n    --transform-translate-x: -1.25rem;\n  }\n\n  .md\\:-translate-x-6 {\n    --transform-translate-x: -1.5rem;\n  }\n\n  .md\\:-translate-x-8 {\n    --transform-translate-x: -2rem;\n  }\n\n  .md\\:-translate-x-10 {\n    --transform-translate-x: -2.5rem;\n  }\n\n  .md\\:-translate-x-12 {\n    --transform-translate-x: -3rem;\n  }\n\n  .md\\:-translate-x-16 {\n    --transform-translate-x: -4rem;\n  }\n\n  .md\\:-translate-x-20 {\n    --transform-translate-x: -5rem;\n  }\n\n  .md\\:-translate-x-24 {\n    --transform-translate-x: -6rem;\n  }\n\n  .md\\:-translate-x-32 {\n    --transform-translate-x: -8rem;\n  }\n\n  .md\\:-translate-x-40 {\n    --transform-translate-x: -10rem;\n  }\n\n  .md\\:-translate-x-48 {\n    --transform-translate-x: -12rem;\n  }\n\n  .md\\:-translate-x-56 {\n    --transform-translate-x: -14rem;\n  }\n\n  .md\\:-translate-x-64 {\n    --transform-translate-x: -16rem;\n  }\n\n  .md\\:-translate-x-px {\n    --transform-translate-x: -1px;\n  }\n\n  .md\\:-translate-x-full {\n    --transform-translate-x: -100%;\n  }\n\n  .md\\:-translate-x-1\\/2 {\n    --transform-translate-x: -50%;\n  }\n\n  .md\\:translate-x-1\\/2 {\n    --transform-translate-x: 50%;\n  }\n\n  .md\\:translate-x-full {\n    --transform-translate-x: 100%;\n  }\n\n  .md\\:translate-y-0 {\n    --transform-translate-y: 0;\n  }\n\n  .md\\:translate-y-1 {\n    --transform-translate-y: 0.25rem;\n  }\n\n  .md\\:translate-y-2 {\n    --transform-translate-y: 0.5rem;\n  }\n\n  .md\\:translate-y-3 {\n    --transform-translate-y: 0.75rem;\n  }\n\n  .md\\:translate-y-4 {\n    --transform-translate-y: 1rem;\n  }\n\n  .md\\:translate-y-5 {\n    --transform-translate-y: 1.25rem;\n  }\n\n  .md\\:translate-y-6 {\n    --transform-translate-y: 1.5rem;\n  }\n\n  .md\\:translate-y-8 {\n    --transform-translate-y: 2rem;\n  }\n\n  .md\\:translate-y-10 {\n    --transform-translate-y: 2.5rem;\n  }\n\n  .md\\:translate-y-12 {\n    --transform-translate-y: 3rem;\n  }\n\n  .md\\:translate-y-16 {\n    --transform-translate-y: 4rem;\n  }\n\n  .md\\:translate-y-20 {\n    --transform-translate-y: 5rem;\n  }\n\n  .md\\:translate-y-24 {\n    --transform-translate-y: 6rem;\n  }\n\n  .md\\:translate-y-32 {\n    --transform-translate-y: 8rem;\n  }\n\n  .md\\:translate-y-40 {\n    --transform-translate-y: 10rem;\n  }\n\n  .md\\:translate-y-48 {\n    --transform-translate-y: 12rem;\n  }\n\n  .md\\:translate-y-56 {\n    --transform-translate-y: 14rem;\n  }\n\n  .md\\:translate-y-64 {\n    --transform-translate-y: 16rem;\n  }\n\n  .md\\:translate-y-px {\n    --transform-translate-y: 1px;\n  }\n\n  .md\\:-translate-y-1 {\n    --transform-translate-y: -0.25rem;\n  }\n\n  .md\\:-translate-y-2 {\n    --transform-translate-y: -0.5rem;\n  }\n\n  .md\\:-translate-y-3 {\n    --transform-translate-y: -0.75rem;\n  }\n\n  .md\\:-translate-y-4 {\n    --transform-translate-y: -1rem;\n  }\n\n  .md\\:-translate-y-5 {\n    --transform-translate-y: -1.25rem;\n  }\n\n  .md\\:-translate-y-6 {\n    --transform-translate-y: -1.5rem;\n  }\n\n  .md\\:-translate-y-8 {\n    --transform-translate-y: -2rem;\n  }\n\n  .md\\:-translate-y-10 {\n    --transform-translate-y: -2.5rem;\n  }\n\n  .md\\:-translate-y-12 {\n    --transform-translate-y: -3rem;\n  }\n\n  .md\\:-translate-y-16 {\n    --transform-translate-y: -4rem;\n  }\n\n  .md\\:-translate-y-20 {\n    --transform-translate-y: -5rem;\n  }\n\n  .md\\:-translate-y-24 {\n    --transform-translate-y: -6rem;\n  }\n\n  .md\\:-translate-y-32 {\n    --transform-translate-y: -8rem;\n  }\n\n  .md\\:-translate-y-40 {\n    --transform-translate-y: -10rem;\n  }\n\n  .md\\:-translate-y-48 {\n    --transform-translate-y: -12rem;\n  }\n\n  .md\\:-translate-y-56 {\n    --transform-translate-y: -14rem;\n  }\n\n  .md\\:-translate-y-64 {\n    --transform-translate-y: -16rem;\n  }\n\n  .md\\:-translate-y-px {\n    --transform-translate-y: -1px;\n  }\n\n  .md\\:-translate-y-full {\n    --transform-translate-y: -100%;\n  }\n\n  .md\\:-translate-y-1\\/2 {\n    --transform-translate-y: -50%;\n  }\n\n  .md\\:translate-y-1\\/2 {\n    --transform-translate-y: 50%;\n  }\n\n  .md\\:translate-y-full {\n    --transform-translate-y: 100%;\n  }\n\n  .md\\:hover\\:translate-x-0:hover {\n    --transform-translate-x: 0;\n  }\n\n  .md\\:hover\\:translate-x-1:hover {\n    --transform-translate-x: 0.25rem;\n  }\n\n  .md\\:hover\\:translate-x-2:hover {\n    --transform-translate-x: 0.5rem;\n  }\n\n  .md\\:hover\\:translate-x-3:hover {\n    --transform-translate-x: 0.75rem;\n  }\n\n  .md\\:hover\\:translate-x-4:hover {\n    --transform-translate-x: 1rem;\n  }\n\n  .md\\:hover\\:translate-x-5:hover {\n    --transform-translate-x: 1.25rem;\n  }\n\n  .md\\:hover\\:translate-x-6:hover {\n    --transform-translate-x: 1.5rem;\n  }\n\n  .md\\:hover\\:translate-x-8:hover {\n    --transform-translate-x: 2rem;\n  }\n\n  .md\\:hover\\:translate-x-10:hover {\n    --transform-translate-x: 2.5rem;\n  }\n\n  .md\\:hover\\:translate-x-12:hover {\n    --transform-translate-x: 3rem;\n  }\n\n  .md\\:hover\\:translate-x-16:hover {\n    --transform-translate-x: 4rem;\n  }\n\n  .md\\:hover\\:translate-x-20:hover {\n    --transform-translate-x: 5rem;\n  }\n\n  .md\\:hover\\:translate-x-24:hover {\n    --transform-translate-x: 6rem;\n  }\n\n  .md\\:hover\\:translate-x-32:hover {\n    --transform-translate-x: 8rem;\n  }\n\n  .md\\:hover\\:translate-x-40:hover {\n    --transform-translate-x: 10rem;\n  }\n\n  .md\\:hover\\:translate-x-48:hover {\n    --transform-translate-x: 12rem;\n  }\n\n  .md\\:hover\\:translate-x-56:hover {\n    --transform-translate-x: 14rem;\n  }\n\n  .md\\:hover\\:translate-x-64:hover {\n    --transform-translate-x: 16rem;\n  }\n\n  .md\\:hover\\:translate-x-px:hover {\n    --transform-translate-x: 1px;\n  }\n\n  .md\\:hover\\:-translate-x-1:hover {\n    --transform-translate-x: -0.25rem;\n  }\n\n  .md\\:hover\\:-translate-x-2:hover {\n    --transform-translate-x: -0.5rem;\n  }\n\n  .md\\:hover\\:-translate-x-3:hover {\n    --transform-translate-x: -0.75rem;\n  }\n\n  .md\\:hover\\:-translate-x-4:hover {\n    --transform-translate-x: -1rem;\n  }\n\n  .md\\:hover\\:-translate-x-5:hover {\n    --transform-translate-x: -1.25rem;\n  }\n\n  .md\\:hover\\:-translate-x-6:hover {\n    --transform-translate-x: -1.5rem;\n  }\n\n  .md\\:hover\\:-translate-x-8:hover {\n    --transform-translate-x: -2rem;\n  }\n\n  .md\\:hover\\:-translate-x-10:hover {\n    --transform-translate-x: -2.5rem;\n  }\n\n  .md\\:hover\\:-translate-x-12:hover {\n    --transform-translate-x: -3rem;\n  }\n\n  .md\\:hover\\:-translate-x-16:hover {\n    --transform-translate-x: -4rem;\n  }\n\n  .md\\:hover\\:-translate-x-20:hover {\n    --transform-translate-x: -5rem;\n  }\n\n  .md\\:hover\\:-translate-x-24:hover {\n    --transform-translate-x: -6rem;\n  }\n\n  .md\\:hover\\:-translate-x-32:hover {\n    --transform-translate-x: -8rem;\n  }\n\n  .md\\:hover\\:-translate-x-40:hover {\n    --transform-translate-x: -10rem;\n  }\n\n  .md\\:hover\\:-translate-x-48:hover {\n    --transform-translate-x: -12rem;\n  }\n\n  .md\\:hover\\:-translate-x-56:hover {\n    --transform-translate-x: -14rem;\n  }\n\n  .md\\:hover\\:-translate-x-64:hover {\n    --transform-translate-x: -16rem;\n  }\n\n  .md\\:hover\\:-translate-x-px:hover {\n    --transform-translate-x: -1px;\n  }\n\n  .md\\:hover\\:-translate-x-full:hover {\n    --transform-translate-x: -100%;\n  }\n\n  .md\\:hover\\:-translate-x-1\\/2:hover {\n    --transform-translate-x: -50%;\n  }\n\n  .md\\:hover\\:translate-x-1\\/2:hover {\n    --transform-translate-x: 50%;\n  }\n\n  .md\\:hover\\:translate-x-full:hover {\n    --transform-translate-x: 100%;\n  }\n\n  .md\\:hover\\:translate-y-0:hover {\n    --transform-translate-y: 0;\n  }\n\n  .md\\:hover\\:translate-y-1:hover {\n    --transform-translate-y: 0.25rem;\n  }\n\n  .md\\:hover\\:translate-y-2:hover {\n    --transform-translate-y: 0.5rem;\n  }\n\n  .md\\:hover\\:translate-y-3:hover {\n    --transform-translate-y: 0.75rem;\n  }\n\n  .md\\:hover\\:translate-y-4:hover {\n    --transform-translate-y: 1rem;\n  }\n\n  .md\\:hover\\:translate-y-5:hover {\n    --transform-translate-y: 1.25rem;\n  }\n\n  .md\\:hover\\:translate-y-6:hover {\n    --transform-translate-y: 1.5rem;\n  }\n\n  .md\\:hover\\:translate-y-8:hover {\n    --transform-translate-y: 2rem;\n  }\n\n  .md\\:hover\\:translate-y-10:hover {\n    --transform-translate-y: 2.5rem;\n  }\n\n  .md\\:hover\\:translate-y-12:hover {\n    --transform-translate-y: 3rem;\n  }\n\n  .md\\:hover\\:translate-y-16:hover {\n    --transform-translate-y: 4rem;\n  }\n\n  .md\\:hover\\:translate-y-20:hover {\n    --transform-translate-y: 5rem;\n  }\n\n  .md\\:hover\\:translate-y-24:hover {\n    --transform-translate-y: 6rem;\n  }\n\n  .md\\:hover\\:translate-y-32:hover {\n    --transform-translate-y: 8rem;\n  }\n\n  .md\\:hover\\:translate-y-40:hover {\n    --transform-translate-y: 10rem;\n  }\n\n  .md\\:hover\\:translate-y-48:hover {\n    --transform-translate-y: 12rem;\n  }\n\n  .md\\:hover\\:translate-y-56:hover {\n    --transform-translate-y: 14rem;\n  }\n\n  .md\\:hover\\:translate-y-64:hover {\n    --transform-translate-y: 16rem;\n  }\n\n  .md\\:hover\\:translate-y-px:hover {\n    --transform-translate-y: 1px;\n  }\n\n  .md\\:hover\\:-translate-y-1:hover {\n    --transform-translate-y: -0.25rem;\n  }\n\n  .md\\:hover\\:-translate-y-2:hover {\n    --transform-translate-y: -0.5rem;\n  }\n\n  .md\\:hover\\:-translate-y-3:hover {\n    --transform-translate-y: -0.75rem;\n  }\n\n  .md\\:hover\\:-translate-y-4:hover {\n    --transform-translate-y: -1rem;\n  }\n\n  .md\\:hover\\:-translate-y-5:hover {\n    --transform-translate-y: -1.25rem;\n  }\n\n  .md\\:hover\\:-translate-y-6:hover {\n    --transform-translate-y: -1.5rem;\n  }\n\n  .md\\:hover\\:-translate-y-8:hover {\n    --transform-translate-y: -2rem;\n  }\n\n  .md\\:hover\\:-translate-y-10:hover {\n    --transform-translate-y: -2.5rem;\n  }\n\n  .md\\:hover\\:-translate-y-12:hover {\n    --transform-translate-y: -3rem;\n  }\n\n  .md\\:hover\\:-translate-y-16:hover {\n    --transform-translate-y: -4rem;\n  }\n\n  .md\\:hover\\:-translate-y-20:hover {\n    --transform-translate-y: -5rem;\n  }\n\n  .md\\:hover\\:-translate-y-24:hover {\n    --transform-translate-y: -6rem;\n  }\n\n  .md\\:hover\\:-translate-y-32:hover {\n    --transform-translate-y: -8rem;\n  }\n\n  .md\\:hover\\:-translate-y-40:hover {\n    --transform-translate-y: -10rem;\n  }\n\n  .md\\:hover\\:-translate-y-48:hover {\n    --transform-translate-y: -12rem;\n  }\n\n  .md\\:hover\\:-translate-y-56:hover {\n    --transform-translate-y: -14rem;\n  }\n\n  .md\\:hover\\:-translate-y-64:hover {\n    --transform-translate-y: -16rem;\n  }\n\n  .md\\:hover\\:-translate-y-px:hover {\n    --transform-translate-y: -1px;\n  }\n\n  .md\\:hover\\:-translate-y-full:hover {\n    --transform-translate-y: -100%;\n  }\n\n  .md\\:hover\\:-translate-y-1\\/2:hover {\n    --transform-translate-y: -50%;\n  }\n\n  .md\\:hover\\:translate-y-1\\/2:hover {\n    --transform-translate-y: 50%;\n  }\n\n  .md\\:hover\\:translate-y-full:hover {\n    --transform-translate-y: 100%;\n  }\n\n  .md\\:focus\\:translate-x-0:focus {\n    --transform-translate-x: 0;\n  }\n\n  .md\\:focus\\:translate-x-1:focus {\n    --transform-translate-x: 0.25rem;\n  }\n\n  .md\\:focus\\:translate-x-2:focus {\n    --transform-translate-x: 0.5rem;\n  }\n\n  .md\\:focus\\:translate-x-3:focus {\n    --transform-translate-x: 0.75rem;\n  }\n\n  .md\\:focus\\:translate-x-4:focus {\n    --transform-translate-x: 1rem;\n  }\n\n  .md\\:focus\\:translate-x-5:focus {\n    --transform-translate-x: 1.25rem;\n  }\n\n  .md\\:focus\\:translate-x-6:focus {\n    --transform-translate-x: 1.5rem;\n  }\n\n  .md\\:focus\\:translate-x-8:focus {\n    --transform-translate-x: 2rem;\n  }\n\n  .md\\:focus\\:translate-x-10:focus {\n    --transform-translate-x: 2.5rem;\n  }\n\n  .md\\:focus\\:translate-x-12:focus {\n    --transform-translate-x: 3rem;\n  }\n\n  .md\\:focus\\:translate-x-16:focus {\n    --transform-translate-x: 4rem;\n  }\n\n  .md\\:focus\\:translate-x-20:focus {\n    --transform-translate-x: 5rem;\n  }\n\n  .md\\:focus\\:translate-x-24:focus {\n    --transform-translate-x: 6rem;\n  }\n\n  .md\\:focus\\:translate-x-32:focus {\n    --transform-translate-x: 8rem;\n  }\n\n  .md\\:focus\\:translate-x-40:focus {\n    --transform-translate-x: 10rem;\n  }\n\n  .md\\:focus\\:translate-x-48:focus {\n    --transform-translate-x: 12rem;\n  }\n\n  .md\\:focus\\:translate-x-56:focus {\n    --transform-translate-x: 14rem;\n  }\n\n  .md\\:focus\\:translate-x-64:focus {\n    --transform-translate-x: 16rem;\n  }\n\n  .md\\:focus\\:translate-x-px:focus {\n    --transform-translate-x: 1px;\n  }\n\n  .md\\:focus\\:-translate-x-1:focus {\n    --transform-translate-x: -0.25rem;\n  }\n\n  .md\\:focus\\:-translate-x-2:focus {\n    --transform-translate-x: -0.5rem;\n  }\n\n  .md\\:focus\\:-translate-x-3:focus {\n    --transform-translate-x: -0.75rem;\n  }\n\n  .md\\:focus\\:-translate-x-4:focus {\n    --transform-translate-x: -1rem;\n  }\n\n  .md\\:focus\\:-translate-x-5:focus {\n    --transform-translate-x: -1.25rem;\n  }\n\n  .md\\:focus\\:-translate-x-6:focus {\n    --transform-translate-x: -1.5rem;\n  }\n\n  .md\\:focus\\:-translate-x-8:focus {\n    --transform-translate-x: -2rem;\n  }\n\n  .md\\:focus\\:-translate-x-10:focus {\n    --transform-translate-x: -2.5rem;\n  }\n\n  .md\\:focus\\:-translate-x-12:focus {\n    --transform-translate-x: -3rem;\n  }\n\n  .md\\:focus\\:-translate-x-16:focus {\n    --transform-translate-x: -4rem;\n  }\n\n  .md\\:focus\\:-translate-x-20:focus {\n    --transform-translate-x: -5rem;\n  }\n\n  .md\\:focus\\:-translate-x-24:focus {\n    --transform-translate-x: -6rem;\n  }\n\n  .md\\:focus\\:-translate-x-32:focus {\n    --transform-translate-x: -8rem;\n  }\n\n  .md\\:focus\\:-translate-x-40:focus {\n    --transform-translate-x: -10rem;\n  }\n\n  .md\\:focus\\:-translate-x-48:focus {\n    --transform-translate-x: -12rem;\n  }\n\n  .md\\:focus\\:-translate-x-56:focus {\n    --transform-translate-x: -14rem;\n  }\n\n  .md\\:focus\\:-translate-x-64:focus {\n    --transform-translate-x: -16rem;\n  }\n\n  .md\\:focus\\:-translate-x-px:focus {\n    --transform-translate-x: -1px;\n  }\n\n  .md\\:focus\\:-translate-x-full:focus {\n    --transform-translate-x: -100%;\n  }\n\n  .md\\:focus\\:-translate-x-1\\/2:focus {\n    --transform-translate-x: -50%;\n  }\n\n  .md\\:focus\\:translate-x-1\\/2:focus {\n    --transform-translate-x: 50%;\n  }\n\n  .md\\:focus\\:translate-x-full:focus {\n    --transform-translate-x: 100%;\n  }\n\n  .md\\:focus\\:translate-y-0:focus {\n    --transform-translate-y: 0;\n  }\n\n  .md\\:focus\\:translate-y-1:focus {\n    --transform-translate-y: 0.25rem;\n  }\n\n  .md\\:focus\\:translate-y-2:focus {\n    --transform-translate-y: 0.5rem;\n  }\n\n  .md\\:focus\\:translate-y-3:focus {\n    --transform-translate-y: 0.75rem;\n  }\n\n  .md\\:focus\\:translate-y-4:focus {\n    --transform-translate-y: 1rem;\n  }\n\n  .md\\:focus\\:translate-y-5:focus {\n    --transform-translate-y: 1.25rem;\n  }\n\n  .md\\:focus\\:translate-y-6:focus {\n    --transform-translate-y: 1.5rem;\n  }\n\n  .md\\:focus\\:translate-y-8:focus {\n    --transform-translate-y: 2rem;\n  }\n\n  .md\\:focus\\:translate-y-10:focus {\n    --transform-translate-y: 2.5rem;\n  }\n\n  .md\\:focus\\:translate-y-12:focus {\n    --transform-translate-y: 3rem;\n  }\n\n  .md\\:focus\\:translate-y-16:focus {\n    --transform-translate-y: 4rem;\n  }\n\n  .md\\:focus\\:translate-y-20:focus {\n    --transform-translate-y: 5rem;\n  }\n\n  .md\\:focus\\:translate-y-24:focus {\n    --transform-translate-y: 6rem;\n  }\n\n  .md\\:focus\\:translate-y-32:focus {\n    --transform-translate-y: 8rem;\n  }\n\n  .md\\:focus\\:translate-y-40:focus {\n    --transform-translate-y: 10rem;\n  }\n\n  .md\\:focus\\:translate-y-48:focus {\n    --transform-translate-y: 12rem;\n  }\n\n  .md\\:focus\\:translate-y-56:focus {\n    --transform-translate-y: 14rem;\n  }\n\n  .md\\:focus\\:translate-y-64:focus {\n    --transform-translate-y: 16rem;\n  }\n\n  .md\\:focus\\:translate-y-px:focus {\n    --transform-translate-y: 1px;\n  }\n\n  .md\\:focus\\:-translate-y-1:focus {\n    --transform-translate-y: -0.25rem;\n  }\n\n  .md\\:focus\\:-translate-y-2:focus {\n    --transform-translate-y: -0.5rem;\n  }\n\n  .md\\:focus\\:-translate-y-3:focus {\n    --transform-translate-y: -0.75rem;\n  }\n\n  .md\\:focus\\:-translate-y-4:focus {\n    --transform-translate-y: -1rem;\n  }\n\n  .md\\:focus\\:-translate-y-5:focus {\n    --transform-translate-y: -1.25rem;\n  }\n\n  .md\\:focus\\:-translate-y-6:focus {\n    --transform-translate-y: -1.5rem;\n  }\n\n  .md\\:focus\\:-translate-y-8:focus {\n    --transform-translate-y: -2rem;\n  }\n\n  .md\\:focus\\:-translate-y-10:focus {\n    --transform-translate-y: -2.5rem;\n  }\n\n  .md\\:focus\\:-translate-y-12:focus {\n    --transform-translate-y: -3rem;\n  }\n\n  .md\\:focus\\:-translate-y-16:focus {\n    --transform-translate-y: -4rem;\n  }\n\n  .md\\:focus\\:-translate-y-20:focus {\n    --transform-translate-y: -5rem;\n  }\n\n  .md\\:focus\\:-translate-y-24:focus {\n    --transform-translate-y: -6rem;\n  }\n\n  .md\\:focus\\:-translate-y-32:focus {\n    --transform-translate-y: -8rem;\n  }\n\n  .md\\:focus\\:-translate-y-40:focus {\n    --transform-translate-y: -10rem;\n  }\n\n  .md\\:focus\\:-translate-y-48:focus {\n    --transform-translate-y: -12rem;\n  }\n\n  .md\\:focus\\:-translate-y-56:focus {\n    --transform-translate-y: -14rem;\n  }\n\n  .md\\:focus\\:-translate-y-64:focus {\n    --transform-translate-y: -16rem;\n  }\n\n  .md\\:focus\\:-translate-y-px:focus {\n    --transform-translate-y: -1px;\n  }\n\n  .md\\:focus\\:-translate-y-full:focus {\n    --transform-translate-y: -100%;\n  }\n\n  .md\\:focus\\:-translate-y-1\\/2:focus {\n    --transform-translate-y: -50%;\n  }\n\n  .md\\:focus\\:translate-y-1\\/2:focus {\n    --transform-translate-y: 50%;\n  }\n\n  .md\\:focus\\:translate-y-full:focus {\n    --transform-translate-y: 100%;\n  }\n\n  .md\\:skew-x-0 {\n    --transform-skew-x: 0;\n  }\n\n  .md\\:skew-x-1 {\n    --transform-skew-x: 1deg;\n  }\n\n  .md\\:skew-x-2 {\n    --transform-skew-x: 2deg;\n  }\n\n  .md\\:skew-x-3 {\n    --transform-skew-x: 3deg;\n  }\n\n  .md\\:skew-x-6 {\n    --transform-skew-x: 6deg;\n  }\n\n  .md\\:skew-x-12 {\n    --transform-skew-x: 12deg;\n  }\n\n  .md\\:-skew-x-12 {\n    --transform-skew-x: -12deg;\n  }\n\n  .md\\:-skew-x-6 {\n    --transform-skew-x: -6deg;\n  }\n\n  .md\\:-skew-x-3 {\n    --transform-skew-x: -3deg;\n  }\n\n  .md\\:-skew-x-2 {\n    --transform-skew-x: -2deg;\n  }\n\n  .md\\:-skew-x-1 {\n    --transform-skew-x: -1deg;\n  }\n\n  .md\\:skew-y-0 {\n    --transform-skew-y: 0;\n  }\n\n  .md\\:skew-y-1 {\n    --transform-skew-y: 1deg;\n  }\n\n  .md\\:skew-y-2 {\n    --transform-skew-y: 2deg;\n  }\n\n  .md\\:skew-y-3 {\n    --transform-skew-y: 3deg;\n  }\n\n  .md\\:skew-y-6 {\n    --transform-skew-y: 6deg;\n  }\n\n  .md\\:skew-y-12 {\n    --transform-skew-y: 12deg;\n  }\n\n  .md\\:-skew-y-12 {\n    --transform-skew-y: -12deg;\n  }\n\n  .md\\:-skew-y-6 {\n    --transform-skew-y: -6deg;\n  }\n\n  .md\\:-skew-y-3 {\n    --transform-skew-y: -3deg;\n  }\n\n  .md\\:-skew-y-2 {\n    --transform-skew-y: -2deg;\n  }\n\n  .md\\:-skew-y-1 {\n    --transform-skew-y: -1deg;\n  }\n\n  .md\\:hover\\:skew-x-0:hover {\n    --transform-skew-x: 0;\n  }\n\n  .md\\:hover\\:skew-x-1:hover {\n    --transform-skew-x: 1deg;\n  }\n\n  .md\\:hover\\:skew-x-2:hover {\n    --transform-skew-x: 2deg;\n  }\n\n  .md\\:hover\\:skew-x-3:hover {\n    --transform-skew-x: 3deg;\n  }\n\n  .md\\:hover\\:skew-x-6:hover {\n    --transform-skew-x: 6deg;\n  }\n\n  .md\\:hover\\:skew-x-12:hover {\n    --transform-skew-x: 12deg;\n  }\n\n  .md\\:hover\\:-skew-x-12:hover {\n    --transform-skew-x: -12deg;\n  }\n\n  .md\\:hover\\:-skew-x-6:hover {\n    --transform-skew-x: -6deg;\n  }\n\n  .md\\:hover\\:-skew-x-3:hover {\n    --transform-skew-x: -3deg;\n  }\n\n  .md\\:hover\\:-skew-x-2:hover {\n    --transform-skew-x: -2deg;\n  }\n\n  .md\\:hover\\:-skew-x-1:hover {\n    --transform-skew-x: -1deg;\n  }\n\n  .md\\:hover\\:skew-y-0:hover {\n    --transform-skew-y: 0;\n  }\n\n  .md\\:hover\\:skew-y-1:hover {\n    --transform-skew-y: 1deg;\n  }\n\n  .md\\:hover\\:skew-y-2:hover {\n    --transform-skew-y: 2deg;\n  }\n\n  .md\\:hover\\:skew-y-3:hover {\n    --transform-skew-y: 3deg;\n  }\n\n  .md\\:hover\\:skew-y-6:hover {\n    --transform-skew-y: 6deg;\n  }\n\n  .md\\:hover\\:skew-y-12:hover {\n    --transform-skew-y: 12deg;\n  }\n\n  .md\\:hover\\:-skew-y-12:hover {\n    --transform-skew-y: -12deg;\n  }\n\n  .md\\:hover\\:-skew-y-6:hover {\n    --transform-skew-y: -6deg;\n  }\n\n  .md\\:hover\\:-skew-y-3:hover {\n    --transform-skew-y: -3deg;\n  }\n\n  .md\\:hover\\:-skew-y-2:hover {\n    --transform-skew-y: -2deg;\n  }\n\n  .md\\:hover\\:-skew-y-1:hover {\n    --transform-skew-y: -1deg;\n  }\n\n  .md\\:focus\\:skew-x-0:focus {\n    --transform-skew-x: 0;\n  }\n\n  .md\\:focus\\:skew-x-1:focus {\n    --transform-skew-x: 1deg;\n  }\n\n  .md\\:focus\\:skew-x-2:focus {\n    --transform-skew-x: 2deg;\n  }\n\n  .md\\:focus\\:skew-x-3:focus {\n    --transform-skew-x: 3deg;\n  }\n\n  .md\\:focus\\:skew-x-6:focus {\n    --transform-skew-x: 6deg;\n  }\n\n  .md\\:focus\\:skew-x-12:focus {\n    --transform-skew-x: 12deg;\n  }\n\n  .md\\:focus\\:-skew-x-12:focus {\n    --transform-skew-x: -12deg;\n  }\n\n  .md\\:focus\\:-skew-x-6:focus {\n    --transform-skew-x: -6deg;\n  }\n\n  .md\\:focus\\:-skew-x-3:focus {\n    --transform-skew-x: -3deg;\n  }\n\n  .md\\:focus\\:-skew-x-2:focus {\n    --transform-skew-x: -2deg;\n  }\n\n  .md\\:focus\\:-skew-x-1:focus {\n    --transform-skew-x: -1deg;\n  }\n\n  .md\\:focus\\:skew-y-0:focus {\n    --transform-skew-y: 0;\n  }\n\n  .md\\:focus\\:skew-y-1:focus {\n    --transform-skew-y: 1deg;\n  }\n\n  .md\\:focus\\:skew-y-2:focus {\n    --transform-skew-y: 2deg;\n  }\n\n  .md\\:focus\\:skew-y-3:focus {\n    --transform-skew-y: 3deg;\n  }\n\n  .md\\:focus\\:skew-y-6:focus {\n    --transform-skew-y: 6deg;\n  }\n\n  .md\\:focus\\:skew-y-12:focus {\n    --transform-skew-y: 12deg;\n  }\n\n  .md\\:focus\\:-skew-y-12:focus {\n    --transform-skew-y: -12deg;\n  }\n\n  .md\\:focus\\:-skew-y-6:focus {\n    --transform-skew-y: -6deg;\n  }\n\n  .md\\:focus\\:-skew-y-3:focus {\n    --transform-skew-y: -3deg;\n  }\n\n  .md\\:focus\\:-skew-y-2:focus {\n    --transform-skew-y: -2deg;\n  }\n\n  .md\\:focus\\:-skew-y-1:focus {\n    --transform-skew-y: -1deg;\n  }\n\n  .md\\:transition-none {\n    transition-property: none;\n  }\n\n  .md\\:transition-all {\n    transition-property: all;\n  }\n\n  .md\\:transition {\n    transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform;\n  }\n\n  .md\\:transition-colors {\n    transition-property: background-color, border-color, color, fill, stroke;\n  }\n\n  .md\\:transition-opacity {\n    transition-property: opacity;\n  }\n\n  .md\\:transition-shadow {\n    transition-property: box-shadow;\n  }\n\n  .md\\:transition-transform {\n    transition-property: transform;\n  }\n\n  .md\\:ease-linear {\n    transition-timing-function: linear;\n  }\n\n  .md\\:ease-in {\n    transition-timing-function: cubic-bezier(0.4, 0, 1, 1);\n  }\n\n  .md\\:ease-out {\n    transition-timing-function: cubic-bezier(0, 0, 0.2, 1);\n  }\n\n  .md\\:ease-in-out {\n    transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);\n  }\n\n  .md\\:duration-75 {\n    transition-duration: 75ms;\n  }\n\n  .md\\:duration-100 {\n    transition-duration: 100ms;\n  }\n\n  .md\\:duration-150 {\n    transition-duration: 150ms;\n  }\n\n  .md\\:duration-200 {\n    transition-duration: 200ms;\n  }\n\n  .md\\:duration-300 {\n    transition-duration: 300ms;\n  }\n\n  .md\\:duration-500 {\n    transition-duration: 500ms;\n  }\n\n  .md\\:duration-700 {\n    transition-duration: 700ms;\n  }\n\n  .md\\:duration-1000 {\n    transition-duration: 1000ms;\n  }\n\n  .md\\:delay-75 {\n    transition-delay: 75ms;\n  }\n\n  .md\\:delay-100 {\n    transition-delay: 100ms;\n  }\n\n  .md\\:delay-150 {\n    transition-delay: 150ms;\n  }\n\n  .md\\:delay-200 {\n    transition-delay: 200ms;\n  }\n\n  .md\\:delay-300 {\n    transition-delay: 300ms;\n  }\n\n  .md\\:delay-500 {\n    transition-delay: 500ms;\n  }\n\n  .md\\:delay-700 {\n    transition-delay: 700ms;\n  }\n\n  .md\\:delay-1000 {\n    transition-delay: 1000ms;\n  }\n\n  .md\\:animate-none {\n    -webkit-animation: none;\n            animation: none;\n  }\n\n  .md\\:animate-spin {\n    -webkit-animation: spin 1s linear infinite;\n            animation: spin 1s linear infinite;\n  }\n\n  .md\\:animate-ping {\n    -webkit-animation: ping 1s cubic-bezier(0, 0, 0.2, 1) infinite;\n            animation: ping 1s cubic-bezier(0, 0, 0.2, 1) infinite;\n  }\n\n  .md\\:animate-pulse {\n    -webkit-animation: pulse 2s cubic-bezier(0.4, 0, 0.6, 1) infinite;\n            animation: pulse 2s cubic-bezier(0.4, 0, 0.6, 1) infinite;\n  }\n\n  .md\\:animate-bounce {\n    -webkit-animation: bounce 1s infinite;\n            animation: bounce 1s infinite;\n  }\n}\n\n@media (min-width: 1024px) {\n  .lg\\:container {\n    width: 100%;\n  }\n\n  @media (min-width: 640px) {\n    .lg\\:container {\n      max-width: 640px;\n    }\n  }\n\n  @media (min-width: 768px) {\n    .lg\\:container {\n      max-width: 768px;\n    }\n  }\n\n  @media (min-width: 1024px) {\n    .lg\\:container {\n      max-width: 1024px;\n    }\n  }\n\n  @media (min-width: 1280px) {\n    .lg\\:container {\n      max-width: 1280px;\n    }\n  }\n\n  .lg\\:space-y-0 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(0px * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(0px * var(--space-y-reverse));\n  }\n\n  .lg\\:space-x-0 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(0px * var(--space-x-reverse));\n    margin-left: calc(0px * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:space-y-1 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(0.25rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(0.25rem * var(--space-y-reverse));\n  }\n\n  .lg\\:space-x-1 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(0.25rem * var(--space-x-reverse));\n    margin-left: calc(0.25rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:space-y-2 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(0.5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(0.5rem * var(--space-y-reverse));\n  }\n\n  .lg\\:space-x-2 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(0.5rem * var(--space-x-reverse));\n    margin-left: calc(0.5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:space-y-3 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(0.75rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(0.75rem * var(--space-y-reverse));\n  }\n\n  .lg\\:space-x-3 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(0.75rem * var(--space-x-reverse));\n    margin-left: calc(0.75rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:space-y-4 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(1rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(1rem * var(--space-y-reverse));\n  }\n\n  .lg\\:space-x-4 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(1rem * var(--space-x-reverse));\n    margin-left: calc(1rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:space-y-5 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(1.25rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(1.25rem * var(--space-y-reverse));\n  }\n\n  .lg\\:space-x-5 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(1.25rem * var(--space-x-reverse));\n    margin-left: calc(1.25rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:space-y-6 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(1.5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(1.5rem * var(--space-y-reverse));\n  }\n\n  .lg\\:space-x-6 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(1.5rem * var(--space-x-reverse));\n    margin-left: calc(1.5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:space-y-8 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(2rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(2rem * var(--space-y-reverse));\n  }\n\n  .lg\\:space-x-8 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(2rem * var(--space-x-reverse));\n    margin-left: calc(2rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:space-y-10 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(2.5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(2.5rem * var(--space-y-reverse));\n  }\n\n  .lg\\:space-x-10 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(2.5rem * var(--space-x-reverse));\n    margin-left: calc(2.5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:space-y-12 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(3rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(3rem * var(--space-y-reverse));\n  }\n\n  .lg\\:space-x-12 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(3rem * var(--space-x-reverse));\n    margin-left: calc(3rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:space-y-16 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(4rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(4rem * var(--space-y-reverse));\n  }\n\n  .lg\\:space-x-16 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(4rem * var(--space-x-reverse));\n    margin-left: calc(4rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:space-y-20 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(5rem * var(--space-y-reverse));\n  }\n\n  .lg\\:space-x-20 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(5rem * var(--space-x-reverse));\n    margin-left: calc(5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:space-y-24 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(6rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(6rem * var(--space-y-reverse));\n  }\n\n  .lg\\:space-x-24 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(6rem * var(--space-x-reverse));\n    margin-left: calc(6rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:space-y-32 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(8rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(8rem * var(--space-y-reverse));\n  }\n\n  .lg\\:space-x-32 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(8rem * var(--space-x-reverse));\n    margin-left: calc(8rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:space-y-40 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(10rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(10rem * var(--space-y-reverse));\n  }\n\n  .lg\\:space-x-40 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(10rem * var(--space-x-reverse));\n    margin-left: calc(10rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:space-y-48 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(12rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(12rem * var(--space-y-reverse));\n  }\n\n  .lg\\:space-x-48 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(12rem * var(--space-x-reverse));\n    margin-left: calc(12rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:space-y-56 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(14rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(14rem * var(--space-y-reverse));\n  }\n\n  .lg\\:space-x-56 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(14rem * var(--space-x-reverse));\n    margin-left: calc(14rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:space-y-64 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(16rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(16rem * var(--space-y-reverse));\n  }\n\n  .lg\\:space-x-64 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(16rem * var(--space-x-reverse));\n    margin-left: calc(16rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:space-y-px > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(1px * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(1px * var(--space-y-reverse));\n  }\n\n  .lg\\:space-x-px > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(1px * var(--space-x-reverse));\n    margin-left: calc(1px * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:-space-y-1 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-0.25rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-0.25rem * var(--space-y-reverse));\n  }\n\n  .lg\\:-space-x-1 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-0.25rem * var(--space-x-reverse));\n    margin-left: calc(-0.25rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:-space-y-2 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-0.5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-0.5rem * var(--space-y-reverse));\n  }\n\n  .lg\\:-space-x-2 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-0.5rem * var(--space-x-reverse));\n    margin-left: calc(-0.5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:-space-y-3 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-0.75rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-0.75rem * var(--space-y-reverse));\n  }\n\n  .lg\\:-space-x-3 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-0.75rem * var(--space-x-reverse));\n    margin-left: calc(-0.75rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:-space-y-4 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-1rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-1rem * var(--space-y-reverse));\n  }\n\n  .lg\\:-space-x-4 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-1rem * var(--space-x-reverse));\n    margin-left: calc(-1rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:-space-y-5 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-1.25rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-1.25rem * var(--space-y-reverse));\n  }\n\n  .lg\\:-space-x-5 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-1.25rem * var(--space-x-reverse));\n    margin-left: calc(-1.25rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:-space-y-6 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-1.5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-1.5rem * var(--space-y-reverse));\n  }\n\n  .lg\\:-space-x-6 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-1.5rem * var(--space-x-reverse));\n    margin-left: calc(-1.5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:-space-y-8 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-2rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-2rem * var(--space-y-reverse));\n  }\n\n  .lg\\:-space-x-8 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-2rem * var(--space-x-reverse));\n    margin-left: calc(-2rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:-space-y-10 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-2.5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-2.5rem * var(--space-y-reverse));\n  }\n\n  .lg\\:-space-x-10 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-2.5rem * var(--space-x-reverse));\n    margin-left: calc(-2.5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:-space-y-12 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-3rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-3rem * var(--space-y-reverse));\n  }\n\n  .lg\\:-space-x-12 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-3rem * var(--space-x-reverse));\n    margin-left: calc(-3rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:-space-y-16 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-4rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-4rem * var(--space-y-reverse));\n  }\n\n  .lg\\:-space-x-16 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-4rem * var(--space-x-reverse));\n    margin-left: calc(-4rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:-space-y-20 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-5rem * var(--space-y-reverse));\n  }\n\n  .lg\\:-space-x-20 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-5rem * var(--space-x-reverse));\n    margin-left: calc(-5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:-space-y-24 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-6rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-6rem * var(--space-y-reverse));\n  }\n\n  .lg\\:-space-x-24 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-6rem * var(--space-x-reverse));\n    margin-left: calc(-6rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:-space-y-32 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-8rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-8rem * var(--space-y-reverse));\n  }\n\n  .lg\\:-space-x-32 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-8rem * var(--space-x-reverse));\n    margin-left: calc(-8rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:-space-y-40 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-10rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-10rem * var(--space-y-reverse));\n  }\n\n  .lg\\:-space-x-40 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-10rem * var(--space-x-reverse));\n    margin-left: calc(-10rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:-space-y-48 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-12rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-12rem * var(--space-y-reverse));\n  }\n\n  .lg\\:-space-x-48 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-12rem * var(--space-x-reverse));\n    margin-left: calc(-12rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:-space-y-56 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-14rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-14rem * var(--space-y-reverse));\n  }\n\n  .lg\\:-space-x-56 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-14rem * var(--space-x-reverse));\n    margin-left: calc(-14rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:-space-y-64 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-16rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-16rem * var(--space-y-reverse));\n  }\n\n  .lg\\:-space-x-64 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-16rem * var(--space-x-reverse));\n    margin-left: calc(-16rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:-space-y-px > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-1px * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-1px * var(--space-y-reverse));\n  }\n\n  .lg\\:-space-x-px > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-1px * var(--space-x-reverse));\n    margin-left: calc(-1px * calc(1 - var(--space-x-reverse)));\n  }\n\n  .lg\\:space-y-reverse > :not(template) ~ :not(template) {\n    --space-y-reverse: 1;\n  }\n\n  .lg\\:space-x-reverse > :not(template) ~ :not(template) {\n    --space-x-reverse: 1;\n  }\n\n  .lg\\:divide-y-0 > :not(template) ~ :not(template) {\n    --divide-y-reverse: 0;\n    border-top-width: calc(0px * calc(1 - var(--divide-y-reverse)));\n    border-bottom-width: calc(0px * var(--divide-y-reverse));\n  }\n\n  .lg\\:divide-x-0 > :not(template) ~ :not(template) {\n    --divide-x-reverse: 0;\n    border-right-width: calc(0px * var(--divide-x-reverse));\n    border-left-width: calc(0px * calc(1 - var(--divide-x-reverse)));\n  }\n\n  .lg\\:divide-y-2 > :not(template) ~ :not(template) {\n    --divide-y-reverse: 0;\n    border-top-width: calc(2px * calc(1 - var(--divide-y-reverse)));\n    border-bottom-width: calc(2px * var(--divide-y-reverse));\n  }\n\n  .lg\\:divide-x-2 > :not(template) ~ :not(template) {\n    --divide-x-reverse: 0;\n    border-right-width: calc(2px * var(--divide-x-reverse));\n    border-left-width: calc(2px * calc(1 - var(--divide-x-reverse)));\n  }\n\n  .lg\\:divide-y-4 > :not(template) ~ :not(template) {\n    --divide-y-reverse: 0;\n    border-top-width: calc(4px * calc(1 - var(--divide-y-reverse)));\n    border-bottom-width: calc(4px * var(--divide-y-reverse));\n  }\n\n  .lg\\:divide-x-4 > :not(template) ~ :not(template) {\n    --divide-x-reverse: 0;\n    border-right-width: calc(4px * var(--divide-x-reverse));\n    border-left-width: calc(4px * calc(1 - var(--divide-x-reverse)));\n  }\n\n  .lg\\:divide-y-8 > :not(template) ~ :not(template) {\n    --divide-y-reverse: 0;\n    border-top-width: calc(8px * calc(1 - var(--divide-y-reverse)));\n    border-bottom-width: calc(8px * var(--divide-y-reverse));\n  }\n\n  .lg\\:divide-x-8 > :not(template) ~ :not(template) {\n    --divide-x-reverse: 0;\n    border-right-width: calc(8px * var(--divide-x-reverse));\n    border-left-width: calc(8px * calc(1 - var(--divide-x-reverse)));\n  }\n\n  .lg\\:divide-y > :not(template) ~ :not(template) {\n    --divide-y-reverse: 0;\n    border-top-width: calc(1px * calc(1 - var(--divide-y-reverse)));\n    border-bottom-width: calc(1px * var(--divide-y-reverse));\n  }\n\n  .lg\\:divide-x > :not(template) ~ :not(template) {\n    --divide-x-reverse: 0;\n    border-right-width: calc(1px * var(--divide-x-reverse));\n    border-left-width: calc(1px * calc(1 - var(--divide-x-reverse)));\n  }\n\n  .lg\\:divide-y-reverse > :not(template) ~ :not(template) {\n    --divide-y-reverse: 1;\n  }\n\n  .lg\\:divide-x-reverse > :not(template) ~ :not(template) {\n    --divide-x-reverse: 1;\n  }\n\n  .lg\\:divide-transparent > :not(template) ~ :not(template) {\n    border-color: transparent;\n  }\n\n  .lg\\:divide-current > :not(template) ~ :not(template) {\n    border-color: currentColor;\n  }\n\n  .lg\\:divide-black > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #000;\n    border-color: rgba(0, 0, 0, var(--divide-opacity));\n  }\n\n  .lg\\:divide-white > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fff;\n    border-color: rgba(255, 255, 255, var(--divide-opacity));\n  }\n\n  .lg\\:divide-gray-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #f7fafc;\n    border-color: rgba(247, 250, 252, var(--divide-opacity));\n  }\n\n  .lg\\:divide-gray-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #edf2f7;\n    border-color: rgba(237, 242, 247, var(--divide-opacity));\n  }\n\n  .lg\\:divide-gray-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #e2e8f0;\n    border-color: rgba(226, 232, 240, var(--divide-opacity));\n  }\n\n  .lg\\:divide-gray-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #cbd5e0;\n    border-color: rgba(203, 213, 224, var(--divide-opacity));\n  }\n\n  .lg\\:divide-gray-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #a0aec0;\n    border-color: rgba(160, 174, 192, var(--divide-opacity));\n  }\n\n  .lg\\:divide-gray-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #718096;\n    border-color: rgba(113, 128, 150, var(--divide-opacity));\n  }\n\n  .lg\\:divide-gray-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #4a5568;\n    border-color: rgba(74, 85, 104, var(--divide-opacity));\n  }\n\n  .lg\\:divide-gray-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #2d3748;\n    border-color: rgba(45, 55, 72, var(--divide-opacity));\n  }\n\n  .lg\\:divide-gray-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #1a202c;\n    border-color: rgba(26, 32, 44, var(--divide-opacity));\n  }\n\n  .lg\\:divide-red-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fff5f5;\n    border-color: rgba(255, 245, 245, var(--divide-opacity));\n  }\n\n  .lg\\:divide-red-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fed7d7;\n    border-color: rgba(254, 215, 215, var(--divide-opacity));\n  }\n\n  .lg\\:divide-red-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #feb2b2;\n    border-color: rgba(254, 178, 178, var(--divide-opacity));\n  }\n\n  .lg\\:divide-red-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fc8181;\n    border-color: rgba(252, 129, 129, var(--divide-opacity));\n  }\n\n  .lg\\:divide-red-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #f56565;\n    border-color: rgba(245, 101, 101, var(--divide-opacity));\n  }\n\n  .lg\\:divide-red-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #e53e3e;\n    border-color: rgba(229, 62, 62, var(--divide-opacity));\n  }\n\n  .lg\\:divide-red-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #c53030;\n    border-color: rgba(197, 48, 48, var(--divide-opacity));\n  }\n\n  .lg\\:divide-red-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #9b2c2c;\n    border-color: rgba(155, 44, 44, var(--divide-opacity));\n  }\n\n  .lg\\:divide-red-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #742a2a;\n    border-color: rgba(116, 42, 42, var(--divide-opacity));\n  }\n\n  .lg\\:divide-orange-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fffaf0;\n    border-color: rgba(255, 250, 240, var(--divide-opacity));\n  }\n\n  .lg\\:divide-orange-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #feebc8;\n    border-color: rgba(254, 235, 200, var(--divide-opacity));\n  }\n\n  .lg\\:divide-orange-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fbd38d;\n    border-color: rgba(251, 211, 141, var(--divide-opacity));\n  }\n\n  .lg\\:divide-orange-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #f6ad55;\n    border-color: rgba(246, 173, 85, var(--divide-opacity));\n  }\n\n  .lg\\:divide-orange-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #ed8936;\n    border-color: rgba(237, 137, 54, var(--divide-opacity));\n  }\n\n  .lg\\:divide-orange-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #dd6b20;\n    border-color: rgba(221, 107, 32, var(--divide-opacity));\n  }\n\n  .lg\\:divide-orange-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #c05621;\n    border-color: rgba(192, 86, 33, var(--divide-opacity));\n  }\n\n  .lg\\:divide-orange-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #9c4221;\n    border-color: rgba(156, 66, 33, var(--divide-opacity));\n  }\n\n  .lg\\:divide-orange-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #7b341e;\n    border-color: rgba(123, 52, 30, var(--divide-opacity));\n  }\n\n  .lg\\:divide-yellow-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fffff0;\n    border-color: rgba(255, 255, 240, var(--divide-opacity));\n  }\n\n  .lg\\:divide-yellow-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fefcbf;\n    border-color: rgba(254, 252, 191, var(--divide-opacity));\n  }\n\n  .lg\\:divide-yellow-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #faf089;\n    border-color: rgba(250, 240, 137, var(--divide-opacity));\n  }\n\n  .lg\\:divide-yellow-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #f6e05e;\n    border-color: rgba(246, 224, 94, var(--divide-opacity));\n  }\n\n  .lg\\:divide-yellow-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #ecc94b;\n    border-color: rgba(236, 201, 75, var(--divide-opacity));\n  }\n\n  .lg\\:divide-yellow-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #d69e2e;\n    border-color: rgba(214, 158, 46, var(--divide-opacity));\n  }\n\n  .lg\\:divide-yellow-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #b7791f;\n    border-color: rgba(183, 121, 31, var(--divide-opacity));\n  }\n\n  .lg\\:divide-yellow-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #975a16;\n    border-color: rgba(151, 90, 22, var(--divide-opacity));\n  }\n\n  .lg\\:divide-yellow-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #744210;\n    border-color: rgba(116, 66, 16, var(--divide-opacity));\n  }\n\n  .lg\\:divide-green-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #f0fff4;\n    border-color: rgba(240, 255, 244, var(--divide-opacity));\n  }\n\n  .lg\\:divide-green-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #c6f6d5;\n    border-color: rgba(198, 246, 213, var(--divide-opacity));\n  }\n\n  .lg\\:divide-green-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #9ae6b4;\n    border-color: rgba(154, 230, 180, var(--divide-opacity));\n  }\n\n  .lg\\:divide-green-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #68d391;\n    border-color: rgba(104, 211, 145, var(--divide-opacity));\n  }\n\n  .lg\\:divide-green-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #48bb78;\n    border-color: rgba(72, 187, 120, var(--divide-opacity));\n  }\n\n  .lg\\:divide-green-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #38a169;\n    border-color: rgba(56, 161, 105, var(--divide-opacity));\n  }\n\n  .lg\\:divide-green-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #2f855a;\n    border-color: rgba(47, 133, 90, var(--divide-opacity));\n  }\n\n  .lg\\:divide-green-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #276749;\n    border-color: rgba(39, 103, 73, var(--divide-opacity));\n  }\n\n  .lg\\:divide-green-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #22543d;\n    border-color: rgba(34, 84, 61, var(--divide-opacity));\n  }\n\n  .lg\\:divide-teal-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #e6fffa;\n    border-color: rgba(230, 255, 250, var(--divide-opacity));\n  }\n\n  .lg\\:divide-teal-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #b2f5ea;\n    border-color: rgba(178, 245, 234, var(--divide-opacity));\n  }\n\n  .lg\\:divide-teal-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #81e6d9;\n    border-color: rgba(129, 230, 217, var(--divide-opacity));\n  }\n\n  .lg\\:divide-teal-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #4fd1c5;\n    border-color: rgba(79, 209, 197, var(--divide-opacity));\n  }\n\n  .lg\\:divide-teal-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #38b2ac;\n    border-color: rgba(56, 178, 172, var(--divide-opacity));\n  }\n\n  .lg\\:divide-teal-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #319795;\n    border-color: rgba(49, 151, 149, var(--divide-opacity));\n  }\n\n  .lg\\:divide-teal-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #2c7a7b;\n    border-color: rgba(44, 122, 123, var(--divide-opacity));\n  }\n\n  .lg\\:divide-teal-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #285e61;\n    border-color: rgba(40, 94, 97, var(--divide-opacity));\n  }\n\n  .lg\\:divide-teal-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #234e52;\n    border-color: rgba(35, 78, 82, var(--divide-opacity));\n  }\n\n  .lg\\:divide-blue-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #ebf8ff;\n    border-color: rgba(235, 248, 255, var(--divide-opacity));\n  }\n\n  .lg\\:divide-blue-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #bee3f8;\n    border-color: rgba(190, 227, 248, var(--divide-opacity));\n  }\n\n  .lg\\:divide-blue-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #90cdf4;\n    border-color: rgba(144, 205, 244, var(--divide-opacity));\n  }\n\n  .lg\\:divide-blue-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #63b3ed;\n    border-color: rgba(99, 179, 237, var(--divide-opacity));\n  }\n\n  .lg\\:divide-blue-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #4299e1;\n    border-color: rgba(66, 153, 225, var(--divide-opacity));\n  }\n\n  .lg\\:divide-blue-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #3182ce;\n    border-color: rgba(49, 130, 206, var(--divide-opacity));\n  }\n\n  .lg\\:divide-blue-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #2b6cb0;\n    border-color: rgba(43, 108, 176, var(--divide-opacity));\n  }\n\n  .lg\\:divide-blue-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #2c5282;\n    border-color: rgba(44, 82, 130, var(--divide-opacity));\n  }\n\n  .lg\\:divide-blue-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #2a4365;\n    border-color: rgba(42, 67, 101, var(--divide-opacity));\n  }\n\n  .lg\\:divide-indigo-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #ebf4ff;\n    border-color: rgba(235, 244, 255, var(--divide-opacity));\n  }\n\n  .lg\\:divide-indigo-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #c3dafe;\n    border-color: rgba(195, 218, 254, var(--divide-opacity));\n  }\n\n  .lg\\:divide-indigo-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #a3bffa;\n    border-color: rgba(163, 191, 250, var(--divide-opacity));\n  }\n\n  .lg\\:divide-indigo-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #7f9cf5;\n    border-color: rgba(127, 156, 245, var(--divide-opacity));\n  }\n\n  .lg\\:divide-indigo-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #667eea;\n    border-color: rgba(102, 126, 234, var(--divide-opacity));\n  }\n\n  .lg\\:divide-indigo-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #5a67d8;\n    border-color: rgba(90, 103, 216, var(--divide-opacity));\n  }\n\n  .lg\\:divide-indigo-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #4c51bf;\n    border-color: rgba(76, 81, 191, var(--divide-opacity));\n  }\n\n  .lg\\:divide-indigo-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #434190;\n    border-color: rgba(67, 65, 144, var(--divide-opacity));\n  }\n\n  .lg\\:divide-indigo-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #3c366b;\n    border-color: rgba(60, 54, 107, var(--divide-opacity));\n  }\n\n  .lg\\:divide-purple-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #faf5ff;\n    border-color: rgba(250, 245, 255, var(--divide-opacity));\n  }\n\n  .lg\\:divide-purple-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #e9d8fd;\n    border-color: rgba(233, 216, 253, var(--divide-opacity));\n  }\n\n  .lg\\:divide-purple-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #d6bcfa;\n    border-color: rgba(214, 188, 250, var(--divide-opacity));\n  }\n\n  .lg\\:divide-purple-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #b794f4;\n    border-color: rgba(183, 148, 244, var(--divide-opacity));\n  }\n\n  .lg\\:divide-purple-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #9f7aea;\n    border-color: rgba(159, 122, 234, var(--divide-opacity));\n  }\n\n  .lg\\:divide-purple-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #805ad5;\n    border-color: rgba(128, 90, 213, var(--divide-opacity));\n  }\n\n  .lg\\:divide-purple-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #6b46c1;\n    border-color: rgba(107, 70, 193, var(--divide-opacity));\n  }\n\n  .lg\\:divide-purple-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #553c9a;\n    border-color: rgba(85, 60, 154, var(--divide-opacity));\n  }\n\n  .lg\\:divide-purple-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #44337a;\n    border-color: rgba(68, 51, 122, var(--divide-opacity));\n  }\n\n  .lg\\:divide-pink-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fff5f7;\n    border-color: rgba(255, 245, 247, var(--divide-opacity));\n  }\n\n  .lg\\:divide-pink-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fed7e2;\n    border-color: rgba(254, 215, 226, var(--divide-opacity));\n  }\n\n  .lg\\:divide-pink-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fbb6ce;\n    border-color: rgba(251, 182, 206, var(--divide-opacity));\n  }\n\n  .lg\\:divide-pink-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #f687b3;\n    border-color: rgba(246, 135, 179, var(--divide-opacity));\n  }\n\n  .lg\\:divide-pink-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #ed64a6;\n    border-color: rgba(237, 100, 166, var(--divide-opacity));\n  }\n\n  .lg\\:divide-pink-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #d53f8c;\n    border-color: rgba(213, 63, 140, var(--divide-opacity));\n  }\n\n  .lg\\:divide-pink-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #b83280;\n    border-color: rgba(184, 50, 128, var(--divide-opacity));\n  }\n\n  .lg\\:divide-pink-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #97266d;\n    border-color: rgba(151, 38, 109, var(--divide-opacity));\n  }\n\n  .lg\\:divide-pink-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #702459;\n    border-color: rgba(112, 36, 89, var(--divide-opacity));\n  }\n\n  .lg\\:divide-grayscale-80 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 8%);\n    border-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--divide-opacity));\n  }\n\n  .lg\\:divide-grayscale-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 10%);\n    border-color: rgba(25.5, 25.5, 25.5, var(--divide-opacity));\n  }\n\n  .lg\\:divide-grayscale-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 20%);\n    border-color: rgba(51, 51, 51, var(--divide-opacity));\n  }\n\n  .lg\\:divide-grayscale-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 30%);\n    border-color: rgba(76.5, 76.5, 76.5, var(--divide-opacity));\n  }\n\n  .lg\\:divide-grayscale-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 40%);\n    border-color: rgba(102, 102, 102, var(--divide-opacity));\n  }\n\n  .lg\\:divide-grayscale-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 50%);\n    border-color: rgba(127.5, 127.5, 127.5, var(--divide-opacity));\n  }\n\n  .lg\\:divide-grayscale-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 60%);\n    border-color: rgba(153, 153, 153, var(--divide-opacity));\n  }\n\n  .lg\\:divide-grayscale-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 70%);\n    border-color: rgba(178.5, 178.5, 178.5, var(--divide-opacity));\n  }\n\n  .lg\\:divide-grayscale-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 80%);\n    border-color: rgba(204, 204, 204, var(--divide-opacity));\n  }\n\n  .lg\\:divide-grayscale-840 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 84%);\n    border-color: rgba(214.2, 214.2, 214.2, var(--divide-opacity));\n  }\n\n  .lg\\:divide-grayscale-870 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 87%);\n    border-color: rgba(221.85, 221.85, 221.85, var(--divide-opacity));\n  }\n\n  .lg\\:divide-grayscale-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 90%);\n    border-color: rgba(229.5, 229.5, 229.5, var(--divide-opacity));\n  }\n\n  .lg\\:divide-grayscale-930 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 93%);\n    border-color: rgba(237.15, 237.15, 237.15, var(--divide-opacity));\n  }\n\n  .lg\\:divide-primary > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(210, 100%, 52%);\n    border-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--divide-opacity));\n  }\n\n  .lg\\:divide-background-main > :not(template) ~ :not(template) {\n    border-color: var(--main-background);\n  }\n\n  .lg\\:divide-background-secondary > :not(template) ~ :not(template) {\n    border-color: var(--secondary-background);\n  }\n\n  .lg\\:divide-foreground > :not(template) ~ :not(template) {\n    border-color: var(--foreground);\n  }\n\n  .lg\\:divide-panels-bg > :not(template) ~ :not(template) {\n    border-color: var(--panels-background);\n  }\n\n  .lg\\:divide-solid > :not(template) ~ :not(template) {\n    border-style: solid;\n  }\n\n  .lg\\:divide-dashed > :not(template) ~ :not(template) {\n    border-style: dashed;\n  }\n\n  .lg\\:divide-dotted > :not(template) ~ :not(template) {\n    border-style: dotted;\n  }\n\n  .lg\\:divide-double > :not(template) ~ :not(template) {\n    border-style: double;\n  }\n\n  .lg\\:divide-none > :not(template) ~ :not(template) {\n    border-style: none;\n  }\n\n  .lg\\:divide-opacity-0 > :not(template) ~ :not(template) {\n    --divide-opacity: 0;\n  }\n\n  .lg\\:divide-opacity-25 > :not(template) ~ :not(template) {\n    --divide-opacity: 0.25;\n  }\n\n  .lg\\:divide-opacity-50 > :not(template) ~ :not(template) {\n    --divide-opacity: 0.5;\n  }\n\n  .lg\\:divide-opacity-75 > :not(template) ~ :not(template) {\n    --divide-opacity: 0.75;\n  }\n\n  .lg\\:divide-opacity-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n  }\n\n  .lg\\:sr-only {\n    position: absolute;\n    width: 1px;\n    height: 1px;\n    padding: 0;\n    margin: -1px;\n    overflow: hidden;\n    clip: rect(0, 0, 0, 0);\n    white-space: nowrap;\n    border-width: 0;\n  }\n\n  .lg\\:not-sr-only {\n    position: static;\n    width: auto;\n    height: auto;\n    padding: 0;\n    margin: 0;\n    overflow: visible;\n    clip: auto;\n    white-space: normal;\n  }\n\n  .lg\\:focus\\:sr-only:focus {\n    position: absolute;\n    width: 1px;\n    height: 1px;\n    padding: 0;\n    margin: -1px;\n    overflow: hidden;\n    clip: rect(0, 0, 0, 0);\n    white-space: nowrap;\n    border-width: 0;\n  }\n\n  .lg\\:focus\\:not-sr-only:focus {\n    position: static;\n    width: auto;\n    height: auto;\n    padding: 0;\n    margin: 0;\n    overflow: visible;\n    clip: auto;\n    white-space: normal;\n  }\n\n  .lg\\:appearance-none {\n    -webkit-appearance: none;\n       -moz-appearance: none;\n            appearance: none;\n  }\n\n  .lg\\:bg-fixed {\n    background-attachment: fixed;\n  }\n\n  .lg\\:bg-local {\n    background-attachment: local;\n  }\n\n  .lg\\:bg-scroll {\n    background-attachment: scroll;\n  }\n\n  .lg\\:bg-clip-border {\n    background-clip: border-box;\n  }\n\n  .lg\\:bg-clip-padding {\n    background-clip: padding-box;\n  }\n\n  .lg\\:bg-clip-content {\n    background-clip: content-box;\n  }\n\n  .lg\\:bg-clip-text {\n    -webkit-background-clip: text;\n            background-clip: text;\n  }\n\n  .lg\\:bg-transparent {\n    background-color: transparent;\n  }\n\n  .lg\\:bg-current {\n    background-color: currentColor;\n  }\n\n  .lg\\:bg-black {\n    --bg-opacity: 1;\n    background-color: #000;\n    background-color: rgba(0, 0, 0, var(--bg-opacity));\n  }\n\n  .lg\\:bg-white {\n    --bg-opacity: 1;\n    background-color: #fff;\n    background-color: rgba(255, 255, 255, var(--bg-opacity));\n  }\n\n  .lg\\:bg-gray-100 {\n    --bg-opacity: 1;\n    background-color: #f7fafc;\n    background-color: rgba(247, 250, 252, var(--bg-opacity));\n  }\n\n  .lg\\:bg-gray-200 {\n    --bg-opacity: 1;\n    background-color: #edf2f7;\n    background-color: rgba(237, 242, 247, var(--bg-opacity));\n  }\n\n  .lg\\:bg-gray-300 {\n    --bg-opacity: 1;\n    background-color: #e2e8f0;\n    background-color: rgba(226, 232, 240, var(--bg-opacity));\n  }\n\n  .lg\\:bg-gray-400 {\n    --bg-opacity: 1;\n    background-color: #cbd5e0;\n    background-color: rgba(203, 213, 224, var(--bg-opacity));\n  }\n\n  .lg\\:bg-gray-500 {\n    --bg-opacity: 1;\n    background-color: #a0aec0;\n    background-color: rgba(160, 174, 192, var(--bg-opacity));\n  }\n\n  .lg\\:bg-gray-600 {\n    --bg-opacity: 1;\n    background-color: #718096;\n    background-color: rgba(113, 128, 150, var(--bg-opacity));\n  }\n\n  .lg\\:bg-gray-700 {\n    --bg-opacity: 1;\n    background-color: #4a5568;\n    background-color: rgba(74, 85, 104, var(--bg-opacity));\n  }\n\n  .lg\\:bg-gray-800 {\n    --bg-opacity: 1;\n    background-color: #2d3748;\n    background-color: rgba(45, 55, 72, var(--bg-opacity));\n  }\n\n  .lg\\:bg-gray-900 {\n    --bg-opacity: 1;\n    background-color: #1a202c;\n    background-color: rgba(26, 32, 44, var(--bg-opacity));\n  }\n\n  .lg\\:bg-red-100 {\n    --bg-opacity: 1;\n    background-color: #fff5f5;\n    background-color: rgba(255, 245, 245, var(--bg-opacity));\n  }\n\n  .lg\\:bg-red-200 {\n    --bg-opacity: 1;\n    background-color: #fed7d7;\n    background-color: rgba(254, 215, 215, var(--bg-opacity));\n  }\n\n  .lg\\:bg-red-300 {\n    --bg-opacity: 1;\n    background-color: #feb2b2;\n    background-color: rgba(254, 178, 178, var(--bg-opacity));\n  }\n\n  .lg\\:bg-red-400 {\n    --bg-opacity: 1;\n    background-color: #fc8181;\n    background-color: rgba(252, 129, 129, var(--bg-opacity));\n  }\n\n  .lg\\:bg-red-500 {\n    --bg-opacity: 1;\n    background-color: #f56565;\n    background-color: rgba(245, 101, 101, var(--bg-opacity));\n  }\n\n  .lg\\:bg-red-600 {\n    --bg-opacity: 1;\n    background-color: #e53e3e;\n    background-color: rgba(229, 62, 62, var(--bg-opacity));\n  }\n\n  .lg\\:bg-red-700 {\n    --bg-opacity: 1;\n    background-color: #c53030;\n    background-color: rgba(197, 48, 48, var(--bg-opacity));\n  }\n\n  .lg\\:bg-red-800 {\n    --bg-opacity: 1;\n    background-color: #9b2c2c;\n    background-color: rgba(155, 44, 44, var(--bg-opacity));\n  }\n\n  .lg\\:bg-red-900 {\n    --bg-opacity: 1;\n    background-color: #742a2a;\n    background-color: rgba(116, 42, 42, var(--bg-opacity));\n  }\n\n  .lg\\:bg-orange-100 {\n    --bg-opacity: 1;\n    background-color: #fffaf0;\n    background-color: rgba(255, 250, 240, var(--bg-opacity));\n  }\n\n  .lg\\:bg-orange-200 {\n    --bg-opacity: 1;\n    background-color: #feebc8;\n    background-color: rgba(254, 235, 200, var(--bg-opacity));\n  }\n\n  .lg\\:bg-orange-300 {\n    --bg-opacity: 1;\n    background-color: #fbd38d;\n    background-color: rgba(251, 211, 141, var(--bg-opacity));\n  }\n\n  .lg\\:bg-orange-400 {\n    --bg-opacity: 1;\n    background-color: #f6ad55;\n    background-color: rgba(246, 173, 85, var(--bg-opacity));\n  }\n\n  .lg\\:bg-orange-500 {\n    --bg-opacity: 1;\n    background-color: #ed8936;\n    background-color: rgba(237, 137, 54, var(--bg-opacity));\n  }\n\n  .lg\\:bg-orange-600 {\n    --bg-opacity: 1;\n    background-color: #dd6b20;\n    background-color: rgba(221, 107, 32, var(--bg-opacity));\n  }\n\n  .lg\\:bg-orange-700 {\n    --bg-opacity: 1;\n    background-color: #c05621;\n    background-color: rgba(192, 86, 33, var(--bg-opacity));\n  }\n\n  .lg\\:bg-orange-800 {\n    --bg-opacity: 1;\n    background-color: #9c4221;\n    background-color: rgba(156, 66, 33, var(--bg-opacity));\n  }\n\n  .lg\\:bg-orange-900 {\n    --bg-opacity: 1;\n    background-color: #7b341e;\n    background-color: rgba(123, 52, 30, var(--bg-opacity));\n  }\n\n  .lg\\:bg-yellow-100 {\n    --bg-opacity: 1;\n    background-color: #fffff0;\n    background-color: rgba(255, 255, 240, var(--bg-opacity));\n  }\n\n  .lg\\:bg-yellow-200 {\n    --bg-opacity: 1;\n    background-color: #fefcbf;\n    background-color: rgba(254, 252, 191, var(--bg-opacity));\n  }\n\n  .lg\\:bg-yellow-300 {\n    --bg-opacity: 1;\n    background-color: #faf089;\n    background-color: rgba(250, 240, 137, var(--bg-opacity));\n  }\n\n  .lg\\:bg-yellow-400 {\n    --bg-opacity: 1;\n    background-color: #f6e05e;\n    background-color: rgba(246, 224, 94, var(--bg-opacity));\n  }\n\n  .lg\\:bg-yellow-500 {\n    --bg-opacity: 1;\n    background-color: #ecc94b;\n    background-color: rgba(236, 201, 75, var(--bg-opacity));\n  }\n\n  .lg\\:bg-yellow-600 {\n    --bg-opacity: 1;\n    background-color: #d69e2e;\n    background-color: rgba(214, 158, 46, var(--bg-opacity));\n  }\n\n  .lg\\:bg-yellow-700 {\n    --bg-opacity: 1;\n    background-color: #b7791f;\n    background-color: rgba(183, 121, 31, var(--bg-opacity));\n  }\n\n  .lg\\:bg-yellow-800 {\n    --bg-opacity: 1;\n    background-color: #975a16;\n    background-color: rgba(151, 90, 22, var(--bg-opacity));\n  }\n\n  .lg\\:bg-yellow-900 {\n    --bg-opacity: 1;\n    background-color: #744210;\n    background-color: rgba(116, 66, 16, var(--bg-opacity));\n  }\n\n  .lg\\:bg-green-100 {\n    --bg-opacity: 1;\n    background-color: #f0fff4;\n    background-color: rgba(240, 255, 244, var(--bg-opacity));\n  }\n\n  .lg\\:bg-green-200 {\n    --bg-opacity: 1;\n    background-color: #c6f6d5;\n    background-color: rgba(198, 246, 213, var(--bg-opacity));\n  }\n\n  .lg\\:bg-green-300 {\n    --bg-opacity: 1;\n    background-color: #9ae6b4;\n    background-color: rgba(154, 230, 180, var(--bg-opacity));\n  }\n\n  .lg\\:bg-green-400 {\n    --bg-opacity: 1;\n    background-color: #68d391;\n    background-color: rgba(104, 211, 145, var(--bg-opacity));\n  }\n\n  .lg\\:bg-green-500 {\n    --bg-opacity: 1;\n    background-color: #48bb78;\n    background-color: rgba(72, 187, 120, var(--bg-opacity));\n  }\n\n  .lg\\:bg-green-600 {\n    --bg-opacity: 1;\n    background-color: #38a169;\n    background-color: rgba(56, 161, 105, var(--bg-opacity));\n  }\n\n  .lg\\:bg-green-700 {\n    --bg-opacity: 1;\n    background-color: #2f855a;\n    background-color: rgba(47, 133, 90, var(--bg-opacity));\n  }\n\n  .lg\\:bg-green-800 {\n    --bg-opacity: 1;\n    background-color: #276749;\n    background-color: rgba(39, 103, 73, var(--bg-opacity));\n  }\n\n  .lg\\:bg-green-900 {\n    --bg-opacity: 1;\n    background-color: #22543d;\n    background-color: rgba(34, 84, 61, var(--bg-opacity));\n  }\n\n  .lg\\:bg-teal-100 {\n    --bg-opacity: 1;\n    background-color: #e6fffa;\n    background-color: rgba(230, 255, 250, var(--bg-opacity));\n  }\n\n  .lg\\:bg-teal-200 {\n    --bg-opacity: 1;\n    background-color: #b2f5ea;\n    background-color: rgba(178, 245, 234, var(--bg-opacity));\n  }\n\n  .lg\\:bg-teal-300 {\n    --bg-opacity: 1;\n    background-color: #81e6d9;\n    background-color: rgba(129, 230, 217, var(--bg-opacity));\n  }\n\n  .lg\\:bg-teal-400 {\n    --bg-opacity: 1;\n    background-color: #4fd1c5;\n    background-color: rgba(79, 209, 197, var(--bg-opacity));\n  }\n\n  .lg\\:bg-teal-500 {\n    --bg-opacity: 1;\n    background-color: #38b2ac;\n    background-color: rgba(56, 178, 172, var(--bg-opacity));\n  }\n\n  .lg\\:bg-teal-600 {\n    --bg-opacity: 1;\n    background-color: #319795;\n    background-color: rgba(49, 151, 149, var(--bg-opacity));\n  }\n\n  .lg\\:bg-teal-700 {\n    --bg-opacity: 1;\n    background-color: #2c7a7b;\n    background-color: rgba(44, 122, 123, var(--bg-opacity));\n  }\n\n  .lg\\:bg-teal-800 {\n    --bg-opacity: 1;\n    background-color: #285e61;\n    background-color: rgba(40, 94, 97, var(--bg-opacity));\n  }\n\n  .lg\\:bg-teal-900 {\n    --bg-opacity: 1;\n    background-color: #234e52;\n    background-color: rgba(35, 78, 82, var(--bg-opacity));\n  }\n\n  .lg\\:bg-blue-100 {\n    --bg-opacity: 1;\n    background-color: #ebf8ff;\n    background-color: rgba(235, 248, 255, var(--bg-opacity));\n  }\n\n  .lg\\:bg-blue-200 {\n    --bg-opacity: 1;\n    background-color: #bee3f8;\n    background-color: rgba(190, 227, 248, var(--bg-opacity));\n  }\n\n  .lg\\:bg-blue-300 {\n    --bg-opacity: 1;\n    background-color: #90cdf4;\n    background-color: rgba(144, 205, 244, var(--bg-opacity));\n  }\n\n  .lg\\:bg-blue-400 {\n    --bg-opacity: 1;\n    background-color: #63b3ed;\n    background-color: rgba(99, 179, 237, var(--bg-opacity));\n  }\n\n  .lg\\:bg-blue-500 {\n    --bg-opacity: 1;\n    background-color: #4299e1;\n    background-color: rgba(66, 153, 225, var(--bg-opacity));\n  }\n\n  .lg\\:bg-blue-600 {\n    --bg-opacity: 1;\n    background-color: #3182ce;\n    background-color: rgba(49, 130, 206, var(--bg-opacity));\n  }\n\n  .lg\\:bg-blue-700 {\n    --bg-opacity: 1;\n    background-color: #2b6cb0;\n    background-color: rgba(43, 108, 176, var(--bg-opacity));\n  }\n\n  .lg\\:bg-blue-800 {\n    --bg-opacity: 1;\n    background-color: #2c5282;\n    background-color: rgba(44, 82, 130, var(--bg-opacity));\n  }\n\n  .lg\\:bg-blue-900 {\n    --bg-opacity: 1;\n    background-color: #2a4365;\n    background-color: rgba(42, 67, 101, var(--bg-opacity));\n  }\n\n  .lg\\:bg-indigo-100 {\n    --bg-opacity: 1;\n    background-color: #ebf4ff;\n    background-color: rgba(235, 244, 255, var(--bg-opacity));\n  }\n\n  .lg\\:bg-indigo-200 {\n    --bg-opacity: 1;\n    background-color: #c3dafe;\n    background-color: rgba(195, 218, 254, var(--bg-opacity));\n  }\n\n  .lg\\:bg-indigo-300 {\n    --bg-opacity: 1;\n    background-color: #a3bffa;\n    background-color: rgba(163, 191, 250, var(--bg-opacity));\n  }\n\n  .lg\\:bg-indigo-400 {\n    --bg-opacity: 1;\n    background-color: #7f9cf5;\n    background-color: rgba(127, 156, 245, var(--bg-opacity));\n  }\n\n  .lg\\:bg-indigo-500 {\n    --bg-opacity: 1;\n    background-color: #667eea;\n    background-color: rgba(102, 126, 234, var(--bg-opacity));\n  }\n\n  .lg\\:bg-indigo-600 {\n    --bg-opacity: 1;\n    background-color: #5a67d8;\n    background-color: rgba(90, 103, 216, var(--bg-opacity));\n  }\n\n  .lg\\:bg-indigo-700 {\n    --bg-opacity: 1;\n    background-color: #4c51bf;\n    background-color: rgba(76, 81, 191, var(--bg-opacity));\n  }\n\n  .lg\\:bg-indigo-800 {\n    --bg-opacity: 1;\n    background-color: #434190;\n    background-color: rgba(67, 65, 144, var(--bg-opacity));\n  }\n\n  .lg\\:bg-indigo-900 {\n    --bg-opacity: 1;\n    background-color: #3c366b;\n    background-color: rgba(60, 54, 107, var(--bg-opacity));\n  }\n\n  .lg\\:bg-purple-100 {\n    --bg-opacity: 1;\n    background-color: #faf5ff;\n    background-color: rgba(250, 245, 255, var(--bg-opacity));\n  }\n\n  .lg\\:bg-purple-200 {\n    --bg-opacity: 1;\n    background-color: #e9d8fd;\n    background-color: rgba(233, 216, 253, var(--bg-opacity));\n  }\n\n  .lg\\:bg-purple-300 {\n    --bg-opacity: 1;\n    background-color: #d6bcfa;\n    background-color: rgba(214, 188, 250, var(--bg-opacity));\n  }\n\n  .lg\\:bg-purple-400 {\n    --bg-opacity: 1;\n    background-color: #b794f4;\n    background-color: rgba(183, 148, 244, var(--bg-opacity));\n  }\n\n  .lg\\:bg-purple-500 {\n    --bg-opacity: 1;\n    background-color: #9f7aea;\n    background-color: rgba(159, 122, 234, var(--bg-opacity));\n  }\n\n  .lg\\:bg-purple-600 {\n    --bg-opacity: 1;\n    background-color: #805ad5;\n    background-color: rgba(128, 90, 213, var(--bg-opacity));\n  }\n\n  .lg\\:bg-purple-700 {\n    --bg-opacity: 1;\n    background-color: #6b46c1;\n    background-color: rgba(107, 70, 193, var(--bg-opacity));\n  }\n\n  .lg\\:bg-purple-800 {\n    --bg-opacity: 1;\n    background-color: #553c9a;\n    background-color: rgba(85, 60, 154, var(--bg-opacity));\n  }\n\n  .lg\\:bg-purple-900 {\n    --bg-opacity: 1;\n    background-color: #44337a;\n    background-color: rgba(68, 51, 122, var(--bg-opacity));\n  }\n\n  .lg\\:bg-pink-100 {\n    --bg-opacity: 1;\n    background-color: #fff5f7;\n    background-color: rgba(255, 245, 247, var(--bg-opacity));\n  }\n\n  .lg\\:bg-pink-200 {\n    --bg-opacity: 1;\n    background-color: #fed7e2;\n    background-color: rgba(254, 215, 226, var(--bg-opacity));\n  }\n\n  .lg\\:bg-pink-300 {\n    --bg-opacity: 1;\n    background-color: #fbb6ce;\n    background-color: rgba(251, 182, 206, var(--bg-opacity));\n  }\n\n  .lg\\:bg-pink-400 {\n    --bg-opacity: 1;\n    background-color: #f687b3;\n    background-color: rgba(246, 135, 179, var(--bg-opacity));\n  }\n\n  .lg\\:bg-pink-500 {\n    --bg-opacity: 1;\n    background-color: #ed64a6;\n    background-color: rgba(237, 100, 166, var(--bg-opacity));\n  }\n\n  .lg\\:bg-pink-600 {\n    --bg-opacity: 1;\n    background-color: #d53f8c;\n    background-color: rgba(213, 63, 140, var(--bg-opacity));\n  }\n\n  .lg\\:bg-pink-700 {\n    --bg-opacity: 1;\n    background-color: #b83280;\n    background-color: rgba(184, 50, 128, var(--bg-opacity));\n  }\n\n  .lg\\:bg-pink-800 {\n    --bg-opacity: 1;\n    background-color: #97266d;\n    background-color: rgba(151, 38, 109, var(--bg-opacity));\n  }\n\n  .lg\\:bg-pink-900 {\n    --bg-opacity: 1;\n    background-color: #702459;\n    background-color: rgba(112, 36, 89, var(--bg-opacity));\n  }\n\n  .lg\\:bg-grayscale-80 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 8%);\n    background-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--bg-opacity));\n  }\n\n  .lg\\:bg-grayscale-100 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 10%);\n    background-color: rgba(25.5, 25.5, 25.5, var(--bg-opacity));\n  }\n\n  .lg\\:bg-grayscale-200 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 20%);\n    background-color: rgba(51, 51, 51, var(--bg-opacity));\n  }\n\n  .lg\\:bg-grayscale-300 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 30%);\n    background-color: rgba(76.5, 76.5, 76.5, var(--bg-opacity));\n  }\n\n  .lg\\:bg-grayscale-400 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 40%);\n    background-color: rgba(102, 102, 102, var(--bg-opacity));\n  }\n\n  .lg\\:bg-grayscale-500 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 50%);\n    background-color: rgba(127.5, 127.5, 127.5, var(--bg-opacity));\n  }\n\n  .lg\\:bg-grayscale-600 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 60%);\n    background-color: rgba(153, 153, 153, var(--bg-opacity));\n  }\n\n  .lg\\:bg-grayscale-700 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 70%);\n    background-color: rgba(178.5, 178.5, 178.5, var(--bg-opacity));\n  }\n\n  .lg\\:bg-grayscale-800 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 80%);\n    background-color: rgba(204, 204, 204, var(--bg-opacity));\n  }\n\n  .lg\\:bg-grayscale-840 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 84%);\n    background-color: rgba(214.2, 214.2, 214.2, var(--bg-opacity));\n  }\n\n  .lg\\:bg-grayscale-870 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 87%);\n    background-color: rgba(221.85, 221.85, 221.85, var(--bg-opacity));\n  }\n\n  .lg\\:bg-grayscale-900 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 90%);\n    background-color: rgba(229.5, 229.5, 229.5, var(--bg-opacity));\n  }\n\n  .lg\\:bg-grayscale-930 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 93%);\n    background-color: rgba(237.15, 237.15, 237.15, var(--bg-opacity));\n  }\n\n  .lg\\:bg-primary {\n    --bg-opacity: 1;\n    background-color: hsl(210, 100%, 52%);\n    background-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--bg-opacity));\n  }\n\n  .lg\\:bg-background-main {\n    background-color: var(--main-background);\n  }\n\n  .lg\\:bg-background-secondary {\n    background-color: var(--secondary-background);\n  }\n\n  .lg\\:bg-foreground {\n    background-color: var(--foreground);\n  }\n\n  .lg\\:bg-panels-bg {\n    background-color: var(--panels-background);\n  }\n\n  .lg\\:hover\\:bg-transparent:hover {\n    background-color: transparent;\n  }\n\n  .lg\\:hover\\:bg-current:hover {\n    background-color: currentColor;\n  }\n\n  .lg\\:hover\\:bg-black:hover {\n    --bg-opacity: 1;\n    background-color: #000;\n    background-color: rgba(0, 0, 0, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-white:hover {\n    --bg-opacity: 1;\n    background-color: #fff;\n    background-color: rgba(255, 255, 255, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-gray-100:hover {\n    --bg-opacity: 1;\n    background-color: #f7fafc;\n    background-color: rgba(247, 250, 252, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-gray-200:hover {\n    --bg-opacity: 1;\n    background-color: #edf2f7;\n    background-color: rgba(237, 242, 247, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-gray-300:hover {\n    --bg-opacity: 1;\n    background-color: #e2e8f0;\n    background-color: rgba(226, 232, 240, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-gray-400:hover {\n    --bg-opacity: 1;\n    background-color: #cbd5e0;\n    background-color: rgba(203, 213, 224, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-gray-500:hover {\n    --bg-opacity: 1;\n    background-color: #a0aec0;\n    background-color: rgba(160, 174, 192, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-gray-600:hover {\n    --bg-opacity: 1;\n    background-color: #718096;\n    background-color: rgba(113, 128, 150, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-gray-700:hover {\n    --bg-opacity: 1;\n    background-color: #4a5568;\n    background-color: rgba(74, 85, 104, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-gray-800:hover {\n    --bg-opacity: 1;\n    background-color: #2d3748;\n    background-color: rgba(45, 55, 72, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-gray-900:hover {\n    --bg-opacity: 1;\n    background-color: #1a202c;\n    background-color: rgba(26, 32, 44, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-red-100:hover {\n    --bg-opacity: 1;\n    background-color: #fff5f5;\n    background-color: rgba(255, 245, 245, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-red-200:hover {\n    --bg-opacity: 1;\n    background-color: #fed7d7;\n    background-color: rgba(254, 215, 215, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-red-300:hover {\n    --bg-opacity: 1;\n    background-color: #feb2b2;\n    background-color: rgba(254, 178, 178, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-red-400:hover {\n    --bg-opacity: 1;\n    background-color: #fc8181;\n    background-color: rgba(252, 129, 129, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-red-500:hover {\n    --bg-opacity: 1;\n    background-color: #f56565;\n    background-color: rgba(245, 101, 101, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-red-600:hover {\n    --bg-opacity: 1;\n    background-color: #e53e3e;\n    background-color: rgba(229, 62, 62, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-red-700:hover {\n    --bg-opacity: 1;\n    background-color: #c53030;\n    background-color: rgba(197, 48, 48, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-red-800:hover {\n    --bg-opacity: 1;\n    background-color: #9b2c2c;\n    background-color: rgba(155, 44, 44, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-red-900:hover {\n    --bg-opacity: 1;\n    background-color: #742a2a;\n    background-color: rgba(116, 42, 42, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-orange-100:hover {\n    --bg-opacity: 1;\n    background-color: #fffaf0;\n    background-color: rgba(255, 250, 240, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-orange-200:hover {\n    --bg-opacity: 1;\n    background-color: #feebc8;\n    background-color: rgba(254, 235, 200, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-orange-300:hover {\n    --bg-opacity: 1;\n    background-color: #fbd38d;\n    background-color: rgba(251, 211, 141, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-orange-400:hover {\n    --bg-opacity: 1;\n    background-color: #f6ad55;\n    background-color: rgba(246, 173, 85, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-orange-500:hover {\n    --bg-opacity: 1;\n    background-color: #ed8936;\n    background-color: rgba(237, 137, 54, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-orange-600:hover {\n    --bg-opacity: 1;\n    background-color: #dd6b20;\n    background-color: rgba(221, 107, 32, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-orange-700:hover {\n    --bg-opacity: 1;\n    background-color: #c05621;\n    background-color: rgba(192, 86, 33, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-orange-800:hover {\n    --bg-opacity: 1;\n    background-color: #9c4221;\n    background-color: rgba(156, 66, 33, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-orange-900:hover {\n    --bg-opacity: 1;\n    background-color: #7b341e;\n    background-color: rgba(123, 52, 30, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-yellow-100:hover {\n    --bg-opacity: 1;\n    background-color: #fffff0;\n    background-color: rgba(255, 255, 240, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-yellow-200:hover {\n    --bg-opacity: 1;\n    background-color: #fefcbf;\n    background-color: rgba(254, 252, 191, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-yellow-300:hover {\n    --bg-opacity: 1;\n    background-color: #faf089;\n    background-color: rgba(250, 240, 137, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-yellow-400:hover {\n    --bg-opacity: 1;\n    background-color: #f6e05e;\n    background-color: rgba(246, 224, 94, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-yellow-500:hover {\n    --bg-opacity: 1;\n    background-color: #ecc94b;\n    background-color: rgba(236, 201, 75, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-yellow-600:hover {\n    --bg-opacity: 1;\n    background-color: #d69e2e;\n    background-color: rgba(214, 158, 46, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-yellow-700:hover {\n    --bg-opacity: 1;\n    background-color: #b7791f;\n    background-color: rgba(183, 121, 31, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-yellow-800:hover {\n    --bg-opacity: 1;\n    background-color: #975a16;\n    background-color: rgba(151, 90, 22, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-yellow-900:hover {\n    --bg-opacity: 1;\n    background-color: #744210;\n    background-color: rgba(116, 66, 16, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-green-100:hover {\n    --bg-opacity: 1;\n    background-color: #f0fff4;\n    background-color: rgba(240, 255, 244, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-green-200:hover {\n    --bg-opacity: 1;\n    background-color: #c6f6d5;\n    background-color: rgba(198, 246, 213, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-green-300:hover {\n    --bg-opacity: 1;\n    background-color: #9ae6b4;\n    background-color: rgba(154, 230, 180, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-green-400:hover {\n    --bg-opacity: 1;\n    background-color: #68d391;\n    background-color: rgba(104, 211, 145, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-green-500:hover {\n    --bg-opacity: 1;\n    background-color: #48bb78;\n    background-color: rgba(72, 187, 120, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-green-600:hover {\n    --bg-opacity: 1;\n    background-color: #38a169;\n    background-color: rgba(56, 161, 105, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-green-700:hover {\n    --bg-opacity: 1;\n    background-color: #2f855a;\n    background-color: rgba(47, 133, 90, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-green-800:hover {\n    --bg-opacity: 1;\n    background-color: #276749;\n    background-color: rgba(39, 103, 73, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-green-900:hover {\n    --bg-opacity: 1;\n    background-color: #22543d;\n    background-color: rgba(34, 84, 61, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-teal-100:hover {\n    --bg-opacity: 1;\n    background-color: #e6fffa;\n    background-color: rgba(230, 255, 250, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-teal-200:hover {\n    --bg-opacity: 1;\n    background-color: #b2f5ea;\n    background-color: rgba(178, 245, 234, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-teal-300:hover {\n    --bg-opacity: 1;\n    background-color: #81e6d9;\n    background-color: rgba(129, 230, 217, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-teal-400:hover {\n    --bg-opacity: 1;\n    background-color: #4fd1c5;\n    background-color: rgba(79, 209, 197, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-teal-500:hover {\n    --bg-opacity: 1;\n    background-color: #38b2ac;\n    background-color: rgba(56, 178, 172, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-teal-600:hover {\n    --bg-opacity: 1;\n    background-color: #319795;\n    background-color: rgba(49, 151, 149, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-teal-700:hover {\n    --bg-opacity: 1;\n    background-color: #2c7a7b;\n    background-color: rgba(44, 122, 123, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-teal-800:hover {\n    --bg-opacity: 1;\n    background-color: #285e61;\n    background-color: rgba(40, 94, 97, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-teal-900:hover {\n    --bg-opacity: 1;\n    background-color: #234e52;\n    background-color: rgba(35, 78, 82, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-blue-100:hover {\n    --bg-opacity: 1;\n    background-color: #ebf8ff;\n    background-color: rgba(235, 248, 255, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-blue-200:hover {\n    --bg-opacity: 1;\n    background-color: #bee3f8;\n    background-color: rgba(190, 227, 248, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-blue-300:hover {\n    --bg-opacity: 1;\n    background-color: #90cdf4;\n    background-color: rgba(144, 205, 244, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-blue-400:hover {\n    --bg-opacity: 1;\n    background-color: #63b3ed;\n    background-color: rgba(99, 179, 237, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-blue-500:hover {\n    --bg-opacity: 1;\n    background-color: #4299e1;\n    background-color: rgba(66, 153, 225, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-blue-600:hover {\n    --bg-opacity: 1;\n    background-color: #3182ce;\n    background-color: rgba(49, 130, 206, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-blue-700:hover {\n    --bg-opacity: 1;\n    background-color: #2b6cb0;\n    background-color: rgba(43, 108, 176, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-blue-800:hover {\n    --bg-opacity: 1;\n    background-color: #2c5282;\n    background-color: rgba(44, 82, 130, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-blue-900:hover {\n    --bg-opacity: 1;\n    background-color: #2a4365;\n    background-color: rgba(42, 67, 101, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-indigo-100:hover {\n    --bg-opacity: 1;\n    background-color: #ebf4ff;\n    background-color: rgba(235, 244, 255, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-indigo-200:hover {\n    --bg-opacity: 1;\n    background-color: #c3dafe;\n    background-color: rgba(195, 218, 254, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-indigo-300:hover {\n    --bg-opacity: 1;\n    background-color: #a3bffa;\n    background-color: rgba(163, 191, 250, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-indigo-400:hover {\n    --bg-opacity: 1;\n    background-color: #7f9cf5;\n    background-color: rgba(127, 156, 245, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-indigo-500:hover {\n    --bg-opacity: 1;\n    background-color: #667eea;\n    background-color: rgba(102, 126, 234, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-indigo-600:hover {\n    --bg-opacity: 1;\n    background-color: #5a67d8;\n    background-color: rgba(90, 103, 216, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-indigo-700:hover {\n    --bg-opacity: 1;\n    background-color: #4c51bf;\n    background-color: rgba(76, 81, 191, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-indigo-800:hover {\n    --bg-opacity: 1;\n    background-color: #434190;\n    background-color: rgba(67, 65, 144, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-indigo-900:hover {\n    --bg-opacity: 1;\n    background-color: #3c366b;\n    background-color: rgba(60, 54, 107, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-purple-100:hover {\n    --bg-opacity: 1;\n    background-color: #faf5ff;\n    background-color: rgba(250, 245, 255, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-purple-200:hover {\n    --bg-opacity: 1;\n    background-color: #e9d8fd;\n    background-color: rgba(233, 216, 253, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-purple-300:hover {\n    --bg-opacity: 1;\n    background-color: #d6bcfa;\n    background-color: rgba(214, 188, 250, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-purple-400:hover {\n    --bg-opacity: 1;\n    background-color: #b794f4;\n    background-color: rgba(183, 148, 244, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-purple-500:hover {\n    --bg-opacity: 1;\n    background-color: #9f7aea;\n    background-color: rgba(159, 122, 234, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-purple-600:hover {\n    --bg-opacity: 1;\n    background-color: #805ad5;\n    background-color: rgba(128, 90, 213, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-purple-700:hover {\n    --bg-opacity: 1;\n    background-color: #6b46c1;\n    background-color: rgba(107, 70, 193, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-purple-800:hover {\n    --bg-opacity: 1;\n    background-color: #553c9a;\n    background-color: rgba(85, 60, 154, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-purple-900:hover {\n    --bg-opacity: 1;\n    background-color: #44337a;\n    background-color: rgba(68, 51, 122, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-pink-100:hover {\n    --bg-opacity: 1;\n    background-color: #fff5f7;\n    background-color: rgba(255, 245, 247, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-pink-200:hover {\n    --bg-opacity: 1;\n    background-color: #fed7e2;\n    background-color: rgba(254, 215, 226, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-pink-300:hover {\n    --bg-opacity: 1;\n    background-color: #fbb6ce;\n    background-color: rgba(251, 182, 206, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-pink-400:hover {\n    --bg-opacity: 1;\n    background-color: #f687b3;\n    background-color: rgba(246, 135, 179, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-pink-500:hover {\n    --bg-opacity: 1;\n    background-color: #ed64a6;\n    background-color: rgba(237, 100, 166, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-pink-600:hover {\n    --bg-opacity: 1;\n    background-color: #d53f8c;\n    background-color: rgba(213, 63, 140, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-pink-700:hover {\n    --bg-opacity: 1;\n    background-color: #b83280;\n    background-color: rgba(184, 50, 128, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-pink-800:hover {\n    --bg-opacity: 1;\n    background-color: #97266d;\n    background-color: rgba(151, 38, 109, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-pink-900:hover {\n    --bg-opacity: 1;\n    background-color: #702459;\n    background-color: rgba(112, 36, 89, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-grayscale-80:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 8%);\n    background-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-grayscale-100:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 10%);\n    background-color: rgba(25.5, 25.5, 25.5, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-grayscale-200:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 20%);\n    background-color: rgba(51, 51, 51, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-grayscale-300:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 30%);\n    background-color: rgba(76.5, 76.5, 76.5, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-grayscale-400:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 40%);\n    background-color: rgba(102, 102, 102, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-grayscale-500:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 50%);\n    background-color: rgba(127.5, 127.5, 127.5, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-grayscale-600:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 60%);\n    background-color: rgba(153, 153, 153, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-grayscale-700:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 70%);\n    background-color: rgba(178.5, 178.5, 178.5, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-grayscale-800:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 80%);\n    background-color: rgba(204, 204, 204, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-grayscale-840:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 84%);\n    background-color: rgba(214.2, 214.2, 214.2, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-grayscale-870:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 87%);\n    background-color: rgba(221.85, 221.85, 221.85, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-grayscale-900:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 90%);\n    background-color: rgba(229.5, 229.5, 229.5, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-grayscale-930:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 93%);\n    background-color: rgba(237.15, 237.15, 237.15, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-primary:hover {\n    --bg-opacity: 1;\n    background-color: hsl(210, 100%, 52%);\n    background-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--bg-opacity));\n  }\n\n  .lg\\:hover\\:bg-background-main:hover {\n    background-color: var(--main-background);\n  }\n\n  .lg\\:hover\\:bg-background-secondary:hover {\n    background-color: var(--secondary-background);\n  }\n\n  .lg\\:hover\\:bg-foreground:hover {\n    background-color: var(--foreground);\n  }\n\n  .lg\\:hover\\:bg-panels-bg:hover {\n    background-color: var(--panels-background);\n  }\n\n  .lg\\:focus\\:bg-transparent:focus {\n    background-color: transparent;\n  }\n\n  .lg\\:focus\\:bg-current:focus {\n    background-color: currentColor;\n  }\n\n  .lg\\:focus\\:bg-black:focus {\n    --bg-opacity: 1;\n    background-color: #000;\n    background-color: rgba(0, 0, 0, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-white:focus {\n    --bg-opacity: 1;\n    background-color: #fff;\n    background-color: rgba(255, 255, 255, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-gray-100:focus {\n    --bg-opacity: 1;\n    background-color: #f7fafc;\n    background-color: rgba(247, 250, 252, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-gray-200:focus {\n    --bg-opacity: 1;\n    background-color: #edf2f7;\n    background-color: rgba(237, 242, 247, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-gray-300:focus {\n    --bg-opacity: 1;\n    background-color: #e2e8f0;\n    background-color: rgba(226, 232, 240, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-gray-400:focus {\n    --bg-opacity: 1;\n    background-color: #cbd5e0;\n    background-color: rgba(203, 213, 224, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-gray-500:focus {\n    --bg-opacity: 1;\n    background-color: #a0aec0;\n    background-color: rgba(160, 174, 192, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-gray-600:focus {\n    --bg-opacity: 1;\n    background-color: #718096;\n    background-color: rgba(113, 128, 150, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-gray-700:focus {\n    --bg-opacity: 1;\n    background-color: #4a5568;\n    background-color: rgba(74, 85, 104, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-gray-800:focus {\n    --bg-opacity: 1;\n    background-color: #2d3748;\n    background-color: rgba(45, 55, 72, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-gray-900:focus {\n    --bg-opacity: 1;\n    background-color: #1a202c;\n    background-color: rgba(26, 32, 44, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-red-100:focus {\n    --bg-opacity: 1;\n    background-color: #fff5f5;\n    background-color: rgba(255, 245, 245, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-red-200:focus {\n    --bg-opacity: 1;\n    background-color: #fed7d7;\n    background-color: rgba(254, 215, 215, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-red-300:focus {\n    --bg-opacity: 1;\n    background-color: #feb2b2;\n    background-color: rgba(254, 178, 178, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-red-400:focus {\n    --bg-opacity: 1;\n    background-color: #fc8181;\n    background-color: rgba(252, 129, 129, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-red-500:focus {\n    --bg-opacity: 1;\n    background-color: #f56565;\n    background-color: rgba(245, 101, 101, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-red-600:focus {\n    --bg-opacity: 1;\n    background-color: #e53e3e;\n    background-color: rgba(229, 62, 62, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-red-700:focus {\n    --bg-opacity: 1;\n    background-color: #c53030;\n    background-color: rgba(197, 48, 48, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-red-800:focus {\n    --bg-opacity: 1;\n    background-color: #9b2c2c;\n    background-color: rgba(155, 44, 44, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-red-900:focus {\n    --bg-opacity: 1;\n    background-color: #742a2a;\n    background-color: rgba(116, 42, 42, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-orange-100:focus {\n    --bg-opacity: 1;\n    background-color: #fffaf0;\n    background-color: rgba(255, 250, 240, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-orange-200:focus {\n    --bg-opacity: 1;\n    background-color: #feebc8;\n    background-color: rgba(254, 235, 200, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-orange-300:focus {\n    --bg-opacity: 1;\n    background-color: #fbd38d;\n    background-color: rgba(251, 211, 141, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-orange-400:focus {\n    --bg-opacity: 1;\n    background-color: #f6ad55;\n    background-color: rgba(246, 173, 85, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-orange-500:focus {\n    --bg-opacity: 1;\n    background-color: #ed8936;\n    background-color: rgba(237, 137, 54, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-orange-600:focus {\n    --bg-opacity: 1;\n    background-color: #dd6b20;\n    background-color: rgba(221, 107, 32, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-orange-700:focus {\n    --bg-opacity: 1;\n    background-color: #c05621;\n    background-color: rgba(192, 86, 33, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-orange-800:focus {\n    --bg-opacity: 1;\n    background-color: #9c4221;\n    background-color: rgba(156, 66, 33, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-orange-900:focus {\n    --bg-opacity: 1;\n    background-color: #7b341e;\n    background-color: rgba(123, 52, 30, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-yellow-100:focus {\n    --bg-opacity: 1;\n    background-color: #fffff0;\n    background-color: rgba(255, 255, 240, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-yellow-200:focus {\n    --bg-opacity: 1;\n    background-color: #fefcbf;\n    background-color: rgba(254, 252, 191, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-yellow-300:focus {\n    --bg-opacity: 1;\n    background-color: #faf089;\n    background-color: rgba(250, 240, 137, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-yellow-400:focus {\n    --bg-opacity: 1;\n    background-color: #f6e05e;\n    background-color: rgba(246, 224, 94, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-yellow-500:focus {\n    --bg-opacity: 1;\n    background-color: #ecc94b;\n    background-color: rgba(236, 201, 75, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-yellow-600:focus {\n    --bg-opacity: 1;\n    background-color: #d69e2e;\n    background-color: rgba(214, 158, 46, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-yellow-700:focus {\n    --bg-opacity: 1;\n    background-color: #b7791f;\n    background-color: rgba(183, 121, 31, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-yellow-800:focus {\n    --bg-opacity: 1;\n    background-color: #975a16;\n    background-color: rgba(151, 90, 22, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-yellow-900:focus {\n    --bg-opacity: 1;\n    background-color: #744210;\n    background-color: rgba(116, 66, 16, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-green-100:focus {\n    --bg-opacity: 1;\n    background-color: #f0fff4;\n    background-color: rgba(240, 255, 244, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-green-200:focus {\n    --bg-opacity: 1;\n    background-color: #c6f6d5;\n    background-color: rgba(198, 246, 213, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-green-300:focus {\n    --bg-opacity: 1;\n    background-color: #9ae6b4;\n    background-color: rgba(154, 230, 180, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-green-400:focus {\n    --bg-opacity: 1;\n    background-color: #68d391;\n    background-color: rgba(104, 211, 145, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-green-500:focus {\n    --bg-opacity: 1;\n    background-color: #48bb78;\n    background-color: rgba(72, 187, 120, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-green-600:focus {\n    --bg-opacity: 1;\n    background-color: #38a169;\n    background-color: rgba(56, 161, 105, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-green-700:focus {\n    --bg-opacity: 1;\n    background-color: #2f855a;\n    background-color: rgba(47, 133, 90, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-green-800:focus {\n    --bg-opacity: 1;\n    background-color: #276749;\n    background-color: rgba(39, 103, 73, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-green-900:focus {\n    --bg-opacity: 1;\n    background-color: #22543d;\n    background-color: rgba(34, 84, 61, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-teal-100:focus {\n    --bg-opacity: 1;\n    background-color: #e6fffa;\n    background-color: rgba(230, 255, 250, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-teal-200:focus {\n    --bg-opacity: 1;\n    background-color: #b2f5ea;\n    background-color: rgba(178, 245, 234, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-teal-300:focus {\n    --bg-opacity: 1;\n    background-color: #81e6d9;\n    background-color: rgba(129, 230, 217, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-teal-400:focus {\n    --bg-opacity: 1;\n    background-color: #4fd1c5;\n    background-color: rgba(79, 209, 197, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-teal-500:focus {\n    --bg-opacity: 1;\n    background-color: #38b2ac;\n    background-color: rgba(56, 178, 172, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-teal-600:focus {\n    --bg-opacity: 1;\n    background-color: #319795;\n    background-color: rgba(49, 151, 149, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-teal-700:focus {\n    --bg-opacity: 1;\n    background-color: #2c7a7b;\n    background-color: rgba(44, 122, 123, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-teal-800:focus {\n    --bg-opacity: 1;\n    background-color: #285e61;\n    background-color: rgba(40, 94, 97, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-teal-900:focus {\n    --bg-opacity: 1;\n    background-color: #234e52;\n    background-color: rgba(35, 78, 82, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-blue-100:focus {\n    --bg-opacity: 1;\n    background-color: #ebf8ff;\n    background-color: rgba(235, 248, 255, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-blue-200:focus {\n    --bg-opacity: 1;\n    background-color: #bee3f8;\n    background-color: rgba(190, 227, 248, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-blue-300:focus {\n    --bg-opacity: 1;\n    background-color: #90cdf4;\n    background-color: rgba(144, 205, 244, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-blue-400:focus {\n    --bg-opacity: 1;\n    background-color: #63b3ed;\n    background-color: rgba(99, 179, 237, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-blue-500:focus {\n    --bg-opacity: 1;\n    background-color: #4299e1;\n    background-color: rgba(66, 153, 225, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-blue-600:focus {\n    --bg-opacity: 1;\n    background-color: #3182ce;\n    background-color: rgba(49, 130, 206, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-blue-700:focus {\n    --bg-opacity: 1;\n    background-color: #2b6cb0;\n    background-color: rgba(43, 108, 176, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-blue-800:focus {\n    --bg-opacity: 1;\n    background-color: #2c5282;\n    background-color: rgba(44, 82, 130, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-blue-900:focus {\n    --bg-opacity: 1;\n    background-color: #2a4365;\n    background-color: rgba(42, 67, 101, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-indigo-100:focus {\n    --bg-opacity: 1;\n    background-color: #ebf4ff;\n    background-color: rgba(235, 244, 255, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-indigo-200:focus {\n    --bg-opacity: 1;\n    background-color: #c3dafe;\n    background-color: rgba(195, 218, 254, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-indigo-300:focus {\n    --bg-opacity: 1;\n    background-color: #a3bffa;\n    background-color: rgba(163, 191, 250, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-indigo-400:focus {\n    --bg-opacity: 1;\n    background-color: #7f9cf5;\n    background-color: rgba(127, 156, 245, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-indigo-500:focus {\n    --bg-opacity: 1;\n    background-color: #667eea;\n    background-color: rgba(102, 126, 234, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-indigo-600:focus {\n    --bg-opacity: 1;\n    background-color: #5a67d8;\n    background-color: rgba(90, 103, 216, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-indigo-700:focus {\n    --bg-opacity: 1;\n    background-color: #4c51bf;\n    background-color: rgba(76, 81, 191, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-indigo-800:focus {\n    --bg-opacity: 1;\n    background-color: #434190;\n    background-color: rgba(67, 65, 144, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-indigo-900:focus {\n    --bg-opacity: 1;\n    background-color: #3c366b;\n    background-color: rgba(60, 54, 107, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-purple-100:focus {\n    --bg-opacity: 1;\n    background-color: #faf5ff;\n    background-color: rgba(250, 245, 255, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-purple-200:focus {\n    --bg-opacity: 1;\n    background-color: #e9d8fd;\n    background-color: rgba(233, 216, 253, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-purple-300:focus {\n    --bg-opacity: 1;\n    background-color: #d6bcfa;\n    background-color: rgba(214, 188, 250, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-purple-400:focus {\n    --bg-opacity: 1;\n    background-color: #b794f4;\n    background-color: rgba(183, 148, 244, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-purple-500:focus {\n    --bg-opacity: 1;\n    background-color: #9f7aea;\n    background-color: rgba(159, 122, 234, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-purple-600:focus {\n    --bg-opacity: 1;\n    background-color: #805ad5;\n    background-color: rgba(128, 90, 213, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-purple-700:focus {\n    --bg-opacity: 1;\n    background-color: #6b46c1;\n    background-color: rgba(107, 70, 193, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-purple-800:focus {\n    --bg-opacity: 1;\n    background-color: #553c9a;\n    background-color: rgba(85, 60, 154, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-purple-900:focus {\n    --bg-opacity: 1;\n    background-color: #44337a;\n    background-color: rgba(68, 51, 122, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-pink-100:focus {\n    --bg-opacity: 1;\n    background-color: #fff5f7;\n    background-color: rgba(255, 245, 247, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-pink-200:focus {\n    --bg-opacity: 1;\n    background-color: #fed7e2;\n    background-color: rgba(254, 215, 226, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-pink-300:focus {\n    --bg-opacity: 1;\n    background-color: #fbb6ce;\n    background-color: rgba(251, 182, 206, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-pink-400:focus {\n    --bg-opacity: 1;\n    background-color: #f687b3;\n    background-color: rgba(246, 135, 179, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-pink-500:focus {\n    --bg-opacity: 1;\n    background-color: #ed64a6;\n    background-color: rgba(237, 100, 166, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-pink-600:focus {\n    --bg-opacity: 1;\n    background-color: #d53f8c;\n    background-color: rgba(213, 63, 140, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-pink-700:focus {\n    --bg-opacity: 1;\n    background-color: #b83280;\n    background-color: rgba(184, 50, 128, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-pink-800:focus {\n    --bg-opacity: 1;\n    background-color: #97266d;\n    background-color: rgba(151, 38, 109, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-pink-900:focus {\n    --bg-opacity: 1;\n    background-color: #702459;\n    background-color: rgba(112, 36, 89, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-grayscale-80:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 8%);\n    background-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-grayscale-100:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 10%);\n    background-color: rgba(25.5, 25.5, 25.5, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-grayscale-200:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 20%);\n    background-color: rgba(51, 51, 51, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-grayscale-300:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 30%);\n    background-color: rgba(76.5, 76.5, 76.5, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-grayscale-400:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 40%);\n    background-color: rgba(102, 102, 102, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-grayscale-500:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 50%);\n    background-color: rgba(127.5, 127.5, 127.5, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-grayscale-600:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 60%);\n    background-color: rgba(153, 153, 153, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-grayscale-700:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 70%);\n    background-color: rgba(178.5, 178.5, 178.5, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-grayscale-800:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 80%);\n    background-color: rgba(204, 204, 204, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-grayscale-840:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 84%);\n    background-color: rgba(214.2, 214.2, 214.2, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-grayscale-870:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 87%);\n    background-color: rgba(221.85, 221.85, 221.85, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-grayscale-900:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 90%);\n    background-color: rgba(229.5, 229.5, 229.5, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-grayscale-930:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 93%);\n    background-color: rgba(237.15, 237.15, 237.15, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-primary:focus {\n    --bg-opacity: 1;\n    background-color: hsl(210, 100%, 52%);\n    background-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--bg-opacity));\n  }\n\n  .lg\\:focus\\:bg-background-main:focus {\n    background-color: var(--main-background);\n  }\n\n  .lg\\:focus\\:bg-background-secondary:focus {\n    background-color: var(--secondary-background);\n  }\n\n  .lg\\:focus\\:bg-foreground:focus {\n    background-color: var(--foreground);\n  }\n\n  .lg\\:focus\\:bg-panels-bg:focus {\n    background-color: var(--panels-background);\n  }\n\n  .lg\\:bg-none {\n    background-image: none;\n  }\n\n  .lg\\:bg-gradient-to-t {\n    background-image: linear-gradient(to top, var(--gradient-color-stops));\n  }\n\n  .lg\\:bg-gradient-to-tr {\n    background-image: linear-gradient(to top right, var(--gradient-color-stops));\n  }\n\n  .lg\\:bg-gradient-to-r {\n    background-image: linear-gradient(to right, var(--gradient-color-stops));\n  }\n\n  .lg\\:bg-gradient-to-br {\n    background-image: linear-gradient(to bottom right, var(--gradient-color-stops));\n  }\n\n  .lg\\:bg-gradient-to-b {\n    background-image: linear-gradient(to bottom, var(--gradient-color-stops));\n  }\n\n  .lg\\:bg-gradient-to-bl {\n    background-image: linear-gradient(to bottom left, var(--gradient-color-stops));\n  }\n\n  .lg\\:bg-gradient-to-l {\n    background-image: linear-gradient(to left, var(--gradient-color-stops));\n  }\n\n  .lg\\:bg-gradient-to-tl {\n    background-image: linear-gradient(to top left, var(--gradient-color-stops));\n  }\n\n  .lg\\:from-transparent {\n    --gradient-from-color: transparent;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .lg\\:from-current {\n    --gradient-from-color: currentColor;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:from-black {\n    --gradient-from-color: #000;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .lg\\:from-white {\n    --gradient-from-color: #fff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:from-gray-100 {\n    --gradient-from-color: #f7fafc;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n  }\n\n  .lg\\:from-gray-200 {\n    --gradient-from-color: #edf2f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n  }\n\n  .lg\\:from-gray-300 {\n    --gradient-from-color: #e2e8f0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n  }\n\n  .lg\\:from-gray-400 {\n    --gradient-from-color: #cbd5e0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n  }\n\n  .lg\\:from-gray-500 {\n    --gradient-from-color: #a0aec0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n  }\n\n  .lg\\:from-gray-600 {\n    --gradient-from-color: #718096;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n  }\n\n  .lg\\:from-gray-700 {\n    --gradient-from-color: #4a5568;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n  }\n\n  .lg\\:from-gray-800 {\n    --gradient-from-color: #2d3748;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n  }\n\n  .lg\\:from-gray-900 {\n    --gradient-from-color: #1a202c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n  }\n\n  .lg\\:from-red-100 {\n    --gradient-from-color: #fff5f5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n  }\n\n  .lg\\:from-red-200 {\n    --gradient-from-color: #fed7d7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n  }\n\n  .lg\\:from-red-300 {\n    --gradient-from-color: #feb2b2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n  }\n\n  .lg\\:from-red-400 {\n    --gradient-from-color: #fc8181;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n  }\n\n  .lg\\:from-red-500 {\n    --gradient-from-color: #f56565;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n  }\n\n  .lg\\:from-red-600 {\n    --gradient-from-color: #e53e3e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n  }\n\n  .lg\\:from-red-700 {\n    --gradient-from-color: #c53030;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n  }\n\n  .lg\\:from-red-800 {\n    --gradient-from-color: #9b2c2c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n  }\n\n  .lg\\:from-red-900 {\n    --gradient-from-color: #742a2a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n  }\n\n  .lg\\:from-orange-100 {\n    --gradient-from-color: #fffaf0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n  }\n\n  .lg\\:from-orange-200 {\n    --gradient-from-color: #feebc8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n  }\n\n  .lg\\:from-orange-300 {\n    --gradient-from-color: #fbd38d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n  }\n\n  .lg\\:from-orange-400 {\n    --gradient-from-color: #f6ad55;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n  }\n\n  .lg\\:from-orange-500 {\n    --gradient-from-color: #ed8936;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n  }\n\n  .lg\\:from-orange-600 {\n    --gradient-from-color: #dd6b20;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n  }\n\n  .lg\\:from-orange-700 {\n    --gradient-from-color: #c05621;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n  }\n\n  .lg\\:from-orange-800 {\n    --gradient-from-color: #9c4221;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n  }\n\n  .lg\\:from-orange-900 {\n    --gradient-from-color: #7b341e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n  }\n\n  .lg\\:from-yellow-100 {\n    --gradient-from-color: #fffff0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n  }\n\n  .lg\\:from-yellow-200 {\n    --gradient-from-color: #fefcbf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n  }\n\n  .lg\\:from-yellow-300 {\n    --gradient-from-color: #faf089;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n  }\n\n  .lg\\:from-yellow-400 {\n    --gradient-from-color: #f6e05e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n  }\n\n  .lg\\:from-yellow-500 {\n    --gradient-from-color: #ecc94b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n  }\n\n  .lg\\:from-yellow-600 {\n    --gradient-from-color: #d69e2e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n  }\n\n  .lg\\:from-yellow-700 {\n    --gradient-from-color: #b7791f;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n  }\n\n  .lg\\:from-yellow-800 {\n    --gradient-from-color: #975a16;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n  }\n\n  .lg\\:from-yellow-900 {\n    --gradient-from-color: #744210;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n  }\n\n  .lg\\:from-green-100 {\n    --gradient-from-color: #f0fff4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n  }\n\n  .lg\\:from-green-200 {\n    --gradient-from-color: #c6f6d5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n  }\n\n  .lg\\:from-green-300 {\n    --gradient-from-color: #9ae6b4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n  }\n\n  .lg\\:from-green-400 {\n    --gradient-from-color: #68d391;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n  }\n\n  .lg\\:from-green-500 {\n    --gradient-from-color: #48bb78;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n  }\n\n  .lg\\:from-green-600 {\n    --gradient-from-color: #38a169;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n  }\n\n  .lg\\:from-green-700 {\n    --gradient-from-color: #2f855a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n  }\n\n  .lg\\:from-green-800 {\n    --gradient-from-color: #276749;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n  }\n\n  .lg\\:from-green-900 {\n    --gradient-from-color: #22543d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n  }\n\n  .lg\\:from-teal-100 {\n    --gradient-from-color: #e6fffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n  }\n\n  .lg\\:from-teal-200 {\n    --gradient-from-color: #b2f5ea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n  }\n\n  .lg\\:from-teal-300 {\n    --gradient-from-color: #81e6d9;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n  }\n\n  .lg\\:from-teal-400 {\n    --gradient-from-color: #4fd1c5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n  }\n\n  .lg\\:from-teal-500 {\n    --gradient-from-color: #38b2ac;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n  }\n\n  .lg\\:from-teal-600 {\n    --gradient-from-color: #319795;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n  }\n\n  .lg\\:from-teal-700 {\n    --gradient-from-color: #2c7a7b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n  }\n\n  .lg\\:from-teal-800 {\n    --gradient-from-color: #285e61;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n  }\n\n  .lg\\:from-teal-900 {\n    --gradient-from-color: #234e52;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n  }\n\n  .lg\\:from-blue-100 {\n    --gradient-from-color: #ebf8ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n  }\n\n  .lg\\:from-blue-200 {\n    --gradient-from-color: #bee3f8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n  }\n\n  .lg\\:from-blue-300 {\n    --gradient-from-color: #90cdf4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n  }\n\n  .lg\\:from-blue-400 {\n    --gradient-from-color: #63b3ed;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n  }\n\n  .lg\\:from-blue-500 {\n    --gradient-from-color: #4299e1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n  }\n\n  .lg\\:from-blue-600 {\n    --gradient-from-color: #3182ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n  }\n\n  .lg\\:from-blue-700 {\n    --gradient-from-color: #2b6cb0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n  }\n\n  .lg\\:from-blue-800 {\n    --gradient-from-color: #2c5282;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n  }\n\n  .lg\\:from-blue-900 {\n    --gradient-from-color: #2a4365;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n  }\n\n  .lg\\:from-indigo-100 {\n    --gradient-from-color: #ebf4ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n  }\n\n  .lg\\:from-indigo-200 {\n    --gradient-from-color: #c3dafe;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n  }\n\n  .lg\\:from-indigo-300 {\n    --gradient-from-color: #a3bffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n  }\n\n  .lg\\:from-indigo-400 {\n    --gradient-from-color: #7f9cf5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n  }\n\n  .lg\\:from-indigo-500 {\n    --gradient-from-color: #667eea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n  }\n\n  .lg\\:from-indigo-600 {\n    --gradient-from-color: #5a67d8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n  }\n\n  .lg\\:from-indigo-700 {\n    --gradient-from-color: #4c51bf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n  }\n\n  .lg\\:from-indigo-800 {\n    --gradient-from-color: #434190;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n  }\n\n  .lg\\:from-indigo-900 {\n    --gradient-from-color: #3c366b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n  }\n\n  .lg\\:from-purple-100 {\n    --gradient-from-color: #faf5ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n  }\n\n  .lg\\:from-purple-200 {\n    --gradient-from-color: #e9d8fd;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n  }\n\n  .lg\\:from-purple-300 {\n    --gradient-from-color: #d6bcfa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n  }\n\n  .lg\\:from-purple-400 {\n    --gradient-from-color: #b794f4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n  }\n\n  .lg\\:from-purple-500 {\n    --gradient-from-color: #9f7aea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n  }\n\n  .lg\\:from-purple-600 {\n    --gradient-from-color: #805ad5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n  }\n\n  .lg\\:from-purple-700 {\n    --gradient-from-color: #6b46c1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n  }\n\n  .lg\\:from-purple-800 {\n    --gradient-from-color: #553c9a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n  }\n\n  .lg\\:from-purple-900 {\n    --gradient-from-color: #44337a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n  }\n\n  .lg\\:from-pink-100 {\n    --gradient-from-color: #fff5f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n  }\n\n  .lg\\:from-pink-200 {\n    --gradient-from-color: #fed7e2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n  }\n\n  .lg\\:from-pink-300 {\n    --gradient-from-color: #fbb6ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n  }\n\n  .lg\\:from-pink-400 {\n    --gradient-from-color: #f687b3;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n  }\n\n  .lg\\:from-pink-500 {\n    --gradient-from-color: #ed64a6;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n  }\n\n  .lg\\:from-pink-600 {\n    --gradient-from-color: #d53f8c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n  }\n\n  .lg\\:from-pink-700 {\n    --gradient-from-color: #b83280;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n  }\n\n  .lg\\:from-pink-800 {\n    --gradient-from-color: #97266d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n  }\n\n  .lg\\:from-pink-900 {\n    --gradient-from-color: #702459;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n  }\n\n  .lg\\:from-grayscale-80 {\n    --gradient-from-color: hsl(0, 0%, 8%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n  }\n\n  .lg\\:from-grayscale-100 {\n    --gradient-from-color: hsl(0, 0%, 10%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n  }\n\n  .lg\\:from-grayscale-200 {\n    --gradient-from-color: hsl(0, 0%, 20%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n  }\n\n  .lg\\:from-grayscale-300 {\n    --gradient-from-color: hsl(0, 0%, 30%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n  }\n\n  .lg\\:from-grayscale-400 {\n    --gradient-from-color: hsl(0, 0%, 40%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n  }\n\n  .lg\\:from-grayscale-500 {\n    --gradient-from-color: hsl(0, 0%, 50%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n  }\n\n  .lg\\:from-grayscale-600 {\n    --gradient-from-color: hsl(0, 0%, 60%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n  }\n\n  .lg\\:from-grayscale-700 {\n    --gradient-from-color: hsl(0, 0%, 70%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n  }\n\n  .lg\\:from-grayscale-800 {\n    --gradient-from-color: hsl(0, 0%, 80%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n  }\n\n  .lg\\:from-grayscale-840 {\n    --gradient-from-color: hsl(0, 0%, 84%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n  }\n\n  .lg\\:from-grayscale-870 {\n    --gradient-from-color: hsl(0, 0%, 87%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n  }\n\n  .lg\\:from-grayscale-900 {\n    --gradient-from-color: hsl(0, 0%, 90%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n  }\n\n  .lg\\:from-grayscale-930 {\n    --gradient-from-color: hsl(0, 0%, 93%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n  }\n\n  .lg\\:from-primary {\n    --gradient-from-color: hsl(210, 100%, 52%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n  }\n\n  .lg\\:from-background-main {\n    --gradient-from-color: var(--main-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:from-background-secondary {\n    --gradient-from-color: var(--secondary-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:from-foreground {\n    --gradient-from-color: var(--foreground);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:from-panels-bg {\n    --gradient-from-color: var(--panels-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:via-transparent {\n    --gradient-via-color: transparent;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .lg\\:via-current {\n    --gradient-via-color: currentColor;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:via-black {\n    --gradient-via-color: #000;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .lg\\:via-white {\n    --gradient-via-color: #fff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:via-gray-100 {\n    --gradient-via-color: #f7fafc;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n  }\n\n  .lg\\:via-gray-200 {\n    --gradient-via-color: #edf2f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n  }\n\n  .lg\\:via-gray-300 {\n    --gradient-via-color: #e2e8f0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n  }\n\n  .lg\\:via-gray-400 {\n    --gradient-via-color: #cbd5e0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n  }\n\n  .lg\\:via-gray-500 {\n    --gradient-via-color: #a0aec0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n  }\n\n  .lg\\:via-gray-600 {\n    --gradient-via-color: #718096;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n  }\n\n  .lg\\:via-gray-700 {\n    --gradient-via-color: #4a5568;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n  }\n\n  .lg\\:via-gray-800 {\n    --gradient-via-color: #2d3748;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n  }\n\n  .lg\\:via-gray-900 {\n    --gradient-via-color: #1a202c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n  }\n\n  .lg\\:via-red-100 {\n    --gradient-via-color: #fff5f5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n  }\n\n  .lg\\:via-red-200 {\n    --gradient-via-color: #fed7d7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n  }\n\n  .lg\\:via-red-300 {\n    --gradient-via-color: #feb2b2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n  }\n\n  .lg\\:via-red-400 {\n    --gradient-via-color: #fc8181;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n  }\n\n  .lg\\:via-red-500 {\n    --gradient-via-color: #f56565;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n  }\n\n  .lg\\:via-red-600 {\n    --gradient-via-color: #e53e3e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n  }\n\n  .lg\\:via-red-700 {\n    --gradient-via-color: #c53030;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n  }\n\n  .lg\\:via-red-800 {\n    --gradient-via-color: #9b2c2c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n  }\n\n  .lg\\:via-red-900 {\n    --gradient-via-color: #742a2a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n  }\n\n  .lg\\:via-orange-100 {\n    --gradient-via-color: #fffaf0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n  }\n\n  .lg\\:via-orange-200 {\n    --gradient-via-color: #feebc8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n  }\n\n  .lg\\:via-orange-300 {\n    --gradient-via-color: #fbd38d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n  }\n\n  .lg\\:via-orange-400 {\n    --gradient-via-color: #f6ad55;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n  }\n\n  .lg\\:via-orange-500 {\n    --gradient-via-color: #ed8936;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n  }\n\n  .lg\\:via-orange-600 {\n    --gradient-via-color: #dd6b20;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n  }\n\n  .lg\\:via-orange-700 {\n    --gradient-via-color: #c05621;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n  }\n\n  .lg\\:via-orange-800 {\n    --gradient-via-color: #9c4221;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n  }\n\n  .lg\\:via-orange-900 {\n    --gradient-via-color: #7b341e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n  }\n\n  .lg\\:via-yellow-100 {\n    --gradient-via-color: #fffff0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n  }\n\n  .lg\\:via-yellow-200 {\n    --gradient-via-color: #fefcbf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n  }\n\n  .lg\\:via-yellow-300 {\n    --gradient-via-color: #faf089;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n  }\n\n  .lg\\:via-yellow-400 {\n    --gradient-via-color: #f6e05e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n  }\n\n  .lg\\:via-yellow-500 {\n    --gradient-via-color: #ecc94b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n  }\n\n  .lg\\:via-yellow-600 {\n    --gradient-via-color: #d69e2e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n  }\n\n  .lg\\:via-yellow-700 {\n    --gradient-via-color: #b7791f;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n  }\n\n  .lg\\:via-yellow-800 {\n    --gradient-via-color: #975a16;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n  }\n\n  .lg\\:via-yellow-900 {\n    --gradient-via-color: #744210;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n  }\n\n  .lg\\:via-green-100 {\n    --gradient-via-color: #f0fff4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n  }\n\n  .lg\\:via-green-200 {\n    --gradient-via-color: #c6f6d5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n  }\n\n  .lg\\:via-green-300 {\n    --gradient-via-color: #9ae6b4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n  }\n\n  .lg\\:via-green-400 {\n    --gradient-via-color: #68d391;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n  }\n\n  .lg\\:via-green-500 {\n    --gradient-via-color: #48bb78;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n  }\n\n  .lg\\:via-green-600 {\n    --gradient-via-color: #38a169;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n  }\n\n  .lg\\:via-green-700 {\n    --gradient-via-color: #2f855a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n  }\n\n  .lg\\:via-green-800 {\n    --gradient-via-color: #276749;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n  }\n\n  .lg\\:via-green-900 {\n    --gradient-via-color: #22543d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n  }\n\n  .lg\\:via-teal-100 {\n    --gradient-via-color: #e6fffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n  }\n\n  .lg\\:via-teal-200 {\n    --gradient-via-color: #b2f5ea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n  }\n\n  .lg\\:via-teal-300 {\n    --gradient-via-color: #81e6d9;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n  }\n\n  .lg\\:via-teal-400 {\n    --gradient-via-color: #4fd1c5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n  }\n\n  .lg\\:via-teal-500 {\n    --gradient-via-color: #38b2ac;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n  }\n\n  .lg\\:via-teal-600 {\n    --gradient-via-color: #319795;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n  }\n\n  .lg\\:via-teal-700 {\n    --gradient-via-color: #2c7a7b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n  }\n\n  .lg\\:via-teal-800 {\n    --gradient-via-color: #285e61;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n  }\n\n  .lg\\:via-teal-900 {\n    --gradient-via-color: #234e52;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n  }\n\n  .lg\\:via-blue-100 {\n    --gradient-via-color: #ebf8ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n  }\n\n  .lg\\:via-blue-200 {\n    --gradient-via-color: #bee3f8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n  }\n\n  .lg\\:via-blue-300 {\n    --gradient-via-color: #90cdf4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n  }\n\n  .lg\\:via-blue-400 {\n    --gradient-via-color: #63b3ed;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n  }\n\n  .lg\\:via-blue-500 {\n    --gradient-via-color: #4299e1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n  }\n\n  .lg\\:via-blue-600 {\n    --gradient-via-color: #3182ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n  }\n\n  .lg\\:via-blue-700 {\n    --gradient-via-color: #2b6cb0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n  }\n\n  .lg\\:via-blue-800 {\n    --gradient-via-color: #2c5282;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n  }\n\n  .lg\\:via-blue-900 {\n    --gradient-via-color: #2a4365;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n  }\n\n  .lg\\:via-indigo-100 {\n    --gradient-via-color: #ebf4ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n  }\n\n  .lg\\:via-indigo-200 {\n    --gradient-via-color: #c3dafe;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n  }\n\n  .lg\\:via-indigo-300 {\n    --gradient-via-color: #a3bffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n  }\n\n  .lg\\:via-indigo-400 {\n    --gradient-via-color: #7f9cf5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n  }\n\n  .lg\\:via-indigo-500 {\n    --gradient-via-color: #667eea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n  }\n\n  .lg\\:via-indigo-600 {\n    --gradient-via-color: #5a67d8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n  }\n\n  .lg\\:via-indigo-700 {\n    --gradient-via-color: #4c51bf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n  }\n\n  .lg\\:via-indigo-800 {\n    --gradient-via-color: #434190;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n  }\n\n  .lg\\:via-indigo-900 {\n    --gradient-via-color: #3c366b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n  }\n\n  .lg\\:via-purple-100 {\n    --gradient-via-color: #faf5ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n  }\n\n  .lg\\:via-purple-200 {\n    --gradient-via-color: #e9d8fd;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n  }\n\n  .lg\\:via-purple-300 {\n    --gradient-via-color: #d6bcfa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n  }\n\n  .lg\\:via-purple-400 {\n    --gradient-via-color: #b794f4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n  }\n\n  .lg\\:via-purple-500 {\n    --gradient-via-color: #9f7aea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n  }\n\n  .lg\\:via-purple-600 {\n    --gradient-via-color: #805ad5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n  }\n\n  .lg\\:via-purple-700 {\n    --gradient-via-color: #6b46c1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n  }\n\n  .lg\\:via-purple-800 {\n    --gradient-via-color: #553c9a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n  }\n\n  .lg\\:via-purple-900 {\n    --gradient-via-color: #44337a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n  }\n\n  .lg\\:via-pink-100 {\n    --gradient-via-color: #fff5f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n  }\n\n  .lg\\:via-pink-200 {\n    --gradient-via-color: #fed7e2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n  }\n\n  .lg\\:via-pink-300 {\n    --gradient-via-color: #fbb6ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n  }\n\n  .lg\\:via-pink-400 {\n    --gradient-via-color: #f687b3;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n  }\n\n  .lg\\:via-pink-500 {\n    --gradient-via-color: #ed64a6;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n  }\n\n  .lg\\:via-pink-600 {\n    --gradient-via-color: #d53f8c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n  }\n\n  .lg\\:via-pink-700 {\n    --gradient-via-color: #b83280;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n  }\n\n  .lg\\:via-pink-800 {\n    --gradient-via-color: #97266d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n  }\n\n  .lg\\:via-pink-900 {\n    --gradient-via-color: #702459;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n  }\n\n  .lg\\:via-grayscale-80 {\n    --gradient-via-color: hsl(0, 0%, 8%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n  }\n\n  .lg\\:via-grayscale-100 {\n    --gradient-via-color: hsl(0, 0%, 10%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n  }\n\n  .lg\\:via-grayscale-200 {\n    --gradient-via-color: hsl(0, 0%, 20%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n  }\n\n  .lg\\:via-grayscale-300 {\n    --gradient-via-color: hsl(0, 0%, 30%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n  }\n\n  .lg\\:via-grayscale-400 {\n    --gradient-via-color: hsl(0, 0%, 40%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n  }\n\n  .lg\\:via-grayscale-500 {\n    --gradient-via-color: hsl(0, 0%, 50%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n  }\n\n  .lg\\:via-grayscale-600 {\n    --gradient-via-color: hsl(0, 0%, 60%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n  }\n\n  .lg\\:via-grayscale-700 {\n    --gradient-via-color: hsl(0, 0%, 70%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n  }\n\n  .lg\\:via-grayscale-800 {\n    --gradient-via-color: hsl(0, 0%, 80%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n  }\n\n  .lg\\:via-grayscale-840 {\n    --gradient-via-color: hsl(0, 0%, 84%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n  }\n\n  .lg\\:via-grayscale-870 {\n    --gradient-via-color: hsl(0, 0%, 87%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n  }\n\n  .lg\\:via-grayscale-900 {\n    --gradient-via-color: hsl(0, 0%, 90%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n  }\n\n  .lg\\:via-grayscale-930 {\n    --gradient-via-color: hsl(0, 0%, 93%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n  }\n\n  .lg\\:via-primary {\n    --gradient-via-color: hsl(210, 100%, 52%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n  }\n\n  .lg\\:via-background-main {\n    --gradient-via-color: var(--main-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:via-background-secondary {\n    --gradient-via-color: var(--secondary-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:via-foreground {\n    --gradient-via-color: var(--foreground);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:via-panels-bg {\n    --gradient-via-color: var(--panels-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:to-transparent {\n    --gradient-to-color: transparent;\n  }\n\n  .lg\\:to-current {\n    --gradient-to-color: currentColor;\n  }\n\n  .lg\\:to-black {\n    --gradient-to-color: #000;\n  }\n\n  .lg\\:to-white {\n    --gradient-to-color: #fff;\n  }\n\n  .lg\\:to-gray-100 {\n    --gradient-to-color: #f7fafc;\n  }\n\n  .lg\\:to-gray-200 {\n    --gradient-to-color: #edf2f7;\n  }\n\n  .lg\\:to-gray-300 {\n    --gradient-to-color: #e2e8f0;\n  }\n\n  .lg\\:to-gray-400 {\n    --gradient-to-color: #cbd5e0;\n  }\n\n  .lg\\:to-gray-500 {\n    --gradient-to-color: #a0aec0;\n  }\n\n  .lg\\:to-gray-600 {\n    --gradient-to-color: #718096;\n  }\n\n  .lg\\:to-gray-700 {\n    --gradient-to-color: #4a5568;\n  }\n\n  .lg\\:to-gray-800 {\n    --gradient-to-color: #2d3748;\n  }\n\n  .lg\\:to-gray-900 {\n    --gradient-to-color: #1a202c;\n  }\n\n  .lg\\:to-red-100 {\n    --gradient-to-color: #fff5f5;\n  }\n\n  .lg\\:to-red-200 {\n    --gradient-to-color: #fed7d7;\n  }\n\n  .lg\\:to-red-300 {\n    --gradient-to-color: #feb2b2;\n  }\n\n  .lg\\:to-red-400 {\n    --gradient-to-color: #fc8181;\n  }\n\n  .lg\\:to-red-500 {\n    --gradient-to-color: #f56565;\n  }\n\n  .lg\\:to-red-600 {\n    --gradient-to-color: #e53e3e;\n  }\n\n  .lg\\:to-red-700 {\n    --gradient-to-color: #c53030;\n  }\n\n  .lg\\:to-red-800 {\n    --gradient-to-color: #9b2c2c;\n  }\n\n  .lg\\:to-red-900 {\n    --gradient-to-color: #742a2a;\n  }\n\n  .lg\\:to-orange-100 {\n    --gradient-to-color: #fffaf0;\n  }\n\n  .lg\\:to-orange-200 {\n    --gradient-to-color: #feebc8;\n  }\n\n  .lg\\:to-orange-300 {\n    --gradient-to-color: #fbd38d;\n  }\n\n  .lg\\:to-orange-400 {\n    --gradient-to-color: #f6ad55;\n  }\n\n  .lg\\:to-orange-500 {\n    --gradient-to-color: #ed8936;\n  }\n\n  .lg\\:to-orange-600 {\n    --gradient-to-color: #dd6b20;\n  }\n\n  .lg\\:to-orange-700 {\n    --gradient-to-color: #c05621;\n  }\n\n  .lg\\:to-orange-800 {\n    --gradient-to-color: #9c4221;\n  }\n\n  .lg\\:to-orange-900 {\n    --gradient-to-color: #7b341e;\n  }\n\n  .lg\\:to-yellow-100 {\n    --gradient-to-color: #fffff0;\n  }\n\n  .lg\\:to-yellow-200 {\n    --gradient-to-color: #fefcbf;\n  }\n\n  .lg\\:to-yellow-300 {\n    --gradient-to-color: #faf089;\n  }\n\n  .lg\\:to-yellow-400 {\n    --gradient-to-color: #f6e05e;\n  }\n\n  .lg\\:to-yellow-500 {\n    --gradient-to-color: #ecc94b;\n  }\n\n  .lg\\:to-yellow-600 {\n    --gradient-to-color: #d69e2e;\n  }\n\n  .lg\\:to-yellow-700 {\n    --gradient-to-color: #b7791f;\n  }\n\n  .lg\\:to-yellow-800 {\n    --gradient-to-color: #975a16;\n  }\n\n  .lg\\:to-yellow-900 {\n    --gradient-to-color: #744210;\n  }\n\n  .lg\\:to-green-100 {\n    --gradient-to-color: #f0fff4;\n  }\n\n  .lg\\:to-green-200 {\n    --gradient-to-color: #c6f6d5;\n  }\n\n  .lg\\:to-green-300 {\n    --gradient-to-color: #9ae6b4;\n  }\n\n  .lg\\:to-green-400 {\n    --gradient-to-color: #68d391;\n  }\n\n  .lg\\:to-green-500 {\n    --gradient-to-color: #48bb78;\n  }\n\n  .lg\\:to-green-600 {\n    --gradient-to-color: #38a169;\n  }\n\n  .lg\\:to-green-700 {\n    --gradient-to-color: #2f855a;\n  }\n\n  .lg\\:to-green-800 {\n    --gradient-to-color: #276749;\n  }\n\n  .lg\\:to-green-900 {\n    --gradient-to-color: #22543d;\n  }\n\n  .lg\\:to-teal-100 {\n    --gradient-to-color: #e6fffa;\n  }\n\n  .lg\\:to-teal-200 {\n    --gradient-to-color: #b2f5ea;\n  }\n\n  .lg\\:to-teal-300 {\n    --gradient-to-color: #81e6d9;\n  }\n\n  .lg\\:to-teal-400 {\n    --gradient-to-color: #4fd1c5;\n  }\n\n  .lg\\:to-teal-500 {\n    --gradient-to-color: #38b2ac;\n  }\n\n  .lg\\:to-teal-600 {\n    --gradient-to-color: #319795;\n  }\n\n  .lg\\:to-teal-700 {\n    --gradient-to-color: #2c7a7b;\n  }\n\n  .lg\\:to-teal-800 {\n    --gradient-to-color: #285e61;\n  }\n\n  .lg\\:to-teal-900 {\n    --gradient-to-color: #234e52;\n  }\n\n  .lg\\:to-blue-100 {\n    --gradient-to-color: #ebf8ff;\n  }\n\n  .lg\\:to-blue-200 {\n    --gradient-to-color: #bee3f8;\n  }\n\n  .lg\\:to-blue-300 {\n    --gradient-to-color: #90cdf4;\n  }\n\n  .lg\\:to-blue-400 {\n    --gradient-to-color: #63b3ed;\n  }\n\n  .lg\\:to-blue-500 {\n    --gradient-to-color: #4299e1;\n  }\n\n  .lg\\:to-blue-600 {\n    --gradient-to-color: #3182ce;\n  }\n\n  .lg\\:to-blue-700 {\n    --gradient-to-color: #2b6cb0;\n  }\n\n  .lg\\:to-blue-800 {\n    --gradient-to-color: #2c5282;\n  }\n\n  .lg\\:to-blue-900 {\n    --gradient-to-color: #2a4365;\n  }\n\n  .lg\\:to-indigo-100 {\n    --gradient-to-color: #ebf4ff;\n  }\n\n  .lg\\:to-indigo-200 {\n    --gradient-to-color: #c3dafe;\n  }\n\n  .lg\\:to-indigo-300 {\n    --gradient-to-color: #a3bffa;\n  }\n\n  .lg\\:to-indigo-400 {\n    --gradient-to-color: #7f9cf5;\n  }\n\n  .lg\\:to-indigo-500 {\n    --gradient-to-color: #667eea;\n  }\n\n  .lg\\:to-indigo-600 {\n    --gradient-to-color: #5a67d8;\n  }\n\n  .lg\\:to-indigo-700 {\n    --gradient-to-color: #4c51bf;\n  }\n\n  .lg\\:to-indigo-800 {\n    --gradient-to-color: #434190;\n  }\n\n  .lg\\:to-indigo-900 {\n    --gradient-to-color: #3c366b;\n  }\n\n  .lg\\:to-purple-100 {\n    --gradient-to-color: #faf5ff;\n  }\n\n  .lg\\:to-purple-200 {\n    --gradient-to-color: #e9d8fd;\n  }\n\n  .lg\\:to-purple-300 {\n    --gradient-to-color: #d6bcfa;\n  }\n\n  .lg\\:to-purple-400 {\n    --gradient-to-color: #b794f4;\n  }\n\n  .lg\\:to-purple-500 {\n    --gradient-to-color: #9f7aea;\n  }\n\n  .lg\\:to-purple-600 {\n    --gradient-to-color: #805ad5;\n  }\n\n  .lg\\:to-purple-700 {\n    --gradient-to-color: #6b46c1;\n  }\n\n  .lg\\:to-purple-800 {\n    --gradient-to-color: #553c9a;\n  }\n\n  .lg\\:to-purple-900 {\n    --gradient-to-color: #44337a;\n  }\n\n  .lg\\:to-pink-100 {\n    --gradient-to-color: #fff5f7;\n  }\n\n  .lg\\:to-pink-200 {\n    --gradient-to-color: #fed7e2;\n  }\n\n  .lg\\:to-pink-300 {\n    --gradient-to-color: #fbb6ce;\n  }\n\n  .lg\\:to-pink-400 {\n    --gradient-to-color: #f687b3;\n  }\n\n  .lg\\:to-pink-500 {\n    --gradient-to-color: #ed64a6;\n  }\n\n  .lg\\:to-pink-600 {\n    --gradient-to-color: #d53f8c;\n  }\n\n  .lg\\:to-pink-700 {\n    --gradient-to-color: #b83280;\n  }\n\n  .lg\\:to-pink-800 {\n    --gradient-to-color: #97266d;\n  }\n\n  .lg\\:to-pink-900 {\n    --gradient-to-color: #702459;\n  }\n\n  .lg\\:to-grayscale-80 {\n    --gradient-to-color: hsl(0, 0%, 8%);\n  }\n\n  .lg\\:to-grayscale-100 {\n    --gradient-to-color: hsl(0, 0%, 10%);\n  }\n\n  .lg\\:to-grayscale-200 {\n    --gradient-to-color: hsl(0, 0%, 20%);\n  }\n\n  .lg\\:to-grayscale-300 {\n    --gradient-to-color: hsl(0, 0%, 30%);\n  }\n\n  .lg\\:to-grayscale-400 {\n    --gradient-to-color: hsl(0, 0%, 40%);\n  }\n\n  .lg\\:to-grayscale-500 {\n    --gradient-to-color: hsl(0, 0%, 50%);\n  }\n\n  .lg\\:to-grayscale-600 {\n    --gradient-to-color: hsl(0, 0%, 60%);\n  }\n\n  .lg\\:to-grayscale-700 {\n    --gradient-to-color: hsl(0, 0%, 70%);\n  }\n\n  .lg\\:to-grayscale-800 {\n    --gradient-to-color: hsl(0, 0%, 80%);\n  }\n\n  .lg\\:to-grayscale-840 {\n    --gradient-to-color: hsl(0, 0%, 84%);\n  }\n\n  .lg\\:to-grayscale-870 {\n    --gradient-to-color: hsl(0, 0%, 87%);\n  }\n\n  .lg\\:to-grayscale-900 {\n    --gradient-to-color: hsl(0, 0%, 90%);\n  }\n\n  .lg\\:to-grayscale-930 {\n    --gradient-to-color: hsl(0, 0%, 93%);\n  }\n\n  .lg\\:to-primary {\n    --gradient-to-color: hsl(210, 100%, 52%);\n  }\n\n  .lg\\:to-background-main {\n    --gradient-to-color: var(--main-background);\n  }\n\n  .lg\\:to-background-secondary {\n    --gradient-to-color: var(--secondary-background);\n  }\n\n  .lg\\:to-foreground {\n    --gradient-to-color: var(--foreground);\n  }\n\n  .lg\\:to-panels-bg {\n    --gradient-to-color: var(--panels-background);\n  }\n\n  .lg\\:hover\\:from-transparent:hover {\n    --gradient-from-color: transparent;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .lg\\:hover\\:from-current:hover {\n    --gradient-from-color: currentColor;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:hover\\:from-black:hover {\n    --gradient-from-color: #000;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .lg\\:hover\\:from-white:hover {\n    --gradient-from-color: #fff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:hover\\:from-gray-100:hover {\n    --gradient-from-color: #f7fafc;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n  }\n\n  .lg\\:hover\\:from-gray-200:hover {\n    --gradient-from-color: #edf2f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n  }\n\n  .lg\\:hover\\:from-gray-300:hover {\n    --gradient-from-color: #e2e8f0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n  }\n\n  .lg\\:hover\\:from-gray-400:hover {\n    --gradient-from-color: #cbd5e0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n  }\n\n  .lg\\:hover\\:from-gray-500:hover {\n    --gradient-from-color: #a0aec0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n  }\n\n  .lg\\:hover\\:from-gray-600:hover {\n    --gradient-from-color: #718096;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n  }\n\n  .lg\\:hover\\:from-gray-700:hover {\n    --gradient-from-color: #4a5568;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n  }\n\n  .lg\\:hover\\:from-gray-800:hover {\n    --gradient-from-color: #2d3748;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n  }\n\n  .lg\\:hover\\:from-gray-900:hover {\n    --gradient-from-color: #1a202c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n  }\n\n  .lg\\:hover\\:from-red-100:hover {\n    --gradient-from-color: #fff5f5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n  }\n\n  .lg\\:hover\\:from-red-200:hover {\n    --gradient-from-color: #fed7d7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n  }\n\n  .lg\\:hover\\:from-red-300:hover {\n    --gradient-from-color: #feb2b2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n  }\n\n  .lg\\:hover\\:from-red-400:hover {\n    --gradient-from-color: #fc8181;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n  }\n\n  .lg\\:hover\\:from-red-500:hover {\n    --gradient-from-color: #f56565;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n  }\n\n  .lg\\:hover\\:from-red-600:hover {\n    --gradient-from-color: #e53e3e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n  }\n\n  .lg\\:hover\\:from-red-700:hover {\n    --gradient-from-color: #c53030;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n  }\n\n  .lg\\:hover\\:from-red-800:hover {\n    --gradient-from-color: #9b2c2c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n  }\n\n  .lg\\:hover\\:from-red-900:hover {\n    --gradient-from-color: #742a2a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n  }\n\n  .lg\\:hover\\:from-orange-100:hover {\n    --gradient-from-color: #fffaf0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n  }\n\n  .lg\\:hover\\:from-orange-200:hover {\n    --gradient-from-color: #feebc8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n  }\n\n  .lg\\:hover\\:from-orange-300:hover {\n    --gradient-from-color: #fbd38d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n  }\n\n  .lg\\:hover\\:from-orange-400:hover {\n    --gradient-from-color: #f6ad55;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n  }\n\n  .lg\\:hover\\:from-orange-500:hover {\n    --gradient-from-color: #ed8936;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n  }\n\n  .lg\\:hover\\:from-orange-600:hover {\n    --gradient-from-color: #dd6b20;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n  }\n\n  .lg\\:hover\\:from-orange-700:hover {\n    --gradient-from-color: #c05621;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n  }\n\n  .lg\\:hover\\:from-orange-800:hover {\n    --gradient-from-color: #9c4221;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n  }\n\n  .lg\\:hover\\:from-orange-900:hover {\n    --gradient-from-color: #7b341e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n  }\n\n  .lg\\:hover\\:from-yellow-100:hover {\n    --gradient-from-color: #fffff0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n  }\n\n  .lg\\:hover\\:from-yellow-200:hover {\n    --gradient-from-color: #fefcbf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n  }\n\n  .lg\\:hover\\:from-yellow-300:hover {\n    --gradient-from-color: #faf089;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n  }\n\n  .lg\\:hover\\:from-yellow-400:hover {\n    --gradient-from-color: #f6e05e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n  }\n\n  .lg\\:hover\\:from-yellow-500:hover {\n    --gradient-from-color: #ecc94b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n  }\n\n  .lg\\:hover\\:from-yellow-600:hover {\n    --gradient-from-color: #d69e2e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n  }\n\n  .lg\\:hover\\:from-yellow-700:hover {\n    --gradient-from-color: #b7791f;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n  }\n\n  .lg\\:hover\\:from-yellow-800:hover {\n    --gradient-from-color: #975a16;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n  }\n\n  .lg\\:hover\\:from-yellow-900:hover {\n    --gradient-from-color: #744210;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n  }\n\n  .lg\\:hover\\:from-green-100:hover {\n    --gradient-from-color: #f0fff4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n  }\n\n  .lg\\:hover\\:from-green-200:hover {\n    --gradient-from-color: #c6f6d5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n  }\n\n  .lg\\:hover\\:from-green-300:hover {\n    --gradient-from-color: #9ae6b4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n  }\n\n  .lg\\:hover\\:from-green-400:hover {\n    --gradient-from-color: #68d391;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n  }\n\n  .lg\\:hover\\:from-green-500:hover {\n    --gradient-from-color: #48bb78;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n  }\n\n  .lg\\:hover\\:from-green-600:hover {\n    --gradient-from-color: #38a169;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n  }\n\n  .lg\\:hover\\:from-green-700:hover {\n    --gradient-from-color: #2f855a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n  }\n\n  .lg\\:hover\\:from-green-800:hover {\n    --gradient-from-color: #276749;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n  }\n\n  .lg\\:hover\\:from-green-900:hover {\n    --gradient-from-color: #22543d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n  }\n\n  .lg\\:hover\\:from-teal-100:hover {\n    --gradient-from-color: #e6fffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n  }\n\n  .lg\\:hover\\:from-teal-200:hover {\n    --gradient-from-color: #b2f5ea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n  }\n\n  .lg\\:hover\\:from-teal-300:hover {\n    --gradient-from-color: #81e6d9;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n  }\n\n  .lg\\:hover\\:from-teal-400:hover {\n    --gradient-from-color: #4fd1c5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n  }\n\n  .lg\\:hover\\:from-teal-500:hover {\n    --gradient-from-color: #38b2ac;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n  }\n\n  .lg\\:hover\\:from-teal-600:hover {\n    --gradient-from-color: #319795;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n  }\n\n  .lg\\:hover\\:from-teal-700:hover {\n    --gradient-from-color: #2c7a7b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n  }\n\n  .lg\\:hover\\:from-teal-800:hover {\n    --gradient-from-color: #285e61;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n  }\n\n  .lg\\:hover\\:from-teal-900:hover {\n    --gradient-from-color: #234e52;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n  }\n\n  .lg\\:hover\\:from-blue-100:hover {\n    --gradient-from-color: #ebf8ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n  }\n\n  .lg\\:hover\\:from-blue-200:hover {\n    --gradient-from-color: #bee3f8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n  }\n\n  .lg\\:hover\\:from-blue-300:hover {\n    --gradient-from-color: #90cdf4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n  }\n\n  .lg\\:hover\\:from-blue-400:hover {\n    --gradient-from-color: #63b3ed;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n  }\n\n  .lg\\:hover\\:from-blue-500:hover {\n    --gradient-from-color: #4299e1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n  }\n\n  .lg\\:hover\\:from-blue-600:hover {\n    --gradient-from-color: #3182ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n  }\n\n  .lg\\:hover\\:from-blue-700:hover {\n    --gradient-from-color: #2b6cb0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n  }\n\n  .lg\\:hover\\:from-blue-800:hover {\n    --gradient-from-color: #2c5282;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n  }\n\n  .lg\\:hover\\:from-blue-900:hover {\n    --gradient-from-color: #2a4365;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n  }\n\n  .lg\\:hover\\:from-indigo-100:hover {\n    --gradient-from-color: #ebf4ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n  }\n\n  .lg\\:hover\\:from-indigo-200:hover {\n    --gradient-from-color: #c3dafe;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n  }\n\n  .lg\\:hover\\:from-indigo-300:hover {\n    --gradient-from-color: #a3bffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n  }\n\n  .lg\\:hover\\:from-indigo-400:hover {\n    --gradient-from-color: #7f9cf5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n  }\n\n  .lg\\:hover\\:from-indigo-500:hover {\n    --gradient-from-color: #667eea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n  }\n\n  .lg\\:hover\\:from-indigo-600:hover {\n    --gradient-from-color: #5a67d8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n  }\n\n  .lg\\:hover\\:from-indigo-700:hover {\n    --gradient-from-color: #4c51bf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n  }\n\n  .lg\\:hover\\:from-indigo-800:hover {\n    --gradient-from-color: #434190;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n  }\n\n  .lg\\:hover\\:from-indigo-900:hover {\n    --gradient-from-color: #3c366b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n  }\n\n  .lg\\:hover\\:from-purple-100:hover {\n    --gradient-from-color: #faf5ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n  }\n\n  .lg\\:hover\\:from-purple-200:hover {\n    --gradient-from-color: #e9d8fd;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n  }\n\n  .lg\\:hover\\:from-purple-300:hover {\n    --gradient-from-color: #d6bcfa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n  }\n\n  .lg\\:hover\\:from-purple-400:hover {\n    --gradient-from-color: #b794f4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n  }\n\n  .lg\\:hover\\:from-purple-500:hover {\n    --gradient-from-color: #9f7aea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n  }\n\n  .lg\\:hover\\:from-purple-600:hover {\n    --gradient-from-color: #805ad5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n  }\n\n  .lg\\:hover\\:from-purple-700:hover {\n    --gradient-from-color: #6b46c1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n  }\n\n  .lg\\:hover\\:from-purple-800:hover {\n    --gradient-from-color: #553c9a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n  }\n\n  .lg\\:hover\\:from-purple-900:hover {\n    --gradient-from-color: #44337a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n  }\n\n  .lg\\:hover\\:from-pink-100:hover {\n    --gradient-from-color: #fff5f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n  }\n\n  .lg\\:hover\\:from-pink-200:hover {\n    --gradient-from-color: #fed7e2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n  }\n\n  .lg\\:hover\\:from-pink-300:hover {\n    --gradient-from-color: #fbb6ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n  }\n\n  .lg\\:hover\\:from-pink-400:hover {\n    --gradient-from-color: #f687b3;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n  }\n\n  .lg\\:hover\\:from-pink-500:hover {\n    --gradient-from-color: #ed64a6;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n  }\n\n  .lg\\:hover\\:from-pink-600:hover {\n    --gradient-from-color: #d53f8c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n  }\n\n  .lg\\:hover\\:from-pink-700:hover {\n    --gradient-from-color: #b83280;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n  }\n\n  .lg\\:hover\\:from-pink-800:hover {\n    --gradient-from-color: #97266d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n  }\n\n  .lg\\:hover\\:from-pink-900:hover {\n    --gradient-from-color: #702459;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n  }\n\n  .lg\\:hover\\:from-grayscale-80:hover {\n    --gradient-from-color: hsl(0, 0%, 8%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n  }\n\n  .lg\\:hover\\:from-grayscale-100:hover {\n    --gradient-from-color: hsl(0, 0%, 10%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n  }\n\n  .lg\\:hover\\:from-grayscale-200:hover {\n    --gradient-from-color: hsl(0, 0%, 20%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n  }\n\n  .lg\\:hover\\:from-grayscale-300:hover {\n    --gradient-from-color: hsl(0, 0%, 30%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n  }\n\n  .lg\\:hover\\:from-grayscale-400:hover {\n    --gradient-from-color: hsl(0, 0%, 40%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n  }\n\n  .lg\\:hover\\:from-grayscale-500:hover {\n    --gradient-from-color: hsl(0, 0%, 50%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n  }\n\n  .lg\\:hover\\:from-grayscale-600:hover {\n    --gradient-from-color: hsl(0, 0%, 60%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n  }\n\n  .lg\\:hover\\:from-grayscale-700:hover {\n    --gradient-from-color: hsl(0, 0%, 70%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n  }\n\n  .lg\\:hover\\:from-grayscale-800:hover {\n    --gradient-from-color: hsl(0, 0%, 80%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n  }\n\n  .lg\\:hover\\:from-grayscale-840:hover {\n    --gradient-from-color: hsl(0, 0%, 84%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n  }\n\n  .lg\\:hover\\:from-grayscale-870:hover {\n    --gradient-from-color: hsl(0, 0%, 87%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n  }\n\n  .lg\\:hover\\:from-grayscale-900:hover {\n    --gradient-from-color: hsl(0, 0%, 90%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n  }\n\n  .lg\\:hover\\:from-grayscale-930:hover {\n    --gradient-from-color: hsl(0, 0%, 93%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n  }\n\n  .lg\\:hover\\:from-primary:hover {\n    --gradient-from-color: hsl(210, 100%, 52%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n  }\n\n  .lg\\:hover\\:from-background-main:hover {\n    --gradient-from-color: var(--main-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:hover\\:from-background-secondary:hover {\n    --gradient-from-color: var(--secondary-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:hover\\:from-foreground:hover {\n    --gradient-from-color: var(--foreground);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:hover\\:from-panels-bg:hover {\n    --gradient-from-color: var(--panels-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:hover\\:via-transparent:hover {\n    --gradient-via-color: transparent;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .lg\\:hover\\:via-current:hover {\n    --gradient-via-color: currentColor;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:hover\\:via-black:hover {\n    --gradient-via-color: #000;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .lg\\:hover\\:via-white:hover {\n    --gradient-via-color: #fff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:hover\\:via-gray-100:hover {\n    --gradient-via-color: #f7fafc;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n  }\n\n  .lg\\:hover\\:via-gray-200:hover {\n    --gradient-via-color: #edf2f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n  }\n\n  .lg\\:hover\\:via-gray-300:hover {\n    --gradient-via-color: #e2e8f0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n  }\n\n  .lg\\:hover\\:via-gray-400:hover {\n    --gradient-via-color: #cbd5e0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n  }\n\n  .lg\\:hover\\:via-gray-500:hover {\n    --gradient-via-color: #a0aec0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n  }\n\n  .lg\\:hover\\:via-gray-600:hover {\n    --gradient-via-color: #718096;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n  }\n\n  .lg\\:hover\\:via-gray-700:hover {\n    --gradient-via-color: #4a5568;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n  }\n\n  .lg\\:hover\\:via-gray-800:hover {\n    --gradient-via-color: #2d3748;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n  }\n\n  .lg\\:hover\\:via-gray-900:hover {\n    --gradient-via-color: #1a202c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n  }\n\n  .lg\\:hover\\:via-red-100:hover {\n    --gradient-via-color: #fff5f5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n  }\n\n  .lg\\:hover\\:via-red-200:hover {\n    --gradient-via-color: #fed7d7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n  }\n\n  .lg\\:hover\\:via-red-300:hover {\n    --gradient-via-color: #feb2b2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n  }\n\n  .lg\\:hover\\:via-red-400:hover {\n    --gradient-via-color: #fc8181;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n  }\n\n  .lg\\:hover\\:via-red-500:hover {\n    --gradient-via-color: #f56565;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n  }\n\n  .lg\\:hover\\:via-red-600:hover {\n    --gradient-via-color: #e53e3e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n  }\n\n  .lg\\:hover\\:via-red-700:hover {\n    --gradient-via-color: #c53030;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n  }\n\n  .lg\\:hover\\:via-red-800:hover {\n    --gradient-via-color: #9b2c2c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n  }\n\n  .lg\\:hover\\:via-red-900:hover {\n    --gradient-via-color: #742a2a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n  }\n\n  .lg\\:hover\\:via-orange-100:hover {\n    --gradient-via-color: #fffaf0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n  }\n\n  .lg\\:hover\\:via-orange-200:hover {\n    --gradient-via-color: #feebc8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n  }\n\n  .lg\\:hover\\:via-orange-300:hover {\n    --gradient-via-color: #fbd38d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n  }\n\n  .lg\\:hover\\:via-orange-400:hover {\n    --gradient-via-color: #f6ad55;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n  }\n\n  .lg\\:hover\\:via-orange-500:hover {\n    --gradient-via-color: #ed8936;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n  }\n\n  .lg\\:hover\\:via-orange-600:hover {\n    --gradient-via-color: #dd6b20;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n  }\n\n  .lg\\:hover\\:via-orange-700:hover {\n    --gradient-via-color: #c05621;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n  }\n\n  .lg\\:hover\\:via-orange-800:hover {\n    --gradient-via-color: #9c4221;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n  }\n\n  .lg\\:hover\\:via-orange-900:hover {\n    --gradient-via-color: #7b341e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n  }\n\n  .lg\\:hover\\:via-yellow-100:hover {\n    --gradient-via-color: #fffff0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n  }\n\n  .lg\\:hover\\:via-yellow-200:hover {\n    --gradient-via-color: #fefcbf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n  }\n\n  .lg\\:hover\\:via-yellow-300:hover {\n    --gradient-via-color: #faf089;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n  }\n\n  .lg\\:hover\\:via-yellow-400:hover {\n    --gradient-via-color: #f6e05e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n  }\n\n  .lg\\:hover\\:via-yellow-500:hover {\n    --gradient-via-color: #ecc94b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n  }\n\n  .lg\\:hover\\:via-yellow-600:hover {\n    --gradient-via-color: #d69e2e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n  }\n\n  .lg\\:hover\\:via-yellow-700:hover {\n    --gradient-via-color: #b7791f;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n  }\n\n  .lg\\:hover\\:via-yellow-800:hover {\n    --gradient-via-color: #975a16;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n  }\n\n  .lg\\:hover\\:via-yellow-900:hover {\n    --gradient-via-color: #744210;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n  }\n\n  .lg\\:hover\\:via-green-100:hover {\n    --gradient-via-color: #f0fff4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n  }\n\n  .lg\\:hover\\:via-green-200:hover {\n    --gradient-via-color: #c6f6d5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n  }\n\n  .lg\\:hover\\:via-green-300:hover {\n    --gradient-via-color: #9ae6b4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n  }\n\n  .lg\\:hover\\:via-green-400:hover {\n    --gradient-via-color: #68d391;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n  }\n\n  .lg\\:hover\\:via-green-500:hover {\n    --gradient-via-color: #48bb78;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n  }\n\n  .lg\\:hover\\:via-green-600:hover {\n    --gradient-via-color: #38a169;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n  }\n\n  .lg\\:hover\\:via-green-700:hover {\n    --gradient-via-color: #2f855a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n  }\n\n  .lg\\:hover\\:via-green-800:hover {\n    --gradient-via-color: #276749;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n  }\n\n  .lg\\:hover\\:via-green-900:hover {\n    --gradient-via-color: #22543d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n  }\n\n  .lg\\:hover\\:via-teal-100:hover {\n    --gradient-via-color: #e6fffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n  }\n\n  .lg\\:hover\\:via-teal-200:hover {\n    --gradient-via-color: #b2f5ea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n  }\n\n  .lg\\:hover\\:via-teal-300:hover {\n    --gradient-via-color: #81e6d9;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n  }\n\n  .lg\\:hover\\:via-teal-400:hover {\n    --gradient-via-color: #4fd1c5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n  }\n\n  .lg\\:hover\\:via-teal-500:hover {\n    --gradient-via-color: #38b2ac;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n  }\n\n  .lg\\:hover\\:via-teal-600:hover {\n    --gradient-via-color: #319795;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n  }\n\n  .lg\\:hover\\:via-teal-700:hover {\n    --gradient-via-color: #2c7a7b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n  }\n\n  .lg\\:hover\\:via-teal-800:hover {\n    --gradient-via-color: #285e61;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n  }\n\n  .lg\\:hover\\:via-teal-900:hover {\n    --gradient-via-color: #234e52;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n  }\n\n  .lg\\:hover\\:via-blue-100:hover {\n    --gradient-via-color: #ebf8ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n  }\n\n  .lg\\:hover\\:via-blue-200:hover {\n    --gradient-via-color: #bee3f8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n  }\n\n  .lg\\:hover\\:via-blue-300:hover {\n    --gradient-via-color: #90cdf4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n  }\n\n  .lg\\:hover\\:via-blue-400:hover {\n    --gradient-via-color: #63b3ed;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n  }\n\n  .lg\\:hover\\:via-blue-500:hover {\n    --gradient-via-color: #4299e1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n  }\n\n  .lg\\:hover\\:via-blue-600:hover {\n    --gradient-via-color: #3182ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n  }\n\n  .lg\\:hover\\:via-blue-700:hover {\n    --gradient-via-color: #2b6cb0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n  }\n\n  .lg\\:hover\\:via-blue-800:hover {\n    --gradient-via-color: #2c5282;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n  }\n\n  .lg\\:hover\\:via-blue-900:hover {\n    --gradient-via-color: #2a4365;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n  }\n\n  .lg\\:hover\\:via-indigo-100:hover {\n    --gradient-via-color: #ebf4ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n  }\n\n  .lg\\:hover\\:via-indigo-200:hover {\n    --gradient-via-color: #c3dafe;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n  }\n\n  .lg\\:hover\\:via-indigo-300:hover {\n    --gradient-via-color: #a3bffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n  }\n\n  .lg\\:hover\\:via-indigo-400:hover {\n    --gradient-via-color: #7f9cf5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n  }\n\n  .lg\\:hover\\:via-indigo-500:hover {\n    --gradient-via-color: #667eea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n  }\n\n  .lg\\:hover\\:via-indigo-600:hover {\n    --gradient-via-color: #5a67d8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n  }\n\n  .lg\\:hover\\:via-indigo-700:hover {\n    --gradient-via-color: #4c51bf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n  }\n\n  .lg\\:hover\\:via-indigo-800:hover {\n    --gradient-via-color: #434190;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n  }\n\n  .lg\\:hover\\:via-indigo-900:hover {\n    --gradient-via-color: #3c366b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n  }\n\n  .lg\\:hover\\:via-purple-100:hover {\n    --gradient-via-color: #faf5ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n  }\n\n  .lg\\:hover\\:via-purple-200:hover {\n    --gradient-via-color: #e9d8fd;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n  }\n\n  .lg\\:hover\\:via-purple-300:hover {\n    --gradient-via-color: #d6bcfa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n  }\n\n  .lg\\:hover\\:via-purple-400:hover {\n    --gradient-via-color: #b794f4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n  }\n\n  .lg\\:hover\\:via-purple-500:hover {\n    --gradient-via-color: #9f7aea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n  }\n\n  .lg\\:hover\\:via-purple-600:hover {\n    --gradient-via-color: #805ad5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n  }\n\n  .lg\\:hover\\:via-purple-700:hover {\n    --gradient-via-color: #6b46c1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n  }\n\n  .lg\\:hover\\:via-purple-800:hover {\n    --gradient-via-color: #553c9a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n  }\n\n  .lg\\:hover\\:via-purple-900:hover {\n    --gradient-via-color: #44337a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n  }\n\n  .lg\\:hover\\:via-pink-100:hover {\n    --gradient-via-color: #fff5f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n  }\n\n  .lg\\:hover\\:via-pink-200:hover {\n    --gradient-via-color: #fed7e2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n  }\n\n  .lg\\:hover\\:via-pink-300:hover {\n    --gradient-via-color: #fbb6ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n  }\n\n  .lg\\:hover\\:via-pink-400:hover {\n    --gradient-via-color: #f687b3;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n  }\n\n  .lg\\:hover\\:via-pink-500:hover {\n    --gradient-via-color: #ed64a6;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n  }\n\n  .lg\\:hover\\:via-pink-600:hover {\n    --gradient-via-color: #d53f8c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n  }\n\n  .lg\\:hover\\:via-pink-700:hover {\n    --gradient-via-color: #b83280;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n  }\n\n  .lg\\:hover\\:via-pink-800:hover {\n    --gradient-via-color: #97266d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n  }\n\n  .lg\\:hover\\:via-pink-900:hover {\n    --gradient-via-color: #702459;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n  }\n\n  .lg\\:hover\\:via-grayscale-80:hover {\n    --gradient-via-color: hsl(0, 0%, 8%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n  }\n\n  .lg\\:hover\\:via-grayscale-100:hover {\n    --gradient-via-color: hsl(0, 0%, 10%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n  }\n\n  .lg\\:hover\\:via-grayscale-200:hover {\n    --gradient-via-color: hsl(0, 0%, 20%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n  }\n\n  .lg\\:hover\\:via-grayscale-300:hover {\n    --gradient-via-color: hsl(0, 0%, 30%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n  }\n\n  .lg\\:hover\\:via-grayscale-400:hover {\n    --gradient-via-color: hsl(0, 0%, 40%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n  }\n\n  .lg\\:hover\\:via-grayscale-500:hover {\n    --gradient-via-color: hsl(0, 0%, 50%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n  }\n\n  .lg\\:hover\\:via-grayscale-600:hover {\n    --gradient-via-color: hsl(0, 0%, 60%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n  }\n\n  .lg\\:hover\\:via-grayscale-700:hover {\n    --gradient-via-color: hsl(0, 0%, 70%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n  }\n\n  .lg\\:hover\\:via-grayscale-800:hover {\n    --gradient-via-color: hsl(0, 0%, 80%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n  }\n\n  .lg\\:hover\\:via-grayscale-840:hover {\n    --gradient-via-color: hsl(0, 0%, 84%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n  }\n\n  .lg\\:hover\\:via-grayscale-870:hover {\n    --gradient-via-color: hsl(0, 0%, 87%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n  }\n\n  .lg\\:hover\\:via-grayscale-900:hover {\n    --gradient-via-color: hsl(0, 0%, 90%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n  }\n\n  .lg\\:hover\\:via-grayscale-930:hover {\n    --gradient-via-color: hsl(0, 0%, 93%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n  }\n\n  .lg\\:hover\\:via-primary:hover {\n    --gradient-via-color: hsl(210, 100%, 52%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n  }\n\n  .lg\\:hover\\:via-background-main:hover {\n    --gradient-via-color: var(--main-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:hover\\:via-background-secondary:hover {\n    --gradient-via-color: var(--secondary-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:hover\\:via-foreground:hover {\n    --gradient-via-color: var(--foreground);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:hover\\:via-panels-bg:hover {\n    --gradient-via-color: var(--panels-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:hover\\:to-transparent:hover {\n    --gradient-to-color: transparent;\n  }\n\n  .lg\\:hover\\:to-current:hover {\n    --gradient-to-color: currentColor;\n  }\n\n  .lg\\:hover\\:to-black:hover {\n    --gradient-to-color: #000;\n  }\n\n  .lg\\:hover\\:to-white:hover {\n    --gradient-to-color: #fff;\n  }\n\n  .lg\\:hover\\:to-gray-100:hover {\n    --gradient-to-color: #f7fafc;\n  }\n\n  .lg\\:hover\\:to-gray-200:hover {\n    --gradient-to-color: #edf2f7;\n  }\n\n  .lg\\:hover\\:to-gray-300:hover {\n    --gradient-to-color: #e2e8f0;\n  }\n\n  .lg\\:hover\\:to-gray-400:hover {\n    --gradient-to-color: #cbd5e0;\n  }\n\n  .lg\\:hover\\:to-gray-500:hover {\n    --gradient-to-color: #a0aec0;\n  }\n\n  .lg\\:hover\\:to-gray-600:hover {\n    --gradient-to-color: #718096;\n  }\n\n  .lg\\:hover\\:to-gray-700:hover {\n    --gradient-to-color: #4a5568;\n  }\n\n  .lg\\:hover\\:to-gray-800:hover {\n    --gradient-to-color: #2d3748;\n  }\n\n  .lg\\:hover\\:to-gray-900:hover {\n    --gradient-to-color: #1a202c;\n  }\n\n  .lg\\:hover\\:to-red-100:hover {\n    --gradient-to-color: #fff5f5;\n  }\n\n  .lg\\:hover\\:to-red-200:hover {\n    --gradient-to-color: #fed7d7;\n  }\n\n  .lg\\:hover\\:to-red-300:hover {\n    --gradient-to-color: #feb2b2;\n  }\n\n  .lg\\:hover\\:to-red-400:hover {\n    --gradient-to-color: #fc8181;\n  }\n\n  .lg\\:hover\\:to-red-500:hover {\n    --gradient-to-color: #f56565;\n  }\n\n  .lg\\:hover\\:to-red-600:hover {\n    --gradient-to-color: #e53e3e;\n  }\n\n  .lg\\:hover\\:to-red-700:hover {\n    --gradient-to-color: #c53030;\n  }\n\n  .lg\\:hover\\:to-red-800:hover {\n    --gradient-to-color: #9b2c2c;\n  }\n\n  .lg\\:hover\\:to-red-900:hover {\n    --gradient-to-color: #742a2a;\n  }\n\n  .lg\\:hover\\:to-orange-100:hover {\n    --gradient-to-color: #fffaf0;\n  }\n\n  .lg\\:hover\\:to-orange-200:hover {\n    --gradient-to-color: #feebc8;\n  }\n\n  .lg\\:hover\\:to-orange-300:hover {\n    --gradient-to-color: #fbd38d;\n  }\n\n  .lg\\:hover\\:to-orange-400:hover {\n    --gradient-to-color: #f6ad55;\n  }\n\n  .lg\\:hover\\:to-orange-500:hover {\n    --gradient-to-color: #ed8936;\n  }\n\n  .lg\\:hover\\:to-orange-600:hover {\n    --gradient-to-color: #dd6b20;\n  }\n\n  .lg\\:hover\\:to-orange-700:hover {\n    --gradient-to-color: #c05621;\n  }\n\n  .lg\\:hover\\:to-orange-800:hover {\n    --gradient-to-color: #9c4221;\n  }\n\n  .lg\\:hover\\:to-orange-900:hover {\n    --gradient-to-color: #7b341e;\n  }\n\n  .lg\\:hover\\:to-yellow-100:hover {\n    --gradient-to-color: #fffff0;\n  }\n\n  .lg\\:hover\\:to-yellow-200:hover {\n    --gradient-to-color: #fefcbf;\n  }\n\n  .lg\\:hover\\:to-yellow-300:hover {\n    --gradient-to-color: #faf089;\n  }\n\n  .lg\\:hover\\:to-yellow-400:hover {\n    --gradient-to-color: #f6e05e;\n  }\n\n  .lg\\:hover\\:to-yellow-500:hover {\n    --gradient-to-color: #ecc94b;\n  }\n\n  .lg\\:hover\\:to-yellow-600:hover {\n    --gradient-to-color: #d69e2e;\n  }\n\n  .lg\\:hover\\:to-yellow-700:hover {\n    --gradient-to-color: #b7791f;\n  }\n\n  .lg\\:hover\\:to-yellow-800:hover {\n    --gradient-to-color: #975a16;\n  }\n\n  .lg\\:hover\\:to-yellow-900:hover {\n    --gradient-to-color: #744210;\n  }\n\n  .lg\\:hover\\:to-green-100:hover {\n    --gradient-to-color: #f0fff4;\n  }\n\n  .lg\\:hover\\:to-green-200:hover {\n    --gradient-to-color: #c6f6d5;\n  }\n\n  .lg\\:hover\\:to-green-300:hover {\n    --gradient-to-color: #9ae6b4;\n  }\n\n  .lg\\:hover\\:to-green-400:hover {\n    --gradient-to-color: #68d391;\n  }\n\n  .lg\\:hover\\:to-green-500:hover {\n    --gradient-to-color: #48bb78;\n  }\n\n  .lg\\:hover\\:to-green-600:hover {\n    --gradient-to-color: #38a169;\n  }\n\n  .lg\\:hover\\:to-green-700:hover {\n    --gradient-to-color: #2f855a;\n  }\n\n  .lg\\:hover\\:to-green-800:hover {\n    --gradient-to-color: #276749;\n  }\n\n  .lg\\:hover\\:to-green-900:hover {\n    --gradient-to-color: #22543d;\n  }\n\n  .lg\\:hover\\:to-teal-100:hover {\n    --gradient-to-color: #e6fffa;\n  }\n\n  .lg\\:hover\\:to-teal-200:hover {\n    --gradient-to-color: #b2f5ea;\n  }\n\n  .lg\\:hover\\:to-teal-300:hover {\n    --gradient-to-color: #81e6d9;\n  }\n\n  .lg\\:hover\\:to-teal-400:hover {\n    --gradient-to-color: #4fd1c5;\n  }\n\n  .lg\\:hover\\:to-teal-500:hover {\n    --gradient-to-color: #38b2ac;\n  }\n\n  .lg\\:hover\\:to-teal-600:hover {\n    --gradient-to-color: #319795;\n  }\n\n  .lg\\:hover\\:to-teal-700:hover {\n    --gradient-to-color: #2c7a7b;\n  }\n\n  .lg\\:hover\\:to-teal-800:hover {\n    --gradient-to-color: #285e61;\n  }\n\n  .lg\\:hover\\:to-teal-900:hover {\n    --gradient-to-color: #234e52;\n  }\n\n  .lg\\:hover\\:to-blue-100:hover {\n    --gradient-to-color: #ebf8ff;\n  }\n\n  .lg\\:hover\\:to-blue-200:hover {\n    --gradient-to-color: #bee3f8;\n  }\n\n  .lg\\:hover\\:to-blue-300:hover {\n    --gradient-to-color: #90cdf4;\n  }\n\n  .lg\\:hover\\:to-blue-400:hover {\n    --gradient-to-color: #63b3ed;\n  }\n\n  .lg\\:hover\\:to-blue-500:hover {\n    --gradient-to-color: #4299e1;\n  }\n\n  .lg\\:hover\\:to-blue-600:hover {\n    --gradient-to-color: #3182ce;\n  }\n\n  .lg\\:hover\\:to-blue-700:hover {\n    --gradient-to-color: #2b6cb0;\n  }\n\n  .lg\\:hover\\:to-blue-800:hover {\n    --gradient-to-color: #2c5282;\n  }\n\n  .lg\\:hover\\:to-blue-900:hover {\n    --gradient-to-color: #2a4365;\n  }\n\n  .lg\\:hover\\:to-indigo-100:hover {\n    --gradient-to-color: #ebf4ff;\n  }\n\n  .lg\\:hover\\:to-indigo-200:hover {\n    --gradient-to-color: #c3dafe;\n  }\n\n  .lg\\:hover\\:to-indigo-300:hover {\n    --gradient-to-color: #a3bffa;\n  }\n\n  .lg\\:hover\\:to-indigo-400:hover {\n    --gradient-to-color: #7f9cf5;\n  }\n\n  .lg\\:hover\\:to-indigo-500:hover {\n    --gradient-to-color: #667eea;\n  }\n\n  .lg\\:hover\\:to-indigo-600:hover {\n    --gradient-to-color: #5a67d8;\n  }\n\n  .lg\\:hover\\:to-indigo-700:hover {\n    --gradient-to-color: #4c51bf;\n  }\n\n  .lg\\:hover\\:to-indigo-800:hover {\n    --gradient-to-color: #434190;\n  }\n\n  .lg\\:hover\\:to-indigo-900:hover {\n    --gradient-to-color: #3c366b;\n  }\n\n  .lg\\:hover\\:to-purple-100:hover {\n    --gradient-to-color: #faf5ff;\n  }\n\n  .lg\\:hover\\:to-purple-200:hover {\n    --gradient-to-color: #e9d8fd;\n  }\n\n  .lg\\:hover\\:to-purple-300:hover {\n    --gradient-to-color: #d6bcfa;\n  }\n\n  .lg\\:hover\\:to-purple-400:hover {\n    --gradient-to-color: #b794f4;\n  }\n\n  .lg\\:hover\\:to-purple-500:hover {\n    --gradient-to-color: #9f7aea;\n  }\n\n  .lg\\:hover\\:to-purple-600:hover {\n    --gradient-to-color: #805ad5;\n  }\n\n  .lg\\:hover\\:to-purple-700:hover {\n    --gradient-to-color: #6b46c1;\n  }\n\n  .lg\\:hover\\:to-purple-800:hover {\n    --gradient-to-color: #553c9a;\n  }\n\n  .lg\\:hover\\:to-purple-900:hover {\n    --gradient-to-color: #44337a;\n  }\n\n  .lg\\:hover\\:to-pink-100:hover {\n    --gradient-to-color: #fff5f7;\n  }\n\n  .lg\\:hover\\:to-pink-200:hover {\n    --gradient-to-color: #fed7e2;\n  }\n\n  .lg\\:hover\\:to-pink-300:hover {\n    --gradient-to-color: #fbb6ce;\n  }\n\n  .lg\\:hover\\:to-pink-400:hover {\n    --gradient-to-color: #f687b3;\n  }\n\n  .lg\\:hover\\:to-pink-500:hover {\n    --gradient-to-color: #ed64a6;\n  }\n\n  .lg\\:hover\\:to-pink-600:hover {\n    --gradient-to-color: #d53f8c;\n  }\n\n  .lg\\:hover\\:to-pink-700:hover {\n    --gradient-to-color: #b83280;\n  }\n\n  .lg\\:hover\\:to-pink-800:hover {\n    --gradient-to-color: #97266d;\n  }\n\n  .lg\\:hover\\:to-pink-900:hover {\n    --gradient-to-color: #702459;\n  }\n\n  .lg\\:hover\\:to-grayscale-80:hover {\n    --gradient-to-color: hsl(0, 0%, 8%);\n  }\n\n  .lg\\:hover\\:to-grayscale-100:hover {\n    --gradient-to-color: hsl(0, 0%, 10%);\n  }\n\n  .lg\\:hover\\:to-grayscale-200:hover {\n    --gradient-to-color: hsl(0, 0%, 20%);\n  }\n\n  .lg\\:hover\\:to-grayscale-300:hover {\n    --gradient-to-color: hsl(0, 0%, 30%);\n  }\n\n  .lg\\:hover\\:to-grayscale-400:hover {\n    --gradient-to-color: hsl(0, 0%, 40%);\n  }\n\n  .lg\\:hover\\:to-grayscale-500:hover {\n    --gradient-to-color: hsl(0, 0%, 50%);\n  }\n\n  .lg\\:hover\\:to-grayscale-600:hover {\n    --gradient-to-color: hsl(0, 0%, 60%);\n  }\n\n  .lg\\:hover\\:to-grayscale-700:hover {\n    --gradient-to-color: hsl(0, 0%, 70%);\n  }\n\n  .lg\\:hover\\:to-grayscale-800:hover {\n    --gradient-to-color: hsl(0, 0%, 80%);\n  }\n\n  .lg\\:hover\\:to-grayscale-840:hover {\n    --gradient-to-color: hsl(0, 0%, 84%);\n  }\n\n  .lg\\:hover\\:to-grayscale-870:hover {\n    --gradient-to-color: hsl(0, 0%, 87%);\n  }\n\n  .lg\\:hover\\:to-grayscale-900:hover {\n    --gradient-to-color: hsl(0, 0%, 90%);\n  }\n\n  .lg\\:hover\\:to-grayscale-930:hover {\n    --gradient-to-color: hsl(0, 0%, 93%);\n  }\n\n  .lg\\:hover\\:to-primary:hover {\n    --gradient-to-color: hsl(210, 100%, 52%);\n  }\n\n  .lg\\:hover\\:to-background-main:hover {\n    --gradient-to-color: var(--main-background);\n  }\n\n  .lg\\:hover\\:to-background-secondary:hover {\n    --gradient-to-color: var(--secondary-background);\n  }\n\n  .lg\\:hover\\:to-foreground:hover {\n    --gradient-to-color: var(--foreground);\n  }\n\n  .lg\\:hover\\:to-panels-bg:hover {\n    --gradient-to-color: var(--panels-background);\n  }\n\n  .lg\\:focus\\:from-transparent:focus {\n    --gradient-from-color: transparent;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .lg\\:focus\\:from-current:focus {\n    --gradient-from-color: currentColor;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:focus\\:from-black:focus {\n    --gradient-from-color: #000;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .lg\\:focus\\:from-white:focus {\n    --gradient-from-color: #fff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:focus\\:from-gray-100:focus {\n    --gradient-from-color: #f7fafc;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n  }\n\n  .lg\\:focus\\:from-gray-200:focus {\n    --gradient-from-color: #edf2f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n  }\n\n  .lg\\:focus\\:from-gray-300:focus {\n    --gradient-from-color: #e2e8f0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n  }\n\n  .lg\\:focus\\:from-gray-400:focus {\n    --gradient-from-color: #cbd5e0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n  }\n\n  .lg\\:focus\\:from-gray-500:focus {\n    --gradient-from-color: #a0aec0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n  }\n\n  .lg\\:focus\\:from-gray-600:focus {\n    --gradient-from-color: #718096;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n  }\n\n  .lg\\:focus\\:from-gray-700:focus {\n    --gradient-from-color: #4a5568;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n  }\n\n  .lg\\:focus\\:from-gray-800:focus {\n    --gradient-from-color: #2d3748;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n  }\n\n  .lg\\:focus\\:from-gray-900:focus {\n    --gradient-from-color: #1a202c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n  }\n\n  .lg\\:focus\\:from-red-100:focus {\n    --gradient-from-color: #fff5f5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n  }\n\n  .lg\\:focus\\:from-red-200:focus {\n    --gradient-from-color: #fed7d7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n  }\n\n  .lg\\:focus\\:from-red-300:focus {\n    --gradient-from-color: #feb2b2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n  }\n\n  .lg\\:focus\\:from-red-400:focus {\n    --gradient-from-color: #fc8181;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n  }\n\n  .lg\\:focus\\:from-red-500:focus {\n    --gradient-from-color: #f56565;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n  }\n\n  .lg\\:focus\\:from-red-600:focus {\n    --gradient-from-color: #e53e3e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n  }\n\n  .lg\\:focus\\:from-red-700:focus {\n    --gradient-from-color: #c53030;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n  }\n\n  .lg\\:focus\\:from-red-800:focus {\n    --gradient-from-color: #9b2c2c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n  }\n\n  .lg\\:focus\\:from-red-900:focus {\n    --gradient-from-color: #742a2a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n  }\n\n  .lg\\:focus\\:from-orange-100:focus {\n    --gradient-from-color: #fffaf0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n  }\n\n  .lg\\:focus\\:from-orange-200:focus {\n    --gradient-from-color: #feebc8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n  }\n\n  .lg\\:focus\\:from-orange-300:focus {\n    --gradient-from-color: #fbd38d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n  }\n\n  .lg\\:focus\\:from-orange-400:focus {\n    --gradient-from-color: #f6ad55;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n  }\n\n  .lg\\:focus\\:from-orange-500:focus {\n    --gradient-from-color: #ed8936;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n  }\n\n  .lg\\:focus\\:from-orange-600:focus {\n    --gradient-from-color: #dd6b20;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n  }\n\n  .lg\\:focus\\:from-orange-700:focus {\n    --gradient-from-color: #c05621;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n  }\n\n  .lg\\:focus\\:from-orange-800:focus {\n    --gradient-from-color: #9c4221;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n  }\n\n  .lg\\:focus\\:from-orange-900:focus {\n    --gradient-from-color: #7b341e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n  }\n\n  .lg\\:focus\\:from-yellow-100:focus {\n    --gradient-from-color: #fffff0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n  }\n\n  .lg\\:focus\\:from-yellow-200:focus {\n    --gradient-from-color: #fefcbf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n  }\n\n  .lg\\:focus\\:from-yellow-300:focus {\n    --gradient-from-color: #faf089;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n  }\n\n  .lg\\:focus\\:from-yellow-400:focus {\n    --gradient-from-color: #f6e05e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n  }\n\n  .lg\\:focus\\:from-yellow-500:focus {\n    --gradient-from-color: #ecc94b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n  }\n\n  .lg\\:focus\\:from-yellow-600:focus {\n    --gradient-from-color: #d69e2e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n  }\n\n  .lg\\:focus\\:from-yellow-700:focus {\n    --gradient-from-color: #b7791f;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n  }\n\n  .lg\\:focus\\:from-yellow-800:focus {\n    --gradient-from-color: #975a16;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n  }\n\n  .lg\\:focus\\:from-yellow-900:focus {\n    --gradient-from-color: #744210;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n  }\n\n  .lg\\:focus\\:from-green-100:focus {\n    --gradient-from-color: #f0fff4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n  }\n\n  .lg\\:focus\\:from-green-200:focus {\n    --gradient-from-color: #c6f6d5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n  }\n\n  .lg\\:focus\\:from-green-300:focus {\n    --gradient-from-color: #9ae6b4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n  }\n\n  .lg\\:focus\\:from-green-400:focus {\n    --gradient-from-color: #68d391;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n  }\n\n  .lg\\:focus\\:from-green-500:focus {\n    --gradient-from-color: #48bb78;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n  }\n\n  .lg\\:focus\\:from-green-600:focus {\n    --gradient-from-color: #38a169;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n  }\n\n  .lg\\:focus\\:from-green-700:focus {\n    --gradient-from-color: #2f855a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n  }\n\n  .lg\\:focus\\:from-green-800:focus {\n    --gradient-from-color: #276749;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n  }\n\n  .lg\\:focus\\:from-green-900:focus {\n    --gradient-from-color: #22543d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n  }\n\n  .lg\\:focus\\:from-teal-100:focus {\n    --gradient-from-color: #e6fffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n  }\n\n  .lg\\:focus\\:from-teal-200:focus {\n    --gradient-from-color: #b2f5ea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n  }\n\n  .lg\\:focus\\:from-teal-300:focus {\n    --gradient-from-color: #81e6d9;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n  }\n\n  .lg\\:focus\\:from-teal-400:focus {\n    --gradient-from-color: #4fd1c5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n  }\n\n  .lg\\:focus\\:from-teal-500:focus {\n    --gradient-from-color: #38b2ac;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n  }\n\n  .lg\\:focus\\:from-teal-600:focus {\n    --gradient-from-color: #319795;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n  }\n\n  .lg\\:focus\\:from-teal-700:focus {\n    --gradient-from-color: #2c7a7b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n  }\n\n  .lg\\:focus\\:from-teal-800:focus {\n    --gradient-from-color: #285e61;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n  }\n\n  .lg\\:focus\\:from-teal-900:focus {\n    --gradient-from-color: #234e52;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n  }\n\n  .lg\\:focus\\:from-blue-100:focus {\n    --gradient-from-color: #ebf8ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n  }\n\n  .lg\\:focus\\:from-blue-200:focus {\n    --gradient-from-color: #bee3f8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n  }\n\n  .lg\\:focus\\:from-blue-300:focus {\n    --gradient-from-color: #90cdf4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n  }\n\n  .lg\\:focus\\:from-blue-400:focus {\n    --gradient-from-color: #63b3ed;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n  }\n\n  .lg\\:focus\\:from-blue-500:focus {\n    --gradient-from-color: #4299e1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n  }\n\n  .lg\\:focus\\:from-blue-600:focus {\n    --gradient-from-color: #3182ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n  }\n\n  .lg\\:focus\\:from-blue-700:focus {\n    --gradient-from-color: #2b6cb0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n  }\n\n  .lg\\:focus\\:from-blue-800:focus {\n    --gradient-from-color: #2c5282;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n  }\n\n  .lg\\:focus\\:from-blue-900:focus {\n    --gradient-from-color: #2a4365;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n  }\n\n  .lg\\:focus\\:from-indigo-100:focus {\n    --gradient-from-color: #ebf4ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n  }\n\n  .lg\\:focus\\:from-indigo-200:focus {\n    --gradient-from-color: #c3dafe;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n  }\n\n  .lg\\:focus\\:from-indigo-300:focus {\n    --gradient-from-color: #a3bffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n  }\n\n  .lg\\:focus\\:from-indigo-400:focus {\n    --gradient-from-color: #7f9cf5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n  }\n\n  .lg\\:focus\\:from-indigo-500:focus {\n    --gradient-from-color: #667eea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n  }\n\n  .lg\\:focus\\:from-indigo-600:focus {\n    --gradient-from-color: #5a67d8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n  }\n\n  .lg\\:focus\\:from-indigo-700:focus {\n    --gradient-from-color: #4c51bf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n  }\n\n  .lg\\:focus\\:from-indigo-800:focus {\n    --gradient-from-color: #434190;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n  }\n\n  .lg\\:focus\\:from-indigo-900:focus {\n    --gradient-from-color: #3c366b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n  }\n\n  .lg\\:focus\\:from-purple-100:focus {\n    --gradient-from-color: #faf5ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n  }\n\n  .lg\\:focus\\:from-purple-200:focus {\n    --gradient-from-color: #e9d8fd;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n  }\n\n  .lg\\:focus\\:from-purple-300:focus {\n    --gradient-from-color: #d6bcfa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n  }\n\n  .lg\\:focus\\:from-purple-400:focus {\n    --gradient-from-color: #b794f4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n  }\n\n  .lg\\:focus\\:from-purple-500:focus {\n    --gradient-from-color: #9f7aea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n  }\n\n  .lg\\:focus\\:from-purple-600:focus {\n    --gradient-from-color: #805ad5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n  }\n\n  .lg\\:focus\\:from-purple-700:focus {\n    --gradient-from-color: #6b46c1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n  }\n\n  .lg\\:focus\\:from-purple-800:focus {\n    --gradient-from-color: #553c9a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n  }\n\n  .lg\\:focus\\:from-purple-900:focus {\n    --gradient-from-color: #44337a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n  }\n\n  .lg\\:focus\\:from-pink-100:focus {\n    --gradient-from-color: #fff5f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n  }\n\n  .lg\\:focus\\:from-pink-200:focus {\n    --gradient-from-color: #fed7e2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n  }\n\n  .lg\\:focus\\:from-pink-300:focus {\n    --gradient-from-color: #fbb6ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n  }\n\n  .lg\\:focus\\:from-pink-400:focus {\n    --gradient-from-color: #f687b3;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n  }\n\n  .lg\\:focus\\:from-pink-500:focus {\n    --gradient-from-color: #ed64a6;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n  }\n\n  .lg\\:focus\\:from-pink-600:focus {\n    --gradient-from-color: #d53f8c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n  }\n\n  .lg\\:focus\\:from-pink-700:focus {\n    --gradient-from-color: #b83280;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n  }\n\n  .lg\\:focus\\:from-pink-800:focus {\n    --gradient-from-color: #97266d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n  }\n\n  .lg\\:focus\\:from-pink-900:focus {\n    --gradient-from-color: #702459;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n  }\n\n  .lg\\:focus\\:from-grayscale-80:focus {\n    --gradient-from-color: hsl(0, 0%, 8%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n  }\n\n  .lg\\:focus\\:from-grayscale-100:focus {\n    --gradient-from-color: hsl(0, 0%, 10%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n  }\n\n  .lg\\:focus\\:from-grayscale-200:focus {\n    --gradient-from-color: hsl(0, 0%, 20%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n  }\n\n  .lg\\:focus\\:from-grayscale-300:focus {\n    --gradient-from-color: hsl(0, 0%, 30%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n  }\n\n  .lg\\:focus\\:from-grayscale-400:focus {\n    --gradient-from-color: hsl(0, 0%, 40%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n  }\n\n  .lg\\:focus\\:from-grayscale-500:focus {\n    --gradient-from-color: hsl(0, 0%, 50%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n  }\n\n  .lg\\:focus\\:from-grayscale-600:focus {\n    --gradient-from-color: hsl(0, 0%, 60%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n  }\n\n  .lg\\:focus\\:from-grayscale-700:focus {\n    --gradient-from-color: hsl(0, 0%, 70%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n  }\n\n  .lg\\:focus\\:from-grayscale-800:focus {\n    --gradient-from-color: hsl(0, 0%, 80%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n  }\n\n  .lg\\:focus\\:from-grayscale-840:focus {\n    --gradient-from-color: hsl(0, 0%, 84%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n  }\n\n  .lg\\:focus\\:from-grayscale-870:focus {\n    --gradient-from-color: hsl(0, 0%, 87%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n  }\n\n  .lg\\:focus\\:from-grayscale-900:focus {\n    --gradient-from-color: hsl(0, 0%, 90%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n  }\n\n  .lg\\:focus\\:from-grayscale-930:focus {\n    --gradient-from-color: hsl(0, 0%, 93%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n  }\n\n  .lg\\:focus\\:from-primary:focus {\n    --gradient-from-color: hsl(210, 100%, 52%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n  }\n\n  .lg\\:focus\\:from-background-main:focus {\n    --gradient-from-color: var(--main-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:focus\\:from-background-secondary:focus {\n    --gradient-from-color: var(--secondary-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:focus\\:from-foreground:focus {\n    --gradient-from-color: var(--foreground);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:focus\\:from-panels-bg:focus {\n    --gradient-from-color: var(--panels-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:focus\\:via-transparent:focus {\n    --gradient-via-color: transparent;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .lg\\:focus\\:via-current:focus {\n    --gradient-via-color: currentColor;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:focus\\:via-black:focus {\n    --gradient-via-color: #000;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .lg\\:focus\\:via-white:focus {\n    --gradient-via-color: #fff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:focus\\:via-gray-100:focus {\n    --gradient-via-color: #f7fafc;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n  }\n\n  .lg\\:focus\\:via-gray-200:focus {\n    --gradient-via-color: #edf2f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n  }\n\n  .lg\\:focus\\:via-gray-300:focus {\n    --gradient-via-color: #e2e8f0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n  }\n\n  .lg\\:focus\\:via-gray-400:focus {\n    --gradient-via-color: #cbd5e0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n  }\n\n  .lg\\:focus\\:via-gray-500:focus {\n    --gradient-via-color: #a0aec0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n  }\n\n  .lg\\:focus\\:via-gray-600:focus {\n    --gradient-via-color: #718096;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n  }\n\n  .lg\\:focus\\:via-gray-700:focus {\n    --gradient-via-color: #4a5568;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n  }\n\n  .lg\\:focus\\:via-gray-800:focus {\n    --gradient-via-color: #2d3748;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n  }\n\n  .lg\\:focus\\:via-gray-900:focus {\n    --gradient-via-color: #1a202c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n  }\n\n  .lg\\:focus\\:via-red-100:focus {\n    --gradient-via-color: #fff5f5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n  }\n\n  .lg\\:focus\\:via-red-200:focus {\n    --gradient-via-color: #fed7d7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n  }\n\n  .lg\\:focus\\:via-red-300:focus {\n    --gradient-via-color: #feb2b2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n  }\n\n  .lg\\:focus\\:via-red-400:focus {\n    --gradient-via-color: #fc8181;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n  }\n\n  .lg\\:focus\\:via-red-500:focus {\n    --gradient-via-color: #f56565;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n  }\n\n  .lg\\:focus\\:via-red-600:focus {\n    --gradient-via-color: #e53e3e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n  }\n\n  .lg\\:focus\\:via-red-700:focus {\n    --gradient-via-color: #c53030;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n  }\n\n  .lg\\:focus\\:via-red-800:focus {\n    --gradient-via-color: #9b2c2c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n  }\n\n  .lg\\:focus\\:via-red-900:focus {\n    --gradient-via-color: #742a2a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n  }\n\n  .lg\\:focus\\:via-orange-100:focus {\n    --gradient-via-color: #fffaf0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n  }\n\n  .lg\\:focus\\:via-orange-200:focus {\n    --gradient-via-color: #feebc8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n  }\n\n  .lg\\:focus\\:via-orange-300:focus {\n    --gradient-via-color: #fbd38d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n  }\n\n  .lg\\:focus\\:via-orange-400:focus {\n    --gradient-via-color: #f6ad55;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n  }\n\n  .lg\\:focus\\:via-orange-500:focus {\n    --gradient-via-color: #ed8936;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n  }\n\n  .lg\\:focus\\:via-orange-600:focus {\n    --gradient-via-color: #dd6b20;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n  }\n\n  .lg\\:focus\\:via-orange-700:focus {\n    --gradient-via-color: #c05621;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n  }\n\n  .lg\\:focus\\:via-orange-800:focus {\n    --gradient-via-color: #9c4221;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n  }\n\n  .lg\\:focus\\:via-orange-900:focus {\n    --gradient-via-color: #7b341e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n  }\n\n  .lg\\:focus\\:via-yellow-100:focus {\n    --gradient-via-color: #fffff0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n  }\n\n  .lg\\:focus\\:via-yellow-200:focus {\n    --gradient-via-color: #fefcbf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n  }\n\n  .lg\\:focus\\:via-yellow-300:focus {\n    --gradient-via-color: #faf089;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n  }\n\n  .lg\\:focus\\:via-yellow-400:focus {\n    --gradient-via-color: #f6e05e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n  }\n\n  .lg\\:focus\\:via-yellow-500:focus {\n    --gradient-via-color: #ecc94b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n  }\n\n  .lg\\:focus\\:via-yellow-600:focus {\n    --gradient-via-color: #d69e2e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n  }\n\n  .lg\\:focus\\:via-yellow-700:focus {\n    --gradient-via-color: #b7791f;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n  }\n\n  .lg\\:focus\\:via-yellow-800:focus {\n    --gradient-via-color: #975a16;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n  }\n\n  .lg\\:focus\\:via-yellow-900:focus {\n    --gradient-via-color: #744210;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n  }\n\n  .lg\\:focus\\:via-green-100:focus {\n    --gradient-via-color: #f0fff4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n  }\n\n  .lg\\:focus\\:via-green-200:focus {\n    --gradient-via-color: #c6f6d5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n  }\n\n  .lg\\:focus\\:via-green-300:focus {\n    --gradient-via-color: #9ae6b4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n  }\n\n  .lg\\:focus\\:via-green-400:focus {\n    --gradient-via-color: #68d391;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n  }\n\n  .lg\\:focus\\:via-green-500:focus {\n    --gradient-via-color: #48bb78;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n  }\n\n  .lg\\:focus\\:via-green-600:focus {\n    --gradient-via-color: #38a169;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n  }\n\n  .lg\\:focus\\:via-green-700:focus {\n    --gradient-via-color: #2f855a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n  }\n\n  .lg\\:focus\\:via-green-800:focus {\n    --gradient-via-color: #276749;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n  }\n\n  .lg\\:focus\\:via-green-900:focus {\n    --gradient-via-color: #22543d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n  }\n\n  .lg\\:focus\\:via-teal-100:focus {\n    --gradient-via-color: #e6fffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n  }\n\n  .lg\\:focus\\:via-teal-200:focus {\n    --gradient-via-color: #b2f5ea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n  }\n\n  .lg\\:focus\\:via-teal-300:focus {\n    --gradient-via-color: #81e6d9;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n  }\n\n  .lg\\:focus\\:via-teal-400:focus {\n    --gradient-via-color: #4fd1c5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n  }\n\n  .lg\\:focus\\:via-teal-500:focus {\n    --gradient-via-color: #38b2ac;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n  }\n\n  .lg\\:focus\\:via-teal-600:focus {\n    --gradient-via-color: #319795;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n  }\n\n  .lg\\:focus\\:via-teal-700:focus {\n    --gradient-via-color: #2c7a7b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n  }\n\n  .lg\\:focus\\:via-teal-800:focus {\n    --gradient-via-color: #285e61;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n  }\n\n  .lg\\:focus\\:via-teal-900:focus {\n    --gradient-via-color: #234e52;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n  }\n\n  .lg\\:focus\\:via-blue-100:focus {\n    --gradient-via-color: #ebf8ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n  }\n\n  .lg\\:focus\\:via-blue-200:focus {\n    --gradient-via-color: #bee3f8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n  }\n\n  .lg\\:focus\\:via-blue-300:focus {\n    --gradient-via-color: #90cdf4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n  }\n\n  .lg\\:focus\\:via-blue-400:focus {\n    --gradient-via-color: #63b3ed;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n  }\n\n  .lg\\:focus\\:via-blue-500:focus {\n    --gradient-via-color: #4299e1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n  }\n\n  .lg\\:focus\\:via-blue-600:focus {\n    --gradient-via-color: #3182ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n  }\n\n  .lg\\:focus\\:via-blue-700:focus {\n    --gradient-via-color: #2b6cb0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n  }\n\n  .lg\\:focus\\:via-blue-800:focus {\n    --gradient-via-color: #2c5282;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n  }\n\n  .lg\\:focus\\:via-blue-900:focus {\n    --gradient-via-color: #2a4365;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n  }\n\n  .lg\\:focus\\:via-indigo-100:focus {\n    --gradient-via-color: #ebf4ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n  }\n\n  .lg\\:focus\\:via-indigo-200:focus {\n    --gradient-via-color: #c3dafe;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n  }\n\n  .lg\\:focus\\:via-indigo-300:focus {\n    --gradient-via-color: #a3bffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n  }\n\n  .lg\\:focus\\:via-indigo-400:focus {\n    --gradient-via-color: #7f9cf5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n  }\n\n  .lg\\:focus\\:via-indigo-500:focus {\n    --gradient-via-color: #667eea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n  }\n\n  .lg\\:focus\\:via-indigo-600:focus {\n    --gradient-via-color: #5a67d8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n  }\n\n  .lg\\:focus\\:via-indigo-700:focus {\n    --gradient-via-color: #4c51bf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n  }\n\n  .lg\\:focus\\:via-indigo-800:focus {\n    --gradient-via-color: #434190;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n  }\n\n  .lg\\:focus\\:via-indigo-900:focus {\n    --gradient-via-color: #3c366b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n  }\n\n  .lg\\:focus\\:via-purple-100:focus {\n    --gradient-via-color: #faf5ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n  }\n\n  .lg\\:focus\\:via-purple-200:focus {\n    --gradient-via-color: #e9d8fd;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n  }\n\n  .lg\\:focus\\:via-purple-300:focus {\n    --gradient-via-color: #d6bcfa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n  }\n\n  .lg\\:focus\\:via-purple-400:focus {\n    --gradient-via-color: #b794f4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n  }\n\n  .lg\\:focus\\:via-purple-500:focus {\n    --gradient-via-color: #9f7aea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n  }\n\n  .lg\\:focus\\:via-purple-600:focus {\n    --gradient-via-color: #805ad5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n  }\n\n  .lg\\:focus\\:via-purple-700:focus {\n    --gradient-via-color: #6b46c1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n  }\n\n  .lg\\:focus\\:via-purple-800:focus {\n    --gradient-via-color: #553c9a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n  }\n\n  .lg\\:focus\\:via-purple-900:focus {\n    --gradient-via-color: #44337a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n  }\n\n  .lg\\:focus\\:via-pink-100:focus {\n    --gradient-via-color: #fff5f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n  }\n\n  .lg\\:focus\\:via-pink-200:focus {\n    --gradient-via-color: #fed7e2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n  }\n\n  .lg\\:focus\\:via-pink-300:focus {\n    --gradient-via-color: #fbb6ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n  }\n\n  .lg\\:focus\\:via-pink-400:focus {\n    --gradient-via-color: #f687b3;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n  }\n\n  .lg\\:focus\\:via-pink-500:focus {\n    --gradient-via-color: #ed64a6;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n  }\n\n  .lg\\:focus\\:via-pink-600:focus {\n    --gradient-via-color: #d53f8c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n  }\n\n  .lg\\:focus\\:via-pink-700:focus {\n    --gradient-via-color: #b83280;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n  }\n\n  .lg\\:focus\\:via-pink-800:focus {\n    --gradient-via-color: #97266d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n  }\n\n  .lg\\:focus\\:via-pink-900:focus {\n    --gradient-via-color: #702459;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n  }\n\n  .lg\\:focus\\:via-grayscale-80:focus {\n    --gradient-via-color: hsl(0, 0%, 8%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n  }\n\n  .lg\\:focus\\:via-grayscale-100:focus {\n    --gradient-via-color: hsl(0, 0%, 10%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n  }\n\n  .lg\\:focus\\:via-grayscale-200:focus {\n    --gradient-via-color: hsl(0, 0%, 20%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n  }\n\n  .lg\\:focus\\:via-grayscale-300:focus {\n    --gradient-via-color: hsl(0, 0%, 30%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n  }\n\n  .lg\\:focus\\:via-grayscale-400:focus {\n    --gradient-via-color: hsl(0, 0%, 40%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n  }\n\n  .lg\\:focus\\:via-grayscale-500:focus {\n    --gradient-via-color: hsl(0, 0%, 50%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n  }\n\n  .lg\\:focus\\:via-grayscale-600:focus {\n    --gradient-via-color: hsl(0, 0%, 60%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n  }\n\n  .lg\\:focus\\:via-grayscale-700:focus {\n    --gradient-via-color: hsl(0, 0%, 70%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n  }\n\n  .lg\\:focus\\:via-grayscale-800:focus {\n    --gradient-via-color: hsl(0, 0%, 80%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n  }\n\n  .lg\\:focus\\:via-grayscale-840:focus {\n    --gradient-via-color: hsl(0, 0%, 84%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n  }\n\n  .lg\\:focus\\:via-grayscale-870:focus {\n    --gradient-via-color: hsl(0, 0%, 87%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n  }\n\n  .lg\\:focus\\:via-grayscale-900:focus {\n    --gradient-via-color: hsl(0, 0%, 90%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n  }\n\n  .lg\\:focus\\:via-grayscale-930:focus {\n    --gradient-via-color: hsl(0, 0%, 93%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n  }\n\n  .lg\\:focus\\:via-primary:focus {\n    --gradient-via-color: hsl(210, 100%, 52%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n  }\n\n  .lg\\:focus\\:via-background-main:focus {\n    --gradient-via-color: var(--main-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:focus\\:via-background-secondary:focus {\n    --gradient-via-color: var(--secondary-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:focus\\:via-foreground:focus {\n    --gradient-via-color: var(--foreground);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:focus\\:via-panels-bg:focus {\n    --gradient-via-color: var(--panels-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .lg\\:focus\\:to-transparent:focus {\n    --gradient-to-color: transparent;\n  }\n\n  .lg\\:focus\\:to-current:focus {\n    --gradient-to-color: currentColor;\n  }\n\n  .lg\\:focus\\:to-black:focus {\n    --gradient-to-color: #000;\n  }\n\n  .lg\\:focus\\:to-white:focus {\n    --gradient-to-color: #fff;\n  }\n\n  .lg\\:focus\\:to-gray-100:focus {\n    --gradient-to-color: #f7fafc;\n  }\n\n  .lg\\:focus\\:to-gray-200:focus {\n    --gradient-to-color: #edf2f7;\n  }\n\n  .lg\\:focus\\:to-gray-300:focus {\n    --gradient-to-color: #e2e8f0;\n  }\n\n  .lg\\:focus\\:to-gray-400:focus {\n    --gradient-to-color: #cbd5e0;\n  }\n\n  .lg\\:focus\\:to-gray-500:focus {\n    --gradient-to-color: #a0aec0;\n  }\n\n  .lg\\:focus\\:to-gray-600:focus {\n    --gradient-to-color: #718096;\n  }\n\n  .lg\\:focus\\:to-gray-700:focus {\n    --gradient-to-color: #4a5568;\n  }\n\n  .lg\\:focus\\:to-gray-800:focus {\n    --gradient-to-color: #2d3748;\n  }\n\n  .lg\\:focus\\:to-gray-900:focus {\n    --gradient-to-color: #1a202c;\n  }\n\n  .lg\\:focus\\:to-red-100:focus {\n    --gradient-to-color: #fff5f5;\n  }\n\n  .lg\\:focus\\:to-red-200:focus {\n    --gradient-to-color: #fed7d7;\n  }\n\n  .lg\\:focus\\:to-red-300:focus {\n    --gradient-to-color: #feb2b2;\n  }\n\n  .lg\\:focus\\:to-red-400:focus {\n    --gradient-to-color: #fc8181;\n  }\n\n  .lg\\:focus\\:to-red-500:focus {\n    --gradient-to-color: #f56565;\n  }\n\n  .lg\\:focus\\:to-red-600:focus {\n    --gradient-to-color: #e53e3e;\n  }\n\n  .lg\\:focus\\:to-red-700:focus {\n    --gradient-to-color: #c53030;\n  }\n\n  .lg\\:focus\\:to-red-800:focus {\n    --gradient-to-color: #9b2c2c;\n  }\n\n  .lg\\:focus\\:to-red-900:focus {\n    --gradient-to-color: #742a2a;\n  }\n\n  .lg\\:focus\\:to-orange-100:focus {\n    --gradient-to-color: #fffaf0;\n  }\n\n  .lg\\:focus\\:to-orange-200:focus {\n    --gradient-to-color: #feebc8;\n  }\n\n  .lg\\:focus\\:to-orange-300:focus {\n    --gradient-to-color: #fbd38d;\n  }\n\n  .lg\\:focus\\:to-orange-400:focus {\n    --gradient-to-color: #f6ad55;\n  }\n\n  .lg\\:focus\\:to-orange-500:focus {\n    --gradient-to-color: #ed8936;\n  }\n\n  .lg\\:focus\\:to-orange-600:focus {\n    --gradient-to-color: #dd6b20;\n  }\n\n  .lg\\:focus\\:to-orange-700:focus {\n    --gradient-to-color: #c05621;\n  }\n\n  .lg\\:focus\\:to-orange-800:focus {\n    --gradient-to-color: #9c4221;\n  }\n\n  .lg\\:focus\\:to-orange-900:focus {\n    --gradient-to-color: #7b341e;\n  }\n\n  .lg\\:focus\\:to-yellow-100:focus {\n    --gradient-to-color: #fffff0;\n  }\n\n  .lg\\:focus\\:to-yellow-200:focus {\n    --gradient-to-color: #fefcbf;\n  }\n\n  .lg\\:focus\\:to-yellow-300:focus {\n    --gradient-to-color: #faf089;\n  }\n\n  .lg\\:focus\\:to-yellow-400:focus {\n    --gradient-to-color: #f6e05e;\n  }\n\n  .lg\\:focus\\:to-yellow-500:focus {\n    --gradient-to-color: #ecc94b;\n  }\n\n  .lg\\:focus\\:to-yellow-600:focus {\n    --gradient-to-color: #d69e2e;\n  }\n\n  .lg\\:focus\\:to-yellow-700:focus {\n    --gradient-to-color: #b7791f;\n  }\n\n  .lg\\:focus\\:to-yellow-800:focus {\n    --gradient-to-color: #975a16;\n  }\n\n  .lg\\:focus\\:to-yellow-900:focus {\n    --gradient-to-color: #744210;\n  }\n\n  .lg\\:focus\\:to-green-100:focus {\n    --gradient-to-color: #f0fff4;\n  }\n\n  .lg\\:focus\\:to-green-200:focus {\n    --gradient-to-color: #c6f6d5;\n  }\n\n  .lg\\:focus\\:to-green-300:focus {\n    --gradient-to-color: #9ae6b4;\n  }\n\n  .lg\\:focus\\:to-green-400:focus {\n    --gradient-to-color: #68d391;\n  }\n\n  .lg\\:focus\\:to-green-500:focus {\n    --gradient-to-color: #48bb78;\n  }\n\n  .lg\\:focus\\:to-green-600:focus {\n    --gradient-to-color: #38a169;\n  }\n\n  .lg\\:focus\\:to-green-700:focus {\n    --gradient-to-color: #2f855a;\n  }\n\n  .lg\\:focus\\:to-green-800:focus {\n    --gradient-to-color: #276749;\n  }\n\n  .lg\\:focus\\:to-green-900:focus {\n    --gradient-to-color: #22543d;\n  }\n\n  .lg\\:focus\\:to-teal-100:focus {\n    --gradient-to-color: #e6fffa;\n  }\n\n  .lg\\:focus\\:to-teal-200:focus {\n    --gradient-to-color: #b2f5ea;\n  }\n\n  .lg\\:focus\\:to-teal-300:focus {\n    --gradient-to-color: #81e6d9;\n  }\n\n  .lg\\:focus\\:to-teal-400:focus {\n    --gradient-to-color: #4fd1c5;\n  }\n\n  .lg\\:focus\\:to-teal-500:focus {\n    --gradient-to-color: #38b2ac;\n  }\n\n  .lg\\:focus\\:to-teal-600:focus {\n    --gradient-to-color: #319795;\n  }\n\n  .lg\\:focus\\:to-teal-700:focus {\n    --gradient-to-color: #2c7a7b;\n  }\n\n  .lg\\:focus\\:to-teal-800:focus {\n    --gradient-to-color: #285e61;\n  }\n\n  .lg\\:focus\\:to-teal-900:focus {\n    --gradient-to-color: #234e52;\n  }\n\n  .lg\\:focus\\:to-blue-100:focus {\n    --gradient-to-color: #ebf8ff;\n  }\n\n  .lg\\:focus\\:to-blue-200:focus {\n    --gradient-to-color: #bee3f8;\n  }\n\n  .lg\\:focus\\:to-blue-300:focus {\n    --gradient-to-color: #90cdf4;\n  }\n\n  .lg\\:focus\\:to-blue-400:focus {\n    --gradient-to-color: #63b3ed;\n  }\n\n  .lg\\:focus\\:to-blue-500:focus {\n    --gradient-to-color: #4299e1;\n  }\n\n  .lg\\:focus\\:to-blue-600:focus {\n    --gradient-to-color: #3182ce;\n  }\n\n  .lg\\:focus\\:to-blue-700:focus {\n    --gradient-to-color: #2b6cb0;\n  }\n\n  .lg\\:focus\\:to-blue-800:focus {\n    --gradient-to-color: #2c5282;\n  }\n\n  .lg\\:focus\\:to-blue-900:focus {\n    --gradient-to-color: #2a4365;\n  }\n\n  .lg\\:focus\\:to-indigo-100:focus {\n    --gradient-to-color: #ebf4ff;\n  }\n\n  .lg\\:focus\\:to-indigo-200:focus {\n    --gradient-to-color: #c3dafe;\n  }\n\n  .lg\\:focus\\:to-indigo-300:focus {\n    --gradient-to-color: #a3bffa;\n  }\n\n  .lg\\:focus\\:to-indigo-400:focus {\n    --gradient-to-color: #7f9cf5;\n  }\n\n  .lg\\:focus\\:to-indigo-500:focus {\n    --gradient-to-color: #667eea;\n  }\n\n  .lg\\:focus\\:to-indigo-600:focus {\n    --gradient-to-color: #5a67d8;\n  }\n\n  .lg\\:focus\\:to-indigo-700:focus {\n    --gradient-to-color: #4c51bf;\n  }\n\n  .lg\\:focus\\:to-indigo-800:focus {\n    --gradient-to-color: #434190;\n  }\n\n  .lg\\:focus\\:to-indigo-900:focus {\n    --gradient-to-color: #3c366b;\n  }\n\n  .lg\\:focus\\:to-purple-100:focus {\n    --gradient-to-color: #faf5ff;\n  }\n\n  .lg\\:focus\\:to-purple-200:focus {\n    --gradient-to-color: #e9d8fd;\n  }\n\n  .lg\\:focus\\:to-purple-300:focus {\n    --gradient-to-color: #d6bcfa;\n  }\n\n  .lg\\:focus\\:to-purple-400:focus {\n    --gradient-to-color: #b794f4;\n  }\n\n  .lg\\:focus\\:to-purple-500:focus {\n    --gradient-to-color: #9f7aea;\n  }\n\n  .lg\\:focus\\:to-purple-600:focus {\n    --gradient-to-color: #805ad5;\n  }\n\n  .lg\\:focus\\:to-purple-700:focus {\n    --gradient-to-color: #6b46c1;\n  }\n\n  .lg\\:focus\\:to-purple-800:focus {\n    --gradient-to-color: #553c9a;\n  }\n\n  .lg\\:focus\\:to-purple-900:focus {\n    --gradient-to-color: #44337a;\n  }\n\n  .lg\\:focus\\:to-pink-100:focus {\n    --gradient-to-color: #fff5f7;\n  }\n\n  .lg\\:focus\\:to-pink-200:focus {\n    --gradient-to-color: #fed7e2;\n  }\n\n  .lg\\:focus\\:to-pink-300:focus {\n    --gradient-to-color: #fbb6ce;\n  }\n\n  .lg\\:focus\\:to-pink-400:focus {\n    --gradient-to-color: #f687b3;\n  }\n\n  .lg\\:focus\\:to-pink-500:focus {\n    --gradient-to-color: #ed64a6;\n  }\n\n  .lg\\:focus\\:to-pink-600:focus {\n    --gradient-to-color: #d53f8c;\n  }\n\n  .lg\\:focus\\:to-pink-700:focus {\n    --gradient-to-color: #b83280;\n  }\n\n  .lg\\:focus\\:to-pink-800:focus {\n    --gradient-to-color: #97266d;\n  }\n\n  .lg\\:focus\\:to-pink-900:focus {\n    --gradient-to-color: #702459;\n  }\n\n  .lg\\:focus\\:to-grayscale-80:focus {\n    --gradient-to-color: hsl(0, 0%, 8%);\n  }\n\n  .lg\\:focus\\:to-grayscale-100:focus {\n    --gradient-to-color: hsl(0, 0%, 10%);\n  }\n\n  .lg\\:focus\\:to-grayscale-200:focus {\n    --gradient-to-color: hsl(0, 0%, 20%);\n  }\n\n  .lg\\:focus\\:to-grayscale-300:focus {\n    --gradient-to-color: hsl(0, 0%, 30%);\n  }\n\n  .lg\\:focus\\:to-grayscale-400:focus {\n    --gradient-to-color: hsl(0, 0%, 40%);\n  }\n\n  .lg\\:focus\\:to-grayscale-500:focus {\n    --gradient-to-color: hsl(0, 0%, 50%);\n  }\n\n  .lg\\:focus\\:to-grayscale-600:focus {\n    --gradient-to-color: hsl(0, 0%, 60%);\n  }\n\n  .lg\\:focus\\:to-grayscale-700:focus {\n    --gradient-to-color: hsl(0, 0%, 70%);\n  }\n\n  .lg\\:focus\\:to-grayscale-800:focus {\n    --gradient-to-color: hsl(0, 0%, 80%);\n  }\n\n  .lg\\:focus\\:to-grayscale-840:focus {\n    --gradient-to-color: hsl(0, 0%, 84%);\n  }\n\n  .lg\\:focus\\:to-grayscale-870:focus {\n    --gradient-to-color: hsl(0, 0%, 87%);\n  }\n\n  .lg\\:focus\\:to-grayscale-900:focus {\n    --gradient-to-color: hsl(0, 0%, 90%);\n  }\n\n  .lg\\:focus\\:to-grayscale-930:focus {\n    --gradient-to-color: hsl(0, 0%, 93%);\n  }\n\n  .lg\\:focus\\:to-primary:focus {\n    --gradient-to-color: hsl(210, 100%, 52%);\n  }\n\n  .lg\\:focus\\:to-background-main:focus {\n    --gradient-to-color: var(--main-background);\n  }\n\n  .lg\\:focus\\:to-background-secondary:focus {\n    --gradient-to-color: var(--secondary-background);\n  }\n\n  .lg\\:focus\\:to-foreground:focus {\n    --gradient-to-color: var(--foreground);\n  }\n\n  .lg\\:focus\\:to-panels-bg:focus {\n    --gradient-to-color: var(--panels-background);\n  }\n\n  .lg\\:bg-opacity-0 {\n    --bg-opacity: 0;\n  }\n\n  .lg\\:bg-opacity-25 {\n    --bg-opacity: 0.25;\n  }\n\n  .lg\\:bg-opacity-50 {\n    --bg-opacity: 0.5;\n  }\n\n  .lg\\:bg-opacity-75 {\n    --bg-opacity: 0.75;\n  }\n\n  .lg\\:bg-opacity-100 {\n    --bg-opacity: 1;\n  }\n\n  .lg\\:hover\\:bg-opacity-0:hover {\n    --bg-opacity: 0;\n  }\n\n  .lg\\:hover\\:bg-opacity-25:hover {\n    --bg-opacity: 0.25;\n  }\n\n  .lg\\:hover\\:bg-opacity-50:hover {\n    --bg-opacity: 0.5;\n  }\n\n  .lg\\:hover\\:bg-opacity-75:hover {\n    --bg-opacity: 0.75;\n  }\n\n  .lg\\:hover\\:bg-opacity-100:hover {\n    --bg-opacity: 1;\n  }\n\n  .lg\\:focus\\:bg-opacity-0:focus {\n    --bg-opacity: 0;\n  }\n\n  .lg\\:focus\\:bg-opacity-25:focus {\n    --bg-opacity: 0.25;\n  }\n\n  .lg\\:focus\\:bg-opacity-50:focus {\n    --bg-opacity: 0.5;\n  }\n\n  .lg\\:focus\\:bg-opacity-75:focus {\n    --bg-opacity: 0.75;\n  }\n\n  .lg\\:focus\\:bg-opacity-100:focus {\n    --bg-opacity: 1;\n  }\n\n  .lg\\:bg-bottom {\n    background-position: bottom;\n  }\n\n  .lg\\:bg-center {\n    background-position: center;\n  }\n\n  .lg\\:bg-left {\n    background-position: left;\n  }\n\n  .lg\\:bg-left-bottom {\n    background-position: left bottom;\n  }\n\n  .lg\\:bg-left-top {\n    background-position: left top;\n  }\n\n  .lg\\:bg-right {\n    background-position: right;\n  }\n\n  .lg\\:bg-right-bottom {\n    background-position: right bottom;\n  }\n\n  .lg\\:bg-right-top {\n    background-position: right top;\n  }\n\n  .lg\\:bg-top {\n    background-position: top;\n  }\n\n  .lg\\:bg-repeat {\n    background-repeat: repeat;\n  }\n\n  .lg\\:bg-no-repeat {\n    background-repeat: no-repeat;\n  }\n\n  .lg\\:bg-repeat-x {\n    background-repeat: repeat-x;\n  }\n\n  .lg\\:bg-repeat-y {\n    background-repeat: repeat-y;\n  }\n\n  .lg\\:bg-repeat-round {\n    background-repeat: round;\n  }\n\n  .lg\\:bg-repeat-space {\n    background-repeat: space;\n  }\n\n  .lg\\:bg-auto {\n    background-size: auto;\n  }\n\n  .lg\\:bg-cover {\n    background-size: cover;\n  }\n\n  .lg\\:bg-contain {\n    background-size: contain;\n  }\n\n  .lg\\:border-collapse {\n    border-collapse: collapse;\n  }\n\n  .lg\\:border-separate {\n    border-collapse: separate;\n  }\n\n  .lg\\:border-transparent {\n    border-color: transparent;\n  }\n\n  .lg\\:border-current {\n    border-color: currentColor;\n  }\n\n  .lg\\:border-black {\n    --border-opacity: 1;\n    border-color: #000;\n    border-color: rgba(0, 0, 0, var(--border-opacity));\n  }\n\n  .lg\\:border-white {\n    --border-opacity: 1;\n    border-color: #fff;\n    border-color: rgba(255, 255, 255, var(--border-opacity));\n  }\n\n  .lg\\:border-gray-100 {\n    --border-opacity: 1;\n    border-color: #f7fafc;\n    border-color: rgba(247, 250, 252, var(--border-opacity));\n  }\n\n  .lg\\:border-gray-200 {\n    --border-opacity: 1;\n    border-color: #edf2f7;\n    border-color: rgba(237, 242, 247, var(--border-opacity));\n  }\n\n  .lg\\:border-gray-300 {\n    --border-opacity: 1;\n    border-color: #e2e8f0;\n    border-color: rgba(226, 232, 240, var(--border-opacity));\n  }\n\n  .lg\\:border-gray-400 {\n    --border-opacity: 1;\n    border-color: #cbd5e0;\n    border-color: rgba(203, 213, 224, var(--border-opacity));\n  }\n\n  .lg\\:border-gray-500 {\n    --border-opacity: 1;\n    border-color: #a0aec0;\n    border-color: rgba(160, 174, 192, var(--border-opacity));\n  }\n\n  .lg\\:border-gray-600 {\n    --border-opacity: 1;\n    border-color: #718096;\n    border-color: rgba(113, 128, 150, var(--border-opacity));\n  }\n\n  .lg\\:border-gray-700 {\n    --border-opacity: 1;\n    border-color: #4a5568;\n    border-color: rgba(74, 85, 104, var(--border-opacity));\n  }\n\n  .lg\\:border-gray-800 {\n    --border-opacity: 1;\n    border-color: #2d3748;\n    border-color: rgba(45, 55, 72, var(--border-opacity));\n  }\n\n  .lg\\:border-gray-900 {\n    --border-opacity: 1;\n    border-color: #1a202c;\n    border-color: rgba(26, 32, 44, var(--border-opacity));\n  }\n\n  .lg\\:border-red-100 {\n    --border-opacity: 1;\n    border-color: #fff5f5;\n    border-color: rgba(255, 245, 245, var(--border-opacity));\n  }\n\n  .lg\\:border-red-200 {\n    --border-opacity: 1;\n    border-color: #fed7d7;\n    border-color: rgba(254, 215, 215, var(--border-opacity));\n  }\n\n  .lg\\:border-red-300 {\n    --border-opacity: 1;\n    border-color: #feb2b2;\n    border-color: rgba(254, 178, 178, var(--border-opacity));\n  }\n\n  .lg\\:border-red-400 {\n    --border-opacity: 1;\n    border-color: #fc8181;\n    border-color: rgba(252, 129, 129, var(--border-opacity));\n  }\n\n  .lg\\:border-red-500 {\n    --border-opacity: 1;\n    border-color: #f56565;\n    border-color: rgba(245, 101, 101, var(--border-opacity));\n  }\n\n  .lg\\:border-red-600 {\n    --border-opacity: 1;\n    border-color: #e53e3e;\n    border-color: rgba(229, 62, 62, var(--border-opacity));\n  }\n\n  .lg\\:border-red-700 {\n    --border-opacity: 1;\n    border-color: #c53030;\n    border-color: rgba(197, 48, 48, var(--border-opacity));\n  }\n\n  .lg\\:border-red-800 {\n    --border-opacity: 1;\n    border-color: #9b2c2c;\n    border-color: rgba(155, 44, 44, var(--border-opacity));\n  }\n\n  .lg\\:border-red-900 {\n    --border-opacity: 1;\n    border-color: #742a2a;\n    border-color: rgba(116, 42, 42, var(--border-opacity));\n  }\n\n  .lg\\:border-orange-100 {\n    --border-opacity: 1;\n    border-color: #fffaf0;\n    border-color: rgba(255, 250, 240, var(--border-opacity));\n  }\n\n  .lg\\:border-orange-200 {\n    --border-opacity: 1;\n    border-color: #feebc8;\n    border-color: rgba(254, 235, 200, var(--border-opacity));\n  }\n\n  .lg\\:border-orange-300 {\n    --border-opacity: 1;\n    border-color: #fbd38d;\n    border-color: rgba(251, 211, 141, var(--border-opacity));\n  }\n\n  .lg\\:border-orange-400 {\n    --border-opacity: 1;\n    border-color: #f6ad55;\n    border-color: rgba(246, 173, 85, var(--border-opacity));\n  }\n\n  .lg\\:border-orange-500 {\n    --border-opacity: 1;\n    border-color: #ed8936;\n    border-color: rgba(237, 137, 54, var(--border-opacity));\n  }\n\n  .lg\\:border-orange-600 {\n    --border-opacity: 1;\n    border-color: #dd6b20;\n    border-color: rgba(221, 107, 32, var(--border-opacity));\n  }\n\n  .lg\\:border-orange-700 {\n    --border-opacity: 1;\n    border-color: #c05621;\n    border-color: rgba(192, 86, 33, var(--border-opacity));\n  }\n\n  .lg\\:border-orange-800 {\n    --border-opacity: 1;\n    border-color: #9c4221;\n    border-color: rgba(156, 66, 33, var(--border-opacity));\n  }\n\n  .lg\\:border-orange-900 {\n    --border-opacity: 1;\n    border-color: #7b341e;\n    border-color: rgba(123, 52, 30, var(--border-opacity));\n  }\n\n  .lg\\:border-yellow-100 {\n    --border-opacity: 1;\n    border-color: #fffff0;\n    border-color: rgba(255, 255, 240, var(--border-opacity));\n  }\n\n  .lg\\:border-yellow-200 {\n    --border-opacity: 1;\n    border-color: #fefcbf;\n    border-color: rgba(254, 252, 191, var(--border-opacity));\n  }\n\n  .lg\\:border-yellow-300 {\n    --border-opacity: 1;\n    border-color: #faf089;\n    border-color: rgba(250, 240, 137, var(--border-opacity));\n  }\n\n  .lg\\:border-yellow-400 {\n    --border-opacity: 1;\n    border-color: #f6e05e;\n    border-color: rgba(246, 224, 94, var(--border-opacity));\n  }\n\n  .lg\\:border-yellow-500 {\n    --border-opacity: 1;\n    border-color: #ecc94b;\n    border-color: rgba(236, 201, 75, var(--border-opacity));\n  }\n\n  .lg\\:border-yellow-600 {\n    --border-opacity: 1;\n    border-color: #d69e2e;\n    border-color: rgba(214, 158, 46, var(--border-opacity));\n  }\n\n  .lg\\:border-yellow-700 {\n    --border-opacity: 1;\n    border-color: #b7791f;\n    border-color: rgba(183, 121, 31, var(--border-opacity));\n  }\n\n  .lg\\:border-yellow-800 {\n    --border-opacity: 1;\n    border-color: #975a16;\n    border-color: rgba(151, 90, 22, var(--border-opacity));\n  }\n\n  .lg\\:border-yellow-900 {\n    --border-opacity: 1;\n    border-color: #744210;\n    border-color: rgba(116, 66, 16, var(--border-opacity));\n  }\n\n  .lg\\:border-green-100 {\n    --border-opacity: 1;\n    border-color: #f0fff4;\n    border-color: rgba(240, 255, 244, var(--border-opacity));\n  }\n\n  .lg\\:border-green-200 {\n    --border-opacity: 1;\n    border-color: #c6f6d5;\n    border-color: rgba(198, 246, 213, var(--border-opacity));\n  }\n\n  .lg\\:border-green-300 {\n    --border-opacity: 1;\n    border-color: #9ae6b4;\n    border-color: rgba(154, 230, 180, var(--border-opacity));\n  }\n\n  .lg\\:border-green-400 {\n    --border-opacity: 1;\n    border-color: #68d391;\n    border-color: rgba(104, 211, 145, var(--border-opacity));\n  }\n\n  .lg\\:border-green-500 {\n    --border-opacity: 1;\n    border-color: #48bb78;\n    border-color: rgba(72, 187, 120, var(--border-opacity));\n  }\n\n  .lg\\:border-green-600 {\n    --border-opacity: 1;\n    border-color: #38a169;\n    border-color: rgba(56, 161, 105, var(--border-opacity));\n  }\n\n  .lg\\:border-green-700 {\n    --border-opacity: 1;\n    border-color: #2f855a;\n    border-color: rgba(47, 133, 90, var(--border-opacity));\n  }\n\n  .lg\\:border-green-800 {\n    --border-opacity: 1;\n    border-color: #276749;\n    border-color: rgba(39, 103, 73, var(--border-opacity));\n  }\n\n  .lg\\:border-green-900 {\n    --border-opacity: 1;\n    border-color: #22543d;\n    border-color: rgba(34, 84, 61, var(--border-opacity));\n  }\n\n  .lg\\:border-teal-100 {\n    --border-opacity: 1;\n    border-color: #e6fffa;\n    border-color: rgba(230, 255, 250, var(--border-opacity));\n  }\n\n  .lg\\:border-teal-200 {\n    --border-opacity: 1;\n    border-color: #b2f5ea;\n    border-color: rgba(178, 245, 234, var(--border-opacity));\n  }\n\n  .lg\\:border-teal-300 {\n    --border-opacity: 1;\n    border-color: #81e6d9;\n    border-color: rgba(129, 230, 217, var(--border-opacity));\n  }\n\n  .lg\\:border-teal-400 {\n    --border-opacity: 1;\n    border-color: #4fd1c5;\n    border-color: rgba(79, 209, 197, var(--border-opacity));\n  }\n\n  .lg\\:border-teal-500 {\n    --border-opacity: 1;\n    border-color: #38b2ac;\n    border-color: rgba(56, 178, 172, var(--border-opacity));\n  }\n\n  .lg\\:border-teal-600 {\n    --border-opacity: 1;\n    border-color: #319795;\n    border-color: rgba(49, 151, 149, var(--border-opacity));\n  }\n\n  .lg\\:border-teal-700 {\n    --border-opacity: 1;\n    border-color: #2c7a7b;\n    border-color: rgba(44, 122, 123, var(--border-opacity));\n  }\n\n  .lg\\:border-teal-800 {\n    --border-opacity: 1;\n    border-color: #285e61;\n    border-color: rgba(40, 94, 97, var(--border-opacity));\n  }\n\n  .lg\\:border-teal-900 {\n    --border-opacity: 1;\n    border-color: #234e52;\n    border-color: rgba(35, 78, 82, var(--border-opacity));\n  }\n\n  .lg\\:border-blue-100 {\n    --border-opacity: 1;\n    border-color: #ebf8ff;\n    border-color: rgba(235, 248, 255, var(--border-opacity));\n  }\n\n  .lg\\:border-blue-200 {\n    --border-opacity: 1;\n    border-color: #bee3f8;\n    border-color: rgba(190, 227, 248, var(--border-opacity));\n  }\n\n  .lg\\:border-blue-300 {\n    --border-opacity: 1;\n    border-color: #90cdf4;\n    border-color: rgba(144, 205, 244, var(--border-opacity));\n  }\n\n  .lg\\:border-blue-400 {\n    --border-opacity: 1;\n    border-color: #63b3ed;\n    border-color: rgba(99, 179, 237, var(--border-opacity));\n  }\n\n  .lg\\:border-blue-500 {\n    --border-opacity: 1;\n    border-color: #4299e1;\n    border-color: rgba(66, 153, 225, var(--border-opacity));\n  }\n\n  .lg\\:border-blue-600 {\n    --border-opacity: 1;\n    border-color: #3182ce;\n    border-color: rgba(49, 130, 206, var(--border-opacity));\n  }\n\n  .lg\\:border-blue-700 {\n    --border-opacity: 1;\n    border-color: #2b6cb0;\n    border-color: rgba(43, 108, 176, var(--border-opacity));\n  }\n\n  .lg\\:border-blue-800 {\n    --border-opacity: 1;\n    border-color: #2c5282;\n    border-color: rgba(44, 82, 130, var(--border-opacity));\n  }\n\n  .lg\\:border-blue-900 {\n    --border-opacity: 1;\n    border-color: #2a4365;\n    border-color: rgba(42, 67, 101, var(--border-opacity));\n  }\n\n  .lg\\:border-indigo-100 {\n    --border-opacity: 1;\n    border-color: #ebf4ff;\n    border-color: rgba(235, 244, 255, var(--border-opacity));\n  }\n\n  .lg\\:border-indigo-200 {\n    --border-opacity: 1;\n    border-color: #c3dafe;\n    border-color: rgba(195, 218, 254, var(--border-opacity));\n  }\n\n  .lg\\:border-indigo-300 {\n    --border-opacity: 1;\n    border-color: #a3bffa;\n    border-color: rgba(163, 191, 250, var(--border-opacity));\n  }\n\n  .lg\\:border-indigo-400 {\n    --border-opacity: 1;\n    border-color: #7f9cf5;\n    border-color: rgba(127, 156, 245, var(--border-opacity));\n  }\n\n  .lg\\:border-indigo-500 {\n    --border-opacity: 1;\n    border-color: #667eea;\n    border-color: rgba(102, 126, 234, var(--border-opacity));\n  }\n\n  .lg\\:border-indigo-600 {\n    --border-opacity: 1;\n    border-color: #5a67d8;\n    border-color: rgba(90, 103, 216, var(--border-opacity));\n  }\n\n  .lg\\:border-indigo-700 {\n    --border-opacity: 1;\n    border-color: #4c51bf;\n    border-color: rgba(76, 81, 191, var(--border-opacity));\n  }\n\n  .lg\\:border-indigo-800 {\n    --border-opacity: 1;\n    border-color: #434190;\n    border-color: rgba(67, 65, 144, var(--border-opacity));\n  }\n\n  .lg\\:border-indigo-900 {\n    --border-opacity: 1;\n    border-color: #3c366b;\n    border-color: rgba(60, 54, 107, var(--border-opacity));\n  }\n\n  .lg\\:border-purple-100 {\n    --border-opacity: 1;\n    border-color: #faf5ff;\n    border-color: rgba(250, 245, 255, var(--border-opacity));\n  }\n\n  .lg\\:border-purple-200 {\n    --border-opacity: 1;\n    border-color: #e9d8fd;\n    border-color: rgba(233, 216, 253, var(--border-opacity));\n  }\n\n  .lg\\:border-purple-300 {\n    --border-opacity: 1;\n    border-color: #d6bcfa;\n    border-color: rgba(214, 188, 250, var(--border-opacity));\n  }\n\n  .lg\\:border-purple-400 {\n    --border-opacity: 1;\n    border-color: #b794f4;\n    border-color: rgba(183, 148, 244, var(--border-opacity));\n  }\n\n  .lg\\:border-purple-500 {\n    --border-opacity: 1;\n    border-color: #9f7aea;\n    border-color: rgba(159, 122, 234, var(--border-opacity));\n  }\n\n  .lg\\:border-purple-600 {\n    --border-opacity: 1;\n    border-color: #805ad5;\n    border-color: rgba(128, 90, 213, var(--border-opacity));\n  }\n\n  .lg\\:border-purple-700 {\n    --border-opacity: 1;\n    border-color: #6b46c1;\n    border-color: rgba(107, 70, 193, var(--border-opacity));\n  }\n\n  .lg\\:border-purple-800 {\n    --border-opacity: 1;\n    border-color: #553c9a;\n    border-color: rgba(85, 60, 154, var(--border-opacity));\n  }\n\n  .lg\\:border-purple-900 {\n    --border-opacity: 1;\n    border-color: #44337a;\n    border-color: rgba(68, 51, 122, var(--border-opacity));\n  }\n\n  .lg\\:border-pink-100 {\n    --border-opacity: 1;\n    border-color: #fff5f7;\n    border-color: rgba(255, 245, 247, var(--border-opacity));\n  }\n\n  .lg\\:border-pink-200 {\n    --border-opacity: 1;\n    border-color: #fed7e2;\n    border-color: rgba(254, 215, 226, var(--border-opacity));\n  }\n\n  .lg\\:border-pink-300 {\n    --border-opacity: 1;\n    border-color: #fbb6ce;\n    border-color: rgba(251, 182, 206, var(--border-opacity));\n  }\n\n  .lg\\:border-pink-400 {\n    --border-opacity: 1;\n    border-color: #f687b3;\n    border-color: rgba(246, 135, 179, var(--border-opacity));\n  }\n\n  .lg\\:border-pink-500 {\n    --border-opacity: 1;\n    border-color: #ed64a6;\n    border-color: rgba(237, 100, 166, var(--border-opacity));\n  }\n\n  .lg\\:border-pink-600 {\n    --border-opacity: 1;\n    border-color: #d53f8c;\n    border-color: rgba(213, 63, 140, var(--border-opacity));\n  }\n\n  .lg\\:border-pink-700 {\n    --border-opacity: 1;\n    border-color: #b83280;\n    border-color: rgba(184, 50, 128, var(--border-opacity));\n  }\n\n  .lg\\:border-pink-800 {\n    --border-opacity: 1;\n    border-color: #97266d;\n    border-color: rgba(151, 38, 109, var(--border-opacity));\n  }\n\n  .lg\\:border-pink-900 {\n    --border-opacity: 1;\n    border-color: #702459;\n    border-color: rgba(112, 36, 89, var(--border-opacity));\n  }\n\n  .lg\\:border-grayscale-80 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 8%);\n    border-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--border-opacity));\n  }\n\n  .lg\\:border-grayscale-100 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 10%);\n    border-color: rgba(25.5, 25.5, 25.5, var(--border-opacity));\n  }\n\n  .lg\\:border-grayscale-200 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 20%);\n    border-color: rgba(51, 51, 51, var(--border-opacity));\n  }\n\n  .lg\\:border-grayscale-300 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 30%);\n    border-color: rgba(76.5, 76.5, 76.5, var(--border-opacity));\n  }\n\n  .lg\\:border-grayscale-400 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 40%);\n    border-color: rgba(102, 102, 102, var(--border-opacity));\n  }\n\n  .lg\\:border-grayscale-500 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 50%);\n    border-color: rgba(127.5, 127.5, 127.5, var(--border-opacity));\n  }\n\n  .lg\\:border-grayscale-600 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 60%);\n    border-color: rgba(153, 153, 153, var(--border-opacity));\n  }\n\n  .lg\\:border-grayscale-700 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 70%);\n    border-color: rgba(178.5, 178.5, 178.5, var(--border-opacity));\n  }\n\n  .lg\\:border-grayscale-800 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 80%);\n    border-color: rgba(204, 204, 204, var(--border-opacity));\n  }\n\n  .lg\\:border-grayscale-840 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 84%);\n    border-color: rgba(214.2, 214.2, 214.2, var(--border-opacity));\n  }\n\n  .lg\\:border-grayscale-870 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 87%);\n    border-color: rgba(221.85, 221.85, 221.85, var(--border-opacity));\n  }\n\n  .lg\\:border-grayscale-900 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 90%);\n    border-color: rgba(229.5, 229.5, 229.5, var(--border-opacity));\n  }\n\n  .lg\\:border-grayscale-930 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 93%);\n    border-color: rgba(237.15, 237.15, 237.15, var(--border-opacity));\n  }\n\n  .lg\\:border-primary {\n    --border-opacity: 1;\n    border-color: hsl(210, 100%, 52%);\n    border-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--border-opacity));\n  }\n\n  .lg\\:border-background-main {\n    border-color: var(--main-background);\n  }\n\n  .lg\\:border-background-secondary {\n    border-color: var(--secondary-background);\n  }\n\n  .lg\\:border-foreground {\n    border-color: var(--foreground);\n  }\n\n  .lg\\:border-panels-bg {\n    border-color: var(--panels-background);\n  }\n\n  .lg\\:hover\\:border-transparent:hover {\n    border-color: transparent;\n  }\n\n  .lg\\:hover\\:border-current:hover {\n    border-color: currentColor;\n  }\n\n  .lg\\:hover\\:border-black:hover {\n    --border-opacity: 1;\n    border-color: #000;\n    border-color: rgba(0, 0, 0, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-white:hover {\n    --border-opacity: 1;\n    border-color: #fff;\n    border-color: rgba(255, 255, 255, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-gray-100:hover {\n    --border-opacity: 1;\n    border-color: #f7fafc;\n    border-color: rgba(247, 250, 252, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-gray-200:hover {\n    --border-opacity: 1;\n    border-color: #edf2f7;\n    border-color: rgba(237, 242, 247, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-gray-300:hover {\n    --border-opacity: 1;\n    border-color: #e2e8f0;\n    border-color: rgba(226, 232, 240, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-gray-400:hover {\n    --border-opacity: 1;\n    border-color: #cbd5e0;\n    border-color: rgba(203, 213, 224, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-gray-500:hover {\n    --border-opacity: 1;\n    border-color: #a0aec0;\n    border-color: rgba(160, 174, 192, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-gray-600:hover {\n    --border-opacity: 1;\n    border-color: #718096;\n    border-color: rgba(113, 128, 150, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-gray-700:hover {\n    --border-opacity: 1;\n    border-color: #4a5568;\n    border-color: rgba(74, 85, 104, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-gray-800:hover {\n    --border-opacity: 1;\n    border-color: #2d3748;\n    border-color: rgba(45, 55, 72, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-gray-900:hover {\n    --border-opacity: 1;\n    border-color: #1a202c;\n    border-color: rgba(26, 32, 44, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-red-100:hover {\n    --border-opacity: 1;\n    border-color: #fff5f5;\n    border-color: rgba(255, 245, 245, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-red-200:hover {\n    --border-opacity: 1;\n    border-color: #fed7d7;\n    border-color: rgba(254, 215, 215, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-red-300:hover {\n    --border-opacity: 1;\n    border-color: #feb2b2;\n    border-color: rgba(254, 178, 178, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-red-400:hover {\n    --border-opacity: 1;\n    border-color: #fc8181;\n    border-color: rgba(252, 129, 129, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-red-500:hover {\n    --border-opacity: 1;\n    border-color: #f56565;\n    border-color: rgba(245, 101, 101, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-red-600:hover {\n    --border-opacity: 1;\n    border-color: #e53e3e;\n    border-color: rgba(229, 62, 62, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-red-700:hover {\n    --border-opacity: 1;\n    border-color: #c53030;\n    border-color: rgba(197, 48, 48, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-red-800:hover {\n    --border-opacity: 1;\n    border-color: #9b2c2c;\n    border-color: rgba(155, 44, 44, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-red-900:hover {\n    --border-opacity: 1;\n    border-color: #742a2a;\n    border-color: rgba(116, 42, 42, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-orange-100:hover {\n    --border-opacity: 1;\n    border-color: #fffaf0;\n    border-color: rgba(255, 250, 240, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-orange-200:hover {\n    --border-opacity: 1;\n    border-color: #feebc8;\n    border-color: rgba(254, 235, 200, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-orange-300:hover {\n    --border-opacity: 1;\n    border-color: #fbd38d;\n    border-color: rgba(251, 211, 141, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-orange-400:hover {\n    --border-opacity: 1;\n    border-color: #f6ad55;\n    border-color: rgba(246, 173, 85, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-orange-500:hover {\n    --border-opacity: 1;\n    border-color: #ed8936;\n    border-color: rgba(237, 137, 54, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-orange-600:hover {\n    --border-opacity: 1;\n    border-color: #dd6b20;\n    border-color: rgba(221, 107, 32, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-orange-700:hover {\n    --border-opacity: 1;\n    border-color: #c05621;\n    border-color: rgba(192, 86, 33, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-orange-800:hover {\n    --border-opacity: 1;\n    border-color: #9c4221;\n    border-color: rgba(156, 66, 33, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-orange-900:hover {\n    --border-opacity: 1;\n    border-color: #7b341e;\n    border-color: rgba(123, 52, 30, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-yellow-100:hover {\n    --border-opacity: 1;\n    border-color: #fffff0;\n    border-color: rgba(255, 255, 240, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-yellow-200:hover {\n    --border-opacity: 1;\n    border-color: #fefcbf;\n    border-color: rgba(254, 252, 191, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-yellow-300:hover {\n    --border-opacity: 1;\n    border-color: #faf089;\n    border-color: rgba(250, 240, 137, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-yellow-400:hover {\n    --border-opacity: 1;\n    border-color: #f6e05e;\n    border-color: rgba(246, 224, 94, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-yellow-500:hover {\n    --border-opacity: 1;\n    border-color: #ecc94b;\n    border-color: rgba(236, 201, 75, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-yellow-600:hover {\n    --border-opacity: 1;\n    border-color: #d69e2e;\n    border-color: rgba(214, 158, 46, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-yellow-700:hover {\n    --border-opacity: 1;\n    border-color: #b7791f;\n    border-color: rgba(183, 121, 31, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-yellow-800:hover {\n    --border-opacity: 1;\n    border-color: #975a16;\n    border-color: rgba(151, 90, 22, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-yellow-900:hover {\n    --border-opacity: 1;\n    border-color: #744210;\n    border-color: rgba(116, 66, 16, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-green-100:hover {\n    --border-opacity: 1;\n    border-color: #f0fff4;\n    border-color: rgba(240, 255, 244, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-green-200:hover {\n    --border-opacity: 1;\n    border-color: #c6f6d5;\n    border-color: rgba(198, 246, 213, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-green-300:hover {\n    --border-opacity: 1;\n    border-color: #9ae6b4;\n    border-color: rgba(154, 230, 180, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-green-400:hover {\n    --border-opacity: 1;\n    border-color: #68d391;\n    border-color: rgba(104, 211, 145, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-green-500:hover {\n    --border-opacity: 1;\n    border-color: #48bb78;\n    border-color: rgba(72, 187, 120, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-green-600:hover {\n    --border-opacity: 1;\n    border-color: #38a169;\n    border-color: rgba(56, 161, 105, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-green-700:hover {\n    --border-opacity: 1;\n    border-color: #2f855a;\n    border-color: rgba(47, 133, 90, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-green-800:hover {\n    --border-opacity: 1;\n    border-color: #276749;\n    border-color: rgba(39, 103, 73, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-green-900:hover {\n    --border-opacity: 1;\n    border-color: #22543d;\n    border-color: rgba(34, 84, 61, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-teal-100:hover {\n    --border-opacity: 1;\n    border-color: #e6fffa;\n    border-color: rgba(230, 255, 250, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-teal-200:hover {\n    --border-opacity: 1;\n    border-color: #b2f5ea;\n    border-color: rgba(178, 245, 234, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-teal-300:hover {\n    --border-opacity: 1;\n    border-color: #81e6d9;\n    border-color: rgba(129, 230, 217, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-teal-400:hover {\n    --border-opacity: 1;\n    border-color: #4fd1c5;\n    border-color: rgba(79, 209, 197, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-teal-500:hover {\n    --border-opacity: 1;\n    border-color: #38b2ac;\n    border-color: rgba(56, 178, 172, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-teal-600:hover {\n    --border-opacity: 1;\n    border-color: #319795;\n    border-color: rgba(49, 151, 149, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-teal-700:hover {\n    --border-opacity: 1;\n    border-color: #2c7a7b;\n    border-color: rgba(44, 122, 123, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-teal-800:hover {\n    --border-opacity: 1;\n    border-color: #285e61;\n    border-color: rgba(40, 94, 97, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-teal-900:hover {\n    --border-opacity: 1;\n    border-color: #234e52;\n    border-color: rgba(35, 78, 82, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-blue-100:hover {\n    --border-opacity: 1;\n    border-color: #ebf8ff;\n    border-color: rgba(235, 248, 255, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-blue-200:hover {\n    --border-opacity: 1;\n    border-color: #bee3f8;\n    border-color: rgba(190, 227, 248, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-blue-300:hover {\n    --border-opacity: 1;\n    border-color: #90cdf4;\n    border-color: rgba(144, 205, 244, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-blue-400:hover {\n    --border-opacity: 1;\n    border-color: #63b3ed;\n    border-color: rgba(99, 179, 237, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-blue-500:hover {\n    --border-opacity: 1;\n    border-color: #4299e1;\n    border-color: rgba(66, 153, 225, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-blue-600:hover {\n    --border-opacity: 1;\n    border-color: #3182ce;\n    border-color: rgba(49, 130, 206, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-blue-700:hover {\n    --border-opacity: 1;\n    border-color: #2b6cb0;\n    border-color: rgba(43, 108, 176, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-blue-800:hover {\n    --border-opacity: 1;\n    border-color: #2c5282;\n    border-color: rgba(44, 82, 130, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-blue-900:hover {\n    --border-opacity: 1;\n    border-color: #2a4365;\n    border-color: rgba(42, 67, 101, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-indigo-100:hover {\n    --border-opacity: 1;\n    border-color: #ebf4ff;\n    border-color: rgba(235, 244, 255, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-indigo-200:hover {\n    --border-opacity: 1;\n    border-color: #c3dafe;\n    border-color: rgba(195, 218, 254, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-indigo-300:hover {\n    --border-opacity: 1;\n    border-color: #a3bffa;\n    border-color: rgba(163, 191, 250, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-indigo-400:hover {\n    --border-opacity: 1;\n    border-color: #7f9cf5;\n    border-color: rgba(127, 156, 245, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-indigo-500:hover {\n    --border-opacity: 1;\n    border-color: #667eea;\n    border-color: rgba(102, 126, 234, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-indigo-600:hover {\n    --border-opacity: 1;\n    border-color: #5a67d8;\n    border-color: rgba(90, 103, 216, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-indigo-700:hover {\n    --border-opacity: 1;\n    border-color: #4c51bf;\n    border-color: rgba(76, 81, 191, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-indigo-800:hover {\n    --border-opacity: 1;\n    border-color: #434190;\n    border-color: rgba(67, 65, 144, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-indigo-900:hover {\n    --border-opacity: 1;\n    border-color: #3c366b;\n    border-color: rgba(60, 54, 107, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-purple-100:hover {\n    --border-opacity: 1;\n    border-color: #faf5ff;\n    border-color: rgba(250, 245, 255, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-purple-200:hover {\n    --border-opacity: 1;\n    border-color: #e9d8fd;\n    border-color: rgba(233, 216, 253, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-purple-300:hover {\n    --border-opacity: 1;\n    border-color: #d6bcfa;\n    border-color: rgba(214, 188, 250, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-purple-400:hover {\n    --border-opacity: 1;\n    border-color: #b794f4;\n    border-color: rgba(183, 148, 244, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-purple-500:hover {\n    --border-opacity: 1;\n    border-color: #9f7aea;\n    border-color: rgba(159, 122, 234, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-purple-600:hover {\n    --border-opacity: 1;\n    border-color: #805ad5;\n    border-color: rgba(128, 90, 213, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-purple-700:hover {\n    --border-opacity: 1;\n    border-color: #6b46c1;\n    border-color: rgba(107, 70, 193, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-purple-800:hover {\n    --border-opacity: 1;\n    border-color: #553c9a;\n    border-color: rgba(85, 60, 154, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-purple-900:hover {\n    --border-opacity: 1;\n    border-color: #44337a;\n    border-color: rgba(68, 51, 122, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-pink-100:hover {\n    --border-opacity: 1;\n    border-color: #fff5f7;\n    border-color: rgba(255, 245, 247, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-pink-200:hover {\n    --border-opacity: 1;\n    border-color: #fed7e2;\n    border-color: rgba(254, 215, 226, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-pink-300:hover {\n    --border-opacity: 1;\n    border-color: #fbb6ce;\n    border-color: rgba(251, 182, 206, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-pink-400:hover {\n    --border-opacity: 1;\n    border-color: #f687b3;\n    border-color: rgba(246, 135, 179, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-pink-500:hover {\n    --border-opacity: 1;\n    border-color: #ed64a6;\n    border-color: rgba(237, 100, 166, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-pink-600:hover {\n    --border-opacity: 1;\n    border-color: #d53f8c;\n    border-color: rgba(213, 63, 140, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-pink-700:hover {\n    --border-opacity: 1;\n    border-color: #b83280;\n    border-color: rgba(184, 50, 128, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-pink-800:hover {\n    --border-opacity: 1;\n    border-color: #97266d;\n    border-color: rgba(151, 38, 109, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-pink-900:hover {\n    --border-opacity: 1;\n    border-color: #702459;\n    border-color: rgba(112, 36, 89, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-grayscale-80:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 8%);\n    border-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-grayscale-100:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 10%);\n    border-color: rgba(25.5, 25.5, 25.5, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-grayscale-200:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 20%);\n    border-color: rgba(51, 51, 51, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-grayscale-300:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 30%);\n    border-color: rgba(76.5, 76.5, 76.5, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-grayscale-400:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 40%);\n    border-color: rgba(102, 102, 102, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-grayscale-500:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 50%);\n    border-color: rgba(127.5, 127.5, 127.5, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-grayscale-600:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 60%);\n    border-color: rgba(153, 153, 153, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-grayscale-700:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 70%);\n    border-color: rgba(178.5, 178.5, 178.5, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-grayscale-800:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 80%);\n    border-color: rgba(204, 204, 204, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-grayscale-840:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 84%);\n    border-color: rgba(214.2, 214.2, 214.2, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-grayscale-870:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 87%);\n    border-color: rgba(221.85, 221.85, 221.85, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-grayscale-900:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 90%);\n    border-color: rgba(229.5, 229.5, 229.5, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-grayscale-930:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 93%);\n    border-color: rgba(237.15, 237.15, 237.15, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-primary:hover {\n    --border-opacity: 1;\n    border-color: hsl(210, 100%, 52%);\n    border-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--border-opacity));\n  }\n\n  .lg\\:hover\\:border-background-main:hover {\n    border-color: var(--main-background);\n  }\n\n  .lg\\:hover\\:border-background-secondary:hover {\n    border-color: var(--secondary-background);\n  }\n\n  .lg\\:hover\\:border-foreground:hover {\n    border-color: var(--foreground);\n  }\n\n  .lg\\:hover\\:border-panels-bg:hover {\n    border-color: var(--panels-background);\n  }\n\n  .lg\\:focus\\:border-transparent:focus {\n    border-color: transparent;\n  }\n\n  .lg\\:focus\\:border-current:focus {\n    border-color: currentColor;\n  }\n\n  .lg\\:focus\\:border-black:focus {\n    --border-opacity: 1;\n    border-color: #000;\n    border-color: rgba(0, 0, 0, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-white:focus {\n    --border-opacity: 1;\n    border-color: #fff;\n    border-color: rgba(255, 255, 255, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-gray-100:focus {\n    --border-opacity: 1;\n    border-color: #f7fafc;\n    border-color: rgba(247, 250, 252, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-gray-200:focus {\n    --border-opacity: 1;\n    border-color: #edf2f7;\n    border-color: rgba(237, 242, 247, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-gray-300:focus {\n    --border-opacity: 1;\n    border-color: #e2e8f0;\n    border-color: rgba(226, 232, 240, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-gray-400:focus {\n    --border-opacity: 1;\n    border-color: #cbd5e0;\n    border-color: rgba(203, 213, 224, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-gray-500:focus {\n    --border-opacity: 1;\n    border-color: #a0aec0;\n    border-color: rgba(160, 174, 192, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-gray-600:focus {\n    --border-opacity: 1;\n    border-color: #718096;\n    border-color: rgba(113, 128, 150, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-gray-700:focus {\n    --border-opacity: 1;\n    border-color: #4a5568;\n    border-color: rgba(74, 85, 104, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-gray-800:focus {\n    --border-opacity: 1;\n    border-color: #2d3748;\n    border-color: rgba(45, 55, 72, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-gray-900:focus {\n    --border-opacity: 1;\n    border-color: #1a202c;\n    border-color: rgba(26, 32, 44, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-red-100:focus {\n    --border-opacity: 1;\n    border-color: #fff5f5;\n    border-color: rgba(255, 245, 245, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-red-200:focus {\n    --border-opacity: 1;\n    border-color: #fed7d7;\n    border-color: rgba(254, 215, 215, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-red-300:focus {\n    --border-opacity: 1;\n    border-color: #feb2b2;\n    border-color: rgba(254, 178, 178, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-red-400:focus {\n    --border-opacity: 1;\n    border-color: #fc8181;\n    border-color: rgba(252, 129, 129, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-red-500:focus {\n    --border-opacity: 1;\n    border-color: #f56565;\n    border-color: rgba(245, 101, 101, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-red-600:focus {\n    --border-opacity: 1;\n    border-color: #e53e3e;\n    border-color: rgba(229, 62, 62, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-red-700:focus {\n    --border-opacity: 1;\n    border-color: #c53030;\n    border-color: rgba(197, 48, 48, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-red-800:focus {\n    --border-opacity: 1;\n    border-color: #9b2c2c;\n    border-color: rgba(155, 44, 44, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-red-900:focus {\n    --border-opacity: 1;\n    border-color: #742a2a;\n    border-color: rgba(116, 42, 42, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-orange-100:focus {\n    --border-opacity: 1;\n    border-color: #fffaf0;\n    border-color: rgba(255, 250, 240, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-orange-200:focus {\n    --border-opacity: 1;\n    border-color: #feebc8;\n    border-color: rgba(254, 235, 200, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-orange-300:focus {\n    --border-opacity: 1;\n    border-color: #fbd38d;\n    border-color: rgba(251, 211, 141, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-orange-400:focus {\n    --border-opacity: 1;\n    border-color: #f6ad55;\n    border-color: rgba(246, 173, 85, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-orange-500:focus {\n    --border-opacity: 1;\n    border-color: #ed8936;\n    border-color: rgba(237, 137, 54, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-orange-600:focus {\n    --border-opacity: 1;\n    border-color: #dd6b20;\n    border-color: rgba(221, 107, 32, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-orange-700:focus {\n    --border-opacity: 1;\n    border-color: #c05621;\n    border-color: rgba(192, 86, 33, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-orange-800:focus {\n    --border-opacity: 1;\n    border-color: #9c4221;\n    border-color: rgba(156, 66, 33, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-orange-900:focus {\n    --border-opacity: 1;\n    border-color: #7b341e;\n    border-color: rgba(123, 52, 30, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-yellow-100:focus {\n    --border-opacity: 1;\n    border-color: #fffff0;\n    border-color: rgba(255, 255, 240, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-yellow-200:focus {\n    --border-opacity: 1;\n    border-color: #fefcbf;\n    border-color: rgba(254, 252, 191, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-yellow-300:focus {\n    --border-opacity: 1;\n    border-color: #faf089;\n    border-color: rgba(250, 240, 137, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-yellow-400:focus {\n    --border-opacity: 1;\n    border-color: #f6e05e;\n    border-color: rgba(246, 224, 94, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-yellow-500:focus {\n    --border-opacity: 1;\n    border-color: #ecc94b;\n    border-color: rgba(236, 201, 75, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-yellow-600:focus {\n    --border-opacity: 1;\n    border-color: #d69e2e;\n    border-color: rgba(214, 158, 46, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-yellow-700:focus {\n    --border-opacity: 1;\n    border-color: #b7791f;\n    border-color: rgba(183, 121, 31, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-yellow-800:focus {\n    --border-opacity: 1;\n    border-color: #975a16;\n    border-color: rgba(151, 90, 22, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-yellow-900:focus {\n    --border-opacity: 1;\n    border-color: #744210;\n    border-color: rgba(116, 66, 16, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-green-100:focus {\n    --border-opacity: 1;\n    border-color: #f0fff4;\n    border-color: rgba(240, 255, 244, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-green-200:focus {\n    --border-opacity: 1;\n    border-color: #c6f6d5;\n    border-color: rgba(198, 246, 213, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-green-300:focus {\n    --border-opacity: 1;\n    border-color: #9ae6b4;\n    border-color: rgba(154, 230, 180, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-green-400:focus {\n    --border-opacity: 1;\n    border-color: #68d391;\n    border-color: rgba(104, 211, 145, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-green-500:focus {\n    --border-opacity: 1;\n    border-color: #48bb78;\n    border-color: rgba(72, 187, 120, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-green-600:focus {\n    --border-opacity: 1;\n    border-color: #38a169;\n    border-color: rgba(56, 161, 105, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-green-700:focus {\n    --border-opacity: 1;\n    border-color: #2f855a;\n    border-color: rgba(47, 133, 90, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-green-800:focus {\n    --border-opacity: 1;\n    border-color: #276749;\n    border-color: rgba(39, 103, 73, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-green-900:focus {\n    --border-opacity: 1;\n    border-color: #22543d;\n    border-color: rgba(34, 84, 61, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-teal-100:focus {\n    --border-opacity: 1;\n    border-color: #e6fffa;\n    border-color: rgba(230, 255, 250, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-teal-200:focus {\n    --border-opacity: 1;\n    border-color: #b2f5ea;\n    border-color: rgba(178, 245, 234, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-teal-300:focus {\n    --border-opacity: 1;\n    border-color: #81e6d9;\n    border-color: rgba(129, 230, 217, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-teal-400:focus {\n    --border-opacity: 1;\n    border-color: #4fd1c5;\n    border-color: rgba(79, 209, 197, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-teal-500:focus {\n    --border-opacity: 1;\n    border-color: #38b2ac;\n    border-color: rgba(56, 178, 172, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-teal-600:focus {\n    --border-opacity: 1;\n    border-color: #319795;\n    border-color: rgba(49, 151, 149, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-teal-700:focus {\n    --border-opacity: 1;\n    border-color: #2c7a7b;\n    border-color: rgba(44, 122, 123, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-teal-800:focus {\n    --border-opacity: 1;\n    border-color: #285e61;\n    border-color: rgba(40, 94, 97, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-teal-900:focus {\n    --border-opacity: 1;\n    border-color: #234e52;\n    border-color: rgba(35, 78, 82, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-blue-100:focus {\n    --border-opacity: 1;\n    border-color: #ebf8ff;\n    border-color: rgba(235, 248, 255, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-blue-200:focus {\n    --border-opacity: 1;\n    border-color: #bee3f8;\n    border-color: rgba(190, 227, 248, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-blue-300:focus {\n    --border-opacity: 1;\n    border-color: #90cdf4;\n    border-color: rgba(144, 205, 244, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-blue-400:focus {\n    --border-opacity: 1;\n    border-color: #63b3ed;\n    border-color: rgba(99, 179, 237, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-blue-500:focus {\n    --border-opacity: 1;\n    border-color: #4299e1;\n    border-color: rgba(66, 153, 225, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-blue-600:focus {\n    --border-opacity: 1;\n    border-color: #3182ce;\n    border-color: rgba(49, 130, 206, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-blue-700:focus {\n    --border-opacity: 1;\n    border-color: #2b6cb0;\n    border-color: rgba(43, 108, 176, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-blue-800:focus {\n    --border-opacity: 1;\n    border-color: #2c5282;\n    border-color: rgba(44, 82, 130, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-blue-900:focus {\n    --border-opacity: 1;\n    border-color: #2a4365;\n    border-color: rgba(42, 67, 101, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-indigo-100:focus {\n    --border-opacity: 1;\n    border-color: #ebf4ff;\n    border-color: rgba(235, 244, 255, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-indigo-200:focus {\n    --border-opacity: 1;\n    border-color: #c3dafe;\n    border-color: rgba(195, 218, 254, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-indigo-300:focus {\n    --border-opacity: 1;\n    border-color: #a3bffa;\n    border-color: rgba(163, 191, 250, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-indigo-400:focus {\n    --border-opacity: 1;\n    border-color: #7f9cf5;\n    border-color: rgba(127, 156, 245, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-indigo-500:focus {\n    --border-opacity: 1;\n    border-color: #667eea;\n    border-color: rgba(102, 126, 234, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-indigo-600:focus {\n    --border-opacity: 1;\n    border-color: #5a67d8;\n    border-color: rgba(90, 103, 216, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-indigo-700:focus {\n    --border-opacity: 1;\n    border-color: #4c51bf;\n    border-color: rgba(76, 81, 191, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-indigo-800:focus {\n    --border-opacity: 1;\n    border-color: #434190;\n    border-color: rgba(67, 65, 144, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-indigo-900:focus {\n    --border-opacity: 1;\n    border-color: #3c366b;\n    border-color: rgba(60, 54, 107, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-purple-100:focus {\n    --border-opacity: 1;\n    border-color: #faf5ff;\n    border-color: rgba(250, 245, 255, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-purple-200:focus {\n    --border-opacity: 1;\n    border-color: #e9d8fd;\n    border-color: rgba(233, 216, 253, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-purple-300:focus {\n    --border-opacity: 1;\n    border-color: #d6bcfa;\n    border-color: rgba(214, 188, 250, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-purple-400:focus {\n    --border-opacity: 1;\n    border-color: #b794f4;\n    border-color: rgba(183, 148, 244, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-purple-500:focus {\n    --border-opacity: 1;\n    border-color: #9f7aea;\n    border-color: rgba(159, 122, 234, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-purple-600:focus {\n    --border-opacity: 1;\n    border-color: #805ad5;\n    border-color: rgba(128, 90, 213, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-purple-700:focus {\n    --border-opacity: 1;\n    border-color: #6b46c1;\n    border-color: rgba(107, 70, 193, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-purple-800:focus {\n    --border-opacity: 1;\n    border-color: #553c9a;\n    border-color: rgba(85, 60, 154, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-purple-900:focus {\n    --border-opacity: 1;\n    border-color: #44337a;\n    border-color: rgba(68, 51, 122, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-pink-100:focus {\n    --border-opacity: 1;\n    border-color: #fff5f7;\n    border-color: rgba(255, 245, 247, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-pink-200:focus {\n    --border-opacity: 1;\n    border-color: #fed7e2;\n    border-color: rgba(254, 215, 226, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-pink-300:focus {\n    --border-opacity: 1;\n    border-color: #fbb6ce;\n    border-color: rgba(251, 182, 206, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-pink-400:focus {\n    --border-opacity: 1;\n    border-color: #f687b3;\n    border-color: rgba(246, 135, 179, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-pink-500:focus {\n    --border-opacity: 1;\n    border-color: #ed64a6;\n    border-color: rgba(237, 100, 166, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-pink-600:focus {\n    --border-opacity: 1;\n    border-color: #d53f8c;\n    border-color: rgba(213, 63, 140, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-pink-700:focus {\n    --border-opacity: 1;\n    border-color: #b83280;\n    border-color: rgba(184, 50, 128, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-pink-800:focus {\n    --border-opacity: 1;\n    border-color: #97266d;\n    border-color: rgba(151, 38, 109, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-pink-900:focus {\n    --border-opacity: 1;\n    border-color: #702459;\n    border-color: rgba(112, 36, 89, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-grayscale-80:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 8%);\n    border-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-grayscale-100:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 10%);\n    border-color: rgba(25.5, 25.5, 25.5, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-grayscale-200:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 20%);\n    border-color: rgba(51, 51, 51, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-grayscale-300:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 30%);\n    border-color: rgba(76.5, 76.5, 76.5, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-grayscale-400:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 40%);\n    border-color: rgba(102, 102, 102, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-grayscale-500:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 50%);\n    border-color: rgba(127.5, 127.5, 127.5, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-grayscale-600:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 60%);\n    border-color: rgba(153, 153, 153, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-grayscale-700:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 70%);\n    border-color: rgba(178.5, 178.5, 178.5, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-grayscale-800:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 80%);\n    border-color: rgba(204, 204, 204, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-grayscale-840:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 84%);\n    border-color: rgba(214.2, 214.2, 214.2, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-grayscale-870:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 87%);\n    border-color: rgba(221.85, 221.85, 221.85, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-grayscale-900:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 90%);\n    border-color: rgba(229.5, 229.5, 229.5, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-grayscale-930:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 93%);\n    border-color: rgba(237.15, 237.15, 237.15, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-primary:focus {\n    --border-opacity: 1;\n    border-color: hsl(210, 100%, 52%);\n    border-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--border-opacity));\n  }\n\n  .lg\\:focus\\:border-background-main:focus {\n    border-color: var(--main-background);\n  }\n\n  .lg\\:focus\\:border-background-secondary:focus {\n    border-color: var(--secondary-background);\n  }\n\n  .lg\\:focus\\:border-foreground:focus {\n    border-color: var(--foreground);\n  }\n\n  .lg\\:focus\\:border-panels-bg:focus {\n    border-color: var(--panels-background);\n  }\n\n  .lg\\:border-opacity-0 {\n    --border-opacity: 0;\n  }\n\n  .lg\\:border-opacity-25 {\n    --border-opacity: 0.25;\n  }\n\n  .lg\\:border-opacity-50 {\n    --border-opacity: 0.5;\n  }\n\n  .lg\\:border-opacity-75 {\n    --border-opacity: 0.75;\n  }\n\n  .lg\\:border-opacity-100 {\n    --border-opacity: 1;\n  }\n\n  .lg\\:hover\\:border-opacity-0:hover {\n    --border-opacity: 0;\n  }\n\n  .lg\\:hover\\:border-opacity-25:hover {\n    --border-opacity: 0.25;\n  }\n\n  .lg\\:hover\\:border-opacity-50:hover {\n    --border-opacity: 0.5;\n  }\n\n  .lg\\:hover\\:border-opacity-75:hover {\n    --border-opacity: 0.75;\n  }\n\n  .lg\\:hover\\:border-opacity-100:hover {\n    --border-opacity: 1;\n  }\n\n  .lg\\:focus\\:border-opacity-0:focus {\n    --border-opacity: 0;\n  }\n\n  .lg\\:focus\\:border-opacity-25:focus {\n    --border-opacity: 0.25;\n  }\n\n  .lg\\:focus\\:border-opacity-50:focus {\n    --border-opacity: 0.5;\n  }\n\n  .lg\\:focus\\:border-opacity-75:focus {\n    --border-opacity: 0.75;\n  }\n\n  .lg\\:focus\\:border-opacity-100:focus {\n    --border-opacity: 1;\n  }\n\n  .lg\\:rounded-none {\n    border-radius: 0;\n  }\n\n  .lg\\:rounded-sm {\n    border-radius: 0.125rem;\n  }\n\n  .lg\\:rounded {\n    border-radius: 0.25rem;\n  }\n\n  .lg\\:rounded-md {\n    border-radius: 0.375rem;\n  }\n\n  .lg\\:rounded-lg {\n    border-radius: 0.5rem;\n  }\n\n  .lg\\:rounded-xl {\n    border-radius: 0.75rem;\n  }\n\n  .lg\\:rounded-2xl {\n    border-radius: 1rem;\n  }\n\n  .lg\\:rounded-3xl {\n    border-radius: 1.5rem;\n  }\n\n  .lg\\:rounded-full {\n    border-radius: 9999px;\n  }\n\n  .lg\\:rounded-t-none {\n    border-top-left-radius: 0;\n    border-top-right-radius: 0;\n  }\n\n  .lg\\:rounded-r-none {\n    border-top-right-radius: 0;\n    border-bottom-right-radius: 0;\n  }\n\n  .lg\\:rounded-b-none {\n    border-bottom-right-radius: 0;\n    border-bottom-left-radius: 0;\n  }\n\n  .lg\\:rounded-l-none {\n    border-top-left-radius: 0;\n    border-bottom-left-radius: 0;\n  }\n\n  .lg\\:rounded-t-sm {\n    border-top-left-radius: 0.125rem;\n    border-top-right-radius: 0.125rem;\n  }\n\n  .lg\\:rounded-r-sm {\n    border-top-right-radius: 0.125rem;\n    border-bottom-right-radius: 0.125rem;\n  }\n\n  .lg\\:rounded-b-sm {\n    border-bottom-right-radius: 0.125rem;\n    border-bottom-left-radius: 0.125rem;\n  }\n\n  .lg\\:rounded-l-sm {\n    border-top-left-radius: 0.125rem;\n    border-bottom-left-radius: 0.125rem;\n  }\n\n  .lg\\:rounded-t {\n    border-top-left-radius: 0.25rem;\n    border-top-right-radius: 0.25rem;\n  }\n\n  .lg\\:rounded-r {\n    border-top-right-radius: 0.25rem;\n    border-bottom-right-radius: 0.25rem;\n  }\n\n  .lg\\:rounded-b {\n    border-bottom-right-radius: 0.25rem;\n    border-bottom-left-radius: 0.25rem;\n  }\n\n  .lg\\:rounded-l {\n    border-top-left-radius: 0.25rem;\n    border-bottom-left-radius: 0.25rem;\n  }\n\n  .lg\\:rounded-t-md {\n    border-top-left-radius: 0.375rem;\n    border-top-right-radius: 0.375rem;\n  }\n\n  .lg\\:rounded-r-md {\n    border-top-right-radius: 0.375rem;\n    border-bottom-right-radius: 0.375rem;\n  }\n\n  .lg\\:rounded-b-md {\n    border-bottom-right-radius: 0.375rem;\n    border-bottom-left-radius: 0.375rem;\n  }\n\n  .lg\\:rounded-l-md {\n    border-top-left-radius: 0.375rem;\n    border-bottom-left-radius: 0.375rem;\n  }\n\n  .lg\\:rounded-t-lg {\n    border-top-left-radius: 0.5rem;\n    border-top-right-radius: 0.5rem;\n  }\n\n  .lg\\:rounded-r-lg {\n    border-top-right-radius: 0.5rem;\n    border-bottom-right-radius: 0.5rem;\n  }\n\n  .lg\\:rounded-b-lg {\n    border-bottom-right-radius: 0.5rem;\n    border-bottom-left-radius: 0.5rem;\n  }\n\n  .lg\\:rounded-l-lg {\n    border-top-left-radius: 0.5rem;\n    border-bottom-left-radius: 0.5rem;\n  }\n\n  .lg\\:rounded-t-xl {\n    border-top-left-radius: 0.75rem;\n    border-top-right-radius: 0.75rem;\n  }\n\n  .lg\\:rounded-r-xl {\n    border-top-right-radius: 0.75rem;\n    border-bottom-right-radius: 0.75rem;\n  }\n\n  .lg\\:rounded-b-xl {\n    border-bottom-right-radius: 0.75rem;\n    border-bottom-left-radius: 0.75rem;\n  }\n\n  .lg\\:rounded-l-xl {\n    border-top-left-radius: 0.75rem;\n    border-bottom-left-radius: 0.75rem;\n  }\n\n  .lg\\:rounded-t-2xl {\n    border-top-left-radius: 1rem;\n    border-top-right-radius: 1rem;\n  }\n\n  .lg\\:rounded-r-2xl {\n    border-top-right-radius: 1rem;\n    border-bottom-right-radius: 1rem;\n  }\n\n  .lg\\:rounded-b-2xl {\n    border-bottom-right-radius: 1rem;\n    border-bottom-left-radius: 1rem;\n  }\n\n  .lg\\:rounded-l-2xl {\n    border-top-left-radius: 1rem;\n    border-bottom-left-radius: 1rem;\n  }\n\n  .lg\\:rounded-t-3xl {\n    border-top-left-radius: 1.5rem;\n    border-top-right-radius: 1.5rem;\n  }\n\n  .lg\\:rounded-r-3xl {\n    border-top-right-radius: 1.5rem;\n    border-bottom-right-radius: 1.5rem;\n  }\n\n  .lg\\:rounded-b-3xl {\n    border-bottom-right-radius: 1.5rem;\n    border-bottom-left-radius: 1.5rem;\n  }\n\n  .lg\\:rounded-l-3xl {\n    border-top-left-radius: 1.5rem;\n    border-bottom-left-radius: 1.5rem;\n  }\n\n  .lg\\:rounded-t-full {\n    border-top-left-radius: 9999px;\n    border-top-right-radius: 9999px;\n  }\n\n  .lg\\:rounded-r-full {\n    border-top-right-radius: 9999px;\n    border-bottom-right-radius: 9999px;\n  }\n\n  .lg\\:rounded-b-full {\n    border-bottom-right-radius: 9999px;\n    border-bottom-left-radius: 9999px;\n  }\n\n  .lg\\:rounded-l-full {\n    border-top-left-radius: 9999px;\n    border-bottom-left-radius: 9999px;\n  }\n\n  .lg\\:rounded-tl-none {\n    border-top-left-radius: 0;\n  }\n\n  .lg\\:rounded-tr-none {\n    border-top-right-radius: 0;\n  }\n\n  .lg\\:rounded-br-none {\n    border-bottom-right-radius: 0;\n  }\n\n  .lg\\:rounded-bl-none {\n    border-bottom-left-radius: 0;\n  }\n\n  .lg\\:rounded-tl-sm {\n    border-top-left-radius: 0.125rem;\n  }\n\n  .lg\\:rounded-tr-sm {\n    border-top-right-radius: 0.125rem;\n  }\n\n  .lg\\:rounded-br-sm {\n    border-bottom-right-radius: 0.125rem;\n  }\n\n  .lg\\:rounded-bl-sm {\n    border-bottom-left-radius: 0.125rem;\n  }\n\n  .lg\\:rounded-tl {\n    border-top-left-radius: 0.25rem;\n  }\n\n  .lg\\:rounded-tr {\n    border-top-right-radius: 0.25rem;\n  }\n\n  .lg\\:rounded-br {\n    border-bottom-right-radius: 0.25rem;\n  }\n\n  .lg\\:rounded-bl {\n    border-bottom-left-radius: 0.25rem;\n  }\n\n  .lg\\:rounded-tl-md {\n    border-top-left-radius: 0.375rem;\n  }\n\n  .lg\\:rounded-tr-md {\n    border-top-right-radius: 0.375rem;\n  }\n\n  .lg\\:rounded-br-md {\n    border-bottom-right-radius: 0.375rem;\n  }\n\n  .lg\\:rounded-bl-md {\n    border-bottom-left-radius: 0.375rem;\n  }\n\n  .lg\\:rounded-tl-lg {\n    border-top-left-radius: 0.5rem;\n  }\n\n  .lg\\:rounded-tr-lg {\n    border-top-right-radius: 0.5rem;\n  }\n\n  .lg\\:rounded-br-lg {\n    border-bottom-right-radius: 0.5rem;\n  }\n\n  .lg\\:rounded-bl-lg {\n    border-bottom-left-radius: 0.5rem;\n  }\n\n  .lg\\:rounded-tl-xl {\n    border-top-left-radius: 0.75rem;\n  }\n\n  .lg\\:rounded-tr-xl {\n    border-top-right-radius: 0.75rem;\n  }\n\n  .lg\\:rounded-br-xl {\n    border-bottom-right-radius: 0.75rem;\n  }\n\n  .lg\\:rounded-bl-xl {\n    border-bottom-left-radius: 0.75rem;\n  }\n\n  .lg\\:rounded-tl-2xl {\n    border-top-left-radius: 1rem;\n  }\n\n  .lg\\:rounded-tr-2xl {\n    border-top-right-radius: 1rem;\n  }\n\n  .lg\\:rounded-br-2xl {\n    border-bottom-right-radius: 1rem;\n  }\n\n  .lg\\:rounded-bl-2xl {\n    border-bottom-left-radius: 1rem;\n  }\n\n  .lg\\:rounded-tl-3xl {\n    border-top-left-radius: 1.5rem;\n  }\n\n  .lg\\:rounded-tr-3xl {\n    border-top-right-radius: 1.5rem;\n  }\n\n  .lg\\:rounded-br-3xl {\n    border-bottom-right-radius: 1.5rem;\n  }\n\n  .lg\\:rounded-bl-3xl {\n    border-bottom-left-radius: 1.5rem;\n  }\n\n  .lg\\:rounded-tl-full {\n    border-top-left-radius: 9999px;\n  }\n\n  .lg\\:rounded-tr-full {\n    border-top-right-radius: 9999px;\n  }\n\n  .lg\\:rounded-br-full {\n    border-bottom-right-radius: 9999px;\n  }\n\n  .lg\\:rounded-bl-full {\n    border-bottom-left-radius: 9999px;\n  }\n\n  .lg\\:border-solid {\n    border-style: solid;\n  }\n\n  .lg\\:border-dashed {\n    border-style: dashed;\n  }\n\n  .lg\\:border-dotted {\n    border-style: dotted;\n  }\n\n  .lg\\:border-double {\n    border-style: double;\n  }\n\n  .lg\\:border-none {\n    border-style: none;\n  }\n\n  .lg\\:border-0 {\n    border-width: 0;\n  }\n\n  .lg\\:border-2 {\n    border-width: 2px;\n  }\n\n  .lg\\:border-4 {\n    border-width: 4px;\n  }\n\n  .lg\\:border-8 {\n    border-width: 8px;\n  }\n\n  .lg\\:border {\n    border-width: 1px;\n  }\n\n  .lg\\:border-t-0 {\n    border-top-width: 0;\n  }\n\n  .lg\\:border-r-0 {\n    border-right-width: 0;\n  }\n\n  .lg\\:border-b-0 {\n    border-bottom-width: 0;\n  }\n\n  .lg\\:border-l-0 {\n    border-left-width: 0;\n  }\n\n  .lg\\:border-t-2 {\n    border-top-width: 2px;\n  }\n\n  .lg\\:border-r-2 {\n    border-right-width: 2px;\n  }\n\n  .lg\\:border-b-2 {\n    border-bottom-width: 2px;\n  }\n\n  .lg\\:border-l-2 {\n    border-left-width: 2px;\n  }\n\n  .lg\\:border-t-4 {\n    border-top-width: 4px;\n  }\n\n  .lg\\:border-r-4 {\n    border-right-width: 4px;\n  }\n\n  .lg\\:border-b-4 {\n    border-bottom-width: 4px;\n  }\n\n  .lg\\:border-l-4 {\n    border-left-width: 4px;\n  }\n\n  .lg\\:border-t-8 {\n    border-top-width: 8px;\n  }\n\n  .lg\\:border-r-8 {\n    border-right-width: 8px;\n  }\n\n  .lg\\:border-b-8 {\n    border-bottom-width: 8px;\n  }\n\n  .lg\\:border-l-8 {\n    border-left-width: 8px;\n  }\n\n  .lg\\:border-t {\n    border-top-width: 1px;\n  }\n\n  .lg\\:border-r {\n    border-right-width: 1px;\n  }\n\n  .lg\\:border-b {\n    border-bottom-width: 1px;\n  }\n\n  .lg\\:border-l {\n    border-left-width: 1px;\n  }\n\n  .lg\\:box-border {\n    box-sizing: border-box;\n  }\n\n  .lg\\:box-content {\n    box-sizing: content-box;\n  }\n\n  .lg\\:cursor-auto {\n    cursor: auto;\n  }\n\n  .lg\\:cursor-default {\n    cursor: default;\n  }\n\n  .lg\\:cursor-pointer {\n    cursor: pointer;\n  }\n\n  .lg\\:cursor-wait {\n    cursor: wait;\n  }\n\n  .lg\\:cursor-text {\n    cursor: text;\n  }\n\n  .lg\\:cursor-move {\n    cursor: move;\n  }\n\n  .lg\\:cursor-not-allowed {\n    cursor: not-allowed;\n  }\n\n  .lg\\:block {\n    display: block;\n  }\n\n  .lg\\:inline-block {\n    display: inline-block;\n  }\n\n  .lg\\:inline {\n    display: inline;\n  }\n\n  .lg\\:flex {\n    display: flex;\n  }\n\n  .lg\\:inline-flex {\n    display: inline-flex;\n  }\n\n  .lg\\:table {\n    display: table;\n  }\n\n  .lg\\:table-caption {\n    display: table-caption;\n  }\n\n  .lg\\:table-cell {\n    display: table-cell;\n  }\n\n  .lg\\:table-column {\n    display: table-column;\n  }\n\n  .lg\\:table-column-group {\n    display: table-column-group;\n  }\n\n  .lg\\:table-footer-group {\n    display: table-footer-group;\n  }\n\n  .lg\\:table-header-group {\n    display: table-header-group;\n  }\n\n  .lg\\:table-row-group {\n    display: table-row-group;\n  }\n\n  .lg\\:table-row {\n    display: table-row;\n  }\n\n  .lg\\:flow-root {\n    display: flow-root;\n  }\n\n  .lg\\:grid {\n    display: grid;\n  }\n\n  .lg\\:inline-grid {\n    display: inline-grid;\n  }\n\n  .lg\\:contents {\n    display: contents;\n  }\n\n  .lg\\:hidden {\n    display: none;\n  }\n\n  .lg\\:flex-row {\n    flex-direction: row;\n  }\n\n  .lg\\:flex-row-reverse {\n    flex-direction: row-reverse;\n  }\n\n  .lg\\:flex-col {\n    flex-direction: column;\n  }\n\n  .lg\\:flex-col-reverse {\n    flex-direction: column-reverse;\n  }\n\n  .lg\\:flex-wrap {\n    flex-wrap: wrap;\n  }\n\n  .lg\\:flex-wrap-reverse {\n    flex-wrap: wrap-reverse;\n  }\n\n  .lg\\:flex-no-wrap {\n    flex-wrap: nowrap;\n  }\n\n  .lg\\:place-items-auto {\n    place-items: auto;\n  }\n\n  .lg\\:place-items-start {\n    place-items: start;\n  }\n\n  .lg\\:place-items-end {\n    place-items: end;\n  }\n\n  .lg\\:place-items-center {\n    place-items: center;\n  }\n\n  .lg\\:place-items-stretch {\n    place-items: stretch;\n  }\n\n  .lg\\:place-content-center {\n    place-content: center;\n  }\n\n  .lg\\:place-content-start {\n    place-content: start;\n  }\n\n  .lg\\:place-content-end {\n    place-content: end;\n  }\n\n  .lg\\:place-content-between {\n    place-content: space-between;\n  }\n\n  .lg\\:place-content-around {\n    place-content: space-around;\n  }\n\n  .lg\\:place-content-evenly {\n    place-content: space-evenly;\n  }\n\n  .lg\\:place-content-stretch {\n    place-content: stretch;\n  }\n\n  .lg\\:place-self-auto {\n    place-self: auto;\n  }\n\n  .lg\\:place-self-start {\n    place-self: start;\n  }\n\n  .lg\\:place-self-end {\n    place-self: end;\n  }\n\n  .lg\\:place-self-center {\n    place-self: center;\n  }\n\n  .lg\\:place-self-stretch {\n    place-self: stretch;\n  }\n\n  .lg\\:items-start {\n    align-items: flex-start;\n  }\n\n  .lg\\:items-end {\n    align-items: flex-end;\n  }\n\n  .lg\\:items-center {\n    align-items: center;\n  }\n\n  .lg\\:items-baseline {\n    align-items: baseline;\n  }\n\n  .lg\\:items-stretch {\n    align-items: stretch;\n  }\n\n  .lg\\:content-center {\n    align-content: center;\n  }\n\n  .lg\\:content-start {\n    align-content: flex-start;\n  }\n\n  .lg\\:content-end {\n    align-content: flex-end;\n  }\n\n  .lg\\:content-between {\n    align-content: space-between;\n  }\n\n  .lg\\:content-around {\n    align-content: space-around;\n  }\n\n  .lg\\:content-evenly {\n    align-content: space-evenly;\n  }\n\n  .lg\\:self-auto {\n    align-self: auto;\n  }\n\n  .lg\\:self-start {\n    align-self: flex-start;\n  }\n\n  .lg\\:self-end {\n    align-self: flex-end;\n  }\n\n  .lg\\:self-center {\n    align-self: center;\n  }\n\n  .lg\\:self-stretch {\n    align-self: stretch;\n  }\n\n  .lg\\:justify-items-auto {\n    justify-items: auto;\n  }\n\n  .lg\\:justify-items-start {\n    justify-items: start;\n  }\n\n  .lg\\:justify-items-end {\n    justify-items: end;\n  }\n\n  .lg\\:justify-items-center {\n    justify-items: center;\n  }\n\n  .lg\\:justify-items-stretch {\n    justify-items: stretch;\n  }\n\n  .lg\\:justify-start {\n    justify-content: flex-start;\n  }\n\n  .lg\\:justify-end {\n    justify-content: flex-end;\n  }\n\n  .lg\\:justify-center {\n    justify-content: center;\n  }\n\n  .lg\\:justify-between {\n    justify-content: space-between;\n  }\n\n  .lg\\:justify-around {\n    justify-content: space-around;\n  }\n\n  .lg\\:justify-evenly {\n    justify-content: space-evenly;\n  }\n\n  .lg\\:justify-self-auto {\n    justify-self: auto;\n  }\n\n  .lg\\:justify-self-start {\n    justify-self: start;\n  }\n\n  .lg\\:justify-self-end {\n    justify-self: end;\n  }\n\n  .lg\\:justify-self-center {\n    justify-self: center;\n  }\n\n  .lg\\:justify-self-stretch {\n    justify-self: stretch;\n  }\n\n  .lg\\:flex-1 {\n    flex: 1 1 0%;\n  }\n\n  .lg\\:flex-auto {\n    flex: 1 1 auto;\n  }\n\n  .lg\\:flex-initial {\n    flex: 0 1 auto;\n  }\n\n  .lg\\:flex-none {\n    flex: none;\n  }\n\n  .lg\\:flex-grow-0 {\n    flex-grow: 0;\n  }\n\n  .lg\\:flex-grow {\n    flex-grow: 1;\n  }\n\n  .lg\\:flex-shrink-0 {\n    flex-shrink: 0;\n  }\n\n  .lg\\:flex-shrink {\n    flex-shrink: 1;\n  }\n\n  .lg\\:order-1 {\n    order: 1;\n  }\n\n  .lg\\:order-2 {\n    order: 2;\n  }\n\n  .lg\\:order-3 {\n    order: 3;\n  }\n\n  .lg\\:order-4 {\n    order: 4;\n  }\n\n  .lg\\:order-5 {\n    order: 5;\n  }\n\n  .lg\\:order-6 {\n    order: 6;\n  }\n\n  .lg\\:order-7 {\n    order: 7;\n  }\n\n  .lg\\:order-8 {\n    order: 8;\n  }\n\n  .lg\\:order-9 {\n    order: 9;\n  }\n\n  .lg\\:order-10 {\n    order: 10;\n  }\n\n  .lg\\:order-11 {\n    order: 11;\n  }\n\n  .lg\\:order-12 {\n    order: 12;\n  }\n\n  .lg\\:order-first {\n    order: -9999;\n  }\n\n  .lg\\:order-last {\n    order: 9999;\n  }\n\n  .lg\\:order-none {\n    order: 0;\n  }\n\n  .lg\\:float-right {\n    float: right;\n  }\n\n  .lg\\:float-left {\n    float: left;\n  }\n\n  .lg\\:float-none {\n    float: none;\n  }\n\n  .lg\\:clearfix:after {\n    content: \"\";\n    display: table;\n    clear: both;\n  }\n\n  .lg\\:clear-left {\n    clear: left;\n  }\n\n  .lg\\:clear-right {\n    clear: right;\n  }\n\n  .lg\\:clear-both {\n    clear: both;\n  }\n\n  .lg\\:clear-none {\n    clear: none;\n  }\n\n  .lg\\:font-sans {\n    font-family: system-ui, -apple-system, BlinkMacSystemFont, \"Segoe UI\", Roboto, \"Helvetica Neue\", Arial, \"Noto Sans\", sans-serif, \"Apple Color Emoji\", \"Segoe UI Emoji\", \"Segoe UI Symbol\", \"Noto Color Emoji\";\n  }\n\n  .lg\\:font-serif {\n    font-family: Georgia, Cambria, \"Times New Roman\", Times, serif;\n  }\n\n  .lg\\:font-mono {\n    font-family: Menlo, Monaco, Consolas, \"Liberation Mono\", \"Courier New\", monospace;\n  }\n\n  .lg\\:font-hairline {\n    font-weight: 100;\n  }\n\n  .lg\\:font-thin {\n    font-weight: 200;\n  }\n\n  .lg\\:font-light {\n    font-weight: 300;\n  }\n\n  .lg\\:font-normal {\n    font-weight: 400;\n  }\n\n  .lg\\:font-medium {\n    font-weight: 500;\n  }\n\n  .lg\\:font-semibold {\n    font-weight: 600;\n  }\n\n  .lg\\:font-bold {\n    font-weight: 700;\n  }\n\n  .lg\\:font-extrabold {\n    font-weight: 800;\n  }\n\n  .lg\\:font-black {\n    font-weight: 900;\n  }\n\n  .lg\\:hover\\:font-hairline:hover {\n    font-weight: 100;\n  }\n\n  .lg\\:hover\\:font-thin:hover {\n    font-weight: 200;\n  }\n\n  .lg\\:hover\\:font-light:hover {\n    font-weight: 300;\n  }\n\n  .lg\\:hover\\:font-normal:hover {\n    font-weight: 400;\n  }\n\n  .lg\\:hover\\:font-medium:hover {\n    font-weight: 500;\n  }\n\n  .lg\\:hover\\:font-semibold:hover {\n    font-weight: 600;\n  }\n\n  .lg\\:hover\\:font-bold:hover {\n    font-weight: 700;\n  }\n\n  .lg\\:hover\\:font-extrabold:hover {\n    font-weight: 800;\n  }\n\n  .lg\\:hover\\:font-black:hover {\n    font-weight: 900;\n  }\n\n  .lg\\:focus\\:font-hairline:focus {\n    font-weight: 100;\n  }\n\n  .lg\\:focus\\:font-thin:focus {\n    font-weight: 200;\n  }\n\n  .lg\\:focus\\:font-light:focus {\n    font-weight: 300;\n  }\n\n  .lg\\:focus\\:font-normal:focus {\n    font-weight: 400;\n  }\n\n  .lg\\:focus\\:font-medium:focus {\n    font-weight: 500;\n  }\n\n  .lg\\:focus\\:font-semibold:focus {\n    font-weight: 600;\n  }\n\n  .lg\\:focus\\:font-bold:focus {\n    font-weight: 700;\n  }\n\n  .lg\\:focus\\:font-extrabold:focus {\n    font-weight: 800;\n  }\n\n  .lg\\:focus\\:font-black:focus {\n    font-weight: 900;\n  }\n\n  .lg\\:h-0 {\n    height: 0;\n  }\n\n  .lg\\:h-1 {\n    height: 0.25rem;\n  }\n\n  .lg\\:h-2 {\n    height: 0.5rem;\n  }\n\n  .lg\\:h-3 {\n    height: 0.75rem;\n  }\n\n  .lg\\:h-4 {\n    height: 1rem;\n  }\n\n  .lg\\:h-5 {\n    height: 1.25rem;\n  }\n\n  .lg\\:h-6 {\n    height: 1.5rem;\n  }\n\n  .lg\\:h-8 {\n    height: 2rem;\n  }\n\n  .lg\\:h-10 {\n    height: 2.5rem;\n  }\n\n  .lg\\:h-12 {\n    height: 3rem;\n  }\n\n  .lg\\:h-16 {\n    height: 4rem;\n  }\n\n  .lg\\:h-20 {\n    height: 5rem;\n  }\n\n  .lg\\:h-24 {\n    height: 6rem;\n  }\n\n  .lg\\:h-32 {\n    height: 8rem;\n  }\n\n  .lg\\:h-40 {\n    height: 10rem;\n  }\n\n  .lg\\:h-48 {\n    height: 12rem;\n  }\n\n  .lg\\:h-56 {\n    height: 14rem;\n  }\n\n  .lg\\:h-64 {\n    height: 16rem;\n  }\n\n  .lg\\:h-auto {\n    height: auto;\n  }\n\n  .lg\\:h-px {\n    height: 1px;\n  }\n\n  .lg\\:h-full {\n    height: 100%;\n  }\n\n  .lg\\:h-screen {\n    height: 100vh;\n  }\n\n  .lg\\:text-xs {\n    font-size: 0.75rem;\n  }\n\n  .lg\\:text-sm {\n    font-size: 0.875rem;\n  }\n\n  .lg\\:text-base {\n    font-size: 1rem;\n  }\n\n  .lg\\:text-lg {\n    font-size: 1.125rem;\n  }\n\n  .lg\\:text-xl {\n    font-size: 1.25rem;\n  }\n\n  .lg\\:text-2xl {\n    font-size: 1.5rem;\n  }\n\n  .lg\\:text-3xl {\n    font-size: 1.875rem;\n  }\n\n  .lg\\:text-4xl {\n    font-size: 2.25rem;\n  }\n\n  .lg\\:text-5xl {\n    font-size: 3rem;\n  }\n\n  .lg\\:text-6xl {\n    font-size: 4rem;\n  }\n\n  .lg\\:leading-3 {\n    line-height: .75rem;\n  }\n\n  .lg\\:leading-4 {\n    line-height: 1rem;\n  }\n\n  .lg\\:leading-5 {\n    line-height: 1.25rem;\n  }\n\n  .lg\\:leading-6 {\n    line-height: 1.5rem;\n  }\n\n  .lg\\:leading-7 {\n    line-height: 1.75rem;\n  }\n\n  .lg\\:leading-8 {\n    line-height: 2rem;\n  }\n\n  .lg\\:leading-9 {\n    line-height: 2.25rem;\n  }\n\n  .lg\\:leading-10 {\n    line-height: 2.5rem;\n  }\n\n  .lg\\:leading-none {\n    line-height: 1;\n  }\n\n  .lg\\:leading-tight {\n    line-height: 1.25;\n  }\n\n  .lg\\:leading-snug {\n    line-height: 1.375;\n  }\n\n  .lg\\:leading-normal {\n    line-height: 1.5;\n  }\n\n  .lg\\:leading-relaxed {\n    line-height: 1.625;\n  }\n\n  .lg\\:leading-loose {\n    line-height: 2;\n  }\n\n  .lg\\:list-inside {\n    list-style-position: inside;\n  }\n\n  .lg\\:list-outside {\n    list-style-position: outside;\n  }\n\n  .lg\\:list-none {\n    list-style-type: none;\n  }\n\n  .lg\\:list-disc {\n    list-style-type: disc;\n  }\n\n  .lg\\:list-decimal {\n    list-style-type: decimal;\n  }\n\n  .lg\\:m-0 {\n    margin: 0;\n  }\n\n  .lg\\:m-1 {\n    margin: 0.25rem;\n  }\n\n  .lg\\:m-2 {\n    margin: 0.5rem;\n  }\n\n  .lg\\:m-3 {\n    margin: 0.75rem;\n  }\n\n  .lg\\:m-4 {\n    margin: 1rem;\n  }\n\n  .lg\\:m-5 {\n    margin: 1.25rem;\n  }\n\n  .lg\\:m-6 {\n    margin: 1.5rem;\n  }\n\n  .lg\\:m-8 {\n    margin: 2rem;\n  }\n\n  .lg\\:m-10 {\n    margin: 2.5rem;\n  }\n\n  .lg\\:m-12 {\n    margin: 3rem;\n  }\n\n  .lg\\:m-16 {\n    margin: 4rem;\n  }\n\n  .lg\\:m-20 {\n    margin: 5rem;\n  }\n\n  .lg\\:m-24 {\n    margin: 6rem;\n  }\n\n  .lg\\:m-32 {\n    margin: 8rem;\n  }\n\n  .lg\\:m-40 {\n    margin: 10rem;\n  }\n\n  .lg\\:m-48 {\n    margin: 12rem;\n  }\n\n  .lg\\:m-56 {\n    margin: 14rem;\n  }\n\n  .lg\\:m-64 {\n    margin: 16rem;\n  }\n\n  .lg\\:m-auto {\n    margin: auto;\n  }\n\n  .lg\\:m-px {\n    margin: 1px;\n  }\n\n  .lg\\:-m-1 {\n    margin: -0.25rem;\n  }\n\n  .lg\\:-m-2 {\n    margin: -0.5rem;\n  }\n\n  .lg\\:-m-3 {\n    margin: -0.75rem;\n  }\n\n  .lg\\:-m-4 {\n    margin: -1rem;\n  }\n\n  .lg\\:-m-5 {\n    margin: -1.25rem;\n  }\n\n  .lg\\:-m-6 {\n    margin: -1.5rem;\n  }\n\n  .lg\\:-m-8 {\n    margin: -2rem;\n  }\n\n  .lg\\:-m-10 {\n    margin: -2.5rem;\n  }\n\n  .lg\\:-m-12 {\n    margin: -3rem;\n  }\n\n  .lg\\:-m-16 {\n    margin: -4rem;\n  }\n\n  .lg\\:-m-20 {\n    margin: -5rem;\n  }\n\n  .lg\\:-m-24 {\n    margin: -6rem;\n  }\n\n  .lg\\:-m-32 {\n    margin: -8rem;\n  }\n\n  .lg\\:-m-40 {\n    margin: -10rem;\n  }\n\n  .lg\\:-m-48 {\n    margin: -12rem;\n  }\n\n  .lg\\:-m-56 {\n    margin: -14rem;\n  }\n\n  .lg\\:-m-64 {\n    margin: -16rem;\n  }\n\n  .lg\\:-m-px {\n    margin: -1px;\n  }\n\n  .lg\\:my-0 {\n    margin-top: 0;\n    margin-bottom: 0;\n  }\n\n  .lg\\:mx-0 {\n    margin-left: 0;\n    margin-right: 0;\n  }\n\n  .lg\\:my-1 {\n    margin-top: 0.25rem;\n    margin-bottom: 0.25rem;\n  }\n\n  .lg\\:mx-1 {\n    margin-left: 0.25rem;\n    margin-right: 0.25rem;\n  }\n\n  .lg\\:my-2 {\n    margin-top: 0.5rem;\n    margin-bottom: 0.5rem;\n  }\n\n  .lg\\:mx-2 {\n    margin-left: 0.5rem;\n    margin-right: 0.5rem;\n  }\n\n  .lg\\:my-3 {\n    margin-top: 0.75rem;\n    margin-bottom: 0.75rem;\n  }\n\n  .lg\\:mx-3 {\n    margin-left: 0.75rem;\n    margin-right: 0.75rem;\n  }\n\n  .lg\\:my-4 {\n    margin-top: 1rem;\n    margin-bottom: 1rem;\n  }\n\n  .lg\\:mx-4 {\n    margin-left: 1rem;\n    margin-right: 1rem;\n  }\n\n  .lg\\:my-5 {\n    margin-top: 1.25rem;\n    margin-bottom: 1.25rem;\n  }\n\n  .lg\\:mx-5 {\n    margin-left: 1.25rem;\n    margin-right: 1.25rem;\n  }\n\n  .lg\\:my-6 {\n    margin-top: 1.5rem;\n    margin-bottom: 1.5rem;\n  }\n\n  .lg\\:mx-6 {\n    margin-left: 1.5rem;\n    margin-right: 1.5rem;\n  }\n\n  .lg\\:my-8 {\n    margin-top: 2rem;\n    margin-bottom: 2rem;\n  }\n\n  .lg\\:mx-8 {\n    margin-left: 2rem;\n    margin-right: 2rem;\n  }\n\n  .lg\\:my-10 {\n    margin-top: 2.5rem;\n    margin-bottom: 2.5rem;\n  }\n\n  .lg\\:mx-10 {\n    margin-left: 2.5rem;\n    margin-right: 2.5rem;\n  }\n\n  .lg\\:my-12 {\n    margin-top: 3rem;\n    margin-bottom: 3rem;\n  }\n\n  .lg\\:mx-12 {\n    margin-left: 3rem;\n    margin-right: 3rem;\n  }\n\n  .lg\\:my-16 {\n    margin-top: 4rem;\n    margin-bottom: 4rem;\n  }\n\n  .lg\\:mx-16 {\n    margin-left: 4rem;\n    margin-right: 4rem;\n  }\n\n  .lg\\:my-20 {\n    margin-top: 5rem;\n    margin-bottom: 5rem;\n  }\n\n  .lg\\:mx-20 {\n    margin-left: 5rem;\n    margin-right: 5rem;\n  }\n\n  .lg\\:my-24 {\n    margin-top: 6rem;\n    margin-bottom: 6rem;\n  }\n\n  .lg\\:mx-24 {\n    margin-left: 6rem;\n    margin-right: 6rem;\n  }\n\n  .lg\\:my-32 {\n    margin-top: 8rem;\n    margin-bottom: 8rem;\n  }\n\n  .lg\\:mx-32 {\n    margin-left: 8rem;\n    margin-right: 8rem;\n  }\n\n  .lg\\:my-40 {\n    margin-top: 10rem;\n    margin-bottom: 10rem;\n  }\n\n  .lg\\:mx-40 {\n    margin-left: 10rem;\n    margin-right: 10rem;\n  }\n\n  .lg\\:my-48 {\n    margin-top: 12rem;\n    margin-bottom: 12rem;\n  }\n\n  .lg\\:mx-48 {\n    margin-left: 12rem;\n    margin-right: 12rem;\n  }\n\n  .lg\\:my-56 {\n    margin-top: 14rem;\n    margin-bottom: 14rem;\n  }\n\n  .lg\\:mx-56 {\n    margin-left: 14rem;\n    margin-right: 14rem;\n  }\n\n  .lg\\:my-64 {\n    margin-top: 16rem;\n    margin-bottom: 16rem;\n  }\n\n  .lg\\:mx-64 {\n    margin-left: 16rem;\n    margin-right: 16rem;\n  }\n\n  .lg\\:my-auto {\n    margin-top: auto;\n    margin-bottom: auto;\n  }\n\n  .lg\\:mx-auto {\n    margin-left: auto;\n    margin-right: auto;\n  }\n\n  .lg\\:my-px {\n    margin-top: 1px;\n    margin-bottom: 1px;\n  }\n\n  .lg\\:mx-px {\n    margin-left: 1px;\n    margin-right: 1px;\n  }\n\n  .lg\\:-my-1 {\n    margin-top: -0.25rem;\n    margin-bottom: -0.25rem;\n  }\n\n  .lg\\:-mx-1 {\n    margin-left: -0.25rem;\n    margin-right: -0.25rem;\n  }\n\n  .lg\\:-my-2 {\n    margin-top: -0.5rem;\n    margin-bottom: -0.5rem;\n  }\n\n  .lg\\:-mx-2 {\n    margin-left: -0.5rem;\n    margin-right: -0.5rem;\n  }\n\n  .lg\\:-my-3 {\n    margin-top: -0.75rem;\n    margin-bottom: -0.75rem;\n  }\n\n  .lg\\:-mx-3 {\n    margin-left: -0.75rem;\n    margin-right: -0.75rem;\n  }\n\n  .lg\\:-my-4 {\n    margin-top: -1rem;\n    margin-bottom: -1rem;\n  }\n\n  .lg\\:-mx-4 {\n    margin-left: -1rem;\n    margin-right: -1rem;\n  }\n\n  .lg\\:-my-5 {\n    margin-top: -1.25rem;\n    margin-bottom: -1.25rem;\n  }\n\n  .lg\\:-mx-5 {\n    margin-left: -1.25rem;\n    margin-right: -1.25rem;\n  }\n\n  .lg\\:-my-6 {\n    margin-top: -1.5rem;\n    margin-bottom: -1.5rem;\n  }\n\n  .lg\\:-mx-6 {\n    margin-left: -1.5rem;\n    margin-right: -1.5rem;\n  }\n\n  .lg\\:-my-8 {\n    margin-top: -2rem;\n    margin-bottom: -2rem;\n  }\n\n  .lg\\:-mx-8 {\n    margin-left: -2rem;\n    margin-right: -2rem;\n  }\n\n  .lg\\:-my-10 {\n    margin-top: -2.5rem;\n    margin-bottom: -2.5rem;\n  }\n\n  .lg\\:-mx-10 {\n    margin-left: -2.5rem;\n    margin-right: -2.5rem;\n  }\n\n  .lg\\:-my-12 {\n    margin-top: -3rem;\n    margin-bottom: -3rem;\n  }\n\n  .lg\\:-mx-12 {\n    margin-left: -3rem;\n    margin-right: -3rem;\n  }\n\n  .lg\\:-my-16 {\n    margin-top: -4rem;\n    margin-bottom: -4rem;\n  }\n\n  .lg\\:-mx-16 {\n    margin-left: -4rem;\n    margin-right: -4rem;\n  }\n\n  .lg\\:-my-20 {\n    margin-top: -5rem;\n    margin-bottom: -5rem;\n  }\n\n  .lg\\:-mx-20 {\n    margin-left: -5rem;\n    margin-right: -5rem;\n  }\n\n  .lg\\:-my-24 {\n    margin-top: -6rem;\n    margin-bottom: -6rem;\n  }\n\n  .lg\\:-mx-24 {\n    margin-left: -6rem;\n    margin-right: -6rem;\n  }\n\n  .lg\\:-my-32 {\n    margin-top: -8rem;\n    margin-bottom: -8rem;\n  }\n\n  .lg\\:-mx-32 {\n    margin-left: -8rem;\n    margin-right: -8rem;\n  }\n\n  .lg\\:-my-40 {\n    margin-top: -10rem;\n    margin-bottom: -10rem;\n  }\n\n  .lg\\:-mx-40 {\n    margin-left: -10rem;\n    margin-right: -10rem;\n  }\n\n  .lg\\:-my-48 {\n    margin-top: -12rem;\n    margin-bottom: -12rem;\n  }\n\n  .lg\\:-mx-48 {\n    margin-left: -12rem;\n    margin-right: -12rem;\n  }\n\n  .lg\\:-my-56 {\n    margin-top: -14rem;\n    margin-bottom: -14rem;\n  }\n\n  .lg\\:-mx-56 {\n    margin-left: -14rem;\n    margin-right: -14rem;\n  }\n\n  .lg\\:-my-64 {\n    margin-top: -16rem;\n    margin-bottom: -16rem;\n  }\n\n  .lg\\:-mx-64 {\n    margin-left: -16rem;\n    margin-right: -16rem;\n  }\n\n  .lg\\:-my-px {\n    margin-top: -1px;\n    margin-bottom: -1px;\n  }\n\n  .lg\\:-mx-px {\n    margin-left: -1px;\n    margin-right: -1px;\n  }\n\n  .lg\\:mt-0 {\n    margin-top: 0;\n  }\n\n  .lg\\:mr-0 {\n    margin-right: 0;\n  }\n\n  .lg\\:mb-0 {\n    margin-bottom: 0;\n  }\n\n  .lg\\:ml-0 {\n    margin-left: 0;\n  }\n\n  .lg\\:mt-1 {\n    margin-top: 0.25rem;\n  }\n\n  .lg\\:mr-1 {\n    margin-right: 0.25rem;\n  }\n\n  .lg\\:mb-1 {\n    margin-bottom: 0.25rem;\n  }\n\n  .lg\\:ml-1 {\n    margin-left: 0.25rem;\n  }\n\n  .lg\\:mt-2 {\n    margin-top: 0.5rem;\n  }\n\n  .lg\\:mr-2 {\n    margin-right: 0.5rem;\n  }\n\n  .lg\\:mb-2 {\n    margin-bottom: 0.5rem;\n  }\n\n  .lg\\:ml-2 {\n    margin-left: 0.5rem;\n  }\n\n  .lg\\:mt-3 {\n    margin-top: 0.75rem;\n  }\n\n  .lg\\:mr-3 {\n    margin-right: 0.75rem;\n  }\n\n  .lg\\:mb-3 {\n    margin-bottom: 0.75rem;\n  }\n\n  .lg\\:ml-3 {\n    margin-left: 0.75rem;\n  }\n\n  .lg\\:mt-4 {\n    margin-top: 1rem;\n  }\n\n  .lg\\:mr-4 {\n    margin-right: 1rem;\n  }\n\n  .lg\\:mb-4 {\n    margin-bottom: 1rem;\n  }\n\n  .lg\\:ml-4 {\n    margin-left: 1rem;\n  }\n\n  .lg\\:mt-5 {\n    margin-top: 1.25rem;\n  }\n\n  .lg\\:mr-5 {\n    margin-right: 1.25rem;\n  }\n\n  .lg\\:mb-5 {\n    margin-bottom: 1.25rem;\n  }\n\n  .lg\\:ml-5 {\n    margin-left: 1.25rem;\n  }\n\n  .lg\\:mt-6 {\n    margin-top: 1.5rem;\n  }\n\n  .lg\\:mr-6 {\n    margin-right: 1.5rem;\n  }\n\n  .lg\\:mb-6 {\n    margin-bottom: 1.5rem;\n  }\n\n  .lg\\:ml-6 {\n    margin-left: 1.5rem;\n  }\n\n  .lg\\:mt-8 {\n    margin-top: 2rem;\n  }\n\n  .lg\\:mr-8 {\n    margin-right: 2rem;\n  }\n\n  .lg\\:mb-8 {\n    margin-bottom: 2rem;\n  }\n\n  .lg\\:ml-8 {\n    margin-left: 2rem;\n  }\n\n  .lg\\:mt-10 {\n    margin-top: 2.5rem;\n  }\n\n  .lg\\:mr-10 {\n    margin-right: 2.5rem;\n  }\n\n  .lg\\:mb-10 {\n    margin-bottom: 2.5rem;\n  }\n\n  .lg\\:ml-10 {\n    margin-left: 2.5rem;\n  }\n\n  .lg\\:mt-12 {\n    margin-top: 3rem;\n  }\n\n  .lg\\:mr-12 {\n    margin-right: 3rem;\n  }\n\n  .lg\\:mb-12 {\n    margin-bottom: 3rem;\n  }\n\n  .lg\\:ml-12 {\n    margin-left: 3rem;\n  }\n\n  .lg\\:mt-16 {\n    margin-top: 4rem;\n  }\n\n  .lg\\:mr-16 {\n    margin-right: 4rem;\n  }\n\n  .lg\\:mb-16 {\n    margin-bottom: 4rem;\n  }\n\n  .lg\\:ml-16 {\n    margin-left: 4rem;\n  }\n\n  .lg\\:mt-20 {\n    margin-top: 5rem;\n  }\n\n  .lg\\:mr-20 {\n    margin-right: 5rem;\n  }\n\n  .lg\\:mb-20 {\n    margin-bottom: 5rem;\n  }\n\n  .lg\\:ml-20 {\n    margin-left: 5rem;\n  }\n\n  .lg\\:mt-24 {\n    margin-top: 6rem;\n  }\n\n  .lg\\:mr-24 {\n    margin-right: 6rem;\n  }\n\n  .lg\\:mb-24 {\n    margin-bottom: 6rem;\n  }\n\n  .lg\\:ml-24 {\n    margin-left: 6rem;\n  }\n\n  .lg\\:mt-32 {\n    margin-top: 8rem;\n  }\n\n  .lg\\:mr-32 {\n    margin-right: 8rem;\n  }\n\n  .lg\\:mb-32 {\n    margin-bottom: 8rem;\n  }\n\n  .lg\\:ml-32 {\n    margin-left: 8rem;\n  }\n\n  .lg\\:mt-40 {\n    margin-top: 10rem;\n  }\n\n  .lg\\:mr-40 {\n    margin-right: 10rem;\n  }\n\n  .lg\\:mb-40 {\n    margin-bottom: 10rem;\n  }\n\n  .lg\\:ml-40 {\n    margin-left: 10rem;\n  }\n\n  .lg\\:mt-48 {\n    margin-top: 12rem;\n  }\n\n  .lg\\:mr-48 {\n    margin-right: 12rem;\n  }\n\n  .lg\\:mb-48 {\n    margin-bottom: 12rem;\n  }\n\n  .lg\\:ml-48 {\n    margin-left: 12rem;\n  }\n\n  .lg\\:mt-56 {\n    margin-top: 14rem;\n  }\n\n  .lg\\:mr-56 {\n    margin-right: 14rem;\n  }\n\n  .lg\\:mb-56 {\n    margin-bottom: 14rem;\n  }\n\n  .lg\\:ml-56 {\n    margin-left: 14rem;\n  }\n\n  .lg\\:mt-64 {\n    margin-top: 16rem;\n  }\n\n  .lg\\:mr-64 {\n    margin-right: 16rem;\n  }\n\n  .lg\\:mb-64 {\n    margin-bottom: 16rem;\n  }\n\n  .lg\\:ml-64 {\n    margin-left: 16rem;\n  }\n\n  .lg\\:mt-auto {\n    margin-top: auto;\n  }\n\n  .lg\\:mr-auto {\n    margin-right: auto;\n  }\n\n  .lg\\:mb-auto {\n    margin-bottom: auto;\n  }\n\n  .lg\\:ml-auto {\n    margin-left: auto;\n  }\n\n  .lg\\:mt-px {\n    margin-top: 1px;\n  }\n\n  .lg\\:mr-px {\n    margin-right: 1px;\n  }\n\n  .lg\\:mb-px {\n    margin-bottom: 1px;\n  }\n\n  .lg\\:ml-px {\n    margin-left: 1px;\n  }\n\n  .lg\\:-mt-1 {\n    margin-top: -0.25rem;\n  }\n\n  .lg\\:-mr-1 {\n    margin-right: -0.25rem;\n  }\n\n  .lg\\:-mb-1 {\n    margin-bottom: -0.25rem;\n  }\n\n  .lg\\:-ml-1 {\n    margin-left: -0.25rem;\n  }\n\n  .lg\\:-mt-2 {\n    margin-top: -0.5rem;\n  }\n\n  .lg\\:-mr-2 {\n    margin-right: -0.5rem;\n  }\n\n  .lg\\:-mb-2 {\n    margin-bottom: -0.5rem;\n  }\n\n  .lg\\:-ml-2 {\n    margin-left: -0.5rem;\n  }\n\n  .lg\\:-mt-3 {\n    margin-top: -0.75rem;\n  }\n\n  .lg\\:-mr-3 {\n    margin-right: -0.75rem;\n  }\n\n  .lg\\:-mb-3 {\n    margin-bottom: -0.75rem;\n  }\n\n  .lg\\:-ml-3 {\n    margin-left: -0.75rem;\n  }\n\n  .lg\\:-mt-4 {\n    margin-top: -1rem;\n  }\n\n  .lg\\:-mr-4 {\n    margin-right: -1rem;\n  }\n\n  .lg\\:-mb-4 {\n    margin-bottom: -1rem;\n  }\n\n  .lg\\:-ml-4 {\n    margin-left: -1rem;\n  }\n\n  .lg\\:-mt-5 {\n    margin-top: -1.25rem;\n  }\n\n  .lg\\:-mr-5 {\n    margin-right: -1.25rem;\n  }\n\n  .lg\\:-mb-5 {\n    margin-bottom: -1.25rem;\n  }\n\n  .lg\\:-ml-5 {\n    margin-left: -1.25rem;\n  }\n\n  .lg\\:-mt-6 {\n    margin-top: -1.5rem;\n  }\n\n  .lg\\:-mr-6 {\n    margin-right: -1.5rem;\n  }\n\n  .lg\\:-mb-6 {\n    margin-bottom: -1.5rem;\n  }\n\n  .lg\\:-ml-6 {\n    margin-left: -1.5rem;\n  }\n\n  .lg\\:-mt-8 {\n    margin-top: -2rem;\n  }\n\n  .lg\\:-mr-8 {\n    margin-right: -2rem;\n  }\n\n  .lg\\:-mb-8 {\n    margin-bottom: -2rem;\n  }\n\n  .lg\\:-ml-8 {\n    margin-left: -2rem;\n  }\n\n  .lg\\:-mt-10 {\n    margin-top: -2.5rem;\n  }\n\n  .lg\\:-mr-10 {\n    margin-right: -2.5rem;\n  }\n\n  .lg\\:-mb-10 {\n    margin-bottom: -2.5rem;\n  }\n\n  .lg\\:-ml-10 {\n    margin-left: -2.5rem;\n  }\n\n  .lg\\:-mt-12 {\n    margin-top: -3rem;\n  }\n\n  .lg\\:-mr-12 {\n    margin-right: -3rem;\n  }\n\n  .lg\\:-mb-12 {\n    margin-bottom: -3rem;\n  }\n\n  .lg\\:-ml-12 {\n    margin-left: -3rem;\n  }\n\n  .lg\\:-mt-16 {\n    margin-top: -4rem;\n  }\n\n  .lg\\:-mr-16 {\n    margin-right: -4rem;\n  }\n\n  .lg\\:-mb-16 {\n    margin-bottom: -4rem;\n  }\n\n  .lg\\:-ml-16 {\n    margin-left: -4rem;\n  }\n\n  .lg\\:-mt-20 {\n    margin-top: -5rem;\n  }\n\n  .lg\\:-mr-20 {\n    margin-right: -5rem;\n  }\n\n  .lg\\:-mb-20 {\n    margin-bottom: -5rem;\n  }\n\n  .lg\\:-ml-20 {\n    margin-left: -5rem;\n  }\n\n  .lg\\:-mt-24 {\n    margin-top: -6rem;\n  }\n\n  .lg\\:-mr-24 {\n    margin-right: -6rem;\n  }\n\n  .lg\\:-mb-24 {\n    margin-bottom: -6rem;\n  }\n\n  .lg\\:-ml-24 {\n    margin-left: -6rem;\n  }\n\n  .lg\\:-mt-32 {\n    margin-top: -8rem;\n  }\n\n  .lg\\:-mr-32 {\n    margin-right: -8rem;\n  }\n\n  .lg\\:-mb-32 {\n    margin-bottom: -8rem;\n  }\n\n  .lg\\:-ml-32 {\n    margin-left: -8rem;\n  }\n\n  .lg\\:-mt-40 {\n    margin-top: -10rem;\n  }\n\n  .lg\\:-mr-40 {\n    margin-right: -10rem;\n  }\n\n  .lg\\:-mb-40 {\n    margin-bottom: -10rem;\n  }\n\n  .lg\\:-ml-40 {\n    margin-left: -10rem;\n  }\n\n  .lg\\:-mt-48 {\n    margin-top: -12rem;\n  }\n\n  .lg\\:-mr-48 {\n    margin-right: -12rem;\n  }\n\n  .lg\\:-mb-48 {\n    margin-bottom: -12rem;\n  }\n\n  .lg\\:-ml-48 {\n    margin-left: -12rem;\n  }\n\n  .lg\\:-mt-56 {\n    margin-top: -14rem;\n  }\n\n  .lg\\:-mr-56 {\n    margin-right: -14rem;\n  }\n\n  .lg\\:-mb-56 {\n    margin-bottom: -14rem;\n  }\n\n  .lg\\:-ml-56 {\n    margin-left: -14rem;\n  }\n\n  .lg\\:-mt-64 {\n    margin-top: -16rem;\n  }\n\n  .lg\\:-mr-64 {\n    margin-right: -16rem;\n  }\n\n  .lg\\:-mb-64 {\n    margin-bottom: -16rem;\n  }\n\n  .lg\\:-ml-64 {\n    margin-left: -16rem;\n  }\n\n  .lg\\:-mt-px {\n    margin-top: -1px;\n  }\n\n  .lg\\:-mr-px {\n    margin-right: -1px;\n  }\n\n  .lg\\:-mb-px {\n    margin-bottom: -1px;\n  }\n\n  .lg\\:-ml-px {\n    margin-left: -1px;\n  }\n\n  .lg\\:max-h-full {\n    max-height: 100%;\n  }\n\n  .lg\\:max-h-screen {\n    max-height: 100vh;\n  }\n\n  .lg\\:max-w-none {\n    max-width: none;\n  }\n\n  .lg\\:max-w-xs {\n    max-width: 20rem;\n  }\n\n  .lg\\:max-w-sm {\n    max-width: 24rem;\n  }\n\n  .lg\\:max-w-md {\n    max-width: 28rem;\n  }\n\n  .lg\\:max-w-lg {\n    max-width: 32rem;\n  }\n\n  .lg\\:max-w-xl {\n    max-width: 36rem;\n  }\n\n  .lg\\:max-w-2xl {\n    max-width: 42rem;\n  }\n\n  .lg\\:max-w-3xl {\n    max-width: 48rem;\n  }\n\n  .lg\\:max-w-4xl {\n    max-width: 56rem;\n  }\n\n  .lg\\:max-w-5xl {\n    max-width: 64rem;\n  }\n\n  .lg\\:max-w-6xl {\n    max-width: 72rem;\n  }\n\n  .lg\\:max-w-full {\n    max-width: 100%;\n  }\n\n  .lg\\:max-w-screen-sm {\n    max-width: 640px;\n  }\n\n  .lg\\:max-w-screen-md {\n    max-width: 768px;\n  }\n\n  .lg\\:max-w-screen-lg {\n    max-width: 1024px;\n  }\n\n  .lg\\:max-w-screen-xl {\n    max-width: 1280px;\n  }\n\n  .lg\\:min-h-0 {\n    min-height: 0;\n  }\n\n  .lg\\:min-h-full {\n    min-height: 100%;\n  }\n\n  .lg\\:min-h-screen {\n    min-height: 100vh;\n  }\n\n  .lg\\:min-w-0 {\n    min-width: 0;\n  }\n\n  .lg\\:min-w-full {\n    min-width: 100%;\n  }\n\n  .lg\\:object-contain {\n    -o-object-fit: contain;\n       object-fit: contain;\n  }\n\n  .lg\\:object-cover {\n    -o-object-fit: cover;\n       object-fit: cover;\n  }\n\n  .lg\\:object-fill {\n    -o-object-fit: fill;\n       object-fit: fill;\n  }\n\n  .lg\\:object-none {\n    -o-object-fit: none;\n       object-fit: none;\n  }\n\n  .lg\\:object-scale-down {\n    -o-object-fit: scale-down;\n       object-fit: scale-down;\n  }\n\n  .lg\\:object-bottom {\n    -o-object-position: bottom;\n       object-position: bottom;\n  }\n\n  .lg\\:object-center {\n    -o-object-position: center;\n       object-position: center;\n  }\n\n  .lg\\:object-left {\n    -o-object-position: left;\n       object-position: left;\n  }\n\n  .lg\\:object-left-bottom {\n    -o-object-position: left bottom;\n       object-position: left bottom;\n  }\n\n  .lg\\:object-left-top {\n    -o-object-position: left top;\n       object-position: left top;\n  }\n\n  .lg\\:object-right {\n    -o-object-position: right;\n       object-position: right;\n  }\n\n  .lg\\:object-right-bottom {\n    -o-object-position: right bottom;\n       object-position: right bottom;\n  }\n\n  .lg\\:object-right-top {\n    -o-object-position: right top;\n       object-position: right top;\n  }\n\n  .lg\\:object-top {\n    -o-object-position: top;\n       object-position: top;\n  }\n\n  .lg\\:opacity-0 {\n    opacity: 0;\n  }\n\n  .lg\\:opacity-25 {\n    opacity: 0.25;\n  }\n\n  .lg\\:opacity-50 {\n    opacity: 0.5;\n  }\n\n  .lg\\:opacity-75 {\n    opacity: 0.75;\n  }\n\n  .lg\\:opacity-100 {\n    opacity: 1;\n  }\n\n  .lg\\:hover\\:opacity-0:hover {\n    opacity: 0;\n  }\n\n  .lg\\:hover\\:opacity-25:hover {\n    opacity: 0.25;\n  }\n\n  .lg\\:hover\\:opacity-50:hover {\n    opacity: 0.5;\n  }\n\n  .lg\\:hover\\:opacity-75:hover {\n    opacity: 0.75;\n  }\n\n  .lg\\:hover\\:opacity-100:hover {\n    opacity: 1;\n  }\n\n  .lg\\:focus\\:opacity-0:focus {\n    opacity: 0;\n  }\n\n  .lg\\:focus\\:opacity-25:focus {\n    opacity: 0.25;\n  }\n\n  .lg\\:focus\\:opacity-50:focus {\n    opacity: 0.5;\n  }\n\n  .lg\\:focus\\:opacity-75:focus {\n    opacity: 0.75;\n  }\n\n  .lg\\:focus\\:opacity-100:focus {\n    opacity: 1;\n  }\n\n  .lg\\:outline-none {\n    outline: 2px solid transparent;\n    outline-offset: 2px;\n  }\n\n  .lg\\:outline-white {\n    outline: 2px dotted white;\n    outline-offset: 2px;\n  }\n\n  .lg\\:outline-black {\n    outline: 2px dotted black;\n    outline-offset: 2px;\n  }\n\n  .lg\\:focus\\:outline-none:focus {\n    outline: 2px solid transparent;\n    outline-offset: 2px;\n  }\n\n  .lg\\:focus\\:outline-white:focus {\n    outline: 2px dotted white;\n    outline-offset: 2px;\n  }\n\n  .lg\\:focus\\:outline-black:focus {\n    outline: 2px dotted black;\n    outline-offset: 2px;\n  }\n\n  .lg\\:overflow-auto {\n    overflow: auto;\n  }\n\n  .lg\\:overflow-hidden {\n    overflow: hidden;\n  }\n\n  .lg\\:overflow-visible {\n    overflow: visible;\n  }\n\n  .lg\\:overflow-scroll {\n    overflow: scroll;\n  }\n\n  .lg\\:overflow-x-auto {\n    overflow-x: auto;\n  }\n\n  .lg\\:overflow-y-auto {\n    overflow-y: auto;\n  }\n\n  .lg\\:overflow-x-hidden {\n    overflow-x: hidden;\n  }\n\n  .lg\\:overflow-y-hidden {\n    overflow-y: hidden;\n  }\n\n  .lg\\:overflow-x-visible {\n    overflow-x: visible;\n  }\n\n  .lg\\:overflow-y-visible {\n    overflow-y: visible;\n  }\n\n  .lg\\:overflow-x-scroll {\n    overflow-x: scroll;\n  }\n\n  .lg\\:overflow-y-scroll {\n    overflow-y: scroll;\n  }\n\n  .lg\\:scrolling-touch {\n    -webkit-overflow-scrolling: touch;\n  }\n\n  .lg\\:scrolling-auto {\n    -webkit-overflow-scrolling: auto;\n  }\n\n  .lg\\:overscroll-auto {\n    -ms-scroll-chaining: chained;\n        overscroll-behavior: auto;\n  }\n\n  .lg\\:overscroll-contain {\n    -ms-scroll-chaining: none;\n        overscroll-behavior: contain;\n  }\n\n  .lg\\:overscroll-none {\n    -ms-scroll-chaining: none;\n        overscroll-behavior: none;\n  }\n\n  .lg\\:overscroll-y-auto {\n    overscroll-behavior-y: auto;\n  }\n\n  .lg\\:overscroll-y-contain {\n    overscroll-behavior-y: contain;\n  }\n\n  .lg\\:overscroll-y-none {\n    overscroll-behavior-y: none;\n  }\n\n  .lg\\:overscroll-x-auto {\n    overscroll-behavior-x: auto;\n  }\n\n  .lg\\:overscroll-x-contain {\n    overscroll-behavior-x: contain;\n  }\n\n  .lg\\:overscroll-x-none {\n    overscroll-behavior-x: none;\n  }\n\n  .lg\\:p-0 {\n    padding: 0;\n  }\n\n  .lg\\:p-1 {\n    padding: 0.25rem;\n  }\n\n  .lg\\:p-2 {\n    padding: 0.5rem;\n  }\n\n  .lg\\:p-3 {\n    padding: 0.75rem;\n  }\n\n  .lg\\:p-4 {\n    padding: 1rem;\n  }\n\n  .lg\\:p-5 {\n    padding: 1.25rem;\n  }\n\n  .lg\\:p-6 {\n    padding: 1.5rem;\n  }\n\n  .lg\\:p-8 {\n    padding: 2rem;\n  }\n\n  .lg\\:p-10 {\n    padding: 2.5rem;\n  }\n\n  .lg\\:p-12 {\n    padding: 3rem;\n  }\n\n  .lg\\:p-16 {\n    padding: 4rem;\n  }\n\n  .lg\\:p-20 {\n    padding: 5rem;\n  }\n\n  .lg\\:p-24 {\n    padding: 6rem;\n  }\n\n  .lg\\:p-32 {\n    padding: 8rem;\n  }\n\n  .lg\\:p-40 {\n    padding: 10rem;\n  }\n\n  .lg\\:p-48 {\n    padding: 12rem;\n  }\n\n  .lg\\:p-56 {\n    padding: 14rem;\n  }\n\n  .lg\\:p-64 {\n    padding: 16rem;\n  }\n\n  .lg\\:p-px {\n    padding: 1px;\n  }\n\n  .lg\\:py-0 {\n    padding-top: 0;\n    padding-bottom: 0;\n  }\n\n  .lg\\:px-0 {\n    padding-left: 0;\n    padding-right: 0;\n  }\n\n  .lg\\:py-1 {\n    padding-top: 0.25rem;\n    padding-bottom: 0.25rem;\n  }\n\n  .lg\\:px-1 {\n    padding-left: 0.25rem;\n    padding-right: 0.25rem;\n  }\n\n  .lg\\:py-2 {\n    padding-top: 0.5rem;\n    padding-bottom: 0.5rem;\n  }\n\n  .lg\\:px-2 {\n    padding-left: 0.5rem;\n    padding-right: 0.5rem;\n  }\n\n  .lg\\:py-3 {\n    padding-top: 0.75rem;\n    padding-bottom: 0.75rem;\n  }\n\n  .lg\\:px-3 {\n    padding-left: 0.75rem;\n    padding-right: 0.75rem;\n  }\n\n  .lg\\:py-4 {\n    padding-top: 1rem;\n    padding-bottom: 1rem;\n  }\n\n  .lg\\:px-4 {\n    padding-left: 1rem;\n    padding-right: 1rem;\n  }\n\n  .lg\\:py-5 {\n    padding-top: 1.25rem;\n    padding-bottom: 1.25rem;\n  }\n\n  .lg\\:px-5 {\n    padding-left: 1.25rem;\n    padding-right: 1.25rem;\n  }\n\n  .lg\\:py-6 {\n    padding-top: 1.5rem;\n    padding-bottom: 1.5rem;\n  }\n\n  .lg\\:px-6 {\n    padding-left: 1.5rem;\n    padding-right: 1.5rem;\n  }\n\n  .lg\\:py-8 {\n    padding-top: 2rem;\n    padding-bottom: 2rem;\n  }\n\n  .lg\\:px-8 {\n    padding-left: 2rem;\n    padding-right: 2rem;\n  }\n\n  .lg\\:py-10 {\n    padding-top: 2.5rem;\n    padding-bottom: 2.5rem;\n  }\n\n  .lg\\:px-10 {\n    padding-left: 2.5rem;\n    padding-right: 2.5rem;\n  }\n\n  .lg\\:py-12 {\n    padding-top: 3rem;\n    padding-bottom: 3rem;\n  }\n\n  .lg\\:px-12 {\n    padding-left: 3rem;\n    padding-right: 3rem;\n  }\n\n  .lg\\:py-16 {\n    padding-top: 4rem;\n    padding-bottom: 4rem;\n  }\n\n  .lg\\:px-16 {\n    padding-left: 4rem;\n    padding-right: 4rem;\n  }\n\n  .lg\\:py-20 {\n    padding-top: 5rem;\n    padding-bottom: 5rem;\n  }\n\n  .lg\\:px-20 {\n    padding-left: 5rem;\n    padding-right: 5rem;\n  }\n\n  .lg\\:py-24 {\n    padding-top: 6rem;\n    padding-bottom: 6rem;\n  }\n\n  .lg\\:px-24 {\n    padding-left: 6rem;\n    padding-right: 6rem;\n  }\n\n  .lg\\:py-32 {\n    padding-top: 8rem;\n    padding-bottom: 8rem;\n  }\n\n  .lg\\:px-32 {\n    padding-left: 8rem;\n    padding-right: 8rem;\n  }\n\n  .lg\\:py-40 {\n    padding-top: 10rem;\n    padding-bottom: 10rem;\n  }\n\n  .lg\\:px-40 {\n    padding-left: 10rem;\n    padding-right: 10rem;\n  }\n\n  .lg\\:py-48 {\n    padding-top: 12rem;\n    padding-bottom: 12rem;\n  }\n\n  .lg\\:px-48 {\n    padding-left: 12rem;\n    padding-right: 12rem;\n  }\n\n  .lg\\:py-56 {\n    padding-top: 14rem;\n    padding-bottom: 14rem;\n  }\n\n  .lg\\:px-56 {\n    padding-left: 14rem;\n    padding-right: 14rem;\n  }\n\n  .lg\\:py-64 {\n    padding-top: 16rem;\n    padding-bottom: 16rem;\n  }\n\n  .lg\\:px-64 {\n    padding-left: 16rem;\n    padding-right: 16rem;\n  }\n\n  .lg\\:py-px {\n    padding-top: 1px;\n    padding-bottom: 1px;\n  }\n\n  .lg\\:px-px {\n    padding-left: 1px;\n    padding-right: 1px;\n  }\n\n  .lg\\:pt-0 {\n    padding-top: 0;\n  }\n\n  .lg\\:pr-0 {\n    padding-right: 0;\n  }\n\n  .lg\\:pb-0 {\n    padding-bottom: 0;\n  }\n\n  .lg\\:pl-0 {\n    padding-left: 0;\n  }\n\n  .lg\\:pt-1 {\n    padding-top: 0.25rem;\n  }\n\n  .lg\\:pr-1 {\n    padding-right: 0.25rem;\n  }\n\n  .lg\\:pb-1 {\n    padding-bottom: 0.25rem;\n  }\n\n  .lg\\:pl-1 {\n    padding-left: 0.25rem;\n  }\n\n  .lg\\:pt-2 {\n    padding-top: 0.5rem;\n  }\n\n  .lg\\:pr-2 {\n    padding-right: 0.5rem;\n  }\n\n  .lg\\:pb-2 {\n    padding-bottom: 0.5rem;\n  }\n\n  .lg\\:pl-2 {\n    padding-left: 0.5rem;\n  }\n\n  .lg\\:pt-3 {\n    padding-top: 0.75rem;\n  }\n\n  .lg\\:pr-3 {\n    padding-right: 0.75rem;\n  }\n\n  .lg\\:pb-3 {\n    padding-bottom: 0.75rem;\n  }\n\n  .lg\\:pl-3 {\n    padding-left: 0.75rem;\n  }\n\n  .lg\\:pt-4 {\n    padding-top: 1rem;\n  }\n\n  .lg\\:pr-4 {\n    padding-right: 1rem;\n  }\n\n  .lg\\:pb-4 {\n    padding-bottom: 1rem;\n  }\n\n  .lg\\:pl-4 {\n    padding-left: 1rem;\n  }\n\n  .lg\\:pt-5 {\n    padding-top: 1.25rem;\n  }\n\n  .lg\\:pr-5 {\n    padding-right: 1.25rem;\n  }\n\n  .lg\\:pb-5 {\n    padding-bottom: 1.25rem;\n  }\n\n  .lg\\:pl-5 {\n    padding-left: 1.25rem;\n  }\n\n  .lg\\:pt-6 {\n    padding-top: 1.5rem;\n  }\n\n  .lg\\:pr-6 {\n    padding-right: 1.5rem;\n  }\n\n  .lg\\:pb-6 {\n    padding-bottom: 1.5rem;\n  }\n\n  .lg\\:pl-6 {\n    padding-left: 1.5rem;\n  }\n\n  .lg\\:pt-8 {\n    padding-top: 2rem;\n  }\n\n  .lg\\:pr-8 {\n    padding-right: 2rem;\n  }\n\n  .lg\\:pb-8 {\n    padding-bottom: 2rem;\n  }\n\n  .lg\\:pl-8 {\n    padding-left: 2rem;\n  }\n\n  .lg\\:pt-10 {\n    padding-top: 2.5rem;\n  }\n\n  .lg\\:pr-10 {\n    padding-right: 2.5rem;\n  }\n\n  .lg\\:pb-10 {\n    padding-bottom: 2.5rem;\n  }\n\n  .lg\\:pl-10 {\n    padding-left: 2.5rem;\n  }\n\n  .lg\\:pt-12 {\n    padding-top: 3rem;\n  }\n\n  .lg\\:pr-12 {\n    padding-right: 3rem;\n  }\n\n  .lg\\:pb-12 {\n    padding-bottom: 3rem;\n  }\n\n  .lg\\:pl-12 {\n    padding-left: 3rem;\n  }\n\n  .lg\\:pt-16 {\n    padding-top: 4rem;\n  }\n\n  .lg\\:pr-16 {\n    padding-right: 4rem;\n  }\n\n  .lg\\:pb-16 {\n    padding-bottom: 4rem;\n  }\n\n  .lg\\:pl-16 {\n    padding-left: 4rem;\n  }\n\n  .lg\\:pt-20 {\n    padding-top: 5rem;\n  }\n\n  .lg\\:pr-20 {\n    padding-right: 5rem;\n  }\n\n  .lg\\:pb-20 {\n    padding-bottom: 5rem;\n  }\n\n  .lg\\:pl-20 {\n    padding-left: 5rem;\n  }\n\n  .lg\\:pt-24 {\n    padding-top: 6rem;\n  }\n\n  .lg\\:pr-24 {\n    padding-right: 6rem;\n  }\n\n  .lg\\:pb-24 {\n    padding-bottom: 6rem;\n  }\n\n  .lg\\:pl-24 {\n    padding-left: 6rem;\n  }\n\n  .lg\\:pt-32 {\n    padding-top: 8rem;\n  }\n\n  .lg\\:pr-32 {\n    padding-right: 8rem;\n  }\n\n  .lg\\:pb-32 {\n    padding-bottom: 8rem;\n  }\n\n  .lg\\:pl-32 {\n    padding-left: 8rem;\n  }\n\n  .lg\\:pt-40 {\n    padding-top: 10rem;\n  }\n\n  .lg\\:pr-40 {\n    padding-right: 10rem;\n  }\n\n  .lg\\:pb-40 {\n    padding-bottom: 10rem;\n  }\n\n  .lg\\:pl-40 {\n    padding-left: 10rem;\n  }\n\n  .lg\\:pt-48 {\n    padding-top: 12rem;\n  }\n\n  .lg\\:pr-48 {\n    padding-right: 12rem;\n  }\n\n  .lg\\:pb-48 {\n    padding-bottom: 12rem;\n  }\n\n  .lg\\:pl-48 {\n    padding-left: 12rem;\n  }\n\n  .lg\\:pt-56 {\n    padding-top: 14rem;\n  }\n\n  .lg\\:pr-56 {\n    padding-right: 14rem;\n  }\n\n  .lg\\:pb-56 {\n    padding-bottom: 14rem;\n  }\n\n  .lg\\:pl-56 {\n    padding-left: 14rem;\n  }\n\n  .lg\\:pt-64 {\n    padding-top: 16rem;\n  }\n\n  .lg\\:pr-64 {\n    padding-right: 16rem;\n  }\n\n  .lg\\:pb-64 {\n    padding-bottom: 16rem;\n  }\n\n  .lg\\:pl-64 {\n    padding-left: 16rem;\n  }\n\n  .lg\\:pt-px {\n    padding-top: 1px;\n  }\n\n  .lg\\:pr-px {\n    padding-right: 1px;\n  }\n\n  .lg\\:pb-px {\n    padding-bottom: 1px;\n  }\n\n  .lg\\:pl-px {\n    padding-left: 1px;\n  }\n\n  .lg\\:placeholder-transparent::-moz-placeholder {\n    color: transparent;\n  }\n\n  .lg\\:placeholder-transparent:-ms-input-placeholder {\n    color: transparent;\n  }\n\n  .lg\\:placeholder-transparent::placeholder {\n    color: transparent;\n  }\n\n  .lg\\:placeholder-current::-moz-placeholder {\n    color: currentColor;\n  }\n\n  .lg\\:placeholder-current:-ms-input-placeholder {\n    color: currentColor;\n  }\n\n  .lg\\:placeholder-current::placeholder {\n    color: currentColor;\n  }\n\n  .lg\\:placeholder-black::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-black:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-black::placeholder {\n    --placeholder-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-white::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-white:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-white::placeholder {\n    --placeholder-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-gray-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-red-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-orange-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-yellow-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-green-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-teal-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-blue-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-indigo-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-purple-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-pink-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-80::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-80:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-80::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-100::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-200::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-300::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-400::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-500::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-600::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-700::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-800::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-840::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-840:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-840::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-870::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-870:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-870::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-900::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-930::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-930:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-grayscale-930::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-primary::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-primary:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-primary::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:placeholder-background-main::-moz-placeholder {\n    color: var(--main-background);\n  }\n\n  .lg\\:placeholder-background-main:-ms-input-placeholder {\n    color: var(--main-background);\n  }\n\n  .lg\\:placeholder-background-main::placeholder {\n    color: var(--main-background);\n  }\n\n  .lg\\:placeholder-background-secondary::-moz-placeholder {\n    color: var(--secondary-background);\n  }\n\n  .lg\\:placeholder-background-secondary:-ms-input-placeholder {\n    color: var(--secondary-background);\n  }\n\n  .lg\\:placeholder-background-secondary::placeholder {\n    color: var(--secondary-background);\n  }\n\n  .lg\\:placeholder-foreground::-moz-placeholder {\n    color: var(--foreground);\n  }\n\n  .lg\\:placeholder-foreground:-ms-input-placeholder {\n    color: var(--foreground);\n  }\n\n  .lg\\:placeholder-foreground::placeholder {\n    color: var(--foreground);\n  }\n\n  .lg\\:placeholder-panels-bg::-moz-placeholder {\n    color: var(--panels-background);\n  }\n\n  .lg\\:placeholder-panels-bg:-ms-input-placeholder {\n    color: var(--panels-background);\n  }\n\n  .lg\\:placeholder-panels-bg::placeholder {\n    color: var(--panels-background);\n  }\n\n  .lg\\:focus\\:placeholder-transparent:focus::-moz-placeholder {\n    color: transparent;\n  }\n\n  .lg\\:focus\\:placeholder-transparent:focus:-ms-input-placeholder {\n    color: transparent;\n  }\n\n  .lg\\:focus\\:placeholder-transparent:focus::placeholder {\n    color: transparent;\n  }\n\n  .lg\\:focus\\:placeholder-current:focus::-moz-placeholder {\n    color: currentColor;\n  }\n\n  .lg\\:focus\\:placeholder-current:focus:-ms-input-placeholder {\n    color: currentColor;\n  }\n\n  .lg\\:focus\\:placeholder-current:focus::placeholder {\n    color: currentColor;\n  }\n\n  .lg\\:focus\\:placeholder-black:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-black:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-black:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-white:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-white:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-white:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-gray-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-red-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-orange-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-yellow-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-green-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-teal-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-blue-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-indigo-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-purple-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-pink-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-80:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-80:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-80:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-840:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-840:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-840:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-870:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-870:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-870:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-930:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-930:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-grayscale-930:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-primary:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-primary:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-primary:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n  }\n\n  .lg\\:focus\\:placeholder-background-main:focus::-moz-placeholder {\n    color: var(--main-background);\n  }\n\n  .lg\\:focus\\:placeholder-background-main:focus:-ms-input-placeholder {\n    color: var(--main-background);\n  }\n\n  .lg\\:focus\\:placeholder-background-main:focus::placeholder {\n    color: var(--main-background);\n  }\n\n  .lg\\:focus\\:placeholder-background-secondary:focus::-moz-placeholder {\n    color: var(--secondary-background);\n  }\n\n  .lg\\:focus\\:placeholder-background-secondary:focus:-ms-input-placeholder {\n    color: var(--secondary-background);\n  }\n\n  .lg\\:focus\\:placeholder-background-secondary:focus::placeholder {\n    color: var(--secondary-background);\n  }\n\n  .lg\\:focus\\:placeholder-foreground:focus::-moz-placeholder {\n    color: var(--foreground);\n  }\n\n  .lg\\:focus\\:placeholder-foreground:focus:-ms-input-placeholder {\n    color: var(--foreground);\n  }\n\n  .lg\\:focus\\:placeholder-foreground:focus::placeholder {\n    color: var(--foreground);\n  }\n\n  .lg\\:focus\\:placeholder-panels-bg:focus::-moz-placeholder {\n    color: var(--panels-background);\n  }\n\n  .lg\\:focus\\:placeholder-panels-bg:focus:-ms-input-placeholder {\n    color: var(--panels-background);\n  }\n\n  .lg\\:focus\\:placeholder-panels-bg:focus::placeholder {\n    color: var(--panels-background);\n  }\n\n  .lg\\:placeholder-opacity-0::-moz-placeholder {\n    --placeholder-opacity: 0;\n  }\n\n  .lg\\:placeholder-opacity-0:-ms-input-placeholder {\n    --placeholder-opacity: 0;\n  }\n\n  .lg\\:placeholder-opacity-0::placeholder {\n    --placeholder-opacity: 0;\n  }\n\n  .lg\\:placeholder-opacity-25::-moz-placeholder {\n    --placeholder-opacity: 0.25;\n  }\n\n  .lg\\:placeholder-opacity-25:-ms-input-placeholder {\n    --placeholder-opacity: 0.25;\n  }\n\n  .lg\\:placeholder-opacity-25::placeholder {\n    --placeholder-opacity: 0.25;\n  }\n\n  .lg\\:placeholder-opacity-50::-moz-placeholder {\n    --placeholder-opacity: 0.5;\n  }\n\n  .lg\\:placeholder-opacity-50:-ms-input-placeholder {\n    --placeholder-opacity: 0.5;\n  }\n\n  .lg\\:placeholder-opacity-50::placeholder {\n    --placeholder-opacity: 0.5;\n  }\n\n  .lg\\:placeholder-opacity-75::-moz-placeholder {\n    --placeholder-opacity: 0.75;\n  }\n\n  .lg\\:placeholder-opacity-75:-ms-input-placeholder {\n    --placeholder-opacity: 0.75;\n  }\n\n  .lg\\:placeholder-opacity-75::placeholder {\n    --placeholder-opacity: 0.75;\n  }\n\n  .lg\\:placeholder-opacity-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n  }\n\n  .lg\\:placeholder-opacity-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n  }\n\n  .lg\\:placeholder-opacity-100::placeholder {\n    --placeholder-opacity: 1;\n  }\n\n  .lg\\:focus\\:placeholder-opacity-0:focus::-moz-placeholder {\n    --placeholder-opacity: 0;\n  }\n\n  .lg\\:focus\\:placeholder-opacity-0:focus:-ms-input-placeholder {\n    --placeholder-opacity: 0;\n  }\n\n  .lg\\:focus\\:placeholder-opacity-0:focus::placeholder {\n    --placeholder-opacity: 0;\n  }\n\n  .lg\\:focus\\:placeholder-opacity-25:focus::-moz-placeholder {\n    --placeholder-opacity: 0.25;\n  }\n\n  .lg\\:focus\\:placeholder-opacity-25:focus:-ms-input-placeholder {\n    --placeholder-opacity: 0.25;\n  }\n\n  .lg\\:focus\\:placeholder-opacity-25:focus::placeholder {\n    --placeholder-opacity: 0.25;\n  }\n\n  .lg\\:focus\\:placeholder-opacity-50:focus::-moz-placeholder {\n    --placeholder-opacity: 0.5;\n  }\n\n  .lg\\:focus\\:placeholder-opacity-50:focus:-ms-input-placeholder {\n    --placeholder-opacity: 0.5;\n  }\n\n  .lg\\:focus\\:placeholder-opacity-50:focus::placeholder {\n    --placeholder-opacity: 0.5;\n  }\n\n  .lg\\:focus\\:placeholder-opacity-75:focus::-moz-placeholder {\n    --placeholder-opacity: 0.75;\n  }\n\n  .lg\\:focus\\:placeholder-opacity-75:focus:-ms-input-placeholder {\n    --placeholder-opacity: 0.75;\n  }\n\n  .lg\\:focus\\:placeholder-opacity-75:focus::placeholder {\n    --placeholder-opacity: 0.75;\n  }\n\n  .lg\\:focus\\:placeholder-opacity-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n  }\n\n  .lg\\:focus\\:placeholder-opacity-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n  }\n\n  .lg\\:focus\\:placeholder-opacity-100:focus::placeholder {\n    --placeholder-opacity: 1;\n  }\n\n  .lg\\:pointer-events-none {\n    pointer-events: none;\n  }\n\n  .lg\\:pointer-events-auto {\n    pointer-events: auto;\n  }\n\n  .lg\\:static {\n    position: static;\n  }\n\n  .lg\\:fixed {\n    position: fixed;\n  }\n\n  .lg\\:absolute {\n    position: absolute;\n  }\n\n  .lg\\:relative {\n    position: relative;\n  }\n\n  .lg\\:sticky {\n    position: -webkit-sticky;\n    position: sticky;\n  }\n\n  .lg\\:inset-0 {\n    top: 0;\n    right: 0;\n    bottom: 0;\n    left: 0;\n  }\n\n  .lg\\:inset-auto {\n    top: auto;\n    right: auto;\n    bottom: auto;\n    left: auto;\n  }\n\n  .lg\\:inset-y-0 {\n    top: 0;\n    bottom: 0;\n  }\n\n  .lg\\:inset-x-0 {\n    right: 0;\n    left: 0;\n  }\n\n  .lg\\:inset-y-auto {\n    top: auto;\n    bottom: auto;\n  }\n\n  .lg\\:inset-x-auto {\n    right: auto;\n    left: auto;\n  }\n\n  .lg\\:top-0 {\n    top: 0;\n  }\n\n  .lg\\:right-0 {\n    right: 0;\n  }\n\n  .lg\\:bottom-0 {\n    bottom: 0;\n  }\n\n  .lg\\:left-0 {\n    left: 0;\n  }\n\n  .lg\\:top-auto {\n    top: auto;\n  }\n\n  .lg\\:right-auto {\n    right: auto;\n  }\n\n  .lg\\:bottom-auto {\n    bottom: auto;\n  }\n\n  .lg\\:left-auto {\n    left: auto;\n  }\n\n  .lg\\:resize-none {\n    resize: none;\n  }\n\n  .lg\\:resize-y {\n    resize: vertical;\n  }\n\n  .lg\\:resize-x {\n    resize: horizontal;\n  }\n\n  .lg\\:resize {\n    resize: both;\n  }\n\n  .lg\\:shadow-xs {\n    box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.05);\n  }\n\n  .lg\\:shadow-sm {\n    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);\n  }\n\n  .lg\\:shadow {\n    box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);\n  }\n\n  .lg\\:shadow-md {\n    box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);\n  }\n\n  .lg\\:shadow-lg {\n    box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);\n  }\n\n  .lg\\:shadow-xl {\n    box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04);\n  }\n\n  .lg\\:shadow-2xl {\n    box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);\n  }\n\n  .lg\\:shadow-inner {\n    box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);\n  }\n\n  .lg\\:shadow-outline {\n    box-shadow: 0 0 0 3px rgba(66, 153, 225, 0.5);\n  }\n\n  .lg\\:shadow-none {\n    box-shadow: none;\n  }\n\n  .lg\\:hover\\:shadow-xs:hover {\n    box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.05);\n  }\n\n  .lg\\:hover\\:shadow-sm:hover {\n    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);\n  }\n\n  .lg\\:hover\\:shadow:hover {\n    box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);\n  }\n\n  .lg\\:hover\\:shadow-md:hover {\n    box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);\n  }\n\n  .lg\\:hover\\:shadow-lg:hover {\n    box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);\n  }\n\n  .lg\\:hover\\:shadow-xl:hover {\n    box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04);\n  }\n\n  .lg\\:hover\\:shadow-2xl:hover {\n    box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);\n  }\n\n  .lg\\:hover\\:shadow-inner:hover {\n    box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);\n  }\n\n  .lg\\:hover\\:shadow-outline:hover {\n    box-shadow: 0 0 0 3px rgba(66, 153, 225, 0.5);\n  }\n\n  .lg\\:hover\\:shadow-none:hover {\n    box-shadow: none;\n  }\n\n  .lg\\:focus\\:shadow-xs:focus {\n    box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.05);\n  }\n\n  .lg\\:focus\\:shadow-sm:focus {\n    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);\n  }\n\n  .lg\\:focus\\:shadow:focus {\n    box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);\n  }\n\n  .lg\\:focus\\:shadow-md:focus {\n    box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);\n  }\n\n  .lg\\:focus\\:shadow-lg:focus {\n    box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);\n  }\n\n  .lg\\:focus\\:shadow-xl:focus {\n    box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04);\n  }\n\n  .lg\\:focus\\:shadow-2xl:focus {\n    box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);\n  }\n\n  .lg\\:focus\\:shadow-inner:focus {\n    box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);\n  }\n\n  .lg\\:focus\\:shadow-outline:focus {\n    box-shadow: 0 0 0 3px rgba(66, 153, 225, 0.5);\n  }\n\n  .lg\\:focus\\:shadow-none:focus {\n    box-shadow: none;\n  }\n\n  .lg\\:fill-current {\n    fill: currentColor;\n  }\n\n  .lg\\:stroke-current {\n    stroke: currentColor;\n  }\n\n  .lg\\:stroke-0 {\n    stroke-width: 0;\n  }\n\n  .lg\\:stroke-1 {\n    stroke-width: 1;\n  }\n\n  .lg\\:stroke-2 {\n    stroke-width: 2;\n  }\n\n  .lg\\:table-auto {\n    table-layout: auto;\n  }\n\n  .lg\\:table-fixed {\n    table-layout: fixed;\n  }\n\n  .lg\\:text-left {\n    text-align: left;\n  }\n\n  .lg\\:text-center {\n    text-align: center;\n  }\n\n  .lg\\:text-right {\n    text-align: right;\n  }\n\n  .lg\\:text-justify {\n    text-align: justify;\n  }\n\n  .lg\\:text-transparent {\n    color: transparent;\n  }\n\n  .lg\\:text-current {\n    color: currentColor;\n  }\n\n  .lg\\:text-black {\n    --text-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--text-opacity));\n  }\n\n  .lg\\:text-white {\n    --text-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--text-opacity));\n  }\n\n  .lg\\:text-gray-100 {\n    --text-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--text-opacity));\n  }\n\n  .lg\\:text-gray-200 {\n    --text-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--text-opacity));\n  }\n\n  .lg\\:text-gray-300 {\n    --text-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--text-opacity));\n  }\n\n  .lg\\:text-gray-400 {\n    --text-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--text-opacity));\n  }\n\n  .lg\\:text-gray-500 {\n    --text-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--text-opacity));\n  }\n\n  .lg\\:text-gray-600 {\n    --text-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--text-opacity));\n  }\n\n  .lg\\:text-gray-700 {\n    --text-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--text-opacity));\n  }\n\n  .lg\\:text-gray-800 {\n    --text-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--text-opacity));\n  }\n\n  .lg\\:text-gray-900 {\n    --text-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--text-opacity));\n  }\n\n  .lg\\:text-red-100 {\n    --text-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--text-opacity));\n  }\n\n  .lg\\:text-red-200 {\n    --text-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--text-opacity));\n  }\n\n  .lg\\:text-red-300 {\n    --text-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--text-opacity));\n  }\n\n  .lg\\:text-red-400 {\n    --text-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--text-opacity));\n  }\n\n  .lg\\:text-red-500 {\n    --text-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--text-opacity));\n  }\n\n  .lg\\:text-red-600 {\n    --text-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--text-opacity));\n  }\n\n  .lg\\:text-red-700 {\n    --text-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--text-opacity));\n  }\n\n  .lg\\:text-red-800 {\n    --text-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--text-opacity));\n  }\n\n  .lg\\:text-red-900 {\n    --text-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--text-opacity));\n  }\n\n  .lg\\:text-orange-100 {\n    --text-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--text-opacity));\n  }\n\n  .lg\\:text-orange-200 {\n    --text-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--text-opacity));\n  }\n\n  .lg\\:text-orange-300 {\n    --text-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--text-opacity));\n  }\n\n  .lg\\:text-orange-400 {\n    --text-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--text-opacity));\n  }\n\n  .lg\\:text-orange-500 {\n    --text-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--text-opacity));\n  }\n\n  .lg\\:text-orange-600 {\n    --text-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--text-opacity));\n  }\n\n  .lg\\:text-orange-700 {\n    --text-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--text-opacity));\n  }\n\n  .lg\\:text-orange-800 {\n    --text-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--text-opacity));\n  }\n\n  .lg\\:text-orange-900 {\n    --text-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--text-opacity));\n  }\n\n  .lg\\:text-yellow-100 {\n    --text-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--text-opacity));\n  }\n\n  .lg\\:text-yellow-200 {\n    --text-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--text-opacity));\n  }\n\n  .lg\\:text-yellow-300 {\n    --text-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--text-opacity));\n  }\n\n  .lg\\:text-yellow-400 {\n    --text-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--text-opacity));\n  }\n\n  .lg\\:text-yellow-500 {\n    --text-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--text-opacity));\n  }\n\n  .lg\\:text-yellow-600 {\n    --text-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--text-opacity));\n  }\n\n  .lg\\:text-yellow-700 {\n    --text-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--text-opacity));\n  }\n\n  .lg\\:text-yellow-800 {\n    --text-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--text-opacity));\n  }\n\n  .lg\\:text-yellow-900 {\n    --text-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--text-opacity));\n  }\n\n  .lg\\:text-green-100 {\n    --text-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--text-opacity));\n  }\n\n  .lg\\:text-green-200 {\n    --text-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--text-opacity));\n  }\n\n  .lg\\:text-green-300 {\n    --text-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--text-opacity));\n  }\n\n  .lg\\:text-green-400 {\n    --text-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--text-opacity));\n  }\n\n  .lg\\:text-green-500 {\n    --text-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--text-opacity));\n  }\n\n  .lg\\:text-green-600 {\n    --text-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--text-opacity));\n  }\n\n  .lg\\:text-green-700 {\n    --text-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--text-opacity));\n  }\n\n  .lg\\:text-green-800 {\n    --text-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--text-opacity));\n  }\n\n  .lg\\:text-green-900 {\n    --text-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--text-opacity));\n  }\n\n  .lg\\:text-teal-100 {\n    --text-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--text-opacity));\n  }\n\n  .lg\\:text-teal-200 {\n    --text-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--text-opacity));\n  }\n\n  .lg\\:text-teal-300 {\n    --text-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--text-opacity));\n  }\n\n  .lg\\:text-teal-400 {\n    --text-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--text-opacity));\n  }\n\n  .lg\\:text-teal-500 {\n    --text-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--text-opacity));\n  }\n\n  .lg\\:text-teal-600 {\n    --text-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--text-opacity));\n  }\n\n  .lg\\:text-teal-700 {\n    --text-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--text-opacity));\n  }\n\n  .lg\\:text-teal-800 {\n    --text-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--text-opacity));\n  }\n\n  .lg\\:text-teal-900 {\n    --text-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--text-opacity));\n  }\n\n  .lg\\:text-blue-100 {\n    --text-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--text-opacity));\n  }\n\n  .lg\\:text-blue-200 {\n    --text-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--text-opacity));\n  }\n\n  .lg\\:text-blue-300 {\n    --text-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--text-opacity));\n  }\n\n  .lg\\:text-blue-400 {\n    --text-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--text-opacity));\n  }\n\n  .lg\\:text-blue-500 {\n    --text-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--text-opacity));\n  }\n\n  .lg\\:text-blue-600 {\n    --text-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--text-opacity));\n  }\n\n  .lg\\:text-blue-700 {\n    --text-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--text-opacity));\n  }\n\n  .lg\\:text-blue-800 {\n    --text-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--text-opacity));\n  }\n\n  .lg\\:text-blue-900 {\n    --text-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--text-opacity));\n  }\n\n  .lg\\:text-indigo-100 {\n    --text-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--text-opacity));\n  }\n\n  .lg\\:text-indigo-200 {\n    --text-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--text-opacity));\n  }\n\n  .lg\\:text-indigo-300 {\n    --text-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--text-opacity));\n  }\n\n  .lg\\:text-indigo-400 {\n    --text-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--text-opacity));\n  }\n\n  .lg\\:text-indigo-500 {\n    --text-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--text-opacity));\n  }\n\n  .lg\\:text-indigo-600 {\n    --text-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--text-opacity));\n  }\n\n  .lg\\:text-indigo-700 {\n    --text-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--text-opacity));\n  }\n\n  .lg\\:text-indigo-800 {\n    --text-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--text-opacity));\n  }\n\n  .lg\\:text-indigo-900 {\n    --text-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--text-opacity));\n  }\n\n  .lg\\:text-purple-100 {\n    --text-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--text-opacity));\n  }\n\n  .lg\\:text-purple-200 {\n    --text-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--text-opacity));\n  }\n\n  .lg\\:text-purple-300 {\n    --text-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--text-opacity));\n  }\n\n  .lg\\:text-purple-400 {\n    --text-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--text-opacity));\n  }\n\n  .lg\\:text-purple-500 {\n    --text-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--text-opacity));\n  }\n\n  .lg\\:text-purple-600 {\n    --text-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--text-opacity));\n  }\n\n  .lg\\:text-purple-700 {\n    --text-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--text-opacity));\n  }\n\n  .lg\\:text-purple-800 {\n    --text-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--text-opacity));\n  }\n\n  .lg\\:text-purple-900 {\n    --text-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--text-opacity));\n  }\n\n  .lg\\:text-pink-100 {\n    --text-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--text-opacity));\n  }\n\n  .lg\\:text-pink-200 {\n    --text-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--text-opacity));\n  }\n\n  .lg\\:text-pink-300 {\n    --text-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--text-opacity));\n  }\n\n  .lg\\:text-pink-400 {\n    --text-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--text-opacity));\n  }\n\n  .lg\\:text-pink-500 {\n    --text-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--text-opacity));\n  }\n\n  .lg\\:text-pink-600 {\n    --text-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--text-opacity));\n  }\n\n  .lg\\:text-pink-700 {\n    --text-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--text-opacity));\n  }\n\n  .lg\\:text-pink-800 {\n    --text-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--text-opacity));\n  }\n\n  .lg\\:text-pink-900 {\n    --text-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--text-opacity));\n  }\n\n  .lg\\:text-grayscale-80 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--text-opacity));\n  }\n\n  .lg\\:text-grayscale-100 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--text-opacity));\n  }\n\n  .lg\\:text-grayscale-200 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--text-opacity));\n  }\n\n  .lg\\:text-grayscale-300 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--text-opacity));\n  }\n\n  .lg\\:text-grayscale-400 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--text-opacity));\n  }\n\n  .lg\\:text-grayscale-500 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--text-opacity));\n  }\n\n  .lg\\:text-grayscale-600 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--text-opacity));\n  }\n\n  .lg\\:text-grayscale-700 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--text-opacity));\n  }\n\n  .lg\\:text-grayscale-800 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--text-opacity));\n  }\n\n  .lg\\:text-grayscale-840 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--text-opacity));\n  }\n\n  .lg\\:text-grayscale-870 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--text-opacity));\n  }\n\n  .lg\\:text-grayscale-900 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--text-opacity));\n  }\n\n  .lg\\:text-grayscale-930 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--text-opacity));\n  }\n\n  .lg\\:text-primary {\n    --text-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--text-opacity));\n  }\n\n  .lg\\:text-background-main {\n    color: var(--main-background);\n  }\n\n  .lg\\:text-background-secondary {\n    color: var(--secondary-background);\n  }\n\n  .lg\\:text-foreground {\n    color: var(--foreground);\n  }\n\n  .lg\\:text-panels-bg {\n    color: var(--panels-background);\n  }\n\n  .lg\\:hover\\:text-transparent:hover {\n    color: transparent;\n  }\n\n  .lg\\:hover\\:text-current:hover {\n    color: currentColor;\n  }\n\n  .lg\\:hover\\:text-black:hover {\n    --text-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-white:hover {\n    --text-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-gray-100:hover {\n    --text-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-gray-200:hover {\n    --text-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-gray-300:hover {\n    --text-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-gray-400:hover {\n    --text-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-gray-500:hover {\n    --text-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-gray-600:hover {\n    --text-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-gray-700:hover {\n    --text-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-gray-800:hover {\n    --text-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-gray-900:hover {\n    --text-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-red-100:hover {\n    --text-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-red-200:hover {\n    --text-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-red-300:hover {\n    --text-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-red-400:hover {\n    --text-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-red-500:hover {\n    --text-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-red-600:hover {\n    --text-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-red-700:hover {\n    --text-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-red-800:hover {\n    --text-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-red-900:hover {\n    --text-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-orange-100:hover {\n    --text-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-orange-200:hover {\n    --text-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-orange-300:hover {\n    --text-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-orange-400:hover {\n    --text-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-orange-500:hover {\n    --text-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-orange-600:hover {\n    --text-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-orange-700:hover {\n    --text-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-orange-800:hover {\n    --text-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-orange-900:hover {\n    --text-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-yellow-100:hover {\n    --text-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-yellow-200:hover {\n    --text-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-yellow-300:hover {\n    --text-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-yellow-400:hover {\n    --text-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-yellow-500:hover {\n    --text-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-yellow-600:hover {\n    --text-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-yellow-700:hover {\n    --text-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-yellow-800:hover {\n    --text-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-yellow-900:hover {\n    --text-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-green-100:hover {\n    --text-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-green-200:hover {\n    --text-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-green-300:hover {\n    --text-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-green-400:hover {\n    --text-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-green-500:hover {\n    --text-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-green-600:hover {\n    --text-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-green-700:hover {\n    --text-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-green-800:hover {\n    --text-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-green-900:hover {\n    --text-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-teal-100:hover {\n    --text-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-teal-200:hover {\n    --text-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-teal-300:hover {\n    --text-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-teal-400:hover {\n    --text-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-teal-500:hover {\n    --text-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-teal-600:hover {\n    --text-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-teal-700:hover {\n    --text-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-teal-800:hover {\n    --text-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-teal-900:hover {\n    --text-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-blue-100:hover {\n    --text-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-blue-200:hover {\n    --text-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-blue-300:hover {\n    --text-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-blue-400:hover {\n    --text-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-blue-500:hover {\n    --text-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-blue-600:hover {\n    --text-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-blue-700:hover {\n    --text-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-blue-800:hover {\n    --text-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-blue-900:hover {\n    --text-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-indigo-100:hover {\n    --text-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-indigo-200:hover {\n    --text-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-indigo-300:hover {\n    --text-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-indigo-400:hover {\n    --text-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-indigo-500:hover {\n    --text-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-indigo-600:hover {\n    --text-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-indigo-700:hover {\n    --text-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-indigo-800:hover {\n    --text-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-indigo-900:hover {\n    --text-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-purple-100:hover {\n    --text-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-purple-200:hover {\n    --text-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-purple-300:hover {\n    --text-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-purple-400:hover {\n    --text-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-purple-500:hover {\n    --text-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-purple-600:hover {\n    --text-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-purple-700:hover {\n    --text-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-purple-800:hover {\n    --text-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-purple-900:hover {\n    --text-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-pink-100:hover {\n    --text-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-pink-200:hover {\n    --text-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-pink-300:hover {\n    --text-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-pink-400:hover {\n    --text-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-pink-500:hover {\n    --text-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-pink-600:hover {\n    --text-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-pink-700:hover {\n    --text-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-pink-800:hover {\n    --text-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-pink-900:hover {\n    --text-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-grayscale-80:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-grayscale-100:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-grayscale-200:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-grayscale-300:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-grayscale-400:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-grayscale-500:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-grayscale-600:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-grayscale-700:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-grayscale-800:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-grayscale-840:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-grayscale-870:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-grayscale-900:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-grayscale-930:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-primary:hover {\n    --text-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--text-opacity));\n  }\n\n  .lg\\:hover\\:text-background-main:hover {\n    color: var(--main-background);\n  }\n\n  .lg\\:hover\\:text-background-secondary:hover {\n    color: var(--secondary-background);\n  }\n\n  .lg\\:hover\\:text-foreground:hover {\n    color: var(--foreground);\n  }\n\n  .lg\\:hover\\:text-panels-bg:hover {\n    color: var(--panels-background);\n  }\n\n  .lg\\:focus\\:text-transparent:focus {\n    color: transparent;\n  }\n\n  .lg\\:focus\\:text-current:focus {\n    color: currentColor;\n  }\n\n  .lg\\:focus\\:text-black:focus {\n    --text-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-white:focus {\n    --text-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-gray-100:focus {\n    --text-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-gray-200:focus {\n    --text-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-gray-300:focus {\n    --text-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-gray-400:focus {\n    --text-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-gray-500:focus {\n    --text-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-gray-600:focus {\n    --text-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-gray-700:focus {\n    --text-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-gray-800:focus {\n    --text-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-gray-900:focus {\n    --text-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-red-100:focus {\n    --text-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-red-200:focus {\n    --text-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-red-300:focus {\n    --text-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-red-400:focus {\n    --text-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-red-500:focus {\n    --text-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-red-600:focus {\n    --text-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-red-700:focus {\n    --text-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-red-800:focus {\n    --text-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-red-900:focus {\n    --text-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-orange-100:focus {\n    --text-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-orange-200:focus {\n    --text-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-orange-300:focus {\n    --text-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-orange-400:focus {\n    --text-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-orange-500:focus {\n    --text-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-orange-600:focus {\n    --text-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-orange-700:focus {\n    --text-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-orange-800:focus {\n    --text-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-orange-900:focus {\n    --text-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-yellow-100:focus {\n    --text-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-yellow-200:focus {\n    --text-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-yellow-300:focus {\n    --text-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-yellow-400:focus {\n    --text-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-yellow-500:focus {\n    --text-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-yellow-600:focus {\n    --text-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-yellow-700:focus {\n    --text-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-yellow-800:focus {\n    --text-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-yellow-900:focus {\n    --text-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-green-100:focus {\n    --text-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-green-200:focus {\n    --text-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-green-300:focus {\n    --text-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-green-400:focus {\n    --text-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-green-500:focus {\n    --text-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-green-600:focus {\n    --text-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-green-700:focus {\n    --text-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-green-800:focus {\n    --text-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-green-900:focus {\n    --text-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-teal-100:focus {\n    --text-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-teal-200:focus {\n    --text-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-teal-300:focus {\n    --text-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-teal-400:focus {\n    --text-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-teal-500:focus {\n    --text-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-teal-600:focus {\n    --text-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-teal-700:focus {\n    --text-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-teal-800:focus {\n    --text-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-teal-900:focus {\n    --text-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-blue-100:focus {\n    --text-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-blue-200:focus {\n    --text-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-blue-300:focus {\n    --text-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-blue-400:focus {\n    --text-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-blue-500:focus {\n    --text-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-blue-600:focus {\n    --text-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-blue-700:focus {\n    --text-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-blue-800:focus {\n    --text-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-blue-900:focus {\n    --text-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-indigo-100:focus {\n    --text-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-indigo-200:focus {\n    --text-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-indigo-300:focus {\n    --text-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-indigo-400:focus {\n    --text-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-indigo-500:focus {\n    --text-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-indigo-600:focus {\n    --text-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-indigo-700:focus {\n    --text-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-indigo-800:focus {\n    --text-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-indigo-900:focus {\n    --text-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-purple-100:focus {\n    --text-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-purple-200:focus {\n    --text-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-purple-300:focus {\n    --text-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-purple-400:focus {\n    --text-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-purple-500:focus {\n    --text-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-purple-600:focus {\n    --text-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-purple-700:focus {\n    --text-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-purple-800:focus {\n    --text-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-purple-900:focus {\n    --text-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-pink-100:focus {\n    --text-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-pink-200:focus {\n    --text-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-pink-300:focus {\n    --text-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-pink-400:focus {\n    --text-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-pink-500:focus {\n    --text-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-pink-600:focus {\n    --text-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-pink-700:focus {\n    --text-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-pink-800:focus {\n    --text-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-pink-900:focus {\n    --text-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-grayscale-80:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-grayscale-100:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-grayscale-200:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-grayscale-300:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-grayscale-400:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-grayscale-500:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-grayscale-600:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-grayscale-700:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-grayscale-800:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-grayscale-840:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-grayscale-870:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-grayscale-900:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-grayscale-930:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-primary:focus {\n    --text-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--text-opacity));\n  }\n\n  .lg\\:focus\\:text-background-main:focus {\n    color: var(--main-background);\n  }\n\n  .lg\\:focus\\:text-background-secondary:focus {\n    color: var(--secondary-background);\n  }\n\n  .lg\\:focus\\:text-foreground:focus {\n    color: var(--foreground);\n  }\n\n  .lg\\:focus\\:text-panels-bg:focus {\n    color: var(--panels-background);\n  }\n\n  .group:hover .lg\\:group-hover\\:text-transparent {\n    color: transparent;\n  }\n\n  .group:hover .lg\\:group-hover\\:text-current {\n    color: currentColor;\n  }\n\n  .group:hover .lg\\:group-hover\\:text-black {\n    --text-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-white {\n    --text-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-gray-100 {\n    --text-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-gray-200 {\n    --text-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-gray-300 {\n    --text-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-gray-400 {\n    --text-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-gray-500 {\n    --text-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-gray-600 {\n    --text-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-gray-700 {\n    --text-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-gray-800 {\n    --text-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-gray-900 {\n    --text-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-red-100 {\n    --text-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-red-200 {\n    --text-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-red-300 {\n    --text-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-red-400 {\n    --text-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-red-500 {\n    --text-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-red-600 {\n    --text-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-red-700 {\n    --text-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-red-800 {\n    --text-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-red-900 {\n    --text-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-orange-100 {\n    --text-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-orange-200 {\n    --text-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-orange-300 {\n    --text-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-orange-400 {\n    --text-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-orange-500 {\n    --text-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-orange-600 {\n    --text-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-orange-700 {\n    --text-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-orange-800 {\n    --text-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-orange-900 {\n    --text-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-yellow-100 {\n    --text-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-yellow-200 {\n    --text-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-yellow-300 {\n    --text-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-yellow-400 {\n    --text-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-yellow-500 {\n    --text-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-yellow-600 {\n    --text-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-yellow-700 {\n    --text-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-yellow-800 {\n    --text-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-yellow-900 {\n    --text-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-green-100 {\n    --text-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-green-200 {\n    --text-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-green-300 {\n    --text-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-green-400 {\n    --text-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-green-500 {\n    --text-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-green-600 {\n    --text-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-green-700 {\n    --text-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-green-800 {\n    --text-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-green-900 {\n    --text-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-teal-100 {\n    --text-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-teal-200 {\n    --text-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-teal-300 {\n    --text-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-teal-400 {\n    --text-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-teal-500 {\n    --text-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-teal-600 {\n    --text-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-teal-700 {\n    --text-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-teal-800 {\n    --text-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-teal-900 {\n    --text-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-blue-100 {\n    --text-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-blue-200 {\n    --text-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-blue-300 {\n    --text-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-blue-400 {\n    --text-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-blue-500 {\n    --text-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-blue-600 {\n    --text-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-blue-700 {\n    --text-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-blue-800 {\n    --text-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-blue-900 {\n    --text-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-indigo-100 {\n    --text-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-indigo-200 {\n    --text-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-indigo-300 {\n    --text-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-indigo-400 {\n    --text-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-indigo-500 {\n    --text-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-indigo-600 {\n    --text-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-indigo-700 {\n    --text-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-indigo-800 {\n    --text-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-indigo-900 {\n    --text-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-purple-100 {\n    --text-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-purple-200 {\n    --text-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-purple-300 {\n    --text-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-purple-400 {\n    --text-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-purple-500 {\n    --text-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-purple-600 {\n    --text-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-purple-700 {\n    --text-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-purple-800 {\n    --text-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-purple-900 {\n    --text-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-pink-100 {\n    --text-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-pink-200 {\n    --text-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-pink-300 {\n    --text-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-pink-400 {\n    --text-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-pink-500 {\n    --text-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-pink-600 {\n    --text-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-pink-700 {\n    --text-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-pink-800 {\n    --text-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-pink-900 {\n    --text-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-grayscale-80 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-grayscale-100 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-grayscale-200 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-grayscale-300 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-grayscale-400 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-grayscale-500 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-grayscale-600 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-grayscale-700 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-grayscale-800 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-grayscale-840 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-grayscale-870 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-grayscale-900 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-grayscale-930 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-primary {\n    --text-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--text-opacity));\n  }\n\n  .group:hover .lg\\:group-hover\\:text-background-main {\n    color: var(--main-background);\n  }\n\n  .group:hover .lg\\:group-hover\\:text-background-secondary {\n    color: var(--secondary-background);\n  }\n\n  .group:hover .lg\\:group-hover\\:text-foreground {\n    color: var(--foreground);\n  }\n\n  .group:hover .lg\\:group-hover\\:text-panels-bg {\n    color: var(--panels-background);\n  }\n\n  .lg\\:text-opacity-0 {\n    --text-opacity: 0;\n  }\n\n  .lg\\:text-opacity-25 {\n    --text-opacity: 0.25;\n  }\n\n  .lg\\:text-opacity-50 {\n    --text-opacity: 0.5;\n  }\n\n  .lg\\:text-opacity-75 {\n    --text-opacity: 0.75;\n  }\n\n  .lg\\:text-opacity-100 {\n    --text-opacity: 1;\n  }\n\n  .lg\\:hover\\:text-opacity-0:hover {\n    --text-opacity: 0;\n  }\n\n  .lg\\:hover\\:text-opacity-25:hover {\n    --text-opacity: 0.25;\n  }\n\n  .lg\\:hover\\:text-opacity-50:hover {\n    --text-opacity: 0.5;\n  }\n\n  .lg\\:hover\\:text-opacity-75:hover {\n    --text-opacity: 0.75;\n  }\n\n  .lg\\:hover\\:text-opacity-100:hover {\n    --text-opacity: 1;\n  }\n\n  .lg\\:focus\\:text-opacity-0:focus {\n    --text-opacity: 0;\n  }\n\n  .lg\\:focus\\:text-opacity-25:focus {\n    --text-opacity: 0.25;\n  }\n\n  .lg\\:focus\\:text-opacity-50:focus {\n    --text-opacity: 0.5;\n  }\n\n  .lg\\:focus\\:text-opacity-75:focus {\n    --text-opacity: 0.75;\n  }\n\n  .lg\\:focus\\:text-opacity-100:focus {\n    --text-opacity: 1;\n  }\n\n  .lg\\:italic {\n    font-style: italic;\n  }\n\n  .lg\\:not-italic {\n    font-style: normal;\n  }\n\n  .lg\\:uppercase {\n    text-transform: uppercase;\n  }\n\n  .lg\\:lowercase {\n    text-transform: lowercase;\n  }\n\n  .lg\\:capitalize {\n    text-transform: capitalize;\n  }\n\n  .lg\\:normal-case {\n    text-transform: none;\n  }\n\n  .lg\\:underline {\n    text-decoration: underline;\n  }\n\n  .lg\\:line-through {\n    text-decoration: line-through;\n  }\n\n  .lg\\:no-underline {\n    text-decoration: none;\n  }\n\n  .lg\\:hover\\:underline:hover {\n    text-decoration: underline;\n  }\n\n  .lg\\:hover\\:line-through:hover {\n    text-decoration: line-through;\n  }\n\n  .lg\\:hover\\:no-underline:hover {\n    text-decoration: none;\n  }\n\n  .lg\\:focus\\:underline:focus {\n    text-decoration: underline;\n  }\n\n  .lg\\:focus\\:line-through:focus {\n    text-decoration: line-through;\n  }\n\n  .lg\\:focus\\:no-underline:focus {\n    text-decoration: none;\n  }\n\n  .lg\\:antialiased {\n    -webkit-font-smoothing: antialiased;\n    -moz-osx-font-smoothing: grayscale;\n  }\n\n  .lg\\:subpixel-antialiased {\n    -webkit-font-smoothing: auto;\n    -moz-osx-font-smoothing: auto;\n  }\n\n  .lg\\:ordinal, .lg\\:slashed-zero, .lg\\:lining-nums, .lg\\:oldstyle-nums, .lg\\:proportional-nums, .lg\\:tabular-nums, .lg\\:diagonal-fractions, .lg\\:stacked-fractions {\n    --font-variant-numeric-ordinal: var(--tailwind-empty,/*!*/ /*!*/);\n    --font-variant-numeric-slashed-zero: var(--tailwind-empty,/*!*/ /*!*/);\n    --font-variant-numeric-figure: var(--tailwind-empty,/*!*/ /*!*/);\n    --font-variant-numeric-spacing: var(--tailwind-empty,/*!*/ /*!*/);\n    --font-variant-numeric-fraction: var(--tailwind-empty,/*!*/ /*!*/);\n    font-variant-numeric: var(--font-variant-numeric-ordinal) var(--font-variant-numeric-slashed-zero) var(--font-variant-numeric-figure) var(--font-variant-numeric-spacing) var(--font-variant-numeric-fraction);\n  }\n\n  .lg\\:normal-nums {\n    font-variant-numeric: normal;\n  }\n\n  .lg\\:ordinal {\n    --font-variant-numeric-ordinal: ordinal;\n  }\n\n  .lg\\:slashed-zero {\n    --font-variant-numeric-slashed-zero: slashed-zero;\n  }\n\n  .lg\\:lining-nums {\n    --font-variant-numeric-figure: lining-nums;\n  }\n\n  .lg\\:oldstyle-nums {\n    --font-variant-numeric-figure: oldstyle-nums;\n  }\n\n  .lg\\:proportional-nums {\n    --font-variant-numeric-spacing: proportional-nums;\n  }\n\n  .lg\\:tabular-nums {\n    --font-variant-numeric-spacing: tabular-nums;\n  }\n\n  .lg\\:diagonal-fractions {\n    --font-variant-numeric-fraction: diagonal-fractions;\n  }\n\n  .lg\\:stacked-fractions {\n    --font-variant-numeric-fraction: stacked-fractions;\n  }\n\n  .lg\\:tracking-tighter {\n    letter-spacing: -0.05em;\n  }\n\n  .lg\\:tracking-tight {\n    letter-spacing: -0.025em;\n  }\n\n  .lg\\:tracking-normal {\n    letter-spacing: 0;\n  }\n\n  .lg\\:tracking-wide {\n    letter-spacing: 0.025em;\n  }\n\n  .lg\\:tracking-wider {\n    letter-spacing: 0.05em;\n  }\n\n  .lg\\:tracking-widest {\n    letter-spacing: 0.1em;\n  }\n\n  .lg\\:select-none {\n    -webkit-user-select: none;\n       -moz-user-select: none;\n        -ms-user-select: none;\n            user-select: none;\n  }\n\n  .lg\\:select-text {\n    -webkit-user-select: text;\n       -moz-user-select: text;\n        -ms-user-select: text;\n            user-select: text;\n  }\n\n  .lg\\:select-all {\n    -webkit-user-select: all;\n       -moz-user-select: all;\n        -ms-user-select: all;\n            user-select: all;\n  }\n\n  .lg\\:select-auto {\n    -webkit-user-select: auto;\n       -moz-user-select: auto;\n        -ms-user-select: auto;\n            user-select: auto;\n  }\n\n  .lg\\:align-baseline {\n    vertical-align: baseline;\n  }\n\n  .lg\\:align-top {\n    vertical-align: top;\n  }\n\n  .lg\\:align-middle {\n    vertical-align: middle;\n  }\n\n  .lg\\:align-bottom {\n    vertical-align: bottom;\n  }\n\n  .lg\\:align-text-top {\n    vertical-align: text-top;\n  }\n\n  .lg\\:align-text-bottom {\n    vertical-align: text-bottom;\n  }\n\n  .lg\\:visible {\n    visibility: visible;\n  }\n\n  .lg\\:invisible {\n    visibility: hidden;\n  }\n\n  .lg\\:whitespace-normal {\n    white-space: normal;\n  }\n\n  .lg\\:whitespace-no-wrap {\n    white-space: nowrap;\n  }\n\n  .lg\\:whitespace-pre {\n    white-space: pre;\n  }\n\n  .lg\\:whitespace-pre-line {\n    white-space: pre-line;\n  }\n\n  .lg\\:whitespace-pre-wrap {\n    white-space: pre-wrap;\n  }\n\n  .lg\\:break-normal {\n    word-wrap: normal;\n    overflow-wrap: normal;\n    word-break: normal;\n  }\n\n  .lg\\:break-words {\n    word-wrap: break-word;\n    overflow-wrap: break-word;\n  }\n\n  .lg\\:break-all {\n    word-break: break-all;\n  }\n\n  .lg\\:truncate {\n    overflow: hidden;\n    text-overflow: ellipsis;\n    white-space: nowrap;\n  }\n\n  .lg\\:w-0 {\n    width: 0;\n  }\n\n  .lg\\:w-1 {\n    width: 0.25rem;\n  }\n\n  .lg\\:w-2 {\n    width: 0.5rem;\n  }\n\n  .lg\\:w-3 {\n    width: 0.75rem;\n  }\n\n  .lg\\:w-4 {\n    width: 1rem;\n  }\n\n  .lg\\:w-5 {\n    width: 1.25rem;\n  }\n\n  .lg\\:w-6 {\n    width: 1.5rem;\n  }\n\n  .lg\\:w-8 {\n    width: 2rem;\n  }\n\n  .lg\\:w-10 {\n    width: 2.5rem;\n  }\n\n  .lg\\:w-12 {\n    width: 3rem;\n  }\n\n  .lg\\:w-16 {\n    width: 4rem;\n  }\n\n  .lg\\:w-20 {\n    width: 5rem;\n  }\n\n  .lg\\:w-24 {\n    width: 6rem;\n  }\n\n  .lg\\:w-32 {\n    width: 8rem;\n  }\n\n  .lg\\:w-40 {\n    width: 10rem;\n  }\n\n  .lg\\:w-48 {\n    width: 12rem;\n  }\n\n  .lg\\:w-56 {\n    width: 14rem;\n  }\n\n  .lg\\:w-64 {\n    width: 16rem;\n  }\n\n  .lg\\:w-auto {\n    width: auto;\n  }\n\n  .lg\\:w-px {\n    width: 1px;\n  }\n\n  .lg\\:w-1\\/2 {\n    width: 50%;\n  }\n\n  .lg\\:w-1\\/3 {\n    width: 33.333333%;\n  }\n\n  .lg\\:w-2\\/3 {\n    width: 66.666667%;\n  }\n\n  .lg\\:w-1\\/4 {\n    width: 25%;\n  }\n\n  .lg\\:w-2\\/4 {\n    width: 50%;\n  }\n\n  .lg\\:w-3\\/4 {\n    width: 75%;\n  }\n\n  .lg\\:w-1\\/5 {\n    width: 20%;\n  }\n\n  .lg\\:w-2\\/5 {\n    width: 40%;\n  }\n\n  .lg\\:w-3\\/5 {\n    width: 60%;\n  }\n\n  .lg\\:w-4\\/5 {\n    width: 80%;\n  }\n\n  .lg\\:w-1\\/6 {\n    width: 16.666667%;\n  }\n\n  .lg\\:w-2\\/6 {\n    width: 33.333333%;\n  }\n\n  .lg\\:w-3\\/6 {\n    width: 50%;\n  }\n\n  .lg\\:w-4\\/6 {\n    width: 66.666667%;\n  }\n\n  .lg\\:w-5\\/6 {\n    width: 83.333333%;\n  }\n\n  .lg\\:w-1\\/12 {\n    width: 8.333333%;\n  }\n\n  .lg\\:w-2\\/12 {\n    width: 16.666667%;\n  }\n\n  .lg\\:w-3\\/12 {\n    width: 25%;\n  }\n\n  .lg\\:w-4\\/12 {\n    width: 33.333333%;\n  }\n\n  .lg\\:w-5\\/12 {\n    width: 41.666667%;\n  }\n\n  .lg\\:w-6\\/12 {\n    width: 50%;\n  }\n\n  .lg\\:w-7\\/12 {\n    width: 58.333333%;\n  }\n\n  .lg\\:w-8\\/12 {\n    width: 66.666667%;\n  }\n\n  .lg\\:w-9\\/12 {\n    width: 75%;\n  }\n\n  .lg\\:w-10\\/12 {\n    width: 83.333333%;\n  }\n\n  .lg\\:w-11\\/12 {\n    width: 91.666667%;\n  }\n\n  .lg\\:w-full {\n    width: 100%;\n  }\n\n  .lg\\:w-screen {\n    width: 100vw;\n  }\n\n  .lg\\:z-0 {\n    z-index: 0;\n  }\n\n  .lg\\:z-10 {\n    z-index: 10;\n  }\n\n  .lg\\:z-20 {\n    z-index: 20;\n  }\n\n  .lg\\:z-30 {\n    z-index: 30;\n  }\n\n  .lg\\:z-40 {\n    z-index: 40;\n  }\n\n  .lg\\:z-50 {\n    z-index: 50;\n  }\n\n  .lg\\:z-auto {\n    z-index: auto;\n  }\n\n  .lg\\:gap-0 {\n    grid-gap: 0;\n    gap: 0;\n  }\n\n  .lg\\:gap-1 {\n    grid-gap: 0.25rem;\n    gap: 0.25rem;\n  }\n\n  .lg\\:gap-2 {\n    grid-gap: 0.5rem;\n    gap: 0.5rem;\n  }\n\n  .lg\\:gap-3 {\n    grid-gap: 0.75rem;\n    gap: 0.75rem;\n  }\n\n  .lg\\:gap-4 {\n    grid-gap: 1rem;\n    gap: 1rem;\n  }\n\n  .lg\\:gap-5 {\n    grid-gap: 1.25rem;\n    gap: 1.25rem;\n  }\n\n  .lg\\:gap-6 {\n    grid-gap: 1.5rem;\n    gap: 1.5rem;\n  }\n\n  .lg\\:gap-8 {\n    grid-gap: 2rem;\n    gap: 2rem;\n  }\n\n  .lg\\:gap-10 {\n    grid-gap: 2.5rem;\n    gap: 2.5rem;\n  }\n\n  .lg\\:gap-12 {\n    grid-gap: 3rem;\n    gap: 3rem;\n  }\n\n  .lg\\:gap-16 {\n    grid-gap: 4rem;\n    gap: 4rem;\n  }\n\n  .lg\\:gap-20 {\n    grid-gap: 5rem;\n    gap: 5rem;\n  }\n\n  .lg\\:gap-24 {\n    grid-gap: 6rem;\n    gap: 6rem;\n  }\n\n  .lg\\:gap-32 {\n    grid-gap: 8rem;\n    gap: 8rem;\n  }\n\n  .lg\\:gap-40 {\n    grid-gap: 10rem;\n    gap: 10rem;\n  }\n\n  .lg\\:gap-48 {\n    grid-gap: 12rem;\n    gap: 12rem;\n  }\n\n  .lg\\:gap-56 {\n    grid-gap: 14rem;\n    gap: 14rem;\n  }\n\n  .lg\\:gap-64 {\n    grid-gap: 16rem;\n    gap: 16rem;\n  }\n\n  .lg\\:gap-px {\n    grid-gap: 1px;\n    gap: 1px;\n  }\n\n  .lg\\:gap-x-0 {\n    grid-column-gap: 0;\n    -moz-column-gap: 0;\n         column-gap: 0;\n  }\n\n  .lg\\:gap-x-1 {\n    grid-column-gap: 0.25rem;\n    -moz-column-gap: 0.25rem;\n         column-gap: 0.25rem;\n  }\n\n  .lg\\:gap-x-2 {\n    grid-column-gap: 0.5rem;\n    -moz-column-gap: 0.5rem;\n         column-gap: 0.5rem;\n  }\n\n  .lg\\:gap-x-3 {\n    grid-column-gap: 0.75rem;\n    -moz-column-gap: 0.75rem;\n         column-gap: 0.75rem;\n  }\n\n  .lg\\:gap-x-4 {\n    grid-column-gap: 1rem;\n    -moz-column-gap: 1rem;\n         column-gap: 1rem;\n  }\n\n  .lg\\:gap-x-5 {\n    grid-column-gap: 1.25rem;\n    -moz-column-gap: 1.25rem;\n         column-gap: 1.25rem;\n  }\n\n  .lg\\:gap-x-6 {\n    grid-column-gap: 1.5rem;\n    -moz-column-gap: 1.5rem;\n         column-gap: 1.5rem;\n  }\n\n  .lg\\:gap-x-8 {\n    grid-column-gap: 2rem;\n    -moz-column-gap: 2rem;\n         column-gap: 2rem;\n  }\n\n  .lg\\:gap-x-10 {\n    grid-column-gap: 2.5rem;\n    -moz-column-gap: 2.5rem;\n         column-gap: 2.5rem;\n  }\n\n  .lg\\:gap-x-12 {\n    grid-column-gap: 3rem;\n    -moz-column-gap: 3rem;\n         column-gap: 3rem;\n  }\n\n  .lg\\:gap-x-16 {\n    grid-column-gap: 4rem;\n    -moz-column-gap: 4rem;\n         column-gap: 4rem;\n  }\n\n  .lg\\:gap-x-20 {\n    grid-column-gap: 5rem;\n    -moz-column-gap: 5rem;\n         column-gap: 5rem;\n  }\n\n  .lg\\:gap-x-24 {\n    grid-column-gap: 6rem;\n    -moz-column-gap: 6rem;\n         column-gap: 6rem;\n  }\n\n  .lg\\:gap-x-32 {\n    grid-column-gap: 8rem;\n    -moz-column-gap: 8rem;\n         column-gap: 8rem;\n  }\n\n  .lg\\:gap-x-40 {\n    grid-column-gap: 10rem;\n    -moz-column-gap: 10rem;\n         column-gap: 10rem;\n  }\n\n  .lg\\:gap-x-48 {\n    grid-column-gap: 12rem;\n    -moz-column-gap: 12rem;\n         column-gap: 12rem;\n  }\n\n  .lg\\:gap-x-56 {\n    grid-column-gap: 14rem;\n    -moz-column-gap: 14rem;\n         column-gap: 14rem;\n  }\n\n  .lg\\:gap-x-64 {\n    grid-column-gap: 16rem;\n    -moz-column-gap: 16rem;\n         column-gap: 16rem;\n  }\n\n  .lg\\:gap-x-px {\n    grid-column-gap: 1px;\n    -moz-column-gap: 1px;\n         column-gap: 1px;\n  }\n\n  .lg\\:gap-y-0 {\n    grid-row-gap: 0;\n    row-gap: 0;\n  }\n\n  .lg\\:gap-y-1 {\n    grid-row-gap: 0.25rem;\n    row-gap: 0.25rem;\n  }\n\n  .lg\\:gap-y-2 {\n    grid-row-gap: 0.5rem;\n    row-gap: 0.5rem;\n  }\n\n  .lg\\:gap-y-3 {\n    grid-row-gap: 0.75rem;\n    row-gap: 0.75rem;\n  }\n\n  .lg\\:gap-y-4 {\n    grid-row-gap: 1rem;\n    row-gap: 1rem;\n  }\n\n  .lg\\:gap-y-5 {\n    grid-row-gap: 1.25rem;\n    row-gap: 1.25rem;\n  }\n\n  .lg\\:gap-y-6 {\n    grid-row-gap: 1.5rem;\n    row-gap: 1.5rem;\n  }\n\n  .lg\\:gap-y-8 {\n    grid-row-gap: 2rem;\n    row-gap: 2rem;\n  }\n\n  .lg\\:gap-y-10 {\n    grid-row-gap: 2.5rem;\n    row-gap: 2.5rem;\n  }\n\n  .lg\\:gap-y-12 {\n    grid-row-gap: 3rem;\n    row-gap: 3rem;\n  }\n\n  .lg\\:gap-y-16 {\n    grid-row-gap: 4rem;\n    row-gap: 4rem;\n  }\n\n  .lg\\:gap-y-20 {\n    grid-row-gap: 5rem;\n    row-gap: 5rem;\n  }\n\n  .lg\\:gap-y-24 {\n    grid-row-gap: 6rem;\n    row-gap: 6rem;\n  }\n\n  .lg\\:gap-y-32 {\n    grid-row-gap: 8rem;\n    row-gap: 8rem;\n  }\n\n  .lg\\:gap-y-40 {\n    grid-row-gap: 10rem;\n    row-gap: 10rem;\n  }\n\n  .lg\\:gap-y-48 {\n    grid-row-gap: 12rem;\n    row-gap: 12rem;\n  }\n\n  .lg\\:gap-y-56 {\n    grid-row-gap: 14rem;\n    row-gap: 14rem;\n  }\n\n  .lg\\:gap-y-64 {\n    grid-row-gap: 16rem;\n    row-gap: 16rem;\n  }\n\n  .lg\\:gap-y-px {\n    grid-row-gap: 1px;\n    row-gap: 1px;\n  }\n\n  .lg\\:grid-flow-row {\n    grid-auto-flow: row;\n  }\n\n  .lg\\:grid-flow-col {\n    grid-auto-flow: column;\n  }\n\n  .lg\\:grid-flow-row-dense {\n    grid-auto-flow: row dense;\n  }\n\n  .lg\\:grid-flow-col-dense {\n    grid-auto-flow: column dense;\n  }\n\n  .lg\\:grid-cols-1 {\n    grid-template-columns: repeat(1, minmax(0, 1fr));\n  }\n\n  .lg\\:grid-cols-2 {\n    grid-template-columns: repeat(2, minmax(0, 1fr));\n  }\n\n  .lg\\:grid-cols-3 {\n    grid-template-columns: repeat(3, minmax(0, 1fr));\n  }\n\n  .lg\\:grid-cols-4 {\n    grid-template-columns: repeat(4, minmax(0, 1fr));\n  }\n\n  .lg\\:grid-cols-5 {\n    grid-template-columns: repeat(5, minmax(0, 1fr));\n  }\n\n  .lg\\:grid-cols-6 {\n    grid-template-columns: repeat(6, minmax(0, 1fr));\n  }\n\n  .lg\\:grid-cols-7 {\n    grid-template-columns: repeat(7, minmax(0, 1fr));\n  }\n\n  .lg\\:grid-cols-8 {\n    grid-template-columns: repeat(8, minmax(0, 1fr));\n  }\n\n  .lg\\:grid-cols-9 {\n    grid-template-columns: repeat(9, minmax(0, 1fr));\n  }\n\n  .lg\\:grid-cols-10 {\n    grid-template-columns: repeat(10, minmax(0, 1fr));\n  }\n\n  .lg\\:grid-cols-11 {\n    grid-template-columns: repeat(11, minmax(0, 1fr));\n  }\n\n  .lg\\:grid-cols-12 {\n    grid-template-columns: repeat(12, minmax(0, 1fr));\n  }\n\n  .lg\\:grid-cols-none {\n    grid-template-columns: none;\n  }\n\n  .lg\\:auto-cols-auto {\n    grid-auto-columns: auto;\n  }\n\n  .lg\\:auto-cols-min {\n    grid-auto-columns: -webkit-min-content;\n    grid-auto-columns: min-content;\n  }\n\n  .lg\\:auto-cols-max {\n    grid-auto-columns: -webkit-max-content;\n    grid-auto-columns: max-content;\n  }\n\n  .lg\\:auto-cols-fr {\n    grid-auto-columns: minmax(0, 1fr);\n  }\n\n  .lg\\:col-auto {\n    grid-column: auto;\n  }\n\n  .lg\\:col-span-1 {\n    grid-column: span 1 / span 1;\n  }\n\n  .lg\\:col-span-2 {\n    grid-column: span 2 / span 2;\n  }\n\n  .lg\\:col-span-3 {\n    grid-column: span 3 / span 3;\n  }\n\n  .lg\\:col-span-4 {\n    grid-column: span 4 / span 4;\n  }\n\n  .lg\\:col-span-5 {\n    grid-column: span 5 / span 5;\n  }\n\n  .lg\\:col-span-6 {\n    grid-column: span 6 / span 6;\n  }\n\n  .lg\\:col-span-7 {\n    grid-column: span 7 / span 7;\n  }\n\n  .lg\\:col-span-8 {\n    grid-column: span 8 / span 8;\n  }\n\n  .lg\\:col-span-9 {\n    grid-column: span 9 / span 9;\n  }\n\n  .lg\\:col-span-10 {\n    grid-column: span 10 / span 10;\n  }\n\n  .lg\\:col-span-11 {\n    grid-column: span 11 / span 11;\n  }\n\n  .lg\\:col-span-12 {\n    grid-column: span 12 / span 12;\n  }\n\n  .lg\\:col-span-full {\n    grid-column: 1 / -1;\n  }\n\n  .lg\\:col-start-1 {\n    grid-column-start: 1;\n  }\n\n  .lg\\:col-start-2 {\n    grid-column-start: 2;\n  }\n\n  .lg\\:col-start-3 {\n    grid-column-start: 3;\n  }\n\n  .lg\\:col-start-4 {\n    grid-column-start: 4;\n  }\n\n  .lg\\:col-start-5 {\n    grid-column-start: 5;\n  }\n\n  .lg\\:col-start-6 {\n    grid-column-start: 6;\n  }\n\n  .lg\\:col-start-7 {\n    grid-column-start: 7;\n  }\n\n  .lg\\:col-start-8 {\n    grid-column-start: 8;\n  }\n\n  .lg\\:col-start-9 {\n    grid-column-start: 9;\n  }\n\n  .lg\\:col-start-10 {\n    grid-column-start: 10;\n  }\n\n  .lg\\:col-start-11 {\n    grid-column-start: 11;\n  }\n\n  .lg\\:col-start-12 {\n    grid-column-start: 12;\n  }\n\n  .lg\\:col-start-13 {\n    grid-column-start: 13;\n  }\n\n  .lg\\:col-start-auto {\n    grid-column-start: auto;\n  }\n\n  .lg\\:col-end-1 {\n    grid-column-end: 1;\n  }\n\n  .lg\\:col-end-2 {\n    grid-column-end: 2;\n  }\n\n  .lg\\:col-end-3 {\n    grid-column-end: 3;\n  }\n\n  .lg\\:col-end-4 {\n    grid-column-end: 4;\n  }\n\n  .lg\\:col-end-5 {\n    grid-column-end: 5;\n  }\n\n  .lg\\:col-end-6 {\n    grid-column-end: 6;\n  }\n\n  .lg\\:col-end-7 {\n    grid-column-end: 7;\n  }\n\n  .lg\\:col-end-8 {\n    grid-column-end: 8;\n  }\n\n  .lg\\:col-end-9 {\n    grid-column-end: 9;\n  }\n\n  .lg\\:col-end-10 {\n    grid-column-end: 10;\n  }\n\n  .lg\\:col-end-11 {\n    grid-column-end: 11;\n  }\n\n  .lg\\:col-end-12 {\n    grid-column-end: 12;\n  }\n\n  .lg\\:col-end-13 {\n    grid-column-end: 13;\n  }\n\n  .lg\\:col-end-auto {\n    grid-column-end: auto;\n  }\n\n  .lg\\:grid-rows-1 {\n    grid-template-rows: repeat(1, minmax(0, 1fr));\n  }\n\n  .lg\\:grid-rows-2 {\n    grid-template-rows: repeat(2, minmax(0, 1fr));\n  }\n\n  .lg\\:grid-rows-3 {\n    grid-template-rows: repeat(3, minmax(0, 1fr));\n  }\n\n  .lg\\:grid-rows-4 {\n    grid-template-rows: repeat(4, minmax(0, 1fr));\n  }\n\n  .lg\\:grid-rows-5 {\n    grid-template-rows: repeat(5, minmax(0, 1fr));\n  }\n\n  .lg\\:grid-rows-6 {\n    grid-template-rows: repeat(6, minmax(0, 1fr));\n  }\n\n  .lg\\:grid-rows-none {\n    grid-template-rows: none;\n  }\n\n  .lg\\:auto-rows-auto {\n    grid-auto-rows: auto;\n  }\n\n  .lg\\:auto-rows-min {\n    grid-auto-rows: -webkit-min-content;\n    grid-auto-rows: min-content;\n  }\n\n  .lg\\:auto-rows-max {\n    grid-auto-rows: -webkit-max-content;\n    grid-auto-rows: max-content;\n  }\n\n  .lg\\:auto-rows-fr {\n    grid-auto-rows: minmax(0, 1fr);\n  }\n\n  .lg\\:row-auto {\n    grid-row: auto;\n  }\n\n  .lg\\:row-span-1 {\n    grid-row: span 1 / span 1;\n  }\n\n  .lg\\:row-span-2 {\n    grid-row: span 2 / span 2;\n  }\n\n  .lg\\:row-span-3 {\n    grid-row: span 3 / span 3;\n  }\n\n  .lg\\:row-span-4 {\n    grid-row: span 4 / span 4;\n  }\n\n  .lg\\:row-span-5 {\n    grid-row: span 5 / span 5;\n  }\n\n  .lg\\:row-span-6 {\n    grid-row: span 6 / span 6;\n  }\n\n  .lg\\:row-span-full {\n    grid-row: 1 / -1;\n  }\n\n  .lg\\:row-start-1 {\n    grid-row-start: 1;\n  }\n\n  .lg\\:row-start-2 {\n    grid-row-start: 2;\n  }\n\n  .lg\\:row-start-3 {\n    grid-row-start: 3;\n  }\n\n  .lg\\:row-start-4 {\n    grid-row-start: 4;\n  }\n\n  .lg\\:row-start-5 {\n    grid-row-start: 5;\n  }\n\n  .lg\\:row-start-6 {\n    grid-row-start: 6;\n  }\n\n  .lg\\:row-start-7 {\n    grid-row-start: 7;\n  }\n\n  .lg\\:row-start-auto {\n    grid-row-start: auto;\n  }\n\n  .lg\\:row-end-1 {\n    grid-row-end: 1;\n  }\n\n  .lg\\:row-end-2 {\n    grid-row-end: 2;\n  }\n\n  .lg\\:row-end-3 {\n    grid-row-end: 3;\n  }\n\n  .lg\\:row-end-4 {\n    grid-row-end: 4;\n  }\n\n  .lg\\:row-end-5 {\n    grid-row-end: 5;\n  }\n\n  .lg\\:row-end-6 {\n    grid-row-end: 6;\n  }\n\n  .lg\\:row-end-7 {\n    grid-row-end: 7;\n  }\n\n  .lg\\:row-end-auto {\n    grid-row-end: auto;\n  }\n\n  .lg\\:transform {\n    --transform-translate-x: 0;\n    --transform-translate-y: 0;\n    --transform-rotate: 0;\n    --transform-skew-x: 0;\n    --transform-skew-y: 0;\n    --transform-scale-x: 1;\n    --transform-scale-y: 1;\n    transform: translateX(var(--transform-translate-x)) translateY(var(--transform-translate-y)) rotate(var(--transform-rotate)) skewX(var(--transform-skew-x)) skewY(var(--transform-skew-y)) scaleX(var(--transform-scale-x)) scaleY(var(--transform-scale-y));\n  }\n\n  .lg\\:transform-none {\n    transform: none;\n  }\n\n  .lg\\:origin-center {\n    transform-origin: center;\n  }\n\n  .lg\\:origin-top {\n    transform-origin: top;\n  }\n\n  .lg\\:origin-top-right {\n    transform-origin: top right;\n  }\n\n  .lg\\:origin-right {\n    transform-origin: right;\n  }\n\n  .lg\\:origin-bottom-right {\n    transform-origin: bottom right;\n  }\n\n  .lg\\:origin-bottom {\n    transform-origin: bottom;\n  }\n\n  .lg\\:origin-bottom-left {\n    transform-origin: bottom left;\n  }\n\n  .lg\\:origin-left {\n    transform-origin: left;\n  }\n\n  .lg\\:origin-top-left {\n    transform-origin: top left;\n  }\n\n  .lg\\:scale-0 {\n    --transform-scale-x: 0;\n    --transform-scale-y: 0;\n  }\n\n  .lg\\:scale-50 {\n    --transform-scale-x: .5;\n    --transform-scale-y: .5;\n  }\n\n  .lg\\:scale-75 {\n    --transform-scale-x: .75;\n    --transform-scale-y: .75;\n  }\n\n  .lg\\:scale-90 {\n    --transform-scale-x: .9;\n    --transform-scale-y: .9;\n  }\n\n  .lg\\:scale-95 {\n    --transform-scale-x: .95;\n    --transform-scale-y: .95;\n  }\n\n  .lg\\:scale-100 {\n    --transform-scale-x: 1;\n    --transform-scale-y: 1;\n  }\n\n  .lg\\:scale-105 {\n    --transform-scale-x: 1.05;\n    --transform-scale-y: 1.05;\n  }\n\n  .lg\\:scale-110 {\n    --transform-scale-x: 1.1;\n    --transform-scale-y: 1.1;\n  }\n\n  .lg\\:scale-125 {\n    --transform-scale-x: 1.25;\n    --transform-scale-y: 1.25;\n  }\n\n  .lg\\:scale-150 {\n    --transform-scale-x: 1.5;\n    --transform-scale-y: 1.5;\n  }\n\n  .lg\\:scale-x-0 {\n    --transform-scale-x: 0;\n  }\n\n  .lg\\:scale-x-50 {\n    --transform-scale-x: .5;\n  }\n\n  .lg\\:scale-x-75 {\n    --transform-scale-x: .75;\n  }\n\n  .lg\\:scale-x-90 {\n    --transform-scale-x: .9;\n  }\n\n  .lg\\:scale-x-95 {\n    --transform-scale-x: .95;\n  }\n\n  .lg\\:scale-x-100 {\n    --transform-scale-x: 1;\n  }\n\n  .lg\\:scale-x-105 {\n    --transform-scale-x: 1.05;\n  }\n\n  .lg\\:scale-x-110 {\n    --transform-scale-x: 1.1;\n  }\n\n  .lg\\:scale-x-125 {\n    --transform-scale-x: 1.25;\n  }\n\n  .lg\\:scale-x-150 {\n    --transform-scale-x: 1.5;\n  }\n\n  .lg\\:scale-y-0 {\n    --transform-scale-y: 0;\n  }\n\n  .lg\\:scale-y-50 {\n    --transform-scale-y: .5;\n  }\n\n  .lg\\:scale-y-75 {\n    --transform-scale-y: .75;\n  }\n\n  .lg\\:scale-y-90 {\n    --transform-scale-y: .9;\n  }\n\n  .lg\\:scale-y-95 {\n    --transform-scale-y: .95;\n  }\n\n  .lg\\:scale-y-100 {\n    --transform-scale-y: 1;\n  }\n\n  .lg\\:scale-y-105 {\n    --transform-scale-y: 1.05;\n  }\n\n  .lg\\:scale-y-110 {\n    --transform-scale-y: 1.1;\n  }\n\n  .lg\\:scale-y-125 {\n    --transform-scale-y: 1.25;\n  }\n\n  .lg\\:scale-y-150 {\n    --transform-scale-y: 1.5;\n  }\n\n  .lg\\:hover\\:scale-0:hover {\n    --transform-scale-x: 0;\n    --transform-scale-y: 0;\n  }\n\n  .lg\\:hover\\:scale-50:hover {\n    --transform-scale-x: .5;\n    --transform-scale-y: .5;\n  }\n\n  .lg\\:hover\\:scale-75:hover {\n    --transform-scale-x: .75;\n    --transform-scale-y: .75;\n  }\n\n  .lg\\:hover\\:scale-90:hover {\n    --transform-scale-x: .9;\n    --transform-scale-y: .9;\n  }\n\n  .lg\\:hover\\:scale-95:hover {\n    --transform-scale-x: .95;\n    --transform-scale-y: .95;\n  }\n\n  .lg\\:hover\\:scale-100:hover {\n    --transform-scale-x: 1;\n    --transform-scale-y: 1;\n  }\n\n  .lg\\:hover\\:scale-105:hover {\n    --transform-scale-x: 1.05;\n    --transform-scale-y: 1.05;\n  }\n\n  .lg\\:hover\\:scale-110:hover {\n    --transform-scale-x: 1.1;\n    --transform-scale-y: 1.1;\n  }\n\n  .lg\\:hover\\:scale-125:hover {\n    --transform-scale-x: 1.25;\n    --transform-scale-y: 1.25;\n  }\n\n  .lg\\:hover\\:scale-150:hover {\n    --transform-scale-x: 1.5;\n    --transform-scale-y: 1.5;\n  }\n\n  .lg\\:hover\\:scale-x-0:hover {\n    --transform-scale-x: 0;\n  }\n\n  .lg\\:hover\\:scale-x-50:hover {\n    --transform-scale-x: .5;\n  }\n\n  .lg\\:hover\\:scale-x-75:hover {\n    --transform-scale-x: .75;\n  }\n\n  .lg\\:hover\\:scale-x-90:hover {\n    --transform-scale-x: .9;\n  }\n\n  .lg\\:hover\\:scale-x-95:hover {\n    --transform-scale-x: .95;\n  }\n\n  .lg\\:hover\\:scale-x-100:hover {\n    --transform-scale-x: 1;\n  }\n\n  .lg\\:hover\\:scale-x-105:hover {\n    --transform-scale-x: 1.05;\n  }\n\n  .lg\\:hover\\:scale-x-110:hover {\n    --transform-scale-x: 1.1;\n  }\n\n  .lg\\:hover\\:scale-x-125:hover {\n    --transform-scale-x: 1.25;\n  }\n\n  .lg\\:hover\\:scale-x-150:hover {\n    --transform-scale-x: 1.5;\n  }\n\n  .lg\\:hover\\:scale-y-0:hover {\n    --transform-scale-y: 0;\n  }\n\n  .lg\\:hover\\:scale-y-50:hover {\n    --transform-scale-y: .5;\n  }\n\n  .lg\\:hover\\:scale-y-75:hover {\n    --transform-scale-y: .75;\n  }\n\n  .lg\\:hover\\:scale-y-90:hover {\n    --transform-scale-y: .9;\n  }\n\n  .lg\\:hover\\:scale-y-95:hover {\n    --transform-scale-y: .95;\n  }\n\n  .lg\\:hover\\:scale-y-100:hover {\n    --transform-scale-y: 1;\n  }\n\n  .lg\\:hover\\:scale-y-105:hover {\n    --transform-scale-y: 1.05;\n  }\n\n  .lg\\:hover\\:scale-y-110:hover {\n    --transform-scale-y: 1.1;\n  }\n\n  .lg\\:hover\\:scale-y-125:hover {\n    --transform-scale-y: 1.25;\n  }\n\n  .lg\\:hover\\:scale-y-150:hover {\n    --transform-scale-y: 1.5;\n  }\n\n  .lg\\:focus\\:scale-0:focus {\n    --transform-scale-x: 0;\n    --transform-scale-y: 0;\n  }\n\n  .lg\\:focus\\:scale-50:focus {\n    --transform-scale-x: .5;\n    --transform-scale-y: .5;\n  }\n\n  .lg\\:focus\\:scale-75:focus {\n    --transform-scale-x: .75;\n    --transform-scale-y: .75;\n  }\n\n  .lg\\:focus\\:scale-90:focus {\n    --transform-scale-x: .9;\n    --transform-scale-y: .9;\n  }\n\n  .lg\\:focus\\:scale-95:focus {\n    --transform-scale-x: .95;\n    --transform-scale-y: .95;\n  }\n\n  .lg\\:focus\\:scale-100:focus {\n    --transform-scale-x: 1;\n    --transform-scale-y: 1;\n  }\n\n  .lg\\:focus\\:scale-105:focus {\n    --transform-scale-x: 1.05;\n    --transform-scale-y: 1.05;\n  }\n\n  .lg\\:focus\\:scale-110:focus {\n    --transform-scale-x: 1.1;\n    --transform-scale-y: 1.1;\n  }\n\n  .lg\\:focus\\:scale-125:focus {\n    --transform-scale-x: 1.25;\n    --transform-scale-y: 1.25;\n  }\n\n  .lg\\:focus\\:scale-150:focus {\n    --transform-scale-x: 1.5;\n    --transform-scale-y: 1.5;\n  }\n\n  .lg\\:focus\\:scale-x-0:focus {\n    --transform-scale-x: 0;\n  }\n\n  .lg\\:focus\\:scale-x-50:focus {\n    --transform-scale-x: .5;\n  }\n\n  .lg\\:focus\\:scale-x-75:focus {\n    --transform-scale-x: .75;\n  }\n\n  .lg\\:focus\\:scale-x-90:focus {\n    --transform-scale-x: .9;\n  }\n\n  .lg\\:focus\\:scale-x-95:focus {\n    --transform-scale-x: .95;\n  }\n\n  .lg\\:focus\\:scale-x-100:focus {\n    --transform-scale-x: 1;\n  }\n\n  .lg\\:focus\\:scale-x-105:focus {\n    --transform-scale-x: 1.05;\n  }\n\n  .lg\\:focus\\:scale-x-110:focus {\n    --transform-scale-x: 1.1;\n  }\n\n  .lg\\:focus\\:scale-x-125:focus {\n    --transform-scale-x: 1.25;\n  }\n\n  .lg\\:focus\\:scale-x-150:focus {\n    --transform-scale-x: 1.5;\n  }\n\n  .lg\\:focus\\:scale-y-0:focus {\n    --transform-scale-y: 0;\n  }\n\n  .lg\\:focus\\:scale-y-50:focus {\n    --transform-scale-y: .5;\n  }\n\n  .lg\\:focus\\:scale-y-75:focus {\n    --transform-scale-y: .75;\n  }\n\n  .lg\\:focus\\:scale-y-90:focus {\n    --transform-scale-y: .9;\n  }\n\n  .lg\\:focus\\:scale-y-95:focus {\n    --transform-scale-y: .95;\n  }\n\n  .lg\\:focus\\:scale-y-100:focus {\n    --transform-scale-y: 1;\n  }\n\n  .lg\\:focus\\:scale-y-105:focus {\n    --transform-scale-y: 1.05;\n  }\n\n  .lg\\:focus\\:scale-y-110:focus {\n    --transform-scale-y: 1.1;\n  }\n\n  .lg\\:focus\\:scale-y-125:focus {\n    --transform-scale-y: 1.25;\n  }\n\n  .lg\\:focus\\:scale-y-150:focus {\n    --transform-scale-y: 1.5;\n  }\n\n  .lg\\:rotate-0 {\n    --transform-rotate: 0;\n  }\n\n  .lg\\:rotate-1 {\n    --transform-rotate: 1deg;\n  }\n\n  .lg\\:rotate-2 {\n    --transform-rotate: 2deg;\n  }\n\n  .lg\\:rotate-3 {\n    --transform-rotate: 3deg;\n  }\n\n  .lg\\:rotate-6 {\n    --transform-rotate: 6deg;\n  }\n\n  .lg\\:rotate-12 {\n    --transform-rotate: 12deg;\n  }\n\n  .lg\\:rotate-45 {\n    --transform-rotate: 45deg;\n  }\n\n  .lg\\:rotate-90 {\n    --transform-rotate: 90deg;\n  }\n\n  .lg\\:rotate-180 {\n    --transform-rotate: 180deg;\n  }\n\n  .lg\\:-rotate-180 {\n    --transform-rotate: -180deg;\n  }\n\n  .lg\\:-rotate-90 {\n    --transform-rotate: -90deg;\n  }\n\n  .lg\\:-rotate-45 {\n    --transform-rotate: -45deg;\n  }\n\n  .lg\\:-rotate-12 {\n    --transform-rotate: -12deg;\n  }\n\n  .lg\\:-rotate-6 {\n    --transform-rotate: -6deg;\n  }\n\n  .lg\\:-rotate-3 {\n    --transform-rotate: -3deg;\n  }\n\n  .lg\\:-rotate-2 {\n    --transform-rotate: -2deg;\n  }\n\n  .lg\\:-rotate-1 {\n    --transform-rotate: -1deg;\n  }\n\n  .lg\\:hover\\:rotate-0:hover {\n    --transform-rotate: 0;\n  }\n\n  .lg\\:hover\\:rotate-1:hover {\n    --transform-rotate: 1deg;\n  }\n\n  .lg\\:hover\\:rotate-2:hover {\n    --transform-rotate: 2deg;\n  }\n\n  .lg\\:hover\\:rotate-3:hover {\n    --transform-rotate: 3deg;\n  }\n\n  .lg\\:hover\\:rotate-6:hover {\n    --transform-rotate: 6deg;\n  }\n\n  .lg\\:hover\\:rotate-12:hover {\n    --transform-rotate: 12deg;\n  }\n\n  .lg\\:hover\\:rotate-45:hover {\n    --transform-rotate: 45deg;\n  }\n\n  .lg\\:hover\\:rotate-90:hover {\n    --transform-rotate: 90deg;\n  }\n\n  .lg\\:hover\\:rotate-180:hover {\n    --transform-rotate: 180deg;\n  }\n\n  .lg\\:hover\\:-rotate-180:hover {\n    --transform-rotate: -180deg;\n  }\n\n  .lg\\:hover\\:-rotate-90:hover {\n    --transform-rotate: -90deg;\n  }\n\n  .lg\\:hover\\:-rotate-45:hover {\n    --transform-rotate: -45deg;\n  }\n\n  .lg\\:hover\\:-rotate-12:hover {\n    --transform-rotate: -12deg;\n  }\n\n  .lg\\:hover\\:-rotate-6:hover {\n    --transform-rotate: -6deg;\n  }\n\n  .lg\\:hover\\:-rotate-3:hover {\n    --transform-rotate: -3deg;\n  }\n\n  .lg\\:hover\\:-rotate-2:hover {\n    --transform-rotate: -2deg;\n  }\n\n  .lg\\:hover\\:-rotate-1:hover {\n    --transform-rotate: -1deg;\n  }\n\n  .lg\\:focus\\:rotate-0:focus {\n    --transform-rotate: 0;\n  }\n\n  .lg\\:focus\\:rotate-1:focus {\n    --transform-rotate: 1deg;\n  }\n\n  .lg\\:focus\\:rotate-2:focus {\n    --transform-rotate: 2deg;\n  }\n\n  .lg\\:focus\\:rotate-3:focus {\n    --transform-rotate: 3deg;\n  }\n\n  .lg\\:focus\\:rotate-6:focus {\n    --transform-rotate: 6deg;\n  }\n\n  .lg\\:focus\\:rotate-12:focus {\n    --transform-rotate: 12deg;\n  }\n\n  .lg\\:focus\\:rotate-45:focus {\n    --transform-rotate: 45deg;\n  }\n\n  .lg\\:focus\\:rotate-90:focus {\n    --transform-rotate: 90deg;\n  }\n\n  .lg\\:focus\\:rotate-180:focus {\n    --transform-rotate: 180deg;\n  }\n\n  .lg\\:focus\\:-rotate-180:focus {\n    --transform-rotate: -180deg;\n  }\n\n  .lg\\:focus\\:-rotate-90:focus {\n    --transform-rotate: -90deg;\n  }\n\n  .lg\\:focus\\:-rotate-45:focus {\n    --transform-rotate: -45deg;\n  }\n\n  .lg\\:focus\\:-rotate-12:focus {\n    --transform-rotate: -12deg;\n  }\n\n  .lg\\:focus\\:-rotate-6:focus {\n    --transform-rotate: -6deg;\n  }\n\n  .lg\\:focus\\:-rotate-3:focus {\n    --transform-rotate: -3deg;\n  }\n\n  .lg\\:focus\\:-rotate-2:focus {\n    --transform-rotate: -2deg;\n  }\n\n  .lg\\:focus\\:-rotate-1:focus {\n    --transform-rotate: -1deg;\n  }\n\n  .lg\\:translate-x-0 {\n    --transform-translate-x: 0;\n  }\n\n  .lg\\:translate-x-1 {\n    --transform-translate-x: 0.25rem;\n  }\n\n  .lg\\:translate-x-2 {\n    --transform-translate-x: 0.5rem;\n  }\n\n  .lg\\:translate-x-3 {\n    --transform-translate-x: 0.75rem;\n  }\n\n  .lg\\:translate-x-4 {\n    --transform-translate-x: 1rem;\n  }\n\n  .lg\\:translate-x-5 {\n    --transform-translate-x: 1.25rem;\n  }\n\n  .lg\\:translate-x-6 {\n    --transform-translate-x: 1.5rem;\n  }\n\n  .lg\\:translate-x-8 {\n    --transform-translate-x: 2rem;\n  }\n\n  .lg\\:translate-x-10 {\n    --transform-translate-x: 2.5rem;\n  }\n\n  .lg\\:translate-x-12 {\n    --transform-translate-x: 3rem;\n  }\n\n  .lg\\:translate-x-16 {\n    --transform-translate-x: 4rem;\n  }\n\n  .lg\\:translate-x-20 {\n    --transform-translate-x: 5rem;\n  }\n\n  .lg\\:translate-x-24 {\n    --transform-translate-x: 6rem;\n  }\n\n  .lg\\:translate-x-32 {\n    --transform-translate-x: 8rem;\n  }\n\n  .lg\\:translate-x-40 {\n    --transform-translate-x: 10rem;\n  }\n\n  .lg\\:translate-x-48 {\n    --transform-translate-x: 12rem;\n  }\n\n  .lg\\:translate-x-56 {\n    --transform-translate-x: 14rem;\n  }\n\n  .lg\\:translate-x-64 {\n    --transform-translate-x: 16rem;\n  }\n\n  .lg\\:translate-x-px {\n    --transform-translate-x: 1px;\n  }\n\n  .lg\\:-translate-x-1 {\n    --transform-translate-x: -0.25rem;\n  }\n\n  .lg\\:-translate-x-2 {\n    --transform-translate-x: -0.5rem;\n  }\n\n  .lg\\:-translate-x-3 {\n    --transform-translate-x: -0.75rem;\n  }\n\n  .lg\\:-translate-x-4 {\n    --transform-translate-x: -1rem;\n  }\n\n  .lg\\:-translate-x-5 {\n    --transform-translate-x: -1.25rem;\n  }\n\n  .lg\\:-translate-x-6 {\n    --transform-translate-x: -1.5rem;\n  }\n\n  .lg\\:-translate-x-8 {\n    --transform-translate-x: -2rem;\n  }\n\n  .lg\\:-translate-x-10 {\n    --transform-translate-x: -2.5rem;\n  }\n\n  .lg\\:-translate-x-12 {\n    --transform-translate-x: -3rem;\n  }\n\n  .lg\\:-translate-x-16 {\n    --transform-translate-x: -4rem;\n  }\n\n  .lg\\:-translate-x-20 {\n    --transform-translate-x: -5rem;\n  }\n\n  .lg\\:-translate-x-24 {\n    --transform-translate-x: -6rem;\n  }\n\n  .lg\\:-translate-x-32 {\n    --transform-translate-x: -8rem;\n  }\n\n  .lg\\:-translate-x-40 {\n    --transform-translate-x: -10rem;\n  }\n\n  .lg\\:-translate-x-48 {\n    --transform-translate-x: -12rem;\n  }\n\n  .lg\\:-translate-x-56 {\n    --transform-translate-x: -14rem;\n  }\n\n  .lg\\:-translate-x-64 {\n    --transform-translate-x: -16rem;\n  }\n\n  .lg\\:-translate-x-px {\n    --transform-translate-x: -1px;\n  }\n\n  .lg\\:-translate-x-full {\n    --transform-translate-x: -100%;\n  }\n\n  .lg\\:-translate-x-1\\/2 {\n    --transform-translate-x: -50%;\n  }\n\n  .lg\\:translate-x-1\\/2 {\n    --transform-translate-x: 50%;\n  }\n\n  .lg\\:translate-x-full {\n    --transform-translate-x: 100%;\n  }\n\n  .lg\\:translate-y-0 {\n    --transform-translate-y: 0;\n  }\n\n  .lg\\:translate-y-1 {\n    --transform-translate-y: 0.25rem;\n  }\n\n  .lg\\:translate-y-2 {\n    --transform-translate-y: 0.5rem;\n  }\n\n  .lg\\:translate-y-3 {\n    --transform-translate-y: 0.75rem;\n  }\n\n  .lg\\:translate-y-4 {\n    --transform-translate-y: 1rem;\n  }\n\n  .lg\\:translate-y-5 {\n    --transform-translate-y: 1.25rem;\n  }\n\n  .lg\\:translate-y-6 {\n    --transform-translate-y: 1.5rem;\n  }\n\n  .lg\\:translate-y-8 {\n    --transform-translate-y: 2rem;\n  }\n\n  .lg\\:translate-y-10 {\n    --transform-translate-y: 2.5rem;\n  }\n\n  .lg\\:translate-y-12 {\n    --transform-translate-y: 3rem;\n  }\n\n  .lg\\:translate-y-16 {\n    --transform-translate-y: 4rem;\n  }\n\n  .lg\\:translate-y-20 {\n    --transform-translate-y: 5rem;\n  }\n\n  .lg\\:translate-y-24 {\n    --transform-translate-y: 6rem;\n  }\n\n  .lg\\:translate-y-32 {\n    --transform-translate-y: 8rem;\n  }\n\n  .lg\\:translate-y-40 {\n    --transform-translate-y: 10rem;\n  }\n\n  .lg\\:translate-y-48 {\n    --transform-translate-y: 12rem;\n  }\n\n  .lg\\:translate-y-56 {\n    --transform-translate-y: 14rem;\n  }\n\n  .lg\\:translate-y-64 {\n    --transform-translate-y: 16rem;\n  }\n\n  .lg\\:translate-y-px {\n    --transform-translate-y: 1px;\n  }\n\n  .lg\\:-translate-y-1 {\n    --transform-translate-y: -0.25rem;\n  }\n\n  .lg\\:-translate-y-2 {\n    --transform-translate-y: -0.5rem;\n  }\n\n  .lg\\:-translate-y-3 {\n    --transform-translate-y: -0.75rem;\n  }\n\n  .lg\\:-translate-y-4 {\n    --transform-translate-y: -1rem;\n  }\n\n  .lg\\:-translate-y-5 {\n    --transform-translate-y: -1.25rem;\n  }\n\n  .lg\\:-translate-y-6 {\n    --transform-translate-y: -1.5rem;\n  }\n\n  .lg\\:-translate-y-8 {\n    --transform-translate-y: -2rem;\n  }\n\n  .lg\\:-translate-y-10 {\n    --transform-translate-y: -2.5rem;\n  }\n\n  .lg\\:-translate-y-12 {\n    --transform-translate-y: -3rem;\n  }\n\n  .lg\\:-translate-y-16 {\n    --transform-translate-y: -4rem;\n  }\n\n  .lg\\:-translate-y-20 {\n    --transform-translate-y: -5rem;\n  }\n\n  .lg\\:-translate-y-24 {\n    --transform-translate-y: -6rem;\n  }\n\n  .lg\\:-translate-y-32 {\n    --transform-translate-y: -8rem;\n  }\n\n  .lg\\:-translate-y-40 {\n    --transform-translate-y: -10rem;\n  }\n\n  .lg\\:-translate-y-48 {\n    --transform-translate-y: -12rem;\n  }\n\n  .lg\\:-translate-y-56 {\n    --transform-translate-y: -14rem;\n  }\n\n  .lg\\:-translate-y-64 {\n    --transform-translate-y: -16rem;\n  }\n\n  .lg\\:-translate-y-px {\n    --transform-translate-y: -1px;\n  }\n\n  .lg\\:-translate-y-full {\n    --transform-translate-y: -100%;\n  }\n\n  .lg\\:-translate-y-1\\/2 {\n    --transform-translate-y: -50%;\n  }\n\n  .lg\\:translate-y-1\\/2 {\n    --transform-translate-y: 50%;\n  }\n\n  .lg\\:translate-y-full {\n    --transform-translate-y: 100%;\n  }\n\n  .lg\\:hover\\:translate-x-0:hover {\n    --transform-translate-x: 0;\n  }\n\n  .lg\\:hover\\:translate-x-1:hover {\n    --transform-translate-x: 0.25rem;\n  }\n\n  .lg\\:hover\\:translate-x-2:hover {\n    --transform-translate-x: 0.5rem;\n  }\n\n  .lg\\:hover\\:translate-x-3:hover {\n    --transform-translate-x: 0.75rem;\n  }\n\n  .lg\\:hover\\:translate-x-4:hover {\n    --transform-translate-x: 1rem;\n  }\n\n  .lg\\:hover\\:translate-x-5:hover {\n    --transform-translate-x: 1.25rem;\n  }\n\n  .lg\\:hover\\:translate-x-6:hover {\n    --transform-translate-x: 1.5rem;\n  }\n\n  .lg\\:hover\\:translate-x-8:hover {\n    --transform-translate-x: 2rem;\n  }\n\n  .lg\\:hover\\:translate-x-10:hover {\n    --transform-translate-x: 2.5rem;\n  }\n\n  .lg\\:hover\\:translate-x-12:hover {\n    --transform-translate-x: 3rem;\n  }\n\n  .lg\\:hover\\:translate-x-16:hover {\n    --transform-translate-x: 4rem;\n  }\n\n  .lg\\:hover\\:translate-x-20:hover {\n    --transform-translate-x: 5rem;\n  }\n\n  .lg\\:hover\\:translate-x-24:hover {\n    --transform-translate-x: 6rem;\n  }\n\n  .lg\\:hover\\:translate-x-32:hover {\n    --transform-translate-x: 8rem;\n  }\n\n  .lg\\:hover\\:translate-x-40:hover {\n    --transform-translate-x: 10rem;\n  }\n\n  .lg\\:hover\\:translate-x-48:hover {\n    --transform-translate-x: 12rem;\n  }\n\n  .lg\\:hover\\:translate-x-56:hover {\n    --transform-translate-x: 14rem;\n  }\n\n  .lg\\:hover\\:translate-x-64:hover {\n    --transform-translate-x: 16rem;\n  }\n\n  .lg\\:hover\\:translate-x-px:hover {\n    --transform-translate-x: 1px;\n  }\n\n  .lg\\:hover\\:-translate-x-1:hover {\n    --transform-translate-x: -0.25rem;\n  }\n\n  .lg\\:hover\\:-translate-x-2:hover {\n    --transform-translate-x: -0.5rem;\n  }\n\n  .lg\\:hover\\:-translate-x-3:hover {\n    --transform-translate-x: -0.75rem;\n  }\n\n  .lg\\:hover\\:-translate-x-4:hover {\n    --transform-translate-x: -1rem;\n  }\n\n  .lg\\:hover\\:-translate-x-5:hover {\n    --transform-translate-x: -1.25rem;\n  }\n\n  .lg\\:hover\\:-translate-x-6:hover {\n    --transform-translate-x: -1.5rem;\n  }\n\n  .lg\\:hover\\:-translate-x-8:hover {\n    --transform-translate-x: -2rem;\n  }\n\n  .lg\\:hover\\:-translate-x-10:hover {\n    --transform-translate-x: -2.5rem;\n  }\n\n  .lg\\:hover\\:-translate-x-12:hover {\n    --transform-translate-x: -3rem;\n  }\n\n  .lg\\:hover\\:-translate-x-16:hover {\n    --transform-translate-x: -4rem;\n  }\n\n  .lg\\:hover\\:-translate-x-20:hover {\n    --transform-translate-x: -5rem;\n  }\n\n  .lg\\:hover\\:-translate-x-24:hover {\n    --transform-translate-x: -6rem;\n  }\n\n  .lg\\:hover\\:-translate-x-32:hover {\n    --transform-translate-x: -8rem;\n  }\n\n  .lg\\:hover\\:-translate-x-40:hover {\n    --transform-translate-x: -10rem;\n  }\n\n  .lg\\:hover\\:-translate-x-48:hover {\n    --transform-translate-x: -12rem;\n  }\n\n  .lg\\:hover\\:-translate-x-56:hover {\n    --transform-translate-x: -14rem;\n  }\n\n  .lg\\:hover\\:-translate-x-64:hover {\n    --transform-translate-x: -16rem;\n  }\n\n  .lg\\:hover\\:-translate-x-px:hover {\n    --transform-translate-x: -1px;\n  }\n\n  .lg\\:hover\\:-translate-x-full:hover {\n    --transform-translate-x: -100%;\n  }\n\n  .lg\\:hover\\:-translate-x-1\\/2:hover {\n    --transform-translate-x: -50%;\n  }\n\n  .lg\\:hover\\:translate-x-1\\/2:hover {\n    --transform-translate-x: 50%;\n  }\n\n  .lg\\:hover\\:translate-x-full:hover {\n    --transform-translate-x: 100%;\n  }\n\n  .lg\\:hover\\:translate-y-0:hover {\n    --transform-translate-y: 0;\n  }\n\n  .lg\\:hover\\:translate-y-1:hover {\n    --transform-translate-y: 0.25rem;\n  }\n\n  .lg\\:hover\\:translate-y-2:hover {\n    --transform-translate-y: 0.5rem;\n  }\n\n  .lg\\:hover\\:translate-y-3:hover {\n    --transform-translate-y: 0.75rem;\n  }\n\n  .lg\\:hover\\:translate-y-4:hover {\n    --transform-translate-y: 1rem;\n  }\n\n  .lg\\:hover\\:translate-y-5:hover {\n    --transform-translate-y: 1.25rem;\n  }\n\n  .lg\\:hover\\:translate-y-6:hover {\n    --transform-translate-y: 1.5rem;\n  }\n\n  .lg\\:hover\\:translate-y-8:hover {\n    --transform-translate-y: 2rem;\n  }\n\n  .lg\\:hover\\:translate-y-10:hover {\n    --transform-translate-y: 2.5rem;\n  }\n\n  .lg\\:hover\\:translate-y-12:hover {\n    --transform-translate-y: 3rem;\n  }\n\n  .lg\\:hover\\:translate-y-16:hover {\n    --transform-translate-y: 4rem;\n  }\n\n  .lg\\:hover\\:translate-y-20:hover {\n    --transform-translate-y: 5rem;\n  }\n\n  .lg\\:hover\\:translate-y-24:hover {\n    --transform-translate-y: 6rem;\n  }\n\n  .lg\\:hover\\:translate-y-32:hover {\n    --transform-translate-y: 8rem;\n  }\n\n  .lg\\:hover\\:translate-y-40:hover {\n    --transform-translate-y: 10rem;\n  }\n\n  .lg\\:hover\\:translate-y-48:hover {\n    --transform-translate-y: 12rem;\n  }\n\n  .lg\\:hover\\:translate-y-56:hover {\n    --transform-translate-y: 14rem;\n  }\n\n  .lg\\:hover\\:translate-y-64:hover {\n    --transform-translate-y: 16rem;\n  }\n\n  .lg\\:hover\\:translate-y-px:hover {\n    --transform-translate-y: 1px;\n  }\n\n  .lg\\:hover\\:-translate-y-1:hover {\n    --transform-translate-y: -0.25rem;\n  }\n\n  .lg\\:hover\\:-translate-y-2:hover {\n    --transform-translate-y: -0.5rem;\n  }\n\n  .lg\\:hover\\:-translate-y-3:hover {\n    --transform-translate-y: -0.75rem;\n  }\n\n  .lg\\:hover\\:-translate-y-4:hover {\n    --transform-translate-y: -1rem;\n  }\n\n  .lg\\:hover\\:-translate-y-5:hover {\n    --transform-translate-y: -1.25rem;\n  }\n\n  .lg\\:hover\\:-translate-y-6:hover {\n    --transform-translate-y: -1.5rem;\n  }\n\n  .lg\\:hover\\:-translate-y-8:hover {\n    --transform-translate-y: -2rem;\n  }\n\n  .lg\\:hover\\:-translate-y-10:hover {\n    --transform-translate-y: -2.5rem;\n  }\n\n  .lg\\:hover\\:-translate-y-12:hover {\n    --transform-translate-y: -3rem;\n  }\n\n  .lg\\:hover\\:-translate-y-16:hover {\n    --transform-translate-y: -4rem;\n  }\n\n  .lg\\:hover\\:-translate-y-20:hover {\n    --transform-translate-y: -5rem;\n  }\n\n  .lg\\:hover\\:-translate-y-24:hover {\n    --transform-translate-y: -6rem;\n  }\n\n  .lg\\:hover\\:-translate-y-32:hover {\n    --transform-translate-y: -8rem;\n  }\n\n  .lg\\:hover\\:-translate-y-40:hover {\n    --transform-translate-y: -10rem;\n  }\n\n  .lg\\:hover\\:-translate-y-48:hover {\n    --transform-translate-y: -12rem;\n  }\n\n  .lg\\:hover\\:-translate-y-56:hover {\n    --transform-translate-y: -14rem;\n  }\n\n  .lg\\:hover\\:-translate-y-64:hover {\n    --transform-translate-y: -16rem;\n  }\n\n  .lg\\:hover\\:-translate-y-px:hover {\n    --transform-translate-y: -1px;\n  }\n\n  .lg\\:hover\\:-translate-y-full:hover {\n    --transform-translate-y: -100%;\n  }\n\n  .lg\\:hover\\:-translate-y-1\\/2:hover {\n    --transform-translate-y: -50%;\n  }\n\n  .lg\\:hover\\:translate-y-1\\/2:hover {\n    --transform-translate-y: 50%;\n  }\n\n  .lg\\:hover\\:translate-y-full:hover {\n    --transform-translate-y: 100%;\n  }\n\n  .lg\\:focus\\:translate-x-0:focus {\n    --transform-translate-x: 0;\n  }\n\n  .lg\\:focus\\:translate-x-1:focus {\n    --transform-translate-x: 0.25rem;\n  }\n\n  .lg\\:focus\\:translate-x-2:focus {\n    --transform-translate-x: 0.5rem;\n  }\n\n  .lg\\:focus\\:translate-x-3:focus {\n    --transform-translate-x: 0.75rem;\n  }\n\n  .lg\\:focus\\:translate-x-4:focus {\n    --transform-translate-x: 1rem;\n  }\n\n  .lg\\:focus\\:translate-x-5:focus {\n    --transform-translate-x: 1.25rem;\n  }\n\n  .lg\\:focus\\:translate-x-6:focus {\n    --transform-translate-x: 1.5rem;\n  }\n\n  .lg\\:focus\\:translate-x-8:focus {\n    --transform-translate-x: 2rem;\n  }\n\n  .lg\\:focus\\:translate-x-10:focus {\n    --transform-translate-x: 2.5rem;\n  }\n\n  .lg\\:focus\\:translate-x-12:focus {\n    --transform-translate-x: 3rem;\n  }\n\n  .lg\\:focus\\:translate-x-16:focus {\n    --transform-translate-x: 4rem;\n  }\n\n  .lg\\:focus\\:translate-x-20:focus {\n    --transform-translate-x: 5rem;\n  }\n\n  .lg\\:focus\\:translate-x-24:focus {\n    --transform-translate-x: 6rem;\n  }\n\n  .lg\\:focus\\:translate-x-32:focus {\n    --transform-translate-x: 8rem;\n  }\n\n  .lg\\:focus\\:translate-x-40:focus {\n    --transform-translate-x: 10rem;\n  }\n\n  .lg\\:focus\\:translate-x-48:focus {\n    --transform-translate-x: 12rem;\n  }\n\n  .lg\\:focus\\:translate-x-56:focus {\n    --transform-translate-x: 14rem;\n  }\n\n  .lg\\:focus\\:translate-x-64:focus {\n    --transform-translate-x: 16rem;\n  }\n\n  .lg\\:focus\\:translate-x-px:focus {\n    --transform-translate-x: 1px;\n  }\n\n  .lg\\:focus\\:-translate-x-1:focus {\n    --transform-translate-x: -0.25rem;\n  }\n\n  .lg\\:focus\\:-translate-x-2:focus {\n    --transform-translate-x: -0.5rem;\n  }\n\n  .lg\\:focus\\:-translate-x-3:focus {\n    --transform-translate-x: -0.75rem;\n  }\n\n  .lg\\:focus\\:-translate-x-4:focus {\n    --transform-translate-x: -1rem;\n  }\n\n  .lg\\:focus\\:-translate-x-5:focus {\n    --transform-translate-x: -1.25rem;\n  }\n\n  .lg\\:focus\\:-translate-x-6:focus {\n    --transform-translate-x: -1.5rem;\n  }\n\n  .lg\\:focus\\:-translate-x-8:focus {\n    --transform-translate-x: -2rem;\n  }\n\n  .lg\\:focus\\:-translate-x-10:focus {\n    --transform-translate-x: -2.5rem;\n  }\n\n  .lg\\:focus\\:-translate-x-12:focus {\n    --transform-translate-x: -3rem;\n  }\n\n  .lg\\:focus\\:-translate-x-16:focus {\n    --transform-translate-x: -4rem;\n  }\n\n  .lg\\:focus\\:-translate-x-20:focus {\n    --transform-translate-x: -5rem;\n  }\n\n  .lg\\:focus\\:-translate-x-24:focus {\n    --transform-translate-x: -6rem;\n  }\n\n  .lg\\:focus\\:-translate-x-32:focus {\n    --transform-translate-x: -8rem;\n  }\n\n  .lg\\:focus\\:-translate-x-40:focus {\n    --transform-translate-x: -10rem;\n  }\n\n  .lg\\:focus\\:-translate-x-48:focus {\n    --transform-translate-x: -12rem;\n  }\n\n  .lg\\:focus\\:-translate-x-56:focus {\n    --transform-translate-x: -14rem;\n  }\n\n  .lg\\:focus\\:-translate-x-64:focus {\n    --transform-translate-x: -16rem;\n  }\n\n  .lg\\:focus\\:-translate-x-px:focus {\n    --transform-translate-x: -1px;\n  }\n\n  .lg\\:focus\\:-translate-x-full:focus {\n    --transform-translate-x: -100%;\n  }\n\n  .lg\\:focus\\:-translate-x-1\\/2:focus {\n    --transform-translate-x: -50%;\n  }\n\n  .lg\\:focus\\:translate-x-1\\/2:focus {\n    --transform-translate-x: 50%;\n  }\n\n  .lg\\:focus\\:translate-x-full:focus {\n    --transform-translate-x: 100%;\n  }\n\n  .lg\\:focus\\:translate-y-0:focus {\n    --transform-translate-y: 0;\n  }\n\n  .lg\\:focus\\:translate-y-1:focus {\n    --transform-translate-y: 0.25rem;\n  }\n\n  .lg\\:focus\\:translate-y-2:focus {\n    --transform-translate-y: 0.5rem;\n  }\n\n  .lg\\:focus\\:translate-y-3:focus {\n    --transform-translate-y: 0.75rem;\n  }\n\n  .lg\\:focus\\:translate-y-4:focus {\n    --transform-translate-y: 1rem;\n  }\n\n  .lg\\:focus\\:translate-y-5:focus {\n    --transform-translate-y: 1.25rem;\n  }\n\n  .lg\\:focus\\:translate-y-6:focus {\n    --transform-translate-y: 1.5rem;\n  }\n\n  .lg\\:focus\\:translate-y-8:focus {\n    --transform-translate-y: 2rem;\n  }\n\n  .lg\\:focus\\:translate-y-10:focus {\n    --transform-translate-y: 2.5rem;\n  }\n\n  .lg\\:focus\\:translate-y-12:focus {\n    --transform-translate-y: 3rem;\n  }\n\n  .lg\\:focus\\:translate-y-16:focus {\n    --transform-translate-y: 4rem;\n  }\n\n  .lg\\:focus\\:translate-y-20:focus {\n    --transform-translate-y: 5rem;\n  }\n\n  .lg\\:focus\\:translate-y-24:focus {\n    --transform-translate-y: 6rem;\n  }\n\n  .lg\\:focus\\:translate-y-32:focus {\n    --transform-translate-y: 8rem;\n  }\n\n  .lg\\:focus\\:translate-y-40:focus {\n    --transform-translate-y: 10rem;\n  }\n\n  .lg\\:focus\\:translate-y-48:focus {\n    --transform-translate-y: 12rem;\n  }\n\n  .lg\\:focus\\:translate-y-56:focus {\n    --transform-translate-y: 14rem;\n  }\n\n  .lg\\:focus\\:translate-y-64:focus {\n    --transform-translate-y: 16rem;\n  }\n\n  .lg\\:focus\\:translate-y-px:focus {\n    --transform-translate-y: 1px;\n  }\n\n  .lg\\:focus\\:-translate-y-1:focus {\n    --transform-translate-y: -0.25rem;\n  }\n\n  .lg\\:focus\\:-translate-y-2:focus {\n    --transform-translate-y: -0.5rem;\n  }\n\n  .lg\\:focus\\:-translate-y-3:focus {\n    --transform-translate-y: -0.75rem;\n  }\n\n  .lg\\:focus\\:-translate-y-4:focus {\n    --transform-translate-y: -1rem;\n  }\n\n  .lg\\:focus\\:-translate-y-5:focus {\n    --transform-translate-y: -1.25rem;\n  }\n\n  .lg\\:focus\\:-translate-y-6:focus {\n    --transform-translate-y: -1.5rem;\n  }\n\n  .lg\\:focus\\:-translate-y-8:focus {\n    --transform-translate-y: -2rem;\n  }\n\n  .lg\\:focus\\:-translate-y-10:focus {\n    --transform-translate-y: -2.5rem;\n  }\n\n  .lg\\:focus\\:-translate-y-12:focus {\n    --transform-translate-y: -3rem;\n  }\n\n  .lg\\:focus\\:-translate-y-16:focus {\n    --transform-translate-y: -4rem;\n  }\n\n  .lg\\:focus\\:-translate-y-20:focus {\n    --transform-translate-y: -5rem;\n  }\n\n  .lg\\:focus\\:-translate-y-24:focus {\n    --transform-translate-y: -6rem;\n  }\n\n  .lg\\:focus\\:-translate-y-32:focus {\n    --transform-translate-y: -8rem;\n  }\n\n  .lg\\:focus\\:-translate-y-40:focus {\n    --transform-translate-y: -10rem;\n  }\n\n  .lg\\:focus\\:-translate-y-48:focus {\n    --transform-translate-y: -12rem;\n  }\n\n  .lg\\:focus\\:-translate-y-56:focus {\n    --transform-translate-y: -14rem;\n  }\n\n  .lg\\:focus\\:-translate-y-64:focus {\n    --transform-translate-y: -16rem;\n  }\n\n  .lg\\:focus\\:-translate-y-px:focus {\n    --transform-translate-y: -1px;\n  }\n\n  .lg\\:focus\\:-translate-y-full:focus {\n    --transform-translate-y: -100%;\n  }\n\n  .lg\\:focus\\:-translate-y-1\\/2:focus {\n    --transform-translate-y: -50%;\n  }\n\n  .lg\\:focus\\:translate-y-1\\/2:focus {\n    --transform-translate-y: 50%;\n  }\n\n  .lg\\:focus\\:translate-y-full:focus {\n    --transform-translate-y: 100%;\n  }\n\n  .lg\\:skew-x-0 {\n    --transform-skew-x: 0;\n  }\n\n  .lg\\:skew-x-1 {\n    --transform-skew-x: 1deg;\n  }\n\n  .lg\\:skew-x-2 {\n    --transform-skew-x: 2deg;\n  }\n\n  .lg\\:skew-x-3 {\n    --transform-skew-x: 3deg;\n  }\n\n  .lg\\:skew-x-6 {\n    --transform-skew-x: 6deg;\n  }\n\n  .lg\\:skew-x-12 {\n    --transform-skew-x: 12deg;\n  }\n\n  .lg\\:-skew-x-12 {\n    --transform-skew-x: -12deg;\n  }\n\n  .lg\\:-skew-x-6 {\n    --transform-skew-x: -6deg;\n  }\n\n  .lg\\:-skew-x-3 {\n    --transform-skew-x: -3deg;\n  }\n\n  .lg\\:-skew-x-2 {\n    --transform-skew-x: -2deg;\n  }\n\n  .lg\\:-skew-x-1 {\n    --transform-skew-x: -1deg;\n  }\n\n  .lg\\:skew-y-0 {\n    --transform-skew-y: 0;\n  }\n\n  .lg\\:skew-y-1 {\n    --transform-skew-y: 1deg;\n  }\n\n  .lg\\:skew-y-2 {\n    --transform-skew-y: 2deg;\n  }\n\n  .lg\\:skew-y-3 {\n    --transform-skew-y: 3deg;\n  }\n\n  .lg\\:skew-y-6 {\n    --transform-skew-y: 6deg;\n  }\n\n  .lg\\:skew-y-12 {\n    --transform-skew-y: 12deg;\n  }\n\n  .lg\\:-skew-y-12 {\n    --transform-skew-y: -12deg;\n  }\n\n  .lg\\:-skew-y-6 {\n    --transform-skew-y: -6deg;\n  }\n\n  .lg\\:-skew-y-3 {\n    --transform-skew-y: -3deg;\n  }\n\n  .lg\\:-skew-y-2 {\n    --transform-skew-y: -2deg;\n  }\n\n  .lg\\:-skew-y-1 {\n    --transform-skew-y: -1deg;\n  }\n\n  .lg\\:hover\\:skew-x-0:hover {\n    --transform-skew-x: 0;\n  }\n\n  .lg\\:hover\\:skew-x-1:hover {\n    --transform-skew-x: 1deg;\n  }\n\n  .lg\\:hover\\:skew-x-2:hover {\n    --transform-skew-x: 2deg;\n  }\n\n  .lg\\:hover\\:skew-x-3:hover {\n    --transform-skew-x: 3deg;\n  }\n\n  .lg\\:hover\\:skew-x-6:hover {\n    --transform-skew-x: 6deg;\n  }\n\n  .lg\\:hover\\:skew-x-12:hover {\n    --transform-skew-x: 12deg;\n  }\n\n  .lg\\:hover\\:-skew-x-12:hover {\n    --transform-skew-x: -12deg;\n  }\n\n  .lg\\:hover\\:-skew-x-6:hover {\n    --transform-skew-x: -6deg;\n  }\n\n  .lg\\:hover\\:-skew-x-3:hover {\n    --transform-skew-x: -3deg;\n  }\n\n  .lg\\:hover\\:-skew-x-2:hover {\n    --transform-skew-x: -2deg;\n  }\n\n  .lg\\:hover\\:-skew-x-1:hover {\n    --transform-skew-x: -1deg;\n  }\n\n  .lg\\:hover\\:skew-y-0:hover {\n    --transform-skew-y: 0;\n  }\n\n  .lg\\:hover\\:skew-y-1:hover {\n    --transform-skew-y: 1deg;\n  }\n\n  .lg\\:hover\\:skew-y-2:hover {\n    --transform-skew-y: 2deg;\n  }\n\n  .lg\\:hover\\:skew-y-3:hover {\n    --transform-skew-y: 3deg;\n  }\n\n  .lg\\:hover\\:skew-y-6:hover {\n    --transform-skew-y: 6deg;\n  }\n\n  .lg\\:hover\\:skew-y-12:hover {\n    --transform-skew-y: 12deg;\n  }\n\n  .lg\\:hover\\:-skew-y-12:hover {\n    --transform-skew-y: -12deg;\n  }\n\n  .lg\\:hover\\:-skew-y-6:hover {\n    --transform-skew-y: -6deg;\n  }\n\n  .lg\\:hover\\:-skew-y-3:hover {\n    --transform-skew-y: -3deg;\n  }\n\n  .lg\\:hover\\:-skew-y-2:hover {\n    --transform-skew-y: -2deg;\n  }\n\n  .lg\\:hover\\:-skew-y-1:hover {\n    --transform-skew-y: -1deg;\n  }\n\n  .lg\\:focus\\:skew-x-0:focus {\n    --transform-skew-x: 0;\n  }\n\n  .lg\\:focus\\:skew-x-1:focus {\n    --transform-skew-x: 1deg;\n  }\n\n  .lg\\:focus\\:skew-x-2:focus {\n    --transform-skew-x: 2deg;\n  }\n\n  .lg\\:focus\\:skew-x-3:focus {\n    --transform-skew-x: 3deg;\n  }\n\n  .lg\\:focus\\:skew-x-6:focus {\n    --transform-skew-x: 6deg;\n  }\n\n  .lg\\:focus\\:skew-x-12:focus {\n    --transform-skew-x: 12deg;\n  }\n\n  .lg\\:focus\\:-skew-x-12:focus {\n    --transform-skew-x: -12deg;\n  }\n\n  .lg\\:focus\\:-skew-x-6:focus {\n    --transform-skew-x: -6deg;\n  }\n\n  .lg\\:focus\\:-skew-x-3:focus {\n    --transform-skew-x: -3deg;\n  }\n\n  .lg\\:focus\\:-skew-x-2:focus {\n    --transform-skew-x: -2deg;\n  }\n\n  .lg\\:focus\\:-skew-x-1:focus {\n    --transform-skew-x: -1deg;\n  }\n\n  .lg\\:focus\\:skew-y-0:focus {\n    --transform-skew-y: 0;\n  }\n\n  .lg\\:focus\\:skew-y-1:focus {\n    --transform-skew-y: 1deg;\n  }\n\n  .lg\\:focus\\:skew-y-2:focus {\n    --transform-skew-y: 2deg;\n  }\n\n  .lg\\:focus\\:skew-y-3:focus {\n    --transform-skew-y: 3deg;\n  }\n\n  .lg\\:focus\\:skew-y-6:focus {\n    --transform-skew-y: 6deg;\n  }\n\n  .lg\\:focus\\:skew-y-12:focus {\n    --transform-skew-y: 12deg;\n  }\n\n  .lg\\:focus\\:-skew-y-12:focus {\n    --transform-skew-y: -12deg;\n  }\n\n  .lg\\:focus\\:-skew-y-6:focus {\n    --transform-skew-y: -6deg;\n  }\n\n  .lg\\:focus\\:-skew-y-3:focus {\n    --transform-skew-y: -3deg;\n  }\n\n  .lg\\:focus\\:-skew-y-2:focus {\n    --transform-skew-y: -2deg;\n  }\n\n  .lg\\:focus\\:-skew-y-1:focus {\n    --transform-skew-y: -1deg;\n  }\n\n  .lg\\:transition-none {\n    transition-property: none;\n  }\n\n  .lg\\:transition-all {\n    transition-property: all;\n  }\n\n  .lg\\:transition {\n    transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform;\n  }\n\n  .lg\\:transition-colors {\n    transition-property: background-color, border-color, color, fill, stroke;\n  }\n\n  .lg\\:transition-opacity {\n    transition-property: opacity;\n  }\n\n  .lg\\:transition-shadow {\n    transition-property: box-shadow;\n  }\n\n  .lg\\:transition-transform {\n    transition-property: transform;\n  }\n\n  .lg\\:ease-linear {\n    transition-timing-function: linear;\n  }\n\n  .lg\\:ease-in {\n    transition-timing-function: cubic-bezier(0.4, 0, 1, 1);\n  }\n\n  .lg\\:ease-out {\n    transition-timing-function: cubic-bezier(0, 0, 0.2, 1);\n  }\n\n  .lg\\:ease-in-out {\n    transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);\n  }\n\n  .lg\\:duration-75 {\n    transition-duration: 75ms;\n  }\n\n  .lg\\:duration-100 {\n    transition-duration: 100ms;\n  }\n\n  .lg\\:duration-150 {\n    transition-duration: 150ms;\n  }\n\n  .lg\\:duration-200 {\n    transition-duration: 200ms;\n  }\n\n  .lg\\:duration-300 {\n    transition-duration: 300ms;\n  }\n\n  .lg\\:duration-500 {\n    transition-duration: 500ms;\n  }\n\n  .lg\\:duration-700 {\n    transition-duration: 700ms;\n  }\n\n  .lg\\:duration-1000 {\n    transition-duration: 1000ms;\n  }\n\n  .lg\\:delay-75 {\n    transition-delay: 75ms;\n  }\n\n  .lg\\:delay-100 {\n    transition-delay: 100ms;\n  }\n\n  .lg\\:delay-150 {\n    transition-delay: 150ms;\n  }\n\n  .lg\\:delay-200 {\n    transition-delay: 200ms;\n  }\n\n  .lg\\:delay-300 {\n    transition-delay: 300ms;\n  }\n\n  .lg\\:delay-500 {\n    transition-delay: 500ms;\n  }\n\n  .lg\\:delay-700 {\n    transition-delay: 700ms;\n  }\n\n  .lg\\:delay-1000 {\n    transition-delay: 1000ms;\n  }\n\n  .lg\\:animate-none {\n    -webkit-animation: none;\n            animation: none;\n  }\n\n  .lg\\:animate-spin {\n    -webkit-animation: spin 1s linear infinite;\n            animation: spin 1s linear infinite;\n  }\n\n  .lg\\:animate-ping {\n    -webkit-animation: ping 1s cubic-bezier(0, 0, 0.2, 1) infinite;\n            animation: ping 1s cubic-bezier(0, 0, 0.2, 1) infinite;\n  }\n\n  .lg\\:animate-pulse {\n    -webkit-animation: pulse 2s cubic-bezier(0.4, 0, 0.6, 1) infinite;\n            animation: pulse 2s cubic-bezier(0.4, 0, 0.6, 1) infinite;\n  }\n\n  .lg\\:animate-bounce {\n    -webkit-animation: bounce 1s infinite;\n            animation: bounce 1s infinite;\n  }\n}\n\n@media (min-width: 1280px) {\n  .xl\\:container {\n    width: 100%;\n  }\n\n  @media (min-width: 640px) {\n    .xl\\:container {\n      max-width: 640px;\n    }\n  }\n\n  @media (min-width: 768px) {\n    .xl\\:container {\n      max-width: 768px;\n    }\n  }\n\n  @media (min-width: 1024px) {\n    .xl\\:container {\n      max-width: 1024px;\n    }\n  }\n\n  @media (min-width: 1280px) {\n    .xl\\:container {\n      max-width: 1280px;\n    }\n  }\n\n  .xl\\:space-y-0 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(0px * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(0px * var(--space-y-reverse));\n  }\n\n  .xl\\:space-x-0 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(0px * var(--space-x-reverse));\n    margin-left: calc(0px * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:space-y-1 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(0.25rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(0.25rem * var(--space-y-reverse));\n  }\n\n  .xl\\:space-x-1 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(0.25rem * var(--space-x-reverse));\n    margin-left: calc(0.25rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:space-y-2 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(0.5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(0.5rem * var(--space-y-reverse));\n  }\n\n  .xl\\:space-x-2 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(0.5rem * var(--space-x-reverse));\n    margin-left: calc(0.5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:space-y-3 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(0.75rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(0.75rem * var(--space-y-reverse));\n  }\n\n  .xl\\:space-x-3 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(0.75rem * var(--space-x-reverse));\n    margin-left: calc(0.75rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:space-y-4 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(1rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(1rem * var(--space-y-reverse));\n  }\n\n  .xl\\:space-x-4 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(1rem * var(--space-x-reverse));\n    margin-left: calc(1rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:space-y-5 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(1.25rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(1.25rem * var(--space-y-reverse));\n  }\n\n  .xl\\:space-x-5 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(1.25rem * var(--space-x-reverse));\n    margin-left: calc(1.25rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:space-y-6 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(1.5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(1.5rem * var(--space-y-reverse));\n  }\n\n  .xl\\:space-x-6 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(1.5rem * var(--space-x-reverse));\n    margin-left: calc(1.5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:space-y-8 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(2rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(2rem * var(--space-y-reverse));\n  }\n\n  .xl\\:space-x-8 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(2rem * var(--space-x-reverse));\n    margin-left: calc(2rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:space-y-10 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(2.5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(2.5rem * var(--space-y-reverse));\n  }\n\n  .xl\\:space-x-10 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(2.5rem * var(--space-x-reverse));\n    margin-left: calc(2.5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:space-y-12 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(3rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(3rem * var(--space-y-reverse));\n  }\n\n  .xl\\:space-x-12 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(3rem * var(--space-x-reverse));\n    margin-left: calc(3rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:space-y-16 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(4rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(4rem * var(--space-y-reverse));\n  }\n\n  .xl\\:space-x-16 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(4rem * var(--space-x-reverse));\n    margin-left: calc(4rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:space-y-20 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(5rem * var(--space-y-reverse));\n  }\n\n  .xl\\:space-x-20 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(5rem * var(--space-x-reverse));\n    margin-left: calc(5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:space-y-24 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(6rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(6rem * var(--space-y-reverse));\n  }\n\n  .xl\\:space-x-24 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(6rem * var(--space-x-reverse));\n    margin-left: calc(6rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:space-y-32 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(8rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(8rem * var(--space-y-reverse));\n  }\n\n  .xl\\:space-x-32 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(8rem * var(--space-x-reverse));\n    margin-left: calc(8rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:space-y-40 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(10rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(10rem * var(--space-y-reverse));\n  }\n\n  .xl\\:space-x-40 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(10rem * var(--space-x-reverse));\n    margin-left: calc(10rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:space-y-48 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(12rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(12rem * var(--space-y-reverse));\n  }\n\n  .xl\\:space-x-48 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(12rem * var(--space-x-reverse));\n    margin-left: calc(12rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:space-y-56 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(14rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(14rem * var(--space-y-reverse));\n  }\n\n  .xl\\:space-x-56 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(14rem * var(--space-x-reverse));\n    margin-left: calc(14rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:space-y-64 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(16rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(16rem * var(--space-y-reverse));\n  }\n\n  .xl\\:space-x-64 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(16rem * var(--space-x-reverse));\n    margin-left: calc(16rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:space-y-px > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(1px * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(1px * var(--space-y-reverse));\n  }\n\n  .xl\\:space-x-px > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(1px * var(--space-x-reverse));\n    margin-left: calc(1px * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:-space-y-1 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-0.25rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-0.25rem * var(--space-y-reverse));\n  }\n\n  .xl\\:-space-x-1 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-0.25rem * var(--space-x-reverse));\n    margin-left: calc(-0.25rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:-space-y-2 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-0.5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-0.5rem * var(--space-y-reverse));\n  }\n\n  .xl\\:-space-x-2 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-0.5rem * var(--space-x-reverse));\n    margin-left: calc(-0.5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:-space-y-3 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-0.75rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-0.75rem * var(--space-y-reverse));\n  }\n\n  .xl\\:-space-x-3 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-0.75rem * var(--space-x-reverse));\n    margin-left: calc(-0.75rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:-space-y-4 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-1rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-1rem * var(--space-y-reverse));\n  }\n\n  .xl\\:-space-x-4 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-1rem * var(--space-x-reverse));\n    margin-left: calc(-1rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:-space-y-5 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-1.25rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-1.25rem * var(--space-y-reverse));\n  }\n\n  .xl\\:-space-x-5 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-1.25rem * var(--space-x-reverse));\n    margin-left: calc(-1.25rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:-space-y-6 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-1.5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-1.5rem * var(--space-y-reverse));\n  }\n\n  .xl\\:-space-x-6 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-1.5rem * var(--space-x-reverse));\n    margin-left: calc(-1.5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:-space-y-8 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-2rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-2rem * var(--space-y-reverse));\n  }\n\n  .xl\\:-space-x-8 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-2rem * var(--space-x-reverse));\n    margin-left: calc(-2rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:-space-y-10 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-2.5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-2.5rem * var(--space-y-reverse));\n  }\n\n  .xl\\:-space-x-10 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-2.5rem * var(--space-x-reverse));\n    margin-left: calc(-2.5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:-space-y-12 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-3rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-3rem * var(--space-y-reverse));\n  }\n\n  .xl\\:-space-x-12 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-3rem * var(--space-x-reverse));\n    margin-left: calc(-3rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:-space-y-16 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-4rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-4rem * var(--space-y-reverse));\n  }\n\n  .xl\\:-space-x-16 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-4rem * var(--space-x-reverse));\n    margin-left: calc(-4rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:-space-y-20 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-5rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-5rem * var(--space-y-reverse));\n  }\n\n  .xl\\:-space-x-20 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-5rem * var(--space-x-reverse));\n    margin-left: calc(-5rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:-space-y-24 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-6rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-6rem * var(--space-y-reverse));\n  }\n\n  .xl\\:-space-x-24 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-6rem * var(--space-x-reverse));\n    margin-left: calc(-6rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:-space-y-32 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-8rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-8rem * var(--space-y-reverse));\n  }\n\n  .xl\\:-space-x-32 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-8rem * var(--space-x-reverse));\n    margin-left: calc(-8rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:-space-y-40 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-10rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-10rem * var(--space-y-reverse));\n  }\n\n  .xl\\:-space-x-40 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-10rem * var(--space-x-reverse));\n    margin-left: calc(-10rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:-space-y-48 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-12rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-12rem * var(--space-y-reverse));\n  }\n\n  .xl\\:-space-x-48 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-12rem * var(--space-x-reverse));\n    margin-left: calc(-12rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:-space-y-56 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-14rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-14rem * var(--space-y-reverse));\n  }\n\n  .xl\\:-space-x-56 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-14rem * var(--space-x-reverse));\n    margin-left: calc(-14rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:-space-y-64 > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-16rem * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-16rem * var(--space-y-reverse));\n  }\n\n  .xl\\:-space-x-64 > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-16rem * var(--space-x-reverse));\n    margin-left: calc(-16rem * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:-space-y-px > :not(template) ~ :not(template) {\n    --space-y-reverse: 0;\n    margin-top: calc(-1px * calc(1 - var(--space-y-reverse)));\n    margin-bottom: calc(-1px * var(--space-y-reverse));\n  }\n\n  .xl\\:-space-x-px > :not(template) ~ :not(template) {\n    --space-x-reverse: 0;\n    margin-right: calc(-1px * var(--space-x-reverse));\n    margin-left: calc(-1px * calc(1 - var(--space-x-reverse)));\n  }\n\n  .xl\\:space-y-reverse > :not(template) ~ :not(template) {\n    --space-y-reverse: 1;\n  }\n\n  .xl\\:space-x-reverse > :not(template) ~ :not(template) {\n    --space-x-reverse: 1;\n  }\n\n  .xl\\:divide-y-0 > :not(template) ~ :not(template) {\n    --divide-y-reverse: 0;\n    border-top-width: calc(0px * calc(1 - var(--divide-y-reverse)));\n    border-bottom-width: calc(0px * var(--divide-y-reverse));\n  }\n\n  .xl\\:divide-x-0 > :not(template) ~ :not(template) {\n    --divide-x-reverse: 0;\n    border-right-width: calc(0px * var(--divide-x-reverse));\n    border-left-width: calc(0px * calc(1 - var(--divide-x-reverse)));\n  }\n\n  .xl\\:divide-y-2 > :not(template) ~ :not(template) {\n    --divide-y-reverse: 0;\n    border-top-width: calc(2px * calc(1 - var(--divide-y-reverse)));\n    border-bottom-width: calc(2px * var(--divide-y-reverse));\n  }\n\n  .xl\\:divide-x-2 > :not(template) ~ :not(template) {\n    --divide-x-reverse: 0;\n    border-right-width: calc(2px * var(--divide-x-reverse));\n    border-left-width: calc(2px * calc(1 - var(--divide-x-reverse)));\n  }\n\n  .xl\\:divide-y-4 > :not(template) ~ :not(template) {\n    --divide-y-reverse: 0;\n    border-top-width: calc(4px * calc(1 - var(--divide-y-reverse)));\n    border-bottom-width: calc(4px * var(--divide-y-reverse));\n  }\n\n  .xl\\:divide-x-4 > :not(template) ~ :not(template) {\n    --divide-x-reverse: 0;\n    border-right-width: calc(4px * var(--divide-x-reverse));\n    border-left-width: calc(4px * calc(1 - var(--divide-x-reverse)));\n  }\n\n  .xl\\:divide-y-8 > :not(template) ~ :not(template) {\n    --divide-y-reverse: 0;\n    border-top-width: calc(8px * calc(1 - var(--divide-y-reverse)));\n    border-bottom-width: calc(8px * var(--divide-y-reverse));\n  }\n\n  .xl\\:divide-x-8 > :not(template) ~ :not(template) {\n    --divide-x-reverse: 0;\n    border-right-width: calc(8px * var(--divide-x-reverse));\n    border-left-width: calc(8px * calc(1 - var(--divide-x-reverse)));\n  }\n\n  .xl\\:divide-y > :not(template) ~ :not(template) {\n    --divide-y-reverse: 0;\n    border-top-width: calc(1px * calc(1 - var(--divide-y-reverse)));\n    border-bottom-width: calc(1px * var(--divide-y-reverse));\n  }\n\n  .xl\\:divide-x > :not(template) ~ :not(template) {\n    --divide-x-reverse: 0;\n    border-right-width: calc(1px * var(--divide-x-reverse));\n    border-left-width: calc(1px * calc(1 - var(--divide-x-reverse)));\n  }\n\n  .xl\\:divide-y-reverse > :not(template) ~ :not(template) {\n    --divide-y-reverse: 1;\n  }\n\n  .xl\\:divide-x-reverse > :not(template) ~ :not(template) {\n    --divide-x-reverse: 1;\n  }\n\n  .xl\\:divide-transparent > :not(template) ~ :not(template) {\n    border-color: transparent;\n  }\n\n  .xl\\:divide-current > :not(template) ~ :not(template) {\n    border-color: currentColor;\n  }\n\n  .xl\\:divide-black > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #000;\n    border-color: rgba(0, 0, 0, var(--divide-opacity));\n  }\n\n  .xl\\:divide-white > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fff;\n    border-color: rgba(255, 255, 255, var(--divide-opacity));\n  }\n\n  .xl\\:divide-gray-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #f7fafc;\n    border-color: rgba(247, 250, 252, var(--divide-opacity));\n  }\n\n  .xl\\:divide-gray-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #edf2f7;\n    border-color: rgba(237, 242, 247, var(--divide-opacity));\n  }\n\n  .xl\\:divide-gray-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #e2e8f0;\n    border-color: rgba(226, 232, 240, var(--divide-opacity));\n  }\n\n  .xl\\:divide-gray-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #cbd5e0;\n    border-color: rgba(203, 213, 224, var(--divide-opacity));\n  }\n\n  .xl\\:divide-gray-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #a0aec0;\n    border-color: rgba(160, 174, 192, var(--divide-opacity));\n  }\n\n  .xl\\:divide-gray-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #718096;\n    border-color: rgba(113, 128, 150, var(--divide-opacity));\n  }\n\n  .xl\\:divide-gray-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #4a5568;\n    border-color: rgba(74, 85, 104, var(--divide-opacity));\n  }\n\n  .xl\\:divide-gray-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #2d3748;\n    border-color: rgba(45, 55, 72, var(--divide-opacity));\n  }\n\n  .xl\\:divide-gray-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #1a202c;\n    border-color: rgba(26, 32, 44, var(--divide-opacity));\n  }\n\n  .xl\\:divide-red-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fff5f5;\n    border-color: rgba(255, 245, 245, var(--divide-opacity));\n  }\n\n  .xl\\:divide-red-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fed7d7;\n    border-color: rgba(254, 215, 215, var(--divide-opacity));\n  }\n\n  .xl\\:divide-red-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #feb2b2;\n    border-color: rgba(254, 178, 178, var(--divide-opacity));\n  }\n\n  .xl\\:divide-red-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fc8181;\n    border-color: rgba(252, 129, 129, var(--divide-opacity));\n  }\n\n  .xl\\:divide-red-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #f56565;\n    border-color: rgba(245, 101, 101, var(--divide-opacity));\n  }\n\n  .xl\\:divide-red-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #e53e3e;\n    border-color: rgba(229, 62, 62, var(--divide-opacity));\n  }\n\n  .xl\\:divide-red-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #c53030;\n    border-color: rgba(197, 48, 48, var(--divide-opacity));\n  }\n\n  .xl\\:divide-red-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #9b2c2c;\n    border-color: rgba(155, 44, 44, var(--divide-opacity));\n  }\n\n  .xl\\:divide-red-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #742a2a;\n    border-color: rgba(116, 42, 42, var(--divide-opacity));\n  }\n\n  .xl\\:divide-orange-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fffaf0;\n    border-color: rgba(255, 250, 240, var(--divide-opacity));\n  }\n\n  .xl\\:divide-orange-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #feebc8;\n    border-color: rgba(254, 235, 200, var(--divide-opacity));\n  }\n\n  .xl\\:divide-orange-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fbd38d;\n    border-color: rgba(251, 211, 141, var(--divide-opacity));\n  }\n\n  .xl\\:divide-orange-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #f6ad55;\n    border-color: rgba(246, 173, 85, var(--divide-opacity));\n  }\n\n  .xl\\:divide-orange-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #ed8936;\n    border-color: rgba(237, 137, 54, var(--divide-opacity));\n  }\n\n  .xl\\:divide-orange-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #dd6b20;\n    border-color: rgba(221, 107, 32, var(--divide-opacity));\n  }\n\n  .xl\\:divide-orange-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #c05621;\n    border-color: rgba(192, 86, 33, var(--divide-opacity));\n  }\n\n  .xl\\:divide-orange-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #9c4221;\n    border-color: rgba(156, 66, 33, var(--divide-opacity));\n  }\n\n  .xl\\:divide-orange-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #7b341e;\n    border-color: rgba(123, 52, 30, var(--divide-opacity));\n  }\n\n  .xl\\:divide-yellow-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fffff0;\n    border-color: rgba(255, 255, 240, var(--divide-opacity));\n  }\n\n  .xl\\:divide-yellow-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fefcbf;\n    border-color: rgba(254, 252, 191, var(--divide-opacity));\n  }\n\n  .xl\\:divide-yellow-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #faf089;\n    border-color: rgba(250, 240, 137, var(--divide-opacity));\n  }\n\n  .xl\\:divide-yellow-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #f6e05e;\n    border-color: rgba(246, 224, 94, var(--divide-opacity));\n  }\n\n  .xl\\:divide-yellow-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #ecc94b;\n    border-color: rgba(236, 201, 75, var(--divide-opacity));\n  }\n\n  .xl\\:divide-yellow-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #d69e2e;\n    border-color: rgba(214, 158, 46, var(--divide-opacity));\n  }\n\n  .xl\\:divide-yellow-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #b7791f;\n    border-color: rgba(183, 121, 31, var(--divide-opacity));\n  }\n\n  .xl\\:divide-yellow-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #975a16;\n    border-color: rgba(151, 90, 22, var(--divide-opacity));\n  }\n\n  .xl\\:divide-yellow-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #744210;\n    border-color: rgba(116, 66, 16, var(--divide-opacity));\n  }\n\n  .xl\\:divide-green-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #f0fff4;\n    border-color: rgba(240, 255, 244, var(--divide-opacity));\n  }\n\n  .xl\\:divide-green-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #c6f6d5;\n    border-color: rgba(198, 246, 213, var(--divide-opacity));\n  }\n\n  .xl\\:divide-green-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #9ae6b4;\n    border-color: rgba(154, 230, 180, var(--divide-opacity));\n  }\n\n  .xl\\:divide-green-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #68d391;\n    border-color: rgba(104, 211, 145, var(--divide-opacity));\n  }\n\n  .xl\\:divide-green-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #48bb78;\n    border-color: rgba(72, 187, 120, var(--divide-opacity));\n  }\n\n  .xl\\:divide-green-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #38a169;\n    border-color: rgba(56, 161, 105, var(--divide-opacity));\n  }\n\n  .xl\\:divide-green-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #2f855a;\n    border-color: rgba(47, 133, 90, var(--divide-opacity));\n  }\n\n  .xl\\:divide-green-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #276749;\n    border-color: rgba(39, 103, 73, var(--divide-opacity));\n  }\n\n  .xl\\:divide-green-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #22543d;\n    border-color: rgba(34, 84, 61, var(--divide-opacity));\n  }\n\n  .xl\\:divide-teal-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #e6fffa;\n    border-color: rgba(230, 255, 250, var(--divide-opacity));\n  }\n\n  .xl\\:divide-teal-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #b2f5ea;\n    border-color: rgba(178, 245, 234, var(--divide-opacity));\n  }\n\n  .xl\\:divide-teal-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #81e6d9;\n    border-color: rgba(129, 230, 217, var(--divide-opacity));\n  }\n\n  .xl\\:divide-teal-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #4fd1c5;\n    border-color: rgba(79, 209, 197, var(--divide-opacity));\n  }\n\n  .xl\\:divide-teal-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #38b2ac;\n    border-color: rgba(56, 178, 172, var(--divide-opacity));\n  }\n\n  .xl\\:divide-teal-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #319795;\n    border-color: rgba(49, 151, 149, var(--divide-opacity));\n  }\n\n  .xl\\:divide-teal-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #2c7a7b;\n    border-color: rgba(44, 122, 123, var(--divide-opacity));\n  }\n\n  .xl\\:divide-teal-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #285e61;\n    border-color: rgba(40, 94, 97, var(--divide-opacity));\n  }\n\n  .xl\\:divide-teal-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #234e52;\n    border-color: rgba(35, 78, 82, var(--divide-opacity));\n  }\n\n  .xl\\:divide-blue-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #ebf8ff;\n    border-color: rgba(235, 248, 255, var(--divide-opacity));\n  }\n\n  .xl\\:divide-blue-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #bee3f8;\n    border-color: rgba(190, 227, 248, var(--divide-opacity));\n  }\n\n  .xl\\:divide-blue-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #90cdf4;\n    border-color: rgba(144, 205, 244, var(--divide-opacity));\n  }\n\n  .xl\\:divide-blue-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #63b3ed;\n    border-color: rgba(99, 179, 237, var(--divide-opacity));\n  }\n\n  .xl\\:divide-blue-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #4299e1;\n    border-color: rgba(66, 153, 225, var(--divide-opacity));\n  }\n\n  .xl\\:divide-blue-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #3182ce;\n    border-color: rgba(49, 130, 206, var(--divide-opacity));\n  }\n\n  .xl\\:divide-blue-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #2b6cb0;\n    border-color: rgba(43, 108, 176, var(--divide-opacity));\n  }\n\n  .xl\\:divide-blue-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #2c5282;\n    border-color: rgba(44, 82, 130, var(--divide-opacity));\n  }\n\n  .xl\\:divide-blue-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #2a4365;\n    border-color: rgba(42, 67, 101, var(--divide-opacity));\n  }\n\n  .xl\\:divide-indigo-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #ebf4ff;\n    border-color: rgba(235, 244, 255, var(--divide-opacity));\n  }\n\n  .xl\\:divide-indigo-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #c3dafe;\n    border-color: rgba(195, 218, 254, var(--divide-opacity));\n  }\n\n  .xl\\:divide-indigo-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #a3bffa;\n    border-color: rgba(163, 191, 250, var(--divide-opacity));\n  }\n\n  .xl\\:divide-indigo-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #7f9cf5;\n    border-color: rgba(127, 156, 245, var(--divide-opacity));\n  }\n\n  .xl\\:divide-indigo-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #667eea;\n    border-color: rgba(102, 126, 234, var(--divide-opacity));\n  }\n\n  .xl\\:divide-indigo-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #5a67d8;\n    border-color: rgba(90, 103, 216, var(--divide-opacity));\n  }\n\n  .xl\\:divide-indigo-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #4c51bf;\n    border-color: rgba(76, 81, 191, var(--divide-opacity));\n  }\n\n  .xl\\:divide-indigo-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #434190;\n    border-color: rgba(67, 65, 144, var(--divide-opacity));\n  }\n\n  .xl\\:divide-indigo-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #3c366b;\n    border-color: rgba(60, 54, 107, var(--divide-opacity));\n  }\n\n  .xl\\:divide-purple-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #faf5ff;\n    border-color: rgba(250, 245, 255, var(--divide-opacity));\n  }\n\n  .xl\\:divide-purple-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #e9d8fd;\n    border-color: rgba(233, 216, 253, var(--divide-opacity));\n  }\n\n  .xl\\:divide-purple-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #d6bcfa;\n    border-color: rgba(214, 188, 250, var(--divide-opacity));\n  }\n\n  .xl\\:divide-purple-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #b794f4;\n    border-color: rgba(183, 148, 244, var(--divide-opacity));\n  }\n\n  .xl\\:divide-purple-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #9f7aea;\n    border-color: rgba(159, 122, 234, var(--divide-opacity));\n  }\n\n  .xl\\:divide-purple-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #805ad5;\n    border-color: rgba(128, 90, 213, var(--divide-opacity));\n  }\n\n  .xl\\:divide-purple-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #6b46c1;\n    border-color: rgba(107, 70, 193, var(--divide-opacity));\n  }\n\n  .xl\\:divide-purple-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #553c9a;\n    border-color: rgba(85, 60, 154, var(--divide-opacity));\n  }\n\n  .xl\\:divide-purple-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #44337a;\n    border-color: rgba(68, 51, 122, var(--divide-opacity));\n  }\n\n  .xl\\:divide-pink-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fff5f7;\n    border-color: rgba(255, 245, 247, var(--divide-opacity));\n  }\n\n  .xl\\:divide-pink-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fed7e2;\n    border-color: rgba(254, 215, 226, var(--divide-opacity));\n  }\n\n  .xl\\:divide-pink-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #fbb6ce;\n    border-color: rgba(251, 182, 206, var(--divide-opacity));\n  }\n\n  .xl\\:divide-pink-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #f687b3;\n    border-color: rgba(246, 135, 179, var(--divide-opacity));\n  }\n\n  .xl\\:divide-pink-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #ed64a6;\n    border-color: rgba(237, 100, 166, var(--divide-opacity));\n  }\n\n  .xl\\:divide-pink-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #d53f8c;\n    border-color: rgba(213, 63, 140, var(--divide-opacity));\n  }\n\n  .xl\\:divide-pink-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #b83280;\n    border-color: rgba(184, 50, 128, var(--divide-opacity));\n  }\n\n  .xl\\:divide-pink-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #97266d;\n    border-color: rgba(151, 38, 109, var(--divide-opacity));\n  }\n\n  .xl\\:divide-pink-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: #702459;\n    border-color: rgba(112, 36, 89, var(--divide-opacity));\n  }\n\n  .xl\\:divide-grayscale-80 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 8%);\n    border-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--divide-opacity));\n  }\n\n  .xl\\:divide-grayscale-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 10%);\n    border-color: rgba(25.5, 25.5, 25.5, var(--divide-opacity));\n  }\n\n  .xl\\:divide-grayscale-200 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 20%);\n    border-color: rgba(51, 51, 51, var(--divide-opacity));\n  }\n\n  .xl\\:divide-grayscale-300 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 30%);\n    border-color: rgba(76.5, 76.5, 76.5, var(--divide-opacity));\n  }\n\n  .xl\\:divide-grayscale-400 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 40%);\n    border-color: rgba(102, 102, 102, var(--divide-opacity));\n  }\n\n  .xl\\:divide-grayscale-500 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 50%);\n    border-color: rgba(127.5, 127.5, 127.5, var(--divide-opacity));\n  }\n\n  .xl\\:divide-grayscale-600 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 60%);\n    border-color: rgba(153, 153, 153, var(--divide-opacity));\n  }\n\n  .xl\\:divide-grayscale-700 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 70%);\n    border-color: rgba(178.5, 178.5, 178.5, var(--divide-opacity));\n  }\n\n  .xl\\:divide-grayscale-800 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 80%);\n    border-color: rgba(204, 204, 204, var(--divide-opacity));\n  }\n\n  .xl\\:divide-grayscale-840 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 84%);\n    border-color: rgba(214.2, 214.2, 214.2, var(--divide-opacity));\n  }\n\n  .xl\\:divide-grayscale-870 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 87%);\n    border-color: rgba(221.85, 221.85, 221.85, var(--divide-opacity));\n  }\n\n  .xl\\:divide-grayscale-900 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 90%);\n    border-color: rgba(229.5, 229.5, 229.5, var(--divide-opacity));\n  }\n\n  .xl\\:divide-grayscale-930 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(0, 0%, 93%);\n    border-color: rgba(237.15, 237.15, 237.15, var(--divide-opacity));\n  }\n\n  .xl\\:divide-primary > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n    border-color: hsl(210, 100%, 52%);\n    border-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--divide-opacity));\n  }\n\n  .xl\\:divide-background-main > :not(template) ~ :not(template) {\n    border-color: var(--main-background);\n  }\n\n  .xl\\:divide-background-secondary > :not(template) ~ :not(template) {\n    border-color: var(--secondary-background);\n  }\n\n  .xl\\:divide-foreground > :not(template) ~ :not(template) {\n    border-color: var(--foreground);\n  }\n\n  .xl\\:divide-panels-bg > :not(template) ~ :not(template) {\n    border-color: var(--panels-background);\n  }\n\n  .xl\\:divide-solid > :not(template) ~ :not(template) {\n    border-style: solid;\n  }\n\n  .xl\\:divide-dashed > :not(template) ~ :not(template) {\n    border-style: dashed;\n  }\n\n  .xl\\:divide-dotted > :not(template) ~ :not(template) {\n    border-style: dotted;\n  }\n\n  .xl\\:divide-double > :not(template) ~ :not(template) {\n    border-style: double;\n  }\n\n  .xl\\:divide-none > :not(template) ~ :not(template) {\n    border-style: none;\n  }\n\n  .xl\\:divide-opacity-0 > :not(template) ~ :not(template) {\n    --divide-opacity: 0;\n  }\n\n  .xl\\:divide-opacity-25 > :not(template) ~ :not(template) {\n    --divide-opacity: 0.25;\n  }\n\n  .xl\\:divide-opacity-50 > :not(template) ~ :not(template) {\n    --divide-opacity: 0.5;\n  }\n\n  .xl\\:divide-opacity-75 > :not(template) ~ :not(template) {\n    --divide-opacity: 0.75;\n  }\n\n  .xl\\:divide-opacity-100 > :not(template) ~ :not(template) {\n    --divide-opacity: 1;\n  }\n\n  .xl\\:sr-only {\n    position: absolute;\n    width: 1px;\n    height: 1px;\n    padding: 0;\n    margin: -1px;\n    overflow: hidden;\n    clip: rect(0, 0, 0, 0);\n    white-space: nowrap;\n    border-width: 0;\n  }\n\n  .xl\\:not-sr-only {\n    position: static;\n    width: auto;\n    height: auto;\n    padding: 0;\n    margin: 0;\n    overflow: visible;\n    clip: auto;\n    white-space: normal;\n  }\n\n  .xl\\:focus\\:sr-only:focus {\n    position: absolute;\n    width: 1px;\n    height: 1px;\n    padding: 0;\n    margin: -1px;\n    overflow: hidden;\n    clip: rect(0, 0, 0, 0);\n    white-space: nowrap;\n    border-width: 0;\n  }\n\n  .xl\\:focus\\:not-sr-only:focus {\n    position: static;\n    width: auto;\n    height: auto;\n    padding: 0;\n    margin: 0;\n    overflow: visible;\n    clip: auto;\n    white-space: normal;\n  }\n\n  .xl\\:appearance-none {\n    -webkit-appearance: none;\n       -moz-appearance: none;\n            appearance: none;\n  }\n\n  .xl\\:bg-fixed {\n    background-attachment: fixed;\n  }\n\n  .xl\\:bg-local {\n    background-attachment: local;\n  }\n\n  .xl\\:bg-scroll {\n    background-attachment: scroll;\n  }\n\n  .xl\\:bg-clip-border {\n    background-clip: border-box;\n  }\n\n  .xl\\:bg-clip-padding {\n    background-clip: padding-box;\n  }\n\n  .xl\\:bg-clip-content {\n    background-clip: content-box;\n  }\n\n  .xl\\:bg-clip-text {\n    -webkit-background-clip: text;\n            background-clip: text;\n  }\n\n  .xl\\:bg-transparent {\n    background-color: transparent;\n  }\n\n  .xl\\:bg-current {\n    background-color: currentColor;\n  }\n\n  .xl\\:bg-black {\n    --bg-opacity: 1;\n    background-color: #000;\n    background-color: rgba(0, 0, 0, var(--bg-opacity));\n  }\n\n  .xl\\:bg-white {\n    --bg-opacity: 1;\n    background-color: #fff;\n    background-color: rgba(255, 255, 255, var(--bg-opacity));\n  }\n\n  .xl\\:bg-gray-100 {\n    --bg-opacity: 1;\n    background-color: #f7fafc;\n    background-color: rgba(247, 250, 252, var(--bg-opacity));\n  }\n\n  .xl\\:bg-gray-200 {\n    --bg-opacity: 1;\n    background-color: #edf2f7;\n    background-color: rgba(237, 242, 247, var(--bg-opacity));\n  }\n\n  .xl\\:bg-gray-300 {\n    --bg-opacity: 1;\n    background-color: #e2e8f0;\n    background-color: rgba(226, 232, 240, var(--bg-opacity));\n  }\n\n  .xl\\:bg-gray-400 {\n    --bg-opacity: 1;\n    background-color: #cbd5e0;\n    background-color: rgba(203, 213, 224, var(--bg-opacity));\n  }\n\n  .xl\\:bg-gray-500 {\n    --bg-opacity: 1;\n    background-color: #a0aec0;\n    background-color: rgba(160, 174, 192, var(--bg-opacity));\n  }\n\n  .xl\\:bg-gray-600 {\n    --bg-opacity: 1;\n    background-color: #718096;\n    background-color: rgba(113, 128, 150, var(--bg-opacity));\n  }\n\n  .xl\\:bg-gray-700 {\n    --bg-opacity: 1;\n    background-color: #4a5568;\n    background-color: rgba(74, 85, 104, var(--bg-opacity));\n  }\n\n  .xl\\:bg-gray-800 {\n    --bg-opacity: 1;\n    background-color: #2d3748;\n    background-color: rgba(45, 55, 72, var(--bg-opacity));\n  }\n\n  .xl\\:bg-gray-900 {\n    --bg-opacity: 1;\n    background-color: #1a202c;\n    background-color: rgba(26, 32, 44, var(--bg-opacity));\n  }\n\n  .xl\\:bg-red-100 {\n    --bg-opacity: 1;\n    background-color: #fff5f5;\n    background-color: rgba(255, 245, 245, var(--bg-opacity));\n  }\n\n  .xl\\:bg-red-200 {\n    --bg-opacity: 1;\n    background-color: #fed7d7;\n    background-color: rgba(254, 215, 215, var(--bg-opacity));\n  }\n\n  .xl\\:bg-red-300 {\n    --bg-opacity: 1;\n    background-color: #feb2b2;\n    background-color: rgba(254, 178, 178, var(--bg-opacity));\n  }\n\n  .xl\\:bg-red-400 {\n    --bg-opacity: 1;\n    background-color: #fc8181;\n    background-color: rgba(252, 129, 129, var(--bg-opacity));\n  }\n\n  .xl\\:bg-red-500 {\n    --bg-opacity: 1;\n    background-color: #f56565;\n    background-color: rgba(245, 101, 101, var(--bg-opacity));\n  }\n\n  .xl\\:bg-red-600 {\n    --bg-opacity: 1;\n    background-color: #e53e3e;\n    background-color: rgba(229, 62, 62, var(--bg-opacity));\n  }\n\n  .xl\\:bg-red-700 {\n    --bg-opacity: 1;\n    background-color: #c53030;\n    background-color: rgba(197, 48, 48, var(--bg-opacity));\n  }\n\n  .xl\\:bg-red-800 {\n    --bg-opacity: 1;\n    background-color: #9b2c2c;\n    background-color: rgba(155, 44, 44, var(--bg-opacity));\n  }\n\n  .xl\\:bg-red-900 {\n    --bg-opacity: 1;\n    background-color: #742a2a;\n    background-color: rgba(116, 42, 42, var(--bg-opacity));\n  }\n\n  .xl\\:bg-orange-100 {\n    --bg-opacity: 1;\n    background-color: #fffaf0;\n    background-color: rgba(255, 250, 240, var(--bg-opacity));\n  }\n\n  .xl\\:bg-orange-200 {\n    --bg-opacity: 1;\n    background-color: #feebc8;\n    background-color: rgba(254, 235, 200, var(--bg-opacity));\n  }\n\n  .xl\\:bg-orange-300 {\n    --bg-opacity: 1;\n    background-color: #fbd38d;\n    background-color: rgba(251, 211, 141, var(--bg-opacity));\n  }\n\n  .xl\\:bg-orange-400 {\n    --bg-opacity: 1;\n    background-color: #f6ad55;\n    background-color: rgba(246, 173, 85, var(--bg-opacity));\n  }\n\n  .xl\\:bg-orange-500 {\n    --bg-opacity: 1;\n    background-color: #ed8936;\n    background-color: rgba(237, 137, 54, var(--bg-opacity));\n  }\n\n  .xl\\:bg-orange-600 {\n    --bg-opacity: 1;\n    background-color: #dd6b20;\n    background-color: rgba(221, 107, 32, var(--bg-opacity));\n  }\n\n  .xl\\:bg-orange-700 {\n    --bg-opacity: 1;\n    background-color: #c05621;\n    background-color: rgba(192, 86, 33, var(--bg-opacity));\n  }\n\n  .xl\\:bg-orange-800 {\n    --bg-opacity: 1;\n    background-color: #9c4221;\n    background-color: rgba(156, 66, 33, var(--bg-opacity));\n  }\n\n  .xl\\:bg-orange-900 {\n    --bg-opacity: 1;\n    background-color: #7b341e;\n    background-color: rgba(123, 52, 30, var(--bg-opacity));\n  }\n\n  .xl\\:bg-yellow-100 {\n    --bg-opacity: 1;\n    background-color: #fffff0;\n    background-color: rgba(255, 255, 240, var(--bg-opacity));\n  }\n\n  .xl\\:bg-yellow-200 {\n    --bg-opacity: 1;\n    background-color: #fefcbf;\n    background-color: rgba(254, 252, 191, var(--bg-opacity));\n  }\n\n  .xl\\:bg-yellow-300 {\n    --bg-opacity: 1;\n    background-color: #faf089;\n    background-color: rgba(250, 240, 137, var(--bg-opacity));\n  }\n\n  .xl\\:bg-yellow-400 {\n    --bg-opacity: 1;\n    background-color: #f6e05e;\n    background-color: rgba(246, 224, 94, var(--bg-opacity));\n  }\n\n  .xl\\:bg-yellow-500 {\n    --bg-opacity: 1;\n    background-color: #ecc94b;\n    background-color: rgba(236, 201, 75, var(--bg-opacity));\n  }\n\n  .xl\\:bg-yellow-600 {\n    --bg-opacity: 1;\n    background-color: #d69e2e;\n    background-color: rgba(214, 158, 46, var(--bg-opacity));\n  }\n\n  .xl\\:bg-yellow-700 {\n    --bg-opacity: 1;\n    background-color: #b7791f;\n    background-color: rgba(183, 121, 31, var(--bg-opacity));\n  }\n\n  .xl\\:bg-yellow-800 {\n    --bg-opacity: 1;\n    background-color: #975a16;\n    background-color: rgba(151, 90, 22, var(--bg-opacity));\n  }\n\n  .xl\\:bg-yellow-900 {\n    --bg-opacity: 1;\n    background-color: #744210;\n    background-color: rgba(116, 66, 16, var(--bg-opacity));\n  }\n\n  .xl\\:bg-green-100 {\n    --bg-opacity: 1;\n    background-color: #f0fff4;\n    background-color: rgba(240, 255, 244, var(--bg-opacity));\n  }\n\n  .xl\\:bg-green-200 {\n    --bg-opacity: 1;\n    background-color: #c6f6d5;\n    background-color: rgba(198, 246, 213, var(--bg-opacity));\n  }\n\n  .xl\\:bg-green-300 {\n    --bg-opacity: 1;\n    background-color: #9ae6b4;\n    background-color: rgba(154, 230, 180, var(--bg-opacity));\n  }\n\n  .xl\\:bg-green-400 {\n    --bg-opacity: 1;\n    background-color: #68d391;\n    background-color: rgba(104, 211, 145, var(--bg-opacity));\n  }\n\n  .xl\\:bg-green-500 {\n    --bg-opacity: 1;\n    background-color: #48bb78;\n    background-color: rgba(72, 187, 120, var(--bg-opacity));\n  }\n\n  .xl\\:bg-green-600 {\n    --bg-opacity: 1;\n    background-color: #38a169;\n    background-color: rgba(56, 161, 105, var(--bg-opacity));\n  }\n\n  .xl\\:bg-green-700 {\n    --bg-opacity: 1;\n    background-color: #2f855a;\n    background-color: rgba(47, 133, 90, var(--bg-opacity));\n  }\n\n  .xl\\:bg-green-800 {\n    --bg-opacity: 1;\n    background-color: #276749;\n    background-color: rgba(39, 103, 73, var(--bg-opacity));\n  }\n\n  .xl\\:bg-green-900 {\n    --bg-opacity: 1;\n    background-color: #22543d;\n    background-color: rgba(34, 84, 61, var(--bg-opacity));\n  }\n\n  .xl\\:bg-teal-100 {\n    --bg-opacity: 1;\n    background-color: #e6fffa;\n    background-color: rgba(230, 255, 250, var(--bg-opacity));\n  }\n\n  .xl\\:bg-teal-200 {\n    --bg-opacity: 1;\n    background-color: #b2f5ea;\n    background-color: rgba(178, 245, 234, var(--bg-opacity));\n  }\n\n  .xl\\:bg-teal-300 {\n    --bg-opacity: 1;\n    background-color: #81e6d9;\n    background-color: rgba(129, 230, 217, var(--bg-opacity));\n  }\n\n  .xl\\:bg-teal-400 {\n    --bg-opacity: 1;\n    background-color: #4fd1c5;\n    background-color: rgba(79, 209, 197, var(--bg-opacity));\n  }\n\n  .xl\\:bg-teal-500 {\n    --bg-opacity: 1;\n    background-color: #38b2ac;\n    background-color: rgba(56, 178, 172, var(--bg-opacity));\n  }\n\n  .xl\\:bg-teal-600 {\n    --bg-opacity: 1;\n    background-color: #319795;\n    background-color: rgba(49, 151, 149, var(--bg-opacity));\n  }\n\n  .xl\\:bg-teal-700 {\n    --bg-opacity: 1;\n    background-color: #2c7a7b;\n    background-color: rgba(44, 122, 123, var(--bg-opacity));\n  }\n\n  .xl\\:bg-teal-800 {\n    --bg-opacity: 1;\n    background-color: #285e61;\n    background-color: rgba(40, 94, 97, var(--bg-opacity));\n  }\n\n  .xl\\:bg-teal-900 {\n    --bg-opacity: 1;\n    background-color: #234e52;\n    background-color: rgba(35, 78, 82, var(--bg-opacity));\n  }\n\n  .xl\\:bg-blue-100 {\n    --bg-opacity: 1;\n    background-color: #ebf8ff;\n    background-color: rgba(235, 248, 255, var(--bg-opacity));\n  }\n\n  .xl\\:bg-blue-200 {\n    --bg-opacity: 1;\n    background-color: #bee3f8;\n    background-color: rgba(190, 227, 248, var(--bg-opacity));\n  }\n\n  .xl\\:bg-blue-300 {\n    --bg-opacity: 1;\n    background-color: #90cdf4;\n    background-color: rgba(144, 205, 244, var(--bg-opacity));\n  }\n\n  .xl\\:bg-blue-400 {\n    --bg-opacity: 1;\n    background-color: #63b3ed;\n    background-color: rgba(99, 179, 237, var(--bg-opacity));\n  }\n\n  .xl\\:bg-blue-500 {\n    --bg-opacity: 1;\n    background-color: #4299e1;\n    background-color: rgba(66, 153, 225, var(--bg-opacity));\n  }\n\n  .xl\\:bg-blue-600 {\n    --bg-opacity: 1;\n    background-color: #3182ce;\n    background-color: rgba(49, 130, 206, var(--bg-opacity));\n  }\n\n  .xl\\:bg-blue-700 {\n    --bg-opacity: 1;\n    background-color: #2b6cb0;\n    background-color: rgba(43, 108, 176, var(--bg-opacity));\n  }\n\n  .xl\\:bg-blue-800 {\n    --bg-opacity: 1;\n    background-color: #2c5282;\n    background-color: rgba(44, 82, 130, var(--bg-opacity));\n  }\n\n  .xl\\:bg-blue-900 {\n    --bg-opacity: 1;\n    background-color: #2a4365;\n    background-color: rgba(42, 67, 101, var(--bg-opacity));\n  }\n\n  .xl\\:bg-indigo-100 {\n    --bg-opacity: 1;\n    background-color: #ebf4ff;\n    background-color: rgba(235, 244, 255, var(--bg-opacity));\n  }\n\n  .xl\\:bg-indigo-200 {\n    --bg-opacity: 1;\n    background-color: #c3dafe;\n    background-color: rgba(195, 218, 254, var(--bg-opacity));\n  }\n\n  .xl\\:bg-indigo-300 {\n    --bg-opacity: 1;\n    background-color: #a3bffa;\n    background-color: rgba(163, 191, 250, var(--bg-opacity));\n  }\n\n  .xl\\:bg-indigo-400 {\n    --bg-opacity: 1;\n    background-color: #7f9cf5;\n    background-color: rgba(127, 156, 245, var(--bg-opacity));\n  }\n\n  .xl\\:bg-indigo-500 {\n    --bg-opacity: 1;\n    background-color: #667eea;\n    background-color: rgba(102, 126, 234, var(--bg-opacity));\n  }\n\n  .xl\\:bg-indigo-600 {\n    --bg-opacity: 1;\n    background-color: #5a67d8;\n    background-color: rgba(90, 103, 216, var(--bg-opacity));\n  }\n\n  .xl\\:bg-indigo-700 {\n    --bg-opacity: 1;\n    background-color: #4c51bf;\n    background-color: rgba(76, 81, 191, var(--bg-opacity));\n  }\n\n  .xl\\:bg-indigo-800 {\n    --bg-opacity: 1;\n    background-color: #434190;\n    background-color: rgba(67, 65, 144, var(--bg-opacity));\n  }\n\n  .xl\\:bg-indigo-900 {\n    --bg-opacity: 1;\n    background-color: #3c366b;\n    background-color: rgba(60, 54, 107, var(--bg-opacity));\n  }\n\n  .xl\\:bg-purple-100 {\n    --bg-opacity: 1;\n    background-color: #faf5ff;\n    background-color: rgba(250, 245, 255, var(--bg-opacity));\n  }\n\n  .xl\\:bg-purple-200 {\n    --bg-opacity: 1;\n    background-color: #e9d8fd;\n    background-color: rgba(233, 216, 253, var(--bg-opacity));\n  }\n\n  .xl\\:bg-purple-300 {\n    --bg-opacity: 1;\n    background-color: #d6bcfa;\n    background-color: rgba(214, 188, 250, var(--bg-opacity));\n  }\n\n  .xl\\:bg-purple-400 {\n    --bg-opacity: 1;\n    background-color: #b794f4;\n    background-color: rgba(183, 148, 244, var(--bg-opacity));\n  }\n\n  .xl\\:bg-purple-500 {\n    --bg-opacity: 1;\n    background-color: #9f7aea;\n    background-color: rgba(159, 122, 234, var(--bg-opacity));\n  }\n\n  .xl\\:bg-purple-600 {\n    --bg-opacity: 1;\n    background-color: #805ad5;\n    background-color: rgba(128, 90, 213, var(--bg-opacity));\n  }\n\n  .xl\\:bg-purple-700 {\n    --bg-opacity: 1;\n    background-color: #6b46c1;\n    background-color: rgba(107, 70, 193, var(--bg-opacity));\n  }\n\n  .xl\\:bg-purple-800 {\n    --bg-opacity: 1;\n    background-color: #553c9a;\n    background-color: rgba(85, 60, 154, var(--bg-opacity));\n  }\n\n  .xl\\:bg-purple-900 {\n    --bg-opacity: 1;\n    background-color: #44337a;\n    background-color: rgba(68, 51, 122, var(--bg-opacity));\n  }\n\n  .xl\\:bg-pink-100 {\n    --bg-opacity: 1;\n    background-color: #fff5f7;\n    background-color: rgba(255, 245, 247, var(--bg-opacity));\n  }\n\n  .xl\\:bg-pink-200 {\n    --bg-opacity: 1;\n    background-color: #fed7e2;\n    background-color: rgba(254, 215, 226, var(--bg-opacity));\n  }\n\n  .xl\\:bg-pink-300 {\n    --bg-opacity: 1;\n    background-color: #fbb6ce;\n    background-color: rgba(251, 182, 206, var(--bg-opacity));\n  }\n\n  .xl\\:bg-pink-400 {\n    --bg-opacity: 1;\n    background-color: #f687b3;\n    background-color: rgba(246, 135, 179, var(--bg-opacity));\n  }\n\n  .xl\\:bg-pink-500 {\n    --bg-opacity: 1;\n    background-color: #ed64a6;\n    background-color: rgba(237, 100, 166, var(--bg-opacity));\n  }\n\n  .xl\\:bg-pink-600 {\n    --bg-opacity: 1;\n    background-color: #d53f8c;\n    background-color: rgba(213, 63, 140, var(--bg-opacity));\n  }\n\n  .xl\\:bg-pink-700 {\n    --bg-opacity: 1;\n    background-color: #b83280;\n    background-color: rgba(184, 50, 128, var(--bg-opacity));\n  }\n\n  .xl\\:bg-pink-800 {\n    --bg-opacity: 1;\n    background-color: #97266d;\n    background-color: rgba(151, 38, 109, var(--bg-opacity));\n  }\n\n  .xl\\:bg-pink-900 {\n    --bg-opacity: 1;\n    background-color: #702459;\n    background-color: rgba(112, 36, 89, var(--bg-opacity));\n  }\n\n  .xl\\:bg-grayscale-80 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 8%);\n    background-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--bg-opacity));\n  }\n\n  .xl\\:bg-grayscale-100 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 10%);\n    background-color: rgba(25.5, 25.5, 25.5, var(--bg-opacity));\n  }\n\n  .xl\\:bg-grayscale-200 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 20%);\n    background-color: rgba(51, 51, 51, var(--bg-opacity));\n  }\n\n  .xl\\:bg-grayscale-300 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 30%);\n    background-color: rgba(76.5, 76.5, 76.5, var(--bg-opacity));\n  }\n\n  .xl\\:bg-grayscale-400 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 40%);\n    background-color: rgba(102, 102, 102, var(--bg-opacity));\n  }\n\n  .xl\\:bg-grayscale-500 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 50%);\n    background-color: rgba(127.5, 127.5, 127.5, var(--bg-opacity));\n  }\n\n  .xl\\:bg-grayscale-600 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 60%);\n    background-color: rgba(153, 153, 153, var(--bg-opacity));\n  }\n\n  .xl\\:bg-grayscale-700 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 70%);\n    background-color: rgba(178.5, 178.5, 178.5, var(--bg-opacity));\n  }\n\n  .xl\\:bg-grayscale-800 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 80%);\n    background-color: rgba(204, 204, 204, var(--bg-opacity));\n  }\n\n  .xl\\:bg-grayscale-840 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 84%);\n    background-color: rgba(214.2, 214.2, 214.2, var(--bg-opacity));\n  }\n\n  .xl\\:bg-grayscale-870 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 87%);\n    background-color: rgba(221.85, 221.85, 221.85, var(--bg-opacity));\n  }\n\n  .xl\\:bg-grayscale-900 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 90%);\n    background-color: rgba(229.5, 229.5, 229.5, var(--bg-opacity));\n  }\n\n  .xl\\:bg-grayscale-930 {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 93%);\n    background-color: rgba(237.15, 237.15, 237.15, var(--bg-opacity));\n  }\n\n  .xl\\:bg-primary {\n    --bg-opacity: 1;\n    background-color: hsl(210, 100%, 52%);\n    background-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--bg-opacity));\n  }\n\n  .xl\\:bg-background-main {\n    background-color: var(--main-background);\n  }\n\n  .xl\\:bg-background-secondary {\n    background-color: var(--secondary-background);\n  }\n\n  .xl\\:bg-foreground {\n    background-color: var(--foreground);\n  }\n\n  .xl\\:bg-panels-bg {\n    background-color: var(--panels-background);\n  }\n\n  .xl\\:hover\\:bg-transparent:hover {\n    background-color: transparent;\n  }\n\n  .xl\\:hover\\:bg-current:hover {\n    background-color: currentColor;\n  }\n\n  .xl\\:hover\\:bg-black:hover {\n    --bg-opacity: 1;\n    background-color: #000;\n    background-color: rgba(0, 0, 0, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-white:hover {\n    --bg-opacity: 1;\n    background-color: #fff;\n    background-color: rgba(255, 255, 255, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-gray-100:hover {\n    --bg-opacity: 1;\n    background-color: #f7fafc;\n    background-color: rgba(247, 250, 252, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-gray-200:hover {\n    --bg-opacity: 1;\n    background-color: #edf2f7;\n    background-color: rgba(237, 242, 247, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-gray-300:hover {\n    --bg-opacity: 1;\n    background-color: #e2e8f0;\n    background-color: rgba(226, 232, 240, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-gray-400:hover {\n    --bg-opacity: 1;\n    background-color: #cbd5e0;\n    background-color: rgba(203, 213, 224, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-gray-500:hover {\n    --bg-opacity: 1;\n    background-color: #a0aec0;\n    background-color: rgba(160, 174, 192, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-gray-600:hover {\n    --bg-opacity: 1;\n    background-color: #718096;\n    background-color: rgba(113, 128, 150, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-gray-700:hover {\n    --bg-opacity: 1;\n    background-color: #4a5568;\n    background-color: rgba(74, 85, 104, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-gray-800:hover {\n    --bg-opacity: 1;\n    background-color: #2d3748;\n    background-color: rgba(45, 55, 72, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-gray-900:hover {\n    --bg-opacity: 1;\n    background-color: #1a202c;\n    background-color: rgba(26, 32, 44, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-red-100:hover {\n    --bg-opacity: 1;\n    background-color: #fff5f5;\n    background-color: rgba(255, 245, 245, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-red-200:hover {\n    --bg-opacity: 1;\n    background-color: #fed7d7;\n    background-color: rgba(254, 215, 215, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-red-300:hover {\n    --bg-opacity: 1;\n    background-color: #feb2b2;\n    background-color: rgba(254, 178, 178, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-red-400:hover {\n    --bg-opacity: 1;\n    background-color: #fc8181;\n    background-color: rgba(252, 129, 129, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-red-500:hover {\n    --bg-opacity: 1;\n    background-color: #f56565;\n    background-color: rgba(245, 101, 101, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-red-600:hover {\n    --bg-opacity: 1;\n    background-color: #e53e3e;\n    background-color: rgba(229, 62, 62, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-red-700:hover {\n    --bg-opacity: 1;\n    background-color: #c53030;\n    background-color: rgba(197, 48, 48, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-red-800:hover {\n    --bg-opacity: 1;\n    background-color: #9b2c2c;\n    background-color: rgba(155, 44, 44, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-red-900:hover {\n    --bg-opacity: 1;\n    background-color: #742a2a;\n    background-color: rgba(116, 42, 42, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-orange-100:hover {\n    --bg-opacity: 1;\n    background-color: #fffaf0;\n    background-color: rgba(255, 250, 240, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-orange-200:hover {\n    --bg-opacity: 1;\n    background-color: #feebc8;\n    background-color: rgba(254, 235, 200, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-orange-300:hover {\n    --bg-opacity: 1;\n    background-color: #fbd38d;\n    background-color: rgba(251, 211, 141, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-orange-400:hover {\n    --bg-opacity: 1;\n    background-color: #f6ad55;\n    background-color: rgba(246, 173, 85, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-orange-500:hover {\n    --bg-opacity: 1;\n    background-color: #ed8936;\n    background-color: rgba(237, 137, 54, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-orange-600:hover {\n    --bg-opacity: 1;\n    background-color: #dd6b20;\n    background-color: rgba(221, 107, 32, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-orange-700:hover {\n    --bg-opacity: 1;\n    background-color: #c05621;\n    background-color: rgba(192, 86, 33, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-orange-800:hover {\n    --bg-opacity: 1;\n    background-color: #9c4221;\n    background-color: rgba(156, 66, 33, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-orange-900:hover {\n    --bg-opacity: 1;\n    background-color: #7b341e;\n    background-color: rgba(123, 52, 30, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-yellow-100:hover {\n    --bg-opacity: 1;\n    background-color: #fffff0;\n    background-color: rgba(255, 255, 240, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-yellow-200:hover {\n    --bg-opacity: 1;\n    background-color: #fefcbf;\n    background-color: rgba(254, 252, 191, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-yellow-300:hover {\n    --bg-opacity: 1;\n    background-color: #faf089;\n    background-color: rgba(250, 240, 137, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-yellow-400:hover {\n    --bg-opacity: 1;\n    background-color: #f6e05e;\n    background-color: rgba(246, 224, 94, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-yellow-500:hover {\n    --bg-opacity: 1;\n    background-color: #ecc94b;\n    background-color: rgba(236, 201, 75, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-yellow-600:hover {\n    --bg-opacity: 1;\n    background-color: #d69e2e;\n    background-color: rgba(214, 158, 46, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-yellow-700:hover {\n    --bg-opacity: 1;\n    background-color: #b7791f;\n    background-color: rgba(183, 121, 31, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-yellow-800:hover {\n    --bg-opacity: 1;\n    background-color: #975a16;\n    background-color: rgba(151, 90, 22, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-yellow-900:hover {\n    --bg-opacity: 1;\n    background-color: #744210;\n    background-color: rgba(116, 66, 16, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-green-100:hover {\n    --bg-opacity: 1;\n    background-color: #f0fff4;\n    background-color: rgba(240, 255, 244, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-green-200:hover {\n    --bg-opacity: 1;\n    background-color: #c6f6d5;\n    background-color: rgba(198, 246, 213, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-green-300:hover {\n    --bg-opacity: 1;\n    background-color: #9ae6b4;\n    background-color: rgba(154, 230, 180, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-green-400:hover {\n    --bg-opacity: 1;\n    background-color: #68d391;\n    background-color: rgba(104, 211, 145, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-green-500:hover {\n    --bg-opacity: 1;\n    background-color: #48bb78;\n    background-color: rgba(72, 187, 120, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-green-600:hover {\n    --bg-opacity: 1;\n    background-color: #38a169;\n    background-color: rgba(56, 161, 105, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-green-700:hover {\n    --bg-opacity: 1;\n    background-color: #2f855a;\n    background-color: rgba(47, 133, 90, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-green-800:hover {\n    --bg-opacity: 1;\n    background-color: #276749;\n    background-color: rgba(39, 103, 73, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-green-900:hover {\n    --bg-opacity: 1;\n    background-color: #22543d;\n    background-color: rgba(34, 84, 61, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-teal-100:hover {\n    --bg-opacity: 1;\n    background-color: #e6fffa;\n    background-color: rgba(230, 255, 250, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-teal-200:hover {\n    --bg-opacity: 1;\n    background-color: #b2f5ea;\n    background-color: rgba(178, 245, 234, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-teal-300:hover {\n    --bg-opacity: 1;\n    background-color: #81e6d9;\n    background-color: rgba(129, 230, 217, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-teal-400:hover {\n    --bg-opacity: 1;\n    background-color: #4fd1c5;\n    background-color: rgba(79, 209, 197, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-teal-500:hover {\n    --bg-opacity: 1;\n    background-color: #38b2ac;\n    background-color: rgba(56, 178, 172, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-teal-600:hover {\n    --bg-opacity: 1;\n    background-color: #319795;\n    background-color: rgba(49, 151, 149, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-teal-700:hover {\n    --bg-opacity: 1;\n    background-color: #2c7a7b;\n    background-color: rgba(44, 122, 123, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-teal-800:hover {\n    --bg-opacity: 1;\n    background-color: #285e61;\n    background-color: rgba(40, 94, 97, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-teal-900:hover {\n    --bg-opacity: 1;\n    background-color: #234e52;\n    background-color: rgba(35, 78, 82, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-blue-100:hover {\n    --bg-opacity: 1;\n    background-color: #ebf8ff;\n    background-color: rgba(235, 248, 255, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-blue-200:hover {\n    --bg-opacity: 1;\n    background-color: #bee3f8;\n    background-color: rgba(190, 227, 248, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-blue-300:hover {\n    --bg-opacity: 1;\n    background-color: #90cdf4;\n    background-color: rgba(144, 205, 244, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-blue-400:hover {\n    --bg-opacity: 1;\n    background-color: #63b3ed;\n    background-color: rgba(99, 179, 237, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-blue-500:hover {\n    --bg-opacity: 1;\n    background-color: #4299e1;\n    background-color: rgba(66, 153, 225, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-blue-600:hover {\n    --bg-opacity: 1;\n    background-color: #3182ce;\n    background-color: rgba(49, 130, 206, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-blue-700:hover {\n    --bg-opacity: 1;\n    background-color: #2b6cb0;\n    background-color: rgba(43, 108, 176, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-blue-800:hover {\n    --bg-opacity: 1;\n    background-color: #2c5282;\n    background-color: rgba(44, 82, 130, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-blue-900:hover {\n    --bg-opacity: 1;\n    background-color: #2a4365;\n    background-color: rgba(42, 67, 101, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-indigo-100:hover {\n    --bg-opacity: 1;\n    background-color: #ebf4ff;\n    background-color: rgba(235, 244, 255, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-indigo-200:hover {\n    --bg-opacity: 1;\n    background-color: #c3dafe;\n    background-color: rgba(195, 218, 254, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-indigo-300:hover {\n    --bg-opacity: 1;\n    background-color: #a3bffa;\n    background-color: rgba(163, 191, 250, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-indigo-400:hover {\n    --bg-opacity: 1;\n    background-color: #7f9cf5;\n    background-color: rgba(127, 156, 245, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-indigo-500:hover {\n    --bg-opacity: 1;\n    background-color: #667eea;\n    background-color: rgba(102, 126, 234, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-indigo-600:hover {\n    --bg-opacity: 1;\n    background-color: #5a67d8;\n    background-color: rgba(90, 103, 216, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-indigo-700:hover {\n    --bg-opacity: 1;\n    background-color: #4c51bf;\n    background-color: rgba(76, 81, 191, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-indigo-800:hover {\n    --bg-opacity: 1;\n    background-color: #434190;\n    background-color: rgba(67, 65, 144, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-indigo-900:hover {\n    --bg-opacity: 1;\n    background-color: #3c366b;\n    background-color: rgba(60, 54, 107, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-purple-100:hover {\n    --bg-opacity: 1;\n    background-color: #faf5ff;\n    background-color: rgba(250, 245, 255, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-purple-200:hover {\n    --bg-opacity: 1;\n    background-color: #e9d8fd;\n    background-color: rgba(233, 216, 253, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-purple-300:hover {\n    --bg-opacity: 1;\n    background-color: #d6bcfa;\n    background-color: rgba(214, 188, 250, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-purple-400:hover {\n    --bg-opacity: 1;\n    background-color: #b794f4;\n    background-color: rgba(183, 148, 244, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-purple-500:hover {\n    --bg-opacity: 1;\n    background-color: #9f7aea;\n    background-color: rgba(159, 122, 234, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-purple-600:hover {\n    --bg-opacity: 1;\n    background-color: #805ad5;\n    background-color: rgba(128, 90, 213, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-purple-700:hover {\n    --bg-opacity: 1;\n    background-color: #6b46c1;\n    background-color: rgba(107, 70, 193, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-purple-800:hover {\n    --bg-opacity: 1;\n    background-color: #553c9a;\n    background-color: rgba(85, 60, 154, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-purple-900:hover {\n    --bg-opacity: 1;\n    background-color: #44337a;\n    background-color: rgba(68, 51, 122, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-pink-100:hover {\n    --bg-opacity: 1;\n    background-color: #fff5f7;\n    background-color: rgba(255, 245, 247, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-pink-200:hover {\n    --bg-opacity: 1;\n    background-color: #fed7e2;\n    background-color: rgba(254, 215, 226, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-pink-300:hover {\n    --bg-opacity: 1;\n    background-color: #fbb6ce;\n    background-color: rgba(251, 182, 206, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-pink-400:hover {\n    --bg-opacity: 1;\n    background-color: #f687b3;\n    background-color: rgba(246, 135, 179, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-pink-500:hover {\n    --bg-opacity: 1;\n    background-color: #ed64a6;\n    background-color: rgba(237, 100, 166, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-pink-600:hover {\n    --bg-opacity: 1;\n    background-color: #d53f8c;\n    background-color: rgba(213, 63, 140, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-pink-700:hover {\n    --bg-opacity: 1;\n    background-color: #b83280;\n    background-color: rgba(184, 50, 128, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-pink-800:hover {\n    --bg-opacity: 1;\n    background-color: #97266d;\n    background-color: rgba(151, 38, 109, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-pink-900:hover {\n    --bg-opacity: 1;\n    background-color: #702459;\n    background-color: rgba(112, 36, 89, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-grayscale-80:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 8%);\n    background-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-grayscale-100:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 10%);\n    background-color: rgba(25.5, 25.5, 25.5, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-grayscale-200:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 20%);\n    background-color: rgba(51, 51, 51, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-grayscale-300:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 30%);\n    background-color: rgba(76.5, 76.5, 76.5, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-grayscale-400:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 40%);\n    background-color: rgba(102, 102, 102, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-grayscale-500:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 50%);\n    background-color: rgba(127.5, 127.5, 127.5, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-grayscale-600:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 60%);\n    background-color: rgba(153, 153, 153, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-grayscale-700:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 70%);\n    background-color: rgba(178.5, 178.5, 178.5, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-grayscale-800:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 80%);\n    background-color: rgba(204, 204, 204, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-grayscale-840:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 84%);\n    background-color: rgba(214.2, 214.2, 214.2, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-grayscale-870:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 87%);\n    background-color: rgba(221.85, 221.85, 221.85, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-grayscale-900:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 90%);\n    background-color: rgba(229.5, 229.5, 229.5, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-grayscale-930:hover {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 93%);\n    background-color: rgba(237.15, 237.15, 237.15, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-primary:hover {\n    --bg-opacity: 1;\n    background-color: hsl(210, 100%, 52%);\n    background-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--bg-opacity));\n  }\n\n  .xl\\:hover\\:bg-background-main:hover {\n    background-color: var(--main-background);\n  }\n\n  .xl\\:hover\\:bg-background-secondary:hover {\n    background-color: var(--secondary-background);\n  }\n\n  .xl\\:hover\\:bg-foreground:hover {\n    background-color: var(--foreground);\n  }\n\n  .xl\\:hover\\:bg-panels-bg:hover {\n    background-color: var(--panels-background);\n  }\n\n  .xl\\:focus\\:bg-transparent:focus {\n    background-color: transparent;\n  }\n\n  .xl\\:focus\\:bg-current:focus {\n    background-color: currentColor;\n  }\n\n  .xl\\:focus\\:bg-black:focus {\n    --bg-opacity: 1;\n    background-color: #000;\n    background-color: rgba(0, 0, 0, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-white:focus {\n    --bg-opacity: 1;\n    background-color: #fff;\n    background-color: rgba(255, 255, 255, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-gray-100:focus {\n    --bg-opacity: 1;\n    background-color: #f7fafc;\n    background-color: rgba(247, 250, 252, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-gray-200:focus {\n    --bg-opacity: 1;\n    background-color: #edf2f7;\n    background-color: rgba(237, 242, 247, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-gray-300:focus {\n    --bg-opacity: 1;\n    background-color: #e2e8f0;\n    background-color: rgba(226, 232, 240, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-gray-400:focus {\n    --bg-opacity: 1;\n    background-color: #cbd5e0;\n    background-color: rgba(203, 213, 224, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-gray-500:focus {\n    --bg-opacity: 1;\n    background-color: #a0aec0;\n    background-color: rgba(160, 174, 192, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-gray-600:focus {\n    --bg-opacity: 1;\n    background-color: #718096;\n    background-color: rgba(113, 128, 150, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-gray-700:focus {\n    --bg-opacity: 1;\n    background-color: #4a5568;\n    background-color: rgba(74, 85, 104, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-gray-800:focus {\n    --bg-opacity: 1;\n    background-color: #2d3748;\n    background-color: rgba(45, 55, 72, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-gray-900:focus {\n    --bg-opacity: 1;\n    background-color: #1a202c;\n    background-color: rgba(26, 32, 44, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-red-100:focus {\n    --bg-opacity: 1;\n    background-color: #fff5f5;\n    background-color: rgba(255, 245, 245, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-red-200:focus {\n    --bg-opacity: 1;\n    background-color: #fed7d7;\n    background-color: rgba(254, 215, 215, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-red-300:focus {\n    --bg-opacity: 1;\n    background-color: #feb2b2;\n    background-color: rgba(254, 178, 178, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-red-400:focus {\n    --bg-opacity: 1;\n    background-color: #fc8181;\n    background-color: rgba(252, 129, 129, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-red-500:focus {\n    --bg-opacity: 1;\n    background-color: #f56565;\n    background-color: rgba(245, 101, 101, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-red-600:focus {\n    --bg-opacity: 1;\n    background-color: #e53e3e;\n    background-color: rgba(229, 62, 62, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-red-700:focus {\n    --bg-opacity: 1;\n    background-color: #c53030;\n    background-color: rgba(197, 48, 48, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-red-800:focus {\n    --bg-opacity: 1;\n    background-color: #9b2c2c;\n    background-color: rgba(155, 44, 44, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-red-900:focus {\n    --bg-opacity: 1;\n    background-color: #742a2a;\n    background-color: rgba(116, 42, 42, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-orange-100:focus {\n    --bg-opacity: 1;\n    background-color: #fffaf0;\n    background-color: rgba(255, 250, 240, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-orange-200:focus {\n    --bg-opacity: 1;\n    background-color: #feebc8;\n    background-color: rgba(254, 235, 200, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-orange-300:focus {\n    --bg-opacity: 1;\n    background-color: #fbd38d;\n    background-color: rgba(251, 211, 141, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-orange-400:focus {\n    --bg-opacity: 1;\n    background-color: #f6ad55;\n    background-color: rgba(246, 173, 85, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-orange-500:focus {\n    --bg-opacity: 1;\n    background-color: #ed8936;\n    background-color: rgba(237, 137, 54, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-orange-600:focus {\n    --bg-opacity: 1;\n    background-color: #dd6b20;\n    background-color: rgba(221, 107, 32, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-orange-700:focus {\n    --bg-opacity: 1;\n    background-color: #c05621;\n    background-color: rgba(192, 86, 33, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-orange-800:focus {\n    --bg-opacity: 1;\n    background-color: #9c4221;\n    background-color: rgba(156, 66, 33, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-orange-900:focus {\n    --bg-opacity: 1;\n    background-color: #7b341e;\n    background-color: rgba(123, 52, 30, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-yellow-100:focus {\n    --bg-opacity: 1;\n    background-color: #fffff0;\n    background-color: rgba(255, 255, 240, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-yellow-200:focus {\n    --bg-opacity: 1;\n    background-color: #fefcbf;\n    background-color: rgba(254, 252, 191, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-yellow-300:focus {\n    --bg-opacity: 1;\n    background-color: #faf089;\n    background-color: rgba(250, 240, 137, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-yellow-400:focus {\n    --bg-opacity: 1;\n    background-color: #f6e05e;\n    background-color: rgba(246, 224, 94, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-yellow-500:focus {\n    --bg-opacity: 1;\n    background-color: #ecc94b;\n    background-color: rgba(236, 201, 75, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-yellow-600:focus {\n    --bg-opacity: 1;\n    background-color: #d69e2e;\n    background-color: rgba(214, 158, 46, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-yellow-700:focus {\n    --bg-opacity: 1;\n    background-color: #b7791f;\n    background-color: rgba(183, 121, 31, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-yellow-800:focus {\n    --bg-opacity: 1;\n    background-color: #975a16;\n    background-color: rgba(151, 90, 22, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-yellow-900:focus {\n    --bg-opacity: 1;\n    background-color: #744210;\n    background-color: rgba(116, 66, 16, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-green-100:focus {\n    --bg-opacity: 1;\n    background-color: #f0fff4;\n    background-color: rgba(240, 255, 244, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-green-200:focus {\n    --bg-opacity: 1;\n    background-color: #c6f6d5;\n    background-color: rgba(198, 246, 213, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-green-300:focus {\n    --bg-opacity: 1;\n    background-color: #9ae6b4;\n    background-color: rgba(154, 230, 180, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-green-400:focus {\n    --bg-opacity: 1;\n    background-color: #68d391;\n    background-color: rgba(104, 211, 145, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-green-500:focus {\n    --bg-opacity: 1;\n    background-color: #48bb78;\n    background-color: rgba(72, 187, 120, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-green-600:focus {\n    --bg-opacity: 1;\n    background-color: #38a169;\n    background-color: rgba(56, 161, 105, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-green-700:focus {\n    --bg-opacity: 1;\n    background-color: #2f855a;\n    background-color: rgba(47, 133, 90, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-green-800:focus {\n    --bg-opacity: 1;\n    background-color: #276749;\n    background-color: rgba(39, 103, 73, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-green-900:focus {\n    --bg-opacity: 1;\n    background-color: #22543d;\n    background-color: rgba(34, 84, 61, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-teal-100:focus {\n    --bg-opacity: 1;\n    background-color: #e6fffa;\n    background-color: rgba(230, 255, 250, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-teal-200:focus {\n    --bg-opacity: 1;\n    background-color: #b2f5ea;\n    background-color: rgba(178, 245, 234, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-teal-300:focus {\n    --bg-opacity: 1;\n    background-color: #81e6d9;\n    background-color: rgba(129, 230, 217, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-teal-400:focus {\n    --bg-opacity: 1;\n    background-color: #4fd1c5;\n    background-color: rgba(79, 209, 197, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-teal-500:focus {\n    --bg-opacity: 1;\n    background-color: #38b2ac;\n    background-color: rgba(56, 178, 172, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-teal-600:focus {\n    --bg-opacity: 1;\n    background-color: #319795;\n    background-color: rgba(49, 151, 149, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-teal-700:focus {\n    --bg-opacity: 1;\n    background-color: #2c7a7b;\n    background-color: rgba(44, 122, 123, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-teal-800:focus {\n    --bg-opacity: 1;\n    background-color: #285e61;\n    background-color: rgba(40, 94, 97, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-teal-900:focus {\n    --bg-opacity: 1;\n    background-color: #234e52;\n    background-color: rgba(35, 78, 82, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-blue-100:focus {\n    --bg-opacity: 1;\n    background-color: #ebf8ff;\n    background-color: rgba(235, 248, 255, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-blue-200:focus {\n    --bg-opacity: 1;\n    background-color: #bee3f8;\n    background-color: rgba(190, 227, 248, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-blue-300:focus {\n    --bg-opacity: 1;\n    background-color: #90cdf4;\n    background-color: rgba(144, 205, 244, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-blue-400:focus {\n    --bg-opacity: 1;\n    background-color: #63b3ed;\n    background-color: rgba(99, 179, 237, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-blue-500:focus {\n    --bg-opacity: 1;\n    background-color: #4299e1;\n    background-color: rgba(66, 153, 225, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-blue-600:focus {\n    --bg-opacity: 1;\n    background-color: #3182ce;\n    background-color: rgba(49, 130, 206, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-blue-700:focus {\n    --bg-opacity: 1;\n    background-color: #2b6cb0;\n    background-color: rgba(43, 108, 176, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-blue-800:focus {\n    --bg-opacity: 1;\n    background-color: #2c5282;\n    background-color: rgba(44, 82, 130, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-blue-900:focus {\n    --bg-opacity: 1;\n    background-color: #2a4365;\n    background-color: rgba(42, 67, 101, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-indigo-100:focus {\n    --bg-opacity: 1;\n    background-color: #ebf4ff;\n    background-color: rgba(235, 244, 255, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-indigo-200:focus {\n    --bg-opacity: 1;\n    background-color: #c3dafe;\n    background-color: rgba(195, 218, 254, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-indigo-300:focus {\n    --bg-opacity: 1;\n    background-color: #a3bffa;\n    background-color: rgba(163, 191, 250, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-indigo-400:focus {\n    --bg-opacity: 1;\n    background-color: #7f9cf5;\n    background-color: rgba(127, 156, 245, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-indigo-500:focus {\n    --bg-opacity: 1;\n    background-color: #667eea;\n    background-color: rgba(102, 126, 234, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-indigo-600:focus {\n    --bg-opacity: 1;\n    background-color: #5a67d8;\n    background-color: rgba(90, 103, 216, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-indigo-700:focus {\n    --bg-opacity: 1;\n    background-color: #4c51bf;\n    background-color: rgba(76, 81, 191, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-indigo-800:focus {\n    --bg-opacity: 1;\n    background-color: #434190;\n    background-color: rgba(67, 65, 144, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-indigo-900:focus {\n    --bg-opacity: 1;\n    background-color: #3c366b;\n    background-color: rgba(60, 54, 107, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-purple-100:focus {\n    --bg-opacity: 1;\n    background-color: #faf5ff;\n    background-color: rgba(250, 245, 255, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-purple-200:focus {\n    --bg-opacity: 1;\n    background-color: #e9d8fd;\n    background-color: rgba(233, 216, 253, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-purple-300:focus {\n    --bg-opacity: 1;\n    background-color: #d6bcfa;\n    background-color: rgba(214, 188, 250, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-purple-400:focus {\n    --bg-opacity: 1;\n    background-color: #b794f4;\n    background-color: rgba(183, 148, 244, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-purple-500:focus {\n    --bg-opacity: 1;\n    background-color: #9f7aea;\n    background-color: rgba(159, 122, 234, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-purple-600:focus {\n    --bg-opacity: 1;\n    background-color: #805ad5;\n    background-color: rgba(128, 90, 213, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-purple-700:focus {\n    --bg-opacity: 1;\n    background-color: #6b46c1;\n    background-color: rgba(107, 70, 193, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-purple-800:focus {\n    --bg-opacity: 1;\n    background-color: #553c9a;\n    background-color: rgba(85, 60, 154, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-purple-900:focus {\n    --bg-opacity: 1;\n    background-color: #44337a;\n    background-color: rgba(68, 51, 122, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-pink-100:focus {\n    --bg-opacity: 1;\n    background-color: #fff5f7;\n    background-color: rgba(255, 245, 247, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-pink-200:focus {\n    --bg-opacity: 1;\n    background-color: #fed7e2;\n    background-color: rgba(254, 215, 226, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-pink-300:focus {\n    --bg-opacity: 1;\n    background-color: #fbb6ce;\n    background-color: rgba(251, 182, 206, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-pink-400:focus {\n    --bg-opacity: 1;\n    background-color: #f687b3;\n    background-color: rgba(246, 135, 179, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-pink-500:focus {\n    --bg-opacity: 1;\n    background-color: #ed64a6;\n    background-color: rgba(237, 100, 166, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-pink-600:focus {\n    --bg-opacity: 1;\n    background-color: #d53f8c;\n    background-color: rgba(213, 63, 140, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-pink-700:focus {\n    --bg-opacity: 1;\n    background-color: #b83280;\n    background-color: rgba(184, 50, 128, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-pink-800:focus {\n    --bg-opacity: 1;\n    background-color: #97266d;\n    background-color: rgba(151, 38, 109, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-pink-900:focus {\n    --bg-opacity: 1;\n    background-color: #702459;\n    background-color: rgba(112, 36, 89, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-grayscale-80:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 8%);\n    background-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-grayscale-100:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 10%);\n    background-color: rgba(25.5, 25.5, 25.5, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-grayscale-200:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 20%);\n    background-color: rgba(51, 51, 51, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-grayscale-300:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 30%);\n    background-color: rgba(76.5, 76.5, 76.5, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-grayscale-400:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 40%);\n    background-color: rgba(102, 102, 102, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-grayscale-500:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 50%);\n    background-color: rgba(127.5, 127.5, 127.5, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-grayscale-600:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 60%);\n    background-color: rgba(153, 153, 153, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-grayscale-700:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 70%);\n    background-color: rgba(178.5, 178.5, 178.5, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-grayscale-800:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 80%);\n    background-color: rgba(204, 204, 204, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-grayscale-840:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 84%);\n    background-color: rgba(214.2, 214.2, 214.2, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-grayscale-870:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 87%);\n    background-color: rgba(221.85, 221.85, 221.85, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-grayscale-900:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 90%);\n    background-color: rgba(229.5, 229.5, 229.5, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-grayscale-930:focus {\n    --bg-opacity: 1;\n    background-color: hsl(0, 0%, 93%);\n    background-color: rgba(237.15, 237.15, 237.15, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-primary:focus {\n    --bg-opacity: 1;\n    background-color: hsl(210, 100%, 52%);\n    background-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--bg-opacity));\n  }\n\n  .xl\\:focus\\:bg-background-main:focus {\n    background-color: var(--main-background);\n  }\n\n  .xl\\:focus\\:bg-background-secondary:focus {\n    background-color: var(--secondary-background);\n  }\n\n  .xl\\:focus\\:bg-foreground:focus {\n    background-color: var(--foreground);\n  }\n\n  .xl\\:focus\\:bg-panels-bg:focus {\n    background-color: var(--panels-background);\n  }\n\n  .xl\\:bg-none {\n    background-image: none;\n  }\n\n  .xl\\:bg-gradient-to-t {\n    background-image: linear-gradient(to top, var(--gradient-color-stops));\n  }\n\n  .xl\\:bg-gradient-to-tr {\n    background-image: linear-gradient(to top right, var(--gradient-color-stops));\n  }\n\n  .xl\\:bg-gradient-to-r {\n    background-image: linear-gradient(to right, var(--gradient-color-stops));\n  }\n\n  .xl\\:bg-gradient-to-br {\n    background-image: linear-gradient(to bottom right, var(--gradient-color-stops));\n  }\n\n  .xl\\:bg-gradient-to-b {\n    background-image: linear-gradient(to bottom, var(--gradient-color-stops));\n  }\n\n  .xl\\:bg-gradient-to-bl {\n    background-image: linear-gradient(to bottom left, var(--gradient-color-stops));\n  }\n\n  .xl\\:bg-gradient-to-l {\n    background-image: linear-gradient(to left, var(--gradient-color-stops));\n  }\n\n  .xl\\:bg-gradient-to-tl {\n    background-image: linear-gradient(to top left, var(--gradient-color-stops));\n  }\n\n  .xl\\:from-transparent {\n    --gradient-from-color: transparent;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .xl\\:from-current {\n    --gradient-from-color: currentColor;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:from-black {\n    --gradient-from-color: #000;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .xl\\:from-white {\n    --gradient-from-color: #fff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:from-gray-100 {\n    --gradient-from-color: #f7fafc;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n  }\n\n  .xl\\:from-gray-200 {\n    --gradient-from-color: #edf2f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n  }\n\n  .xl\\:from-gray-300 {\n    --gradient-from-color: #e2e8f0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n  }\n\n  .xl\\:from-gray-400 {\n    --gradient-from-color: #cbd5e0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n  }\n\n  .xl\\:from-gray-500 {\n    --gradient-from-color: #a0aec0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n  }\n\n  .xl\\:from-gray-600 {\n    --gradient-from-color: #718096;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n  }\n\n  .xl\\:from-gray-700 {\n    --gradient-from-color: #4a5568;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n  }\n\n  .xl\\:from-gray-800 {\n    --gradient-from-color: #2d3748;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n  }\n\n  .xl\\:from-gray-900 {\n    --gradient-from-color: #1a202c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n  }\n\n  .xl\\:from-red-100 {\n    --gradient-from-color: #fff5f5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n  }\n\n  .xl\\:from-red-200 {\n    --gradient-from-color: #fed7d7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n  }\n\n  .xl\\:from-red-300 {\n    --gradient-from-color: #feb2b2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n  }\n\n  .xl\\:from-red-400 {\n    --gradient-from-color: #fc8181;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n  }\n\n  .xl\\:from-red-500 {\n    --gradient-from-color: #f56565;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n  }\n\n  .xl\\:from-red-600 {\n    --gradient-from-color: #e53e3e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n  }\n\n  .xl\\:from-red-700 {\n    --gradient-from-color: #c53030;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n  }\n\n  .xl\\:from-red-800 {\n    --gradient-from-color: #9b2c2c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n  }\n\n  .xl\\:from-red-900 {\n    --gradient-from-color: #742a2a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n  }\n\n  .xl\\:from-orange-100 {\n    --gradient-from-color: #fffaf0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n  }\n\n  .xl\\:from-orange-200 {\n    --gradient-from-color: #feebc8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n  }\n\n  .xl\\:from-orange-300 {\n    --gradient-from-color: #fbd38d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n  }\n\n  .xl\\:from-orange-400 {\n    --gradient-from-color: #f6ad55;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n  }\n\n  .xl\\:from-orange-500 {\n    --gradient-from-color: #ed8936;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n  }\n\n  .xl\\:from-orange-600 {\n    --gradient-from-color: #dd6b20;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n  }\n\n  .xl\\:from-orange-700 {\n    --gradient-from-color: #c05621;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n  }\n\n  .xl\\:from-orange-800 {\n    --gradient-from-color: #9c4221;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n  }\n\n  .xl\\:from-orange-900 {\n    --gradient-from-color: #7b341e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n  }\n\n  .xl\\:from-yellow-100 {\n    --gradient-from-color: #fffff0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n  }\n\n  .xl\\:from-yellow-200 {\n    --gradient-from-color: #fefcbf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n  }\n\n  .xl\\:from-yellow-300 {\n    --gradient-from-color: #faf089;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n  }\n\n  .xl\\:from-yellow-400 {\n    --gradient-from-color: #f6e05e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n  }\n\n  .xl\\:from-yellow-500 {\n    --gradient-from-color: #ecc94b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n  }\n\n  .xl\\:from-yellow-600 {\n    --gradient-from-color: #d69e2e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n  }\n\n  .xl\\:from-yellow-700 {\n    --gradient-from-color: #b7791f;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n  }\n\n  .xl\\:from-yellow-800 {\n    --gradient-from-color: #975a16;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n  }\n\n  .xl\\:from-yellow-900 {\n    --gradient-from-color: #744210;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n  }\n\n  .xl\\:from-green-100 {\n    --gradient-from-color: #f0fff4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n  }\n\n  .xl\\:from-green-200 {\n    --gradient-from-color: #c6f6d5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n  }\n\n  .xl\\:from-green-300 {\n    --gradient-from-color: #9ae6b4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n  }\n\n  .xl\\:from-green-400 {\n    --gradient-from-color: #68d391;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n  }\n\n  .xl\\:from-green-500 {\n    --gradient-from-color: #48bb78;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n  }\n\n  .xl\\:from-green-600 {\n    --gradient-from-color: #38a169;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n  }\n\n  .xl\\:from-green-700 {\n    --gradient-from-color: #2f855a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n  }\n\n  .xl\\:from-green-800 {\n    --gradient-from-color: #276749;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n  }\n\n  .xl\\:from-green-900 {\n    --gradient-from-color: #22543d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n  }\n\n  .xl\\:from-teal-100 {\n    --gradient-from-color: #e6fffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n  }\n\n  .xl\\:from-teal-200 {\n    --gradient-from-color: #b2f5ea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n  }\n\n  .xl\\:from-teal-300 {\n    --gradient-from-color: #81e6d9;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n  }\n\n  .xl\\:from-teal-400 {\n    --gradient-from-color: #4fd1c5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n  }\n\n  .xl\\:from-teal-500 {\n    --gradient-from-color: #38b2ac;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n  }\n\n  .xl\\:from-teal-600 {\n    --gradient-from-color: #319795;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n  }\n\n  .xl\\:from-teal-700 {\n    --gradient-from-color: #2c7a7b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n  }\n\n  .xl\\:from-teal-800 {\n    --gradient-from-color: #285e61;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n  }\n\n  .xl\\:from-teal-900 {\n    --gradient-from-color: #234e52;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n  }\n\n  .xl\\:from-blue-100 {\n    --gradient-from-color: #ebf8ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n  }\n\n  .xl\\:from-blue-200 {\n    --gradient-from-color: #bee3f8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n  }\n\n  .xl\\:from-blue-300 {\n    --gradient-from-color: #90cdf4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n  }\n\n  .xl\\:from-blue-400 {\n    --gradient-from-color: #63b3ed;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n  }\n\n  .xl\\:from-blue-500 {\n    --gradient-from-color: #4299e1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n  }\n\n  .xl\\:from-blue-600 {\n    --gradient-from-color: #3182ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n  }\n\n  .xl\\:from-blue-700 {\n    --gradient-from-color: #2b6cb0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n  }\n\n  .xl\\:from-blue-800 {\n    --gradient-from-color: #2c5282;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n  }\n\n  .xl\\:from-blue-900 {\n    --gradient-from-color: #2a4365;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n  }\n\n  .xl\\:from-indigo-100 {\n    --gradient-from-color: #ebf4ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n  }\n\n  .xl\\:from-indigo-200 {\n    --gradient-from-color: #c3dafe;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n  }\n\n  .xl\\:from-indigo-300 {\n    --gradient-from-color: #a3bffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n  }\n\n  .xl\\:from-indigo-400 {\n    --gradient-from-color: #7f9cf5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n  }\n\n  .xl\\:from-indigo-500 {\n    --gradient-from-color: #667eea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n  }\n\n  .xl\\:from-indigo-600 {\n    --gradient-from-color: #5a67d8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n  }\n\n  .xl\\:from-indigo-700 {\n    --gradient-from-color: #4c51bf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n  }\n\n  .xl\\:from-indigo-800 {\n    --gradient-from-color: #434190;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n  }\n\n  .xl\\:from-indigo-900 {\n    --gradient-from-color: #3c366b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n  }\n\n  .xl\\:from-purple-100 {\n    --gradient-from-color: #faf5ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n  }\n\n  .xl\\:from-purple-200 {\n    --gradient-from-color: #e9d8fd;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n  }\n\n  .xl\\:from-purple-300 {\n    --gradient-from-color: #d6bcfa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n  }\n\n  .xl\\:from-purple-400 {\n    --gradient-from-color: #b794f4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n  }\n\n  .xl\\:from-purple-500 {\n    --gradient-from-color: #9f7aea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n  }\n\n  .xl\\:from-purple-600 {\n    --gradient-from-color: #805ad5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n  }\n\n  .xl\\:from-purple-700 {\n    --gradient-from-color: #6b46c1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n  }\n\n  .xl\\:from-purple-800 {\n    --gradient-from-color: #553c9a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n  }\n\n  .xl\\:from-purple-900 {\n    --gradient-from-color: #44337a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n  }\n\n  .xl\\:from-pink-100 {\n    --gradient-from-color: #fff5f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n  }\n\n  .xl\\:from-pink-200 {\n    --gradient-from-color: #fed7e2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n  }\n\n  .xl\\:from-pink-300 {\n    --gradient-from-color: #fbb6ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n  }\n\n  .xl\\:from-pink-400 {\n    --gradient-from-color: #f687b3;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n  }\n\n  .xl\\:from-pink-500 {\n    --gradient-from-color: #ed64a6;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n  }\n\n  .xl\\:from-pink-600 {\n    --gradient-from-color: #d53f8c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n  }\n\n  .xl\\:from-pink-700 {\n    --gradient-from-color: #b83280;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n  }\n\n  .xl\\:from-pink-800 {\n    --gradient-from-color: #97266d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n  }\n\n  .xl\\:from-pink-900 {\n    --gradient-from-color: #702459;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n  }\n\n  .xl\\:from-grayscale-80 {\n    --gradient-from-color: hsl(0, 0%, 8%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n  }\n\n  .xl\\:from-grayscale-100 {\n    --gradient-from-color: hsl(0, 0%, 10%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n  }\n\n  .xl\\:from-grayscale-200 {\n    --gradient-from-color: hsl(0, 0%, 20%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n  }\n\n  .xl\\:from-grayscale-300 {\n    --gradient-from-color: hsl(0, 0%, 30%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n  }\n\n  .xl\\:from-grayscale-400 {\n    --gradient-from-color: hsl(0, 0%, 40%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n  }\n\n  .xl\\:from-grayscale-500 {\n    --gradient-from-color: hsl(0, 0%, 50%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n  }\n\n  .xl\\:from-grayscale-600 {\n    --gradient-from-color: hsl(0, 0%, 60%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n  }\n\n  .xl\\:from-grayscale-700 {\n    --gradient-from-color: hsl(0, 0%, 70%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n  }\n\n  .xl\\:from-grayscale-800 {\n    --gradient-from-color: hsl(0, 0%, 80%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n  }\n\n  .xl\\:from-grayscale-840 {\n    --gradient-from-color: hsl(0, 0%, 84%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n  }\n\n  .xl\\:from-grayscale-870 {\n    --gradient-from-color: hsl(0, 0%, 87%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n  }\n\n  .xl\\:from-grayscale-900 {\n    --gradient-from-color: hsl(0, 0%, 90%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n  }\n\n  .xl\\:from-grayscale-930 {\n    --gradient-from-color: hsl(0, 0%, 93%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n  }\n\n  .xl\\:from-primary {\n    --gradient-from-color: hsl(210, 100%, 52%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n  }\n\n  .xl\\:from-background-main {\n    --gradient-from-color: var(--main-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:from-background-secondary {\n    --gradient-from-color: var(--secondary-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:from-foreground {\n    --gradient-from-color: var(--foreground);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:from-panels-bg {\n    --gradient-from-color: var(--panels-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:via-transparent {\n    --gradient-via-color: transparent;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .xl\\:via-current {\n    --gradient-via-color: currentColor;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:via-black {\n    --gradient-via-color: #000;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .xl\\:via-white {\n    --gradient-via-color: #fff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:via-gray-100 {\n    --gradient-via-color: #f7fafc;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n  }\n\n  .xl\\:via-gray-200 {\n    --gradient-via-color: #edf2f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n  }\n\n  .xl\\:via-gray-300 {\n    --gradient-via-color: #e2e8f0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n  }\n\n  .xl\\:via-gray-400 {\n    --gradient-via-color: #cbd5e0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n  }\n\n  .xl\\:via-gray-500 {\n    --gradient-via-color: #a0aec0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n  }\n\n  .xl\\:via-gray-600 {\n    --gradient-via-color: #718096;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n  }\n\n  .xl\\:via-gray-700 {\n    --gradient-via-color: #4a5568;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n  }\n\n  .xl\\:via-gray-800 {\n    --gradient-via-color: #2d3748;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n  }\n\n  .xl\\:via-gray-900 {\n    --gradient-via-color: #1a202c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n  }\n\n  .xl\\:via-red-100 {\n    --gradient-via-color: #fff5f5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n  }\n\n  .xl\\:via-red-200 {\n    --gradient-via-color: #fed7d7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n  }\n\n  .xl\\:via-red-300 {\n    --gradient-via-color: #feb2b2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n  }\n\n  .xl\\:via-red-400 {\n    --gradient-via-color: #fc8181;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n  }\n\n  .xl\\:via-red-500 {\n    --gradient-via-color: #f56565;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n  }\n\n  .xl\\:via-red-600 {\n    --gradient-via-color: #e53e3e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n  }\n\n  .xl\\:via-red-700 {\n    --gradient-via-color: #c53030;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n  }\n\n  .xl\\:via-red-800 {\n    --gradient-via-color: #9b2c2c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n  }\n\n  .xl\\:via-red-900 {\n    --gradient-via-color: #742a2a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n  }\n\n  .xl\\:via-orange-100 {\n    --gradient-via-color: #fffaf0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n  }\n\n  .xl\\:via-orange-200 {\n    --gradient-via-color: #feebc8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n  }\n\n  .xl\\:via-orange-300 {\n    --gradient-via-color: #fbd38d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n  }\n\n  .xl\\:via-orange-400 {\n    --gradient-via-color: #f6ad55;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n  }\n\n  .xl\\:via-orange-500 {\n    --gradient-via-color: #ed8936;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n  }\n\n  .xl\\:via-orange-600 {\n    --gradient-via-color: #dd6b20;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n  }\n\n  .xl\\:via-orange-700 {\n    --gradient-via-color: #c05621;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n  }\n\n  .xl\\:via-orange-800 {\n    --gradient-via-color: #9c4221;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n  }\n\n  .xl\\:via-orange-900 {\n    --gradient-via-color: #7b341e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n  }\n\n  .xl\\:via-yellow-100 {\n    --gradient-via-color: #fffff0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n  }\n\n  .xl\\:via-yellow-200 {\n    --gradient-via-color: #fefcbf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n  }\n\n  .xl\\:via-yellow-300 {\n    --gradient-via-color: #faf089;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n  }\n\n  .xl\\:via-yellow-400 {\n    --gradient-via-color: #f6e05e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n  }\n\n  .xl\\:via-yellow-500 {\n    --gradient-via-color: #ecc94b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n  }\n\n  .xl\\:via-yellow-600 {\n    --gradient-via-color: #d69e2e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n  }\n\n  .xl\\:via-yellow-700 {\n    --gradient-via-color: #b7791f;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n  }\n\n  .xl\\:via-yellow-800 {\n    --gradient-via-color: #975a16;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n  }\n\n  .xl\\:via-yellow-900 {\n    --gradient-via-color: #744210;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n  }\n\n  .xl\\:via-green-100 {\n    --gradient-via-color: #f0fff4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n  }\n\n  .xl\\:via-green-200 {\n    --gradient-via-color: #c6f6d5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n  }\n\n  .xl\\:via-green-300 {\n    --gradient-via-color: #9ae6b4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n  }\n\n  .xl\\:via-green-400 {\n    --gradient-via-color: #68d391;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n  }\n\n  .xl\\:via-green-500 {\n    --gradient-via-color: #48bb78;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n  }\n\n  .xl\\:via-green-600 {\n    --gradient-via-color: #38a169;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n  }\n\n  .xl\\:via-green-700 {\n    --gradient-via-color: #2f855a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n  }\n\n  .xl\\:via-green-800 {\n    --gradient-via-color: #276749;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n  }\n\n  .xl\\:via-green-900 {\n    --gradient-via-color: #22543d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n  }\n\n  .xl\\:via-teal-100 {\n    --gradient-via-color: #e6fffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n  }\n\n  .xl\\:via-teal-200 {\n    --gradient-via-color: #b2f5ea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n  }\n\n  .xl\\:via-teal-300 {\n    --gradient-via-color: #81e6d9;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n  }\n\n  .xl\\:via-teal-400 {\n    --gradient-via-color: #4fd1c5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n  }\n\n  .xl\\:via-teal-500 {\n    --gradient-via-color: #38b2ac;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n  }\n\n  .xl\\:via-teal-600 {\n    --gradient-via-color: #319795;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n  }\n\n  .xl\\:via-teal-700 {\n    --gradient-via-color: #2c7a7b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n  }\n\n  .xl\\:via-teal-800 {\n    --gradient-via-color: #285e61;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n  }\n\n  .xl\\:via-teal-900 {\n    --gradient-via-color: #234e52;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n  }\n\n  .xl\\:via-blue-100 {\n    --gradient-via-color: #ebf8ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n  }\n\n  .xl\\:via-blue-200 {\n    --gradient-via-color: #bee3f8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n  }\n\n  .xl\\:via-blue-300 {\n    --gradient-via-color: #90cdf4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n  }\n\n  .xl\\:via-blue-400 {\n    --gradient-via-color: #63b3ed;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n  }\n\n  .xl\\:via-blue-500 {\n    --gradient-via-color: #4299e1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n  }\n\n  .xl\\:via-blue-600 {\n    --gradient-via-color: #3182ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n  }\n\n  .xl\\:via-blue-700 {\n    --gradient-via-color: #2b6cb0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n  }\n\n  .xl\\:via-blue-800 {\n    --gradient-via-color: #2c5282;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n  }\n\n  .xl\\:via-blue-900 {\n    --gradient-via-color: #2a4365;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n  }\n\n  .xl\\:via-indigo-100 {\n    --gradient-via-color: #ebf4ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n  }\n\n  .xl\\:via-indigo-200 {\n    --gradient-via-color: #c3dafe;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n  }\n\n  .xl\\:via-indigo-300 {\n    --gradient-via-color: #a3bffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n  }\n\n  .xl\\:via-indigo-400 {\n    --gradient-via-color: #7f9cf5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n  }\n\n  .xl\\:via-indigo-500 {\n    --gradient-via-color: #667eea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n  }\n\n  .xl\\:via-indigo-600 {\n    --gradient-via-color: #5a67d8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n  }\n\n  .xl\\:via-indigo-700 {\n    --gradient-via-color: #4c51bf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n  }\n\n  .xl\\:via-indigo-800 {\n    --gradient-via-color: #434190;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n  }\n\n  .xl\\:via-indigo-900 {\n    --gradient-via-color: #3c366b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n  }\n\n  .xl\\:via-purple-100 {\n    --gradient-via-color: #faf5ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n  }\n\n  .xl\\:via-purple-200 {\n    --gradient-via-color: #e9d8fd;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n  }\n\n  .xl\\:via-purple-300 {\n    --gradient-via-color: #d6bcfa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n  }\n\n  .xl\\:via-purple-400 {\n    --gradient-via-color: #b794f4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n  }\n\n  .xl\\:via-purple-500 {\n    --gradient-via-color: #9f7aea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n  }\n\n  .xl\\:via-purple-600 {\n    --gradient-via-color: #805ad5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n  }\n\n  .xl\\:via-purple-700 {\n    --gradient-via-color: #6b46c1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n  }\n\n  .xl\\:via-purple-800 {\n    --gradient-via-color: #553c9a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n  }\n\n  .xl\\:via-purple-900 {\n    --gradient-via-color: #44337a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n  }\n\n  .xl\\:via-pink-100 {\n    --gradient-via-color: #fff5f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n  }\n\n  .xl\\:via-pink-200 {\n    --gradient-via-color: #fed7e2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n  }\n\n  .xl\\:via-pink-300 {\n    --gradient-via-color: #fbb6ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n  }\n\n  .xl\\:via-pink-400 {\n    --gradient-via-color: #f687b3;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n  }\n\n  .xl\\:via-pink-500 {\n    --gradient-via-color: #ed64a6;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n  }\n\n  .xl\\:via-pink-600 {\n    --gradient-via-color: #d53f8c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n  }\n\n  .xl\\:via-pink-700 {\n    --gradient-via-color: #b83280;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n  }\n\n  .xl\\:via-pink-800 {\n    --gradient-via-color: #97266d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n  }\n\n  .xl\\:via-pink-900 {\n    --gradient-via-color: #702459;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n  }\n\n  .xl\\:via-grayscale-80 {\n    --gradient-via-color: hsl(0, 0%, 8%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n  }\n\n  .xl\\:via-grayscale-100 {\n    --gradient-via-color: hsl(0, 0%, 10%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n  }\n\n  .xl\\:via-grayscale-200 {\n    --gradient-via-color: hsl(0, 0%, 20%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n  }\n\n  .xl\\:via-grayscale-300 {\n    --gradient-via-color: hsl(0, 0%, 30%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n  }\n\n  .xl\\:via-grayscale-400 {\n    --gradient-via-color: hsl(0, 0%, 40%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n  }\n\n  .xl\\:via-grayscale-500 {\n    --gradient-via-color: hsl(0, 0%, 50%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n  }\n\n  .xl\\:via-grayscale-600 {\n    --gradient-via-color: hsl(0, 0%, 60%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n  }\n\n  .xl\\:via-grayscale-700 {\n    --gradient-via-color: hsl(0, 0%, 70%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n  }\n\n  .xl\\:via-grayscale-800 {\n    --gradient-via-color: hsl(0, 0%, 80%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n  }\n\n  .xl\\:via-grayscale-840 {\n    --gradient-via-color: hsl(0, 0%, 84%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n  }\n\n  .xl\\:via-grayscale-870 {\n    --gradient-via-color: hsl(0, 0%, 87%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n  }\n\n  .xl\\:via-grayscale-900 {\n    --gradient-via-color: hsl(0, 0%, 90%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n  }\n\n  .xl\\:via-grayscale-930 {\n    --gradient-via-color: hsl(0, 0%, 93%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n  }\n\n  .xl\\:via-primary {\n    --gradient-via-color: hsl(210, 100%, 52%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n  }\n\n  .xl\\:via-background-main {\n    --gradient-via-color: var(--main-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:via-background-secondary {\n    --gradient-via-color: var(--secondary-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:via-foreground {\n    --gradient-via-color: var(--foreground);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:via-panels-bg {\n    --gradient-via-color: var(--panels-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:to-transparent {\n    --gradient-to-color: transparent;\n  }\n\n  .xl\\:to-current {\n    --gradient-to-color: currentColor;\n  }\n\n  .xl\\:to-black {\n    --gradient-to-color: #000;\n  }\n\n  .xl\\:to-white {\n    --gradient-to-color: #fff;\n  }\n\n  .xl\\:to-gray-100 {\n    --gradient-to-color: #f7fafc;\n  }\n\n  .xl\\:to-gray-200 {\n    --gradient-to-color: #edf2f7;\n  }\n\n  .xl\\:to-gray-300 {\n    --gradient-to-color: #e2e8f0;\n  }\n\n  .xl\\:to-gray-400 {\n    --gradient-to-color: #cbd5e0;\n  }\n\n  .xl\\:to-gray-500 {\n    --gradient-to-color: #a0aec0;\n  }\n\n  .xl\\:to-gray-600 {\n    --gradient-to-color: #718096;\n  }\n\n  .xl\\:to-gray-700 {\n    --gradient-to-color: #4a5568;\n  }\n\n  .xl\\:to-gray-800 {\n    --gradient-to-color: #2d3748;\n  }\n\n  .xl\\:to-gray-900 {\n    --gradient-to-color: #1a202c;\n  }\n\n  .xl\\:to-red-100 {\n    --gradient-to-color: #fff5f5;\n  }\n\n  .xl\\:to-red-200 {\n    --gradient-to-color: #fed7d7;\n  }\n\n  .xl\\:to-red-300 {\n    --gradient-to-color: #feb2b2;\n  }\n\n  .xl\\:to-red-400 {\n    --gradient-to-color: #fc8181;\n  }\n\n  .xl\\:to-red-500 {\n    --gradient-to-color: #f56565;\n  }\n\n  .xl\\:to-red-600 {\n    --gradient-to-color: #e53e3e;\n  }\n\n  .xl\\:to-red-700 {\n    --gradient-to-color: #c53030;\n  }\n\n  .xl\\:to-red-800 {\n    --gradient-to-color: #9b2c2c;\n  }\n\n  .xl\\:to-red-900 {\n    --gradient-to-color: #742a2a;\n  }\n\n  .xl\\:to-orange-100 {\n    --gradient-to-color: #fffaf0;\n  }\n\n  .xl\\:to-orange-200 {\n    --gradient-to-color: #feebc8;\n  }\n\n  .xl\\:to-orange-300 {\n    --gradient-to-color: #fbd38d;\n  }\n\n  .xl\\:to-orange-400 {\n    --gradient-to-color: #f6ad55;\n  }\n\n  .xl\\:to-orange-500 {\n    --gradient-to-color: #ed8936;\n  }\n\n  .xl\\:to-orange-600 {\n    --gradient-to-color: #dd6b20;\n  }\n\n  .xl\\:to-orange-700 {\n    --gradient-to-color: #c05621;\n  }\n\n  .xl\\:to-orange-800 {\n    --gradient-to-color: #9c4221;\n  }\n\n  .xl\\:to-orange-900 {\n    --gradient-to-color: #7b341e;\n  }\n\n  .xl\\:to-yellow-100 {\n    --gradient-to-color: #fffff0;\n  }\n\n  .xl\\:to-yellow-200 {\n    --gradient-to-color: #fefcbf;\n  }\n\n  .xl\\:to-yellow-300 {\n    --gradient-to-color: #faf089;\n  }\n\n  .xl\\:to-yellow-400 {\n    --gradient-to-color: #f6e05e;\n  }\n\n  .xl\\:to-yellow-500 {\n    --gradient-to-color: #ecc94b;\n  }\n\n  .xl\\:to-yellow-600 {\n    --gradient-to-color: #d69e2e;\n  }\n\n  .xl\\:to-yellow-700 {\n    --gradient-to-color: #b7791f;\n  }\n\n  .xl\\:to-yellow-800 {\n    --gradient-to-color: #975a16;\n  }\n\n  .xl\\:to-yellow-900 {\n    --gradient-to-color: #744210;\n  }\n\n  .xl\\:to-green-100 {\n    --gradient-to-color: #f0fff4;\n  }\n\n  .xl\\:to-green-200 {\n    --gradient-to-color: #c6f6d5;\n  }\n\n  .xl\\:to-green-300 {\n    --gradient-to-color: #9ae6b4;\n  }\n\n  .xl\\:to-green-400 {\n    --gradient-to-color: #68d391;\n  }\n\n  .xl\\:to-green-500 {\n    --gradient-to-color: #48bb78;\n  }\n\n  .xl\\:to-green-600 {\n    --gradient-to-color: #38a169;\n  }\n\n  .xl\\:to-green-700 {\n    --gradient-to-color: #2f855a;\n  }\n\n  .xl\\:to-green-800 {\n    --gradient-to-color: #276749;\n  }\n\n  .xl\\:to-green-900 {\n    --gradient-to-color: #22543d;\n  }\n\n  .xl\\:to-teal-100 {\n    --gradient-to-color: #e6fffa;\n  }\n\n  .xl\\:to-teal-200 {\n    --gradient-to-color: #b2f5ea;\n  }\n\n  .xl\\:to-teal-300 {\n    --gradient-to-color: #81e6d9;\n  }\n\n  .xl\\:to-teal-400 {\n    --gradient-to-color: #4fd1c5;\n  }\n\n  .xl\\:to-teal-500 {\n    --gradient-to-color: #38b2ac;\n  }\n\n  .xl\\:to-teal-600 {\n    --gradient-to-color: #319795;\n  }\n\n  .xl\\:to-teal-700 {\n    --gradient-to-color: #2c7a7b;\n  }\n\n  .xl\\:to-teal-800 {\n    --gradient-to-color: #285e61;\n  }\n\n  .xl\\:to-teal-900 {\n    --gradient-to-color: #234e52;\n  }\n\n  .xl\\:to-blue-100 {\n    --gradient-to-color: #ebf8ff;\n  }\n\n  .xl\\:to-blue-200 {\n    --gradient-to-color: #bee3f8;\n  }\n\n  .xl\\:to-blue-300 {\n    --gradient-to-color: #90cdf4;\n  }\n\n  .xl\\:to-blue-400 {\n    --gradient-to-color: #63b3ed;\n  }\n\n  .xl\\:to-blue-500 {\n    --gradient-to-color: #4299e1;\n  }\n\n  .xl\\:to-blue-600 {\n    --gradient-to-color: #3182ce;\n  }\n\n  .xl\\:to-blue-700 {\n    --gradient-to-color: #2b6cb0;\n  }\n\n  .xl\\:to-blue-800 {\n    --gradient-to-color: #2c5282;\n  }\n\n  .xl\\:to-blue-900 {\n    --gradient-to-color: #2a4365;\n  }\n\n  .xl\\:to-indigo-100 {\n    --gradient-to-color: #ebf4ff;\n  }\n\n  .xl\\:to-indigo-200 {\n    --gradient-to-color: #c3dafe;\n  }\n\n  .xl\\:to-indigo-300 {\n    --gradient-to-color: #a3bffa;\n  }\n\n  .xl\\:to-indigo-400 {\n    --gradient-to-color: #7f9cf5;\n  }\n\n  .xl\\:to-indigo-500 {\n    --gradient-to-color: #667eea;\n  }\n\n  .xl\\:to-indigo-600 {\n    --gradient-to-color: #5a67d8;\n  }\n\n  .xl\\:to-indigo-700 {\n    --gradient-to-color: #4c51bf;\n  }\n\n  .xl\\:to-indigo-800 {\n    --gradient-to-color: #434190;\n  }\n\n  .xl\\:to-indigo-900 {\n    --gradient-to-color: #3c366b;\n  }\n\n  .xl\\:to-purple-100 {\n    --gradient-to-color: #faf5ff;\n  }\n\n  .xl\\:to-purple-200 {\n    --gradient-to-color: #e9d8fd;\n  }\n\n  .xl\\:to-purple-300 {\n    --gradient-to-color: #d6bcfa;\n  }\n\n  .xl\\:to-purple-400 {\n    --gradient-to-color: #b794f4;\n  }\n\n  .xl\\:to-purple-500 {\n    --gradient-to-color: #9f7aea;\n  }\n\n  .xl\\:to-purple-600 {\n    --gradient-to-color: #805ad5;\n  }\n\n  .xl\\:to-purple-700 {\n    --gradient-to-color: #6b46c1;\n  }\n\n  .xl\\:to-purple-800 {\n    --gradient-to-color: #553c9a;\n  }\n\n  .xl\\:to-purple-900 {\n    --gradient-to-color: #44337a;\n  }\n\n  .xl\\:to-pink-100 {\n    --gradient-to-color: #fff5f7;\n  }\n\n  .xl\\:to-pink-200 {\n    --gradient-to-color: #fed7e2;\n  }\n\n  .xl\\:to-pink-300 {\n    --gradient-to-color: #fbb6ce;\n  }\n\n  .xl\\:to-pink-400 {\n    --gradient-to-color: #f687b3;\n  }\n\n  .xl\\:to-pink-500 {\n    --gradient-to-color: #ed64a6;\n  }\n\n  .xl\\:to-pink-600 {\n    --gradient-to-color: #d53f8c;\n  }\n\n  .xl\\:to-pink-700 {\n    --gradient-to-color: #b83280;\n  }\n\n  .xl\\:to-pink-800 {\n    --gradient-to-color: #97266d;\n  }\n\n  .xl\\:to-pink-900 {\n    --gradient-to-color: #702459;\n  }\n\n  .xl\\:to-grayscale-80 {\n    --gradient-to-color: hsl(0, 0%, 8%);\n  }\n\n  .xl\\:to-grayscale-100 {\n    --gradient-to-color: hsl(0, 0%, 10%);\n  }\n\n  .xl\\:to-grayscale-200 {\n    --gradient-to-color: hsl(0, 0%, 20%);\n  }\n\n  .xl\\:to-grayscale-300 {\n    --gradient-to-color: hsl(0, 0%, 30%);\n  }\n\n  .xl\\:to-grayscale-400 {\n    --gradient-to-color: hsl(0, 0%, 40%);\n  }\n\n  .xl\\:to-grayscale-500 {\n    --gradient-to-color: hsl(0, 0%, 50%);\n  }\n\n  .xl\\:to-grayscale-600 {\n    --gradient-to-color: hsl(0, 0%, 60%);\n  }\n\n  .xl\\:to-grayscale-700 {\n    --gradient-to-color: hsl(0, 0%, 70%);\n  }\n\n  .xl\\:to-grayscale-800 {\n    --gradient-to-color: hsl(0, 0%, 80%);\n  }\n\n  .xl\\:to-grayscale-840 {\n    --gradient-to-color: hsl(0, 0%, 84%);\n  }\n\n  .xl\\:to-grayscale-870 {\n    --gradient-to-color: hsl(0, 0%, 87%);\n  }\n\n  .xl\\:to-grayscale-900 {\n    --gradient-to-color: hsl(0, 0%, 90%);\n  }\n\n  .xl\\:to-grayscale-930 {\n    --gradient-to-color: hsl(0, 0%, 93%);\n  }\n\n  .xl\\:to-primary {\n    --gradient-to-color: hsl(210, 100%, 52%);\n  }\n\n  .xl\\:to-background-main {\n    --gradient-to-color: var(--main-background);\n  }\n\n  .xl\\:to-background-secondary {\n    --gradient-to-color: var(--secondary-background);\n  }\n\n  .xl\\:to-foreground {\n    --gradient-to-color: var(--foreground);\n  }\n\n  .xl\\:to-panels-bg {\n    --gradient-to-color: var(--panels-background);\n  }\n\n  .xl\\:hover\\:from-transparent:hover {\n    --gradient-from-color: transparent;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .xl\\:hover\\:from-current:hover {\n    --gradient-from-color: currentColor;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:hover\\:from-black:hover {\n    --gradient-from-color: #000;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .xl\\:hover\\:from-white:hover {\n    --gradient-from-color: #fff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:hover\\:from-gray-100:hover {\n    --gradient-from-color: #f7fafc;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n  }\n\n  .xl\\:hover\\:from-gray-200:hover {\n    --gradient-from-color: #edf2f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n  }\n\n  .xl\\:hover\\:from-gray-300:hover {\n    --gradient-from-color: #e2e8f0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n  }\n\n  .xl\\:hover\\:from-gray-400:hover {\n    --gradient-from-color: #cbd5e0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n  }\n\n  .xl\\:hover\\:from-gray-500:hover {\n    --gradient-from-color: #a0aec0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n  }\n\n  .xl\\:hover\\:from-gray-600:hover {\n    --gradient-from-color: #718096;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n  }\n\n  .xl\\:hover\\:from-gray-700:hover {\n    --gradient-from-color: #4a5568;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n  }\n\n  .xl\\:hover\\:from-gray-800:hover {\n    --gradient-from-color: #2d3748;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n  }\n\n  .xl\\:hover\\:from-gray-900:hover {\n    --gradient-from-color: #1a202c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n  }\n\n  .xl\\:hover\\:from-red-100:hover {\n    --gradient-from-color: #fff5f5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n  }\n\n  .xl\\:hover\\:from-red-200:hover {\n    --gradient-from-color: #fed7d7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n  }\n\n  .xl\\:hover\\:from-red-300:hover {\n    --gradient-from-color: #feb2b2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n  }\n\n  .xl\\:hover\\:from-red-400:hover {\n    --gradient-from-color: #fc8181;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n  }\n\n  .xl\\:hover\\:from-red-500:hover {\n    --gradient-from-color: #f56565;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n  }\n\n  .xl\\:hover\\:from-red-600:hover {\n    --gradient-from-color: #e53e3e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n  }\n\n  .xl\\:hover\\:from-red-700:hover {\n    --gradient-from-color: #c53030;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n  }\n\n  .xl\\:hover\\:from-red-800:hover {\n    --gradient-from-color: #9b2c2c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n  }\n\n  .xl\\:hover\\:from-red-900:hover {\n    --gradient-from-color: #742a2a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n  }\n\n  .xl\\:hover\\:from-orange-100:hover {\n    --gradient-from-color: #fffaf0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n  }\n\n  .xl\\:hover\\:from-orange-200:hover {\n    --gradient-from-color: #feebc8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n  }\n\n  .xl\\:hover\\:from-orange-300:hover {\n    --gradient-from-color: #fbd38d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n  }\n\n  .xl\\:hover\\:from-orange-400:hover {\n    --gradient-from-color: #f6ad55;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n  }\n\n  .xl\\:hover\\:from-orange-500:hover {\n    --gradient-from-color: #ed8936;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n  }\n\n  .xl\\:hover\\:from-orange-600:hover {\n    --gradient-from-color: #dd6b20;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n  }\n\n  .xl\\:hover\\:from-orange-700:hover {\n    --gradient-from-color: #c05621;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n  }\n\n  .xl\\:hover\\:from-orange-800:hover {\n    --gradient-from-color: #9c4221;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n  }\n\n  .xl\\:hover\\:from-orange-900:hover {\n    --gradient-from-color: #7b341e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n  }\n\n  .xl\\:hover\\:from-yellow-100:hover {\n    --gradient-from-color: #fffff0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n  }\n\n  .xl\\:hover\\:from-yellow-200:hover {\n    --gradient-from-color: #fefcbf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n  }\n\n  .xl\\:hover\\:from-yellow-300:hover {\n    --gradient-from-color: #faf089;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n  }\n\n  .xl\\:hover\\:from-yellow-400:hover {\n    --gradient-from-color: #f6e05e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n  }\n\n  .xl\\:hover\\:from-yellow-500:hover {\n    --gradient-from-color: #ecc94b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n  }\n\n  .xl\\:hover\\:from-yellow-600:hover {\n    --gradient-from-color: #d69e2e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n  }\n\n  .xl\\:hover\\:from-yellow-700:hover {\n    --gradient-from-color: #b7791f;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n  }\n\n  .xl\\:hover\\:from-yellow-800:hover {\n    --gradient-from-color: #975a16;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n  }\n\n  .xl\\:hover\\:from-yellow-900:hover {\n    --gradient-from-color: #744210;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n  }\n\n  .xl\\:hover\\:from-green-100:hover {\n    --gradient-from-color: #f0fff4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n  }\n\n  .xl\\:hover\\:from-green-200:hover {\n    --gradient-from-color: #c6f6d5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n  }\n\n  .xl\\:hover\\:from-green-300:hover {\n    --gradient-from-color: #9ae6b4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n  }\n\n  .xl\\:hover\\:from-green-400:hover {\n    --gradient-from-color: #68d391;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n  }\n\n  .xl\\:hover\\:from-green-500:hover {\n    --gradient-from-color: #48bb78;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n  }\n\n  .xl\\:hover\\:from-green-600:hover {\n    --gradient-from-color: #38a169;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n  }\n\n  .xl\\:hover\\:from-green-700:hover {\n    --gradient-from-color: #2f855a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n  }\n\n  .xl\\:hover\\:from-green-800:hover {\n    --gradient-from-color: #276749;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n  }\n\n  .xl\\:hover\\:from-green-900:hover {\n    --gradient-from-color: #22543d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n  }\n\n  .xl\\:hover\\:from-teal-100:hover {\n    --gradient-from-color: #e6fffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n  }\n\n  .xl\\:hover\\:from-teal-200:hover {\n    --gradient-from-color: #b2f5ea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n  }\n\n  .xl\\:hover\\:from-teal-300:hover {\n    --gradient-from-color: #81e6d9;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n  }\n\n  .xl\\:hover\\:from-teal-400:hover {\n    --gradient-from-color: #4fd1c5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n  }\n\n  .xl\\:hover\\:from-teal-500:hover {\n    --gradient-from-color: #38b2ac;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n  }\n\n  .xl\\:hover\\:from-teal-600:hover {\n    --gradient-from-color: #319795;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n  }\n\n  .xl\\:hover\\:from-teal-700:hover {\n    --gradient-from-color: #2c7a7b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n  }\n\n  .xl\\:hover\\:from-teal-800:hover {\n    --gradient-from-color: #285e61;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n  }\n\n  .xl\\:hover\\:from-teal-900:hover {\n    --gradient-from-color: #234e52;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n  }\n\n  .xl\\:hover\\:from-blue-100:hover {\n    --gradient-from-color: #ebf8ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n  }\n\n  .xl\\:hover\\:from-blue-200:hover {\n    --gradient-from-color: #bee3f8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n  }\n\n  .xl\\:hover\\:from-blue-300:hover {\n    --gradient-from-color: #90cdf4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n  }\n\n  .xl\\:hover\\:from-blue-400:hover {\n    --gradient-from-color: #63b3ed;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n  }\n\n  .xl\\:hover\\:from-blue-500:hover {\n    --gradient-from-color: #4299e1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n  }\n\n  .xl\\:hover\\:from-blue-600:hover {\n    --gradient-from-color: #3182ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n  }\n\n  .xl\\:hover\\:from-blue-700:hover {\n    --gradient-from-color: #2b6cb0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n  }\n\n  .xl\\:hover\\:from-blue-800:hover {\n    --gradient-from-color: #2c5282;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n  }\n\n  .xl\\:hover\\:from-blue-900:hover {\n    --gradient-from-color: #2a4365;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n  }\n\n  .xl\\:hover\\:from-indigo-100:hover {\n    --gradient-from-color: #ebf4ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n  }\n\n  .xl\\:hover\\:from-indigo-200:hover {\n    --gradient-from-color: #c3dafe;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n  }\n\n  .xl\\:hover\\:from-indigo-300:hover {\n    --gradient-from-color: #a3bffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n  }\n\n  .xl\\:hover\\:from-indigo-400:hover {\n    --gradient-from-color: #7f9cf5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n  }\n\n  .xl\\:hover\\:from-indigo-500:hover {\n    --gradient-from-color: #667eea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n  }\n\n  .xl\\:hover\\:from-indigo-600:hover {\n    --gradient-from-color: #5a67d8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n  }\n\n  .xl\\:hover\\:from-indigo-700:hover {\n    --gradient-from-color: #4c51bf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n  }\n\n  .xl\\:hover\\:from-indigo-800:hover {\n    --gradient-from-color: #434190;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n  }\n\n  .xl\\:hover\\:from-indigo-900:hover {\n    --gradient-from-color: #3c366b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n  }\n\n  .xl\\:hover\\:from-purple-100:hover {\n    --gradient-from-color: #faf5ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n  }\n\n  .xl\\:hover\\:from-purple-200:hover {\n    --gradient-from-color: #e9d8fd;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n  }\n\n  .xl\\:hover\\:from-purple-300:hover {\n    --gradient-from-color: #d6bcfa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n  }\n\n  .xl\\:hover\\:from-purple-400:hover {\n    --gradient-from-color: #b794f4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n  }\n\n  .xl\\:hover\\:from-purple-500:hover {\n    --gradient-from-color: #9f7aea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n  }\n\n  .xl\\:hover\\:from-purple-600:hover {\n    --gradient-from-color: #805ad5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n  }\n\n  .xl\\:hover\\:from-purple-700:hover {\n    --gradient-from-color: #6b46c1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n  }\n\n  .xl\\:hover\\:from-purple-800:hover {\n    --gradient-from-color: #553c9a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n  }\n\n  .xl\\:hover\\:from-purple-900:hover {\n    --gradient-from-color: #44337a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n  }\n\n  .xl\\:hover\\:from-pink-100:hover {\n    --gradient-from-color: #fff5f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n  }\n\n  .xl\\:hover\\:from-pink-200:hover {\n    --gradient-from-color: #fed7e2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n  }\n\n  .xl\\:hover\\:from-pink-300:hover {\n    --gradient-from-color: #fbb6ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n  }\n\n  .xl\\:hover\\:from-pink-400:hover {\n    --gradient-from-color: #f687b3;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n  }\n\n  .xl\\:hover\\:from-pink-500:hover {\n    --gradient-from-color: #ed64a6;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n  }\n\n  .xl\\:hover\\:from-pink-600:hover {\n    --gradient-from-color: #d53f8c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n  }\n\n  .xl\\:hover\\:from-pink-700:hover {\n    --gradient-from-color: #b83280;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n  }\n\n  .xl\\:hover\\:from-pink-800:hover {\n    --gradient-from-color: #97266d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n  }\n\n  .xl\\:hover\\:from-pink-900:hover {\n    --gradient-from-color: #702459;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n  }\n\n  .xl\\:hover\\:from-grayscale-80:hover {\n    --gradient-from-color: hsl(0, 0%, 8%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n  }\n\n  .xl\\:hover\\:from-grayscale-100:hover {\n    --gradient-from-color: hsl(0, 0%, 10%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n  }\n\n  .xl\\:hover\\:from-grayscale-200:hover {\n    --gradient-from-color: hsl(0, 0%, 20%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n  }\n\n  .xl\\:hover\\:from-grayscale-300:hover {\n    --gradient-from-color: hsl(0, 0%, 30%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n  }\n\n  .xl\\:hover\\:from-grayscale-400:hover {\n    --gradient-from-color: hsl(0, 0%, 40%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n  }\n\n  .xl\\:hover\\:from-grayscale-500:hover {\n    --gradient-from-color: hsl(0, 0%, 50%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n  }\n\n  .xl\\:hover\\:from-grayscale-600:hover {\n    --gradient-from-color: hsl(0, 0%, 60%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n  }\n\n  .xl\\:hover\\:from-grayscale-700:hover {\n    --gradient-from-color: hsl(0, 0%, 70%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n  }\n\n  .xl\\:hover\\:from-grayscale-800:hover {\n    --gradient-from-color: hsl(0, 0%, 80%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n  }\n\n  .xl\\:hover\\:from-grayscale-840:hover {\n    --gradient-from-color: hsl(0, 0%, 84%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n  }\n\n  .xl\\:hover\\:from-grayscale-870:hover {\n    --gradient-from-color: hsl(0, 0%, 87%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n  }\n\n  .xl\\:hover\\:from-grayscale-900:hover {\n    --gradient-from-color: hsl(0, 0%, 90%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n  }\n\n  .xl\\:hover\\:from-grayscale-930:hover {\n    --gradient-from-color: hsl(0, 0%, 93%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n  }\n\n  .xl\\:hover\\:from-primary:hover {\n    --gradient-from-color: hsl(210, 100%, 52%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n  }\n\n  .xl\\:hover\\:from-background-main:hover {\n    --gradient-from-color: var(--main-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:hover\\:from-background-secondary:hover {\n    --gradient-from-color: var(--secondary-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:hover\\:from-foreground:hover {\n    --gradient-from-color: var(--foreground);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:hover\\:from-panels-bg:hover {\n    --gradient-from-color: var(--panels-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:hover\\:via-transparent:hover {\n    --gradient-via-color: transparent;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .xl\\:hover\\:via-current:hover {\n    --gradient-via-color: currentColor;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:hover\\:via-black:hover {\n    --gradient-via-color: #000;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .xl\\:hover\\:via-white:hover {\n    --gradient-via-color: #fff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:hover\\:via-gray-100:hover {\n    --gradient-via-color: #f7fafc;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n  }\n\n  .xl\\:hover\\:via-gray-200:hover {\n    --gradient-via-color: #edf2f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n  }\n\n  .xl\\:hover\\:via-gray-300:hover {\n    --gradient-via-color: #e2e8f0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n  }\n\n  .xl\\:hover\\:via-gray-400:hover {\n    --gradient-via-color: #cbd5e0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n  }\n\n  .xl\\:hover\\:via-gray-500:hover {\n    --gradient-via-color: #a0aec0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n  }\n\n  .xl\\:hover\\:via-gray-600:hover {\n    --gradient-via-color: #718096;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n  }\n\n  .xl\\:hover\\:via-gray-700:hover {\n    --gradient-via-color: #4a5568;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n  }\n\n  .xl\\:hover\\:via-gray-800:hover {\n    --gradient-via-color: #2d3748;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n  }\n\n  .xl\\:hover\\:via-gray-900:hover {\n    --gradient-via-color: #1a202c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n  }\n\n  .xl\\:hover\\:via-red-100:hover {\n    --gradient-via-color: #fff5f5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n  }\n\n  .xl\\:hover\\:via-red-200:hover {\n    --gradient-via-color: #fed7d7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n  }\n\n  .xl\\:hover\\:via-red-300:hover {\n    --gradient-via-color: #feb2b2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n  }\n\n  .xl\\:hover\\:via-red-400:hover {\n    --gradient-via-color: #fc8181;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n  }\n\n  .xl\\:hover\\:via-red-500:hover {\n    --gradient-via-color: #f56565;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n  }\n\n  .xl\\:hover\\:via-red-600:hover {\n    --gradient-via-color: #e53e3e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n  }\n\n  .xl\\:hover\\:via-red-700:hover {\n    --gradient-via-color: #c53030;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n  }\n\n  .xl\\:hover\\:via-red-800:hover {\n    --gradient-via-color: #9b2c2c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n  }\n\n  .xl\\:hover\\:via-red-900:hover {\n    --gradient-via-color: #742a2a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n  }\n\n  .xl\\:hover\\:via-orange-100:hover {\n    --gradient-via-color: #fffaf0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n  }\n\n  .xl\\:hover\\:via-orange-200:hover {\n    --gradient-via-color: #feebc8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n  }\n\n  .xl\\:hover\\:via-orange-300:hover {\n    --gradient-via-color: #fbd38d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n  }\n\n  .xl\\:hover\\:via-orange-400:hover {\n    --gradient-via-color: #f6ad55;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n  }\n\n  .xl\\:hover\\:via-orange-500:hover {\n    --gradient-via-color: #ed8936;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n  }\n\n  .xl\\:hover\\:via-orange-600:hover {\n    --gradient-via-color: #dd6b20;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n  }\n\n  .xl\\:hover\\:via-orange-700:hover {\n    --gradient-via-color: #c05621;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n  }\n\n  .xl\\:hover\\:via-orange-800:hover {\n    --gradient-via-color: #9c4221;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n  }\n\n  .xl\\:hover\\:via-orange-900:hover {\n    --gradient-via-color: #7b341e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n  }\n\n  .xl\\:hover\\:via-yellow-100:hover {\n    --gradient-via-color: #fffff0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n  }\n\n  .xl\\:hover\\:via-yellow-200:hover {\n    --gradient-via-color: #fefcbf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n  }\n\n  .xl\\:hover\\:via-yellow-300:hover {\n    --gradient-via-color: #faf089;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n  }\n\n  .xl\\:hover\\:via-yellow-400:hover {\n    --gradient-via-color: #f6e05e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n  }\n\n  .xl\\:hover\\:via-yellow-500:hover {\n    --gradient-via-color: #ecc94b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n  }\n\n  .xl\\:hover\\:via-yellow-600:hover {\n    --gradient-via-color: #d69e2e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n  }\n\n  .xl\\:hover\\:via-yellow-700:hover {\n    --gradient-via-color: #b7791f;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n  }\n\n  .xl\\:hover\\:via-yellow-800:hover {\n    --gradient-via-color: #975a16;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n  }\n\n  .xl\\:hover\\:via-yellow-900:hover {\n    --gradient-via-color: #744210;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n  }\n\n  .xl\\:hover\\:via-green-100:hover {\n    --gradient-via-color: #f0fff4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n  }\n\n  .xl\\:hover\\:via-green-200:hover {\n    --gradient-via-color: #c6f6d5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n  }\n\n  .xl\\:hover\\:via-green-300:hover {\n    --gradient-via-color: #9ae6b4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n  }\n\n  .xl\\:hover\\:via-green-400:hover {\n    --gradient-via-color: #68d391;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n  }\n\n  .xl\\:hover\\:via-green-500:hover {\n    --gradient-via-color: #48bb78;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n  }\n\n  .xl\\:hover\\:via-green-600:hover {\n    --gradient-via-color: #38a169;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n  }\n\n  .xl\\:hover\\:via-green-700:hover {\n    --gradient-via-color: #2f855a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n  }\n\n  .xl\\:hover\\:via-green-800:hover {\n    --gradient-via-color: #276749;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n  }\n\n  .xl\\:hover\\:via-green-900:hover {\n    --gradient-via-color: #22543d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n  }\n\n  .xl\\:hover\\:via-teal-100:hover {\n    --gradient-via-color: #e6fffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n  }\n\n  .xl\\:hover\\:via-teal-200:hover {\n    --gradient-via-color: #b2f5ea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n  }\n\n  .xl\\:hover\\:via-teal-300:hover {\n    --gradient-via-color: #81e6d9;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n  }\n\n  .xl\\:hover\\:via-teal-400:hover {\n    --gradient-via-color: #4fd1c5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n  }\n\n  .xl\\:hover\\:via-teal-500:hover {\n    --gradient-via-color: #38b2ac;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n  }\n\n  .xl\\:hover\\:via-teal-600:hover {\n    --gradient-via-color: #319795;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n  }\n\n  .xl\\:hover\\:via-teal-700:hover {\n    --gradient-via-color: #2c7a7b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n  }\n\n  .xl\\:hover\\:via-teal-800:hover {\n    --gradient-via-color: #285e61;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n  }\n\n  .xl\\:hover\\:via-teal-900:hover {\n    --gradient-via-color: #234e52;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n  }\n\n  .xl\\:hover\\:via-blue-100:hover {\n    --gradient-via-color: #ebf8ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n  }\n\n  .xl\\:hover\\:via-blue-200:hover {\n    --gradient-via-color: #bee3f8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n  }\n\n  .xl\\:hover\\:via-blue-300:hover {\n    --gradient-via-color: #90cdf4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n  }\n\n  .xl\\:hover\\:via-blue-400:hover {\n    --gradient-via-color: #63b3ed;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n  }\n\n  .xl\\:hover\\:via-blue-500:hover {\n    --gradient-via-color: #4299e1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n  }\n\n  .xl\\:hover\\:via-blue-600:hover {\n    --gradient-via-color: #3182ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n  }\n\n  .xl\\:hover\\:via-blue-700:hover {\n    --gradient-via-color: #2b6cb0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n  }\n\n  .xl\\:hover\\:via-blue-800:hover {\n    --gradient-via-color: #2c5282;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n  }\n\n  .xl\\:hover\\:via-blue-900:hover {\n    --gradient-via-color: #2a4365;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n  }\n\n  .xl\\:hover\\:via-indigo-100:hover {\n    --gradient-via-color: #ebf4ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n  }\n\n  .xl\\:hover\\:via-indigo-200:hover {\n    --gradient-via-color: #c3dafe;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n  }\n\n  .xl\\:hover\\:via-indigo-300:hover {\n    --gradient-via-color: #a3bffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n  }\n\n  .xl\\:hover\\:via-indigo-400:hover {\n    --gradient-via-color: #7f9cf5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n  }\n\n  .xl\\:hover\\:via-indigo-500:hover {\n    --gradient-via-color: #667eea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n  }\n\n  .xl\\:hover\\:via-indigo-600:hover {\n    --gradient-via-color: #5a67d8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n  }\n\n  .xl\\:hover\\:via-indigo-700:hover {\n    --gradient-via-color: #4c51bf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n  }\n\n  .xl\\:hover\\:via-indigo-800:hover {\n    --gradient-via-color: #434190;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n  }\n\n  .xl\\:hover\\:via-indigo-900:hover {\n    --gradient-via-color: #3c366b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n  }\n\n  .xl\\:hover\\:via-purple-100:hover {\n    --gradient-via-color: #faf5ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n  }\n\n  .xl\\:hover\\:via-purple-200:hover {\n    --gradient-via-color: #e9d8fd;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n  }\n\n  .xl\\:hover\\:via-purple-300:hover {\n    --gradient-via-color: #d6bcfa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n  }\n\n  .xl\\:hover\\:via-purple-400:hover {\n    --gradient-via-color: #b794f4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n  }\n\n  .xl\\:hover\\:via-purple-500:hover {\n    --gradient-via-color: #9f7aea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n  }\n\n  .xl\\:hover\\:via-purple-600:hover {\n    --gradient-via-color: #805ad5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n  }\n\n  .xl\\:hover\\:via-purple-700:hover {\n    --gradient-via-color: #6b46c1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n  }\n\n  .xl\\:hover\\:via-purple-800:hover {\n    --gradient-via-color: #553c9a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n  }\n\n  .xl\\:hover\\:via-purple-900:hover {\n    --gradient-via-color: #44337a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n  }\n\n  .xl\\:hover\\:via-pink-100:hover {\n    --gradient-via-color: #fff5f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n  }\n\n  .xl\\:hover\\:via-pink-200:hover {\n    --gradient-via-color: #fed7e2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n  }\n\n  .xl\\:hover\\:via-pink-300:hover {\n    --gradient-via-color: #fbb6ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n  }\n\n  .xl\\:hover\\:via-pink-400:hover {\n    --gradient-via-color: #f687b3;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n  }\n\n  .xl\\:hover\\:via-pink-500:hover {\n    --gradient-via-color: #ed64a6;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n  }\n\n  .xl\\:hover\\:via-pink-600:hover {\n    --gradient-via-color: #d53f8c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n  }\n\n  .xl\\:hover\\:via-pink-700:hover {\n    --gradient-via-color: #b83280;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n  }\n\n  .xl\\:hover\\:via-pink-800:hover {\n    --gradient-via-color: #97266d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n  }\n\n  .xl\\:hover\\:via-pink-900:hover {\n    --gradient-via-color: #702459;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n  }\n\n  .xl\\:hover\\:via-grayscale-80:hover {\n    --gradient-via-color: hsl(0, 0%, 8%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n  }\n\n  .xl\\:hover\\:via-grayscale-100:hover {\n    --gradient-via-color: hsl(0, 0%, 10%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n  }\n\n  .xl\\:hover\\:via-grayscale-200:hover {\n    --gradient-via-color: hsl(0, 0%, 20%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n  }\n\n  .xl\\:hover\\:via-grayscale-300:hover {\n    --gradient-via-color: hsl(0, 0%, 30%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n  }\n\n  .xl\\:hover\\:via-grayscale-400:hover {\n    --gradient-via-color: hsl(0, 0%, 40%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n  }\n\n  .xl\\:hover\\:via-grayscale-500:hover {\n    --gradient-via-color: hsl(0, 0%, 50%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n  }\n\n  .xl\\:hover\\:via-grayscale-600:hover {\n    --gradient-via-color: hsl(0, 0%, 60%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n  }\n\n  .xl\\:hover\\:via-grayscale-700:hover {\n    --gradient-via-color: hsl(0, 0%, 70%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n  }\n\n  .xl\\:hover\\:via-grayscale-800:hover {\n    --gradient-via-color: hsl(0, 0%, 80%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n  }\n\n  .xl\\:hover\\:via-grayscale-840:hover {\n    --gradient-via-color: hsl(0, 0%, 84%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n  }\n\n  .xl\\:hover\\:via-grayscale-870:hover {\n    --gradient-via-color: hsl(0, 0%, 87%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n  }\n\n  .xl\\:hover\\:via-grayscale-900:hover {\n    --gradient-via-color: hsl(0, 0%, 90%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n  }\n\n  .xl\\:hover\\:via-grayscale-930:hover {\n    --gradient-via-color: hsl(0, 0%, 93%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n  }\n\n  .xl\\:hover\\:via-primary:hover {\n    --gradient-via-color: hsl(210, 100%, 52%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n  }\n\n  .xl\\:hover\\:via-background-main:hover {\n    --gradient-via-color: var(--main-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:hover\\:via-background-secondary:hover {\n    --gradient-via-color: var(--secondary-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:hover\\:via-foreground:hover {\n    --gradient-via-color: var(--foreground);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:hover\\:via-panels-bg:hover {\n    --gradient-via-color: var(--panels-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:hover\\:to-transparent:hover {\n    --gradient-to-color: transparent;\n  }\n\n  .xl\\:hover\\:to-current:hover {\n    --gradient-to-color: currentColor;\n  }\n\n  .xl\\:hover\\:to-black:hover {\n    --gradient-to-color: #000;\n  }\n\n  .xl\\:hover\\:to-white:hover {\n    --gradient-to-color: #fff;\n  }\n\n  .xl\\:hover\\:to-gray-100:hover {\n    --gradient-to-color: #f7fafc;\n  }\n\n  .xl\\:hover\\:to-gray-200:hover {\n    --gradient-to-color: #edf2f7;\n  }\n\n  .xl\\:hover\\:to-gray-300:hover {\n    --gradient-to-color: #e2e8f0;\n  }\n\n  .xl\\:hover\\:to-gray-400:hover {\n    --gradient-to-color: #cbd5e0;\n  }\n\n  .xl\\:hover\\:to-gray-500:hover {\n    --gradient-to-color: #a0aec0;\n  }\n\n  .xl\\:hover\\:to-gray-600:hover {\n    --gradient-to-color: #718096;\n  }\n\n  .xl\\:hover\\:to-gray-700:hover {\n    --gradient-to-color: #4a5568;\n  }\n\n  .xl\\:hover\\:to-gray-800:hover {\n    --gradient-to-color: #2d3748;\n  }\n\n  .xl\\:hover\\:to-gray-900:hover {\n    --gradient-to-color: #1a202c;\n  }\n\n  .xl\\:hover\\:to-red-100:hover {\n    --gradient-to-color: #fff5f5;\n  }\n\n  .xl\\:hover\\:to-red-200:hover {\n    --gradient-to-color: #fed7d7;\n  }\n\n  .xl\\:hover\\:to-red-300:hover {\n    --gradient-to-color: #feb2b2;\n  }\n\n  .xl\\:hover\\:to-red-400:hover {\n    --gradient-to-color: #fc8181;\n  }\n\n  .xl\\:hover\\:to-red-500:hover {\n    --gradient-to-color: #f56565;\n  }\n\n  .xl\\:hover\\:to-red-600:hover {\n    --gradient-to-color: #e53e3e;\n  }\n\n  .xl\\:hover\\:to-red-700:hover {\n    --gradient-to-color: #c53030;\n  }\n\n  .xl\\:hover\\:to-red-800:hover {\n    --gradient-to-color: #9b2c2c;\n  }\n\n  .xl\\:hover\\:to-red-900:hover {\n    --gradient-to-color: #742a2a;\n  }\n\n  .xl\\:hover\\:to-orange-100:hover {\n    --gradient-to-color: #fffaf0;\n  }\n\n  .xl\\:hover\\:to-orange-200:hover {\n    --gradient-to-color: #feebc8;\n  }\n\n  .xl\\:hover\\:to-orange-300:hover {\n    --gradient-to-color: #fbd38d;\n  }\n\n  .xl\\:hover\\:to-orange-400:hover {\n    --gradient-to-color: #f6ad55;\n  }\n\n  .xl\\:hover\\:to-orange-500:hover {\n    --gradient-to-color: #ed8936;\n  }\n\n  .xl\\:hover\\:to-orange-600:hover {\n    --gradient-to-color: #dd6b20;\n  }\n\n  .xl\\:hover\\:to-orange-700:hover {\n    --gradient-to-color: #c05621;\n  }\n\n  .xl\\:hover\\:to-orange-800:hover {\n    --gradient-to-color: #9c4221;\n  }\n\n  .xl\\:hover\\:to-orange-900:hover {\n    --gradient-to-color: #7b341e;\n  }\n\n  .xl\\:hover\\:to-yellow-100:hover {\n    --gradient-to-color: #fffff0;\n  }\n\n  .xl\\:hover\\:to-yellow-200:hover {\n    --gradient-to-color: #fefcbf;\n  }\n\n  .xl\\:hover\\:to-yellow-300:hover {\n    --gradient-to-color: #faf089;\n  }\n\n  .xl\\:hover\\:to-yellow-400:hover {\n    --gradient-to-color: #f6e05e;\n  }\n\n  .xl\\:hover\\:to-yellow-500:hover {\n    --gradient-to-color: #ecc94b;\n  }\n\n  .xl\\:hover\\:to-yellow-600:hover {\n    --gradient-to-color: #d69e2e;\n  }\n\n  .xl\\:hover\\:to-yellow-700:hover {\n    --gradient-to-color: #b7791f;\n  }\n\n  .xl\\:hover\\:to-yellow-800:hover {\n    --gradient-to-color: #975a16;\n  }\n\n  .xl\\:hover\\:to-yellow-900:hover {\n    --gradient-to-color: #744210;\n  }\n\n  .xl\\:hover\\:to-green-100:hover {\n    --gradient-to-color: #f0fff4;\n  }\n\n  .xl\\:hover\\:to-green-200:hover {\n    --gradient-to-color: #c6f6d5;\n  }\n\n  .xl\\:hover\\:to-green-300:hover {\n    --gradient-to-color: #9ae6b4;\n  }\n\n  .xl\\:hover\\:to-green-400:hover {\n    --gradient-to-color: #68d391;\n  }\n\n  .xl\\:hover\\:to-green-500:hover {\n    --gradient-to-color: #48bb78;\n  }\n\n  .xl\\:hover\\:to-green-600:hover {\n    --gradient-to-color: #38a169;\n  }\n\n  .xl\\:hover\\:to-green-700:hover {\n    --gradient-to-color: #2f855a;\n  }\n\n  .xl\\:hover\\:to-green-800:hover {\n    --gradient-to-color: #276749;\n  }\n\n  .xl\\:hover\\:to-green-900:hover {\n    --gradient-to-color: #22543d;\n  }\n\n  .xl\\:hover\\:to-teal-100:hover {\n    --gradient-to-color: #e6fffa;\n  }\n\n  .xl\\:hover\\:to-teal-200:hover {\n    --gradient-to-color: #b2f5ea;\n  }\n\n  .xl\\:hover\\:to-teal-300:hover {\n    --gradient-to-color: #81e6d9;\n  }\n\n  .xl\\:hover\\:to-teal-400:hover {\n    --gradient-to-color: #4fd1c5;\n  }\n\n  .xl\\:hover\\:to-teal-500:hover {\n    --gradient-to-color: #38b2ac;\n  }\n\n  .xl\\:hover\\:to-teal-600:hover {\n    --gradient-to-color: #319795;\n  }\n\n  .xl\\:hover\\:to-teal-700:hover {\n    --gradient-to-color: #2c7a7b;\n  }\n\n  .xl\\:hover\\:to-teal-800:hover {\n    --gradient-to-color: #285e61;\n  }\n\n  .xl\\:hover\\:to-teal-900:hover {\n    --gradient-to-color: #234e52;\n  }\n\n  .xl\\:hover\\:to-blue-100:hover {\n    --gradient-to-color: #ebf8ff;\n  }\n\n  .xl\\:hover\\:to-blue-200:hover {\n    --gradient-to-color: #bee3f8;\n  }\n\n  .xl\\:hover\\:to-blue-300:hover {\n    --gradient-to-color: #90cdf4;\n  }\n\n  .xl\\:hover\\:to-blue-400:hover {\n    --gradient-to-color: #63b3ed;\n  }\n\n  .xl\\:hover\\:to-blue-500:hover {\n    --gradient-to-color: #4299e1;\n  }\n\n  .xl\\:hover\\:to-blue-600:hover {\n    --gradient-to-color: #3182ce;\n  }\n\n  .xl\\:hover\\:to-blue-700:hover {\n    --gradient-to-color: #2b6cb0;\n  }\n\n  .xl\\:hover\\:to-blue-800:hover {\n    --gradient-to-color: #2c5282;\n  }\n\n  .xl\\:hover\\:to-blue-900:hover {\n    --gradient-to-color: #2a4365;\n  }\n\n  .xl\\:hover\\:to-indigo-100:hover {\n    --gradient-to-color: #ebf4ff;\n  }\n\n  .xl\\:hover\\:to-indigo-200:hover {\n    --gradient-to-color: #c3dafe;\n  }\n\n  .xl\\:hover\\:to-indigo-300:hover {\n    --gradient-to-color: #a3bffa;\n  }\n\n  .xl\\:hover\\:to-indigo-400:hover {\n    --gradient-to-color: #7f9cf5;\n  }\n\n  .xl\\:hover\\:to-indigo-500:hover {\n    --gradient-to-color: #667eea;\n  }\n\n  .xl\\:hover\\:to-indigo-600:hover {\n    --gradient-to-color: #5a67d8;\n  }\n\n  .xl\\:hover\\:to-indigo-700:hover {\n    --gradient-to-color: #4c51bf;\n  }\n\n  .xl\\:hover\\:to-indigo-800:hover {\n    --gradient-to-color: #434190;\n  }\n\n  .xl\\:hover\\:to-indigo-900:hover {\n    --gradient-to-color: #3c366b;\n  }\n\n  .xl\\:hover\\:to-purple-100:hover {\n    --gradient-to-color: #faf5ff;\n  }\n\n  .xl\\:hover\\:to-purple-200:hover {\n    --gradient-to-color: #e9d8fd;\n  }\n\n  .xl\\:hover\\:to-purple-300:hover {\n    --gradient-to-color: #d6bcfa;\n  }\n\n  .xl\\:hover\\:to-purple-400:hover {\n    --gradient-to-color: #b794f4;\n  }\n\n  .xl\\:hover\\:to-purple-500:hover {\n    --gradient-to-color: #9f7aea;\n  }\n\n  .xl\\:hover\\:to-purple-600:hover {\n    --gradient-to-color: #805ad5;\n  }\n\n  .xl\\:hover\\:to-purple-700:hover {\n    --gradient-to-color: #6b46c1;\n  }\n\n  .xl\\:hover\\:to-purple-800:hover {\n    --gradient-to-color: #553c9a;\n  }\n\n  .xl\\:hover\\:to-purple-900:hover {\n    --gradient-to-color: #44337a;\n  }\n\n  .xl\\:hover\\:to-pink-100:hover {\n    --gradient-to-color: #fff5f7;\n  }\n\n  .xl\\:hover\\:to-pink-200:hover {\n    --gradient-to-color: #fed7e2;\n  }\n\n  .xl\\:hover\\:to-pink-300:hover {\n    --gradient-to-color: #fbb6ce;\n  }\n\n  .xl\\:hover\\:to-pink-400:hover {\n    --gradient-to-color: #f687b3;\n  }\n\n  .xl\\:hover\\:to-pink-500:hover {\n    --gradient-to-color: #ed64a6;\n  }\n\n  .xl\\:hover\\:to-pink-600:hover {\n    --gradient-to-color: #d53f8c;\n  }\n\n  .xl\\:hover\\:to-pink-700:hover {\n    --gradient-to-color: #b83280;\n  }\n\n  .xl\\:hover\\:to-pink-800:hover {\n    --gradient-to-color: #97266d;\n  }\n\n  .xl\\:hover\\:to-pink-900:hover {\n    --gradient-to-color: #702459;\n  }\n\n  .xl\\:hover\\:to-grayscale-80:hover {\n    --gradient-to-color: hsl(0, 0%, 8%);\n  }\n\n  .xl\\:hover\\:to-grayscale-100:hover {\n    --gradient-to-color: hsl(0, 0%, 10%);\n  }\n\n  .xl\\:hover\\:to-grayscale-200:hover {\n    --gradient-to-color: hsl(0, 0%, 20%);\n  }\n\n  .xl\\:hover\\:to-grayscale-300:hover {\n    --gradient-to-color: hsl(0, 0%, 30%);\n  }\n\n  .xl\\:hover\\:to-grayscale-400:hover {\n    --gradient-to-color: hsl(0, 0%, 40%);\n  }\n\n  .xl\\:hover\\:to-grayscale-500:hover {\n    --gradient-to-color: hsl(0, 0%, 50%);\n  }\n\n  .xl\\:hover\\:to-grayscale-600:hover {\n    --gradient-to-color: hsl(0, 0%, 60%);\n  }\n\n  .xl\\:hover\\:to-grayscale-700:hover {\n    --gradient-to-color: hsl(0, 0%, 70%);\n  }\n\n  .xl\\:hover\\:to-grayscale-800:hover {\n    --gradient-to-color: hsl(0, 0%, 80%);\n  }\n\n  .xl\\:hover\\:to-grayscale-840:hover {\n    --gradient-to-color: hsl(0, 0%, 84%);\n  }\n\n  .xl\\:hover\\:to-grayscale-870:hover {\n    --gradient-to-color: hsl(0, 0%, 87%);\n  }\n\n  .xl\\:hover\\:to-grayscale-900:hover {\n    --gradient-to-color: hsl(0, 0%, 90%);\n  }\n\n  .xl\\:hover\\:to-grayscale-930:hover {\n    --gradient-to-color: hsl(0, 0%, 93%);\n  }\n\n  .xl\\:hover\\:to-primary:hover {\n    --gradient-to-color: hsl(210, 100%, 52%);\n  }\n\n  .xl\\:hover\\:to-background-main:hover {\n    --gradient-to-color: var(--main-background);\n  }\n\n  .xl\\:hover\\:to-background-secondary:hover {\n    --gradient-to-color: var(--secondary-background);\n  }\n\n  .xl\\:hover\\:to-foreground:hover {\n    --gradient-to-color: var(--foreground);\n  }\n\n  .xl\\:hover\\:to-panels-bg:hover {\n    --gradient-to-color: var(--panels-background);\n  }\n\n  .xl\\:focus\\:from-transparent:focus {\n    --gradient-from-color: transparent;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .xl\\:focus\\:from-current:focus {\n    --gradient-from-color: currentColor;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:focus\\:from-black:focus {\n    --gradient-from-color: #000;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .xl\\:focus\\:from-white:focus {\n    --gradient-from-color: #fff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:focus\\:from-gray-100:focus {\n    --gradient-from-color: #f7fafc;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n  }\n\n  .xl\\:focus\\:from-gray-200:focus {\n    --gradient-from-color: #edf2f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n  }\n\n  .xl\\:focus\\:from-gray-300:focus {\n    --gradient-from-color: #e2e8f0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n  }\n\n  .xl\\:focus\\:from-gray-400:focus {\n    --gradient-from-color: #cbd5e0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n  }\n\n  .xl\\:focus\\:from-gray-500:focus {\n    --gradient-from-color: #a0aec0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n  }\n\n  .xl\\:focus\\:from-gray-600:focus {\n    --gradient-from-color: #718096;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n  }\n\n  .xl\\:focus\\:from-gray-700:focus {\n    --gradient-from-color: #4a5568;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n  }\n\n  .xl\\:focus\\:from-gray-800:focus {\n    --gradient-from-color: #2d3748;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n  }\n\n  .xl\\:focus\\:from-gray-900:focus {\n    --gradient-from-color: #1a202c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n  }\n\n  .xl\\:focus\\:from-red-100:focus {\n    --gradient-from-color: #fff5f5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n  }\n\n  .xl\\:focus\\:from-red-200:focus {\n    --gradient-from-color: #fed7d7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n  }\n\n  .xl\\:focus\\:from-red-300:focus {\n    --gradient-from-color: #feb2b2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n  }\n\n  .xl\\:focus\\:from-red-400:focus {\n    --gradient-from-color: #fc8181;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n  }\n\n  .xl\\:focus\\:from-red-500:focus {\n    --gradient-from-color: #f56565;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n  }\n\n  .xl\\:focus\\:from-red-600:focus {\n    --gradient-from-color: #e53e3e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n  }\n\n  .xl\\:focus\\:from-red-700:focus {\n    --gradient-from-color: #c53030;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n  }\n\n  .xl\\:focus\\:from-red-800:focus {\n    --gradient-from-color: #9b2c2c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n  }\n\n  .xl\\:focus\\:from-red-900:focus {\n    --gradient-from-color: #742a2a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n  }\n\n  .xl\\:focus\\:from-orange-100:focus {\n    --gradient-from-color: #fffaf0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n  }\n\n  .xl\\:focus\\:from-orange-200:focus {\n    --gradient-from-color: #feebc8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n  }\n\n  .xl\\:focus\\:from-orange-300:focus {\n    --gradient-from-color: #fbd38d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n  }\n\n  .xl\\:focus\\:from-orange-400:focus {\n    --gradient-from-color: #f6ad55;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n  }\n\n  .xl\\:focus\\:from-orange-500:focus {\n    --gradient-from-color: #ed8936;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n  }\n\n  .xl\\:focus\\:from-orange-600:focus {\n    --gradient-from-color: #dd6b20;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n  }\n\n  .xl\\:focus\\:from-orange-700:focus {\n    --gradient-from-color: #c05621;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n  }\n\n  .xl\\:focus\\:from-orange-800:focus {\n    --gradient-from-color: #9c4221;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n  }\n\n  .xl\\:focus\\:from-orange-900:focus {\n    --gradient-from-color: #7b341e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n  }\n\n  .xl\\:focus\\:from-yellow-100:focus {\n    --gradient-from-color: #fffff0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n  }\n\n  .xl\\:focus\\:from-yellow-200:focus {\n    --gradient-from-color: #fefcbf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n  }\n\n  .xl\\:focus\\:from-yellow-300:focus {\n    --gradient-from-color: #faf089;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n  }\n\n  .xl\\:focus\\:from-yellow-400:focus {\n    --gradient-from-color: #f6e05e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n  }\n\n  .xl\\:focus\\:from-yellow-500:focus {\n    --gradient-from-color: #ecc94b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n  }\n\n  .xl\\:focus\\:from-yellow-600:focus {\n    --gradient-from-color: #d69e2e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n  }\n\n  .xl\\:focus\\:from-yellow-700:focus {\n    --gradient-from-color: #b7791f;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n  }\n\n  .xl\\:focus\\:from-yellow-800:focus {\n    --gradient-from-color: #975a16;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n  }\n\n  .xl\\:focus\\:from-yellow-900:focus {\n    --gradient-from-color: #744210;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n  }\n\n  .xl\\:focus\\:from-green-100:focus {\n    --gradient-from-color: #f0fff4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n  }\n\n  .xl\\:focus\\:from-green-200:focus {\n    --gradient-from-color: #c6f6d5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n  }\n\n  .xl\\:focus\\:from-green-300:focus {\n    --gradient-from-color: #9ae6b4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n  }\n\n  .xl\\:focus\\:from-green-400:focus {\n    --gradient-from-color: #68d391;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n  }\n\n  .xl\\:focus\\:from-green-500:focus {\n    --gradient-from-color: #48bb78;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n  }\n\n  .xl\\:focus\\:from-green-600:focus {\n    --gradient-from-color: #38a169;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n  }\n\n  .xl\\:focus\\:from-green-700:focus {\n    --gradient-from-color: #2f855a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n  }\n\n  .xl\\:focus\\:from-green-800:focus {\n    --gradient-from-color: #276749;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n  }\n\n  .xl\\:focus\\:from-green-900:focus {\n    --gradient-from-color: #22543d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n  }\n\n  .xl\\:focus\\:from-teal-100:focus {\n    --gradient-from-color: #e6fffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n  }\n\n  .xl\\:focus\\:from-teal-200:focus {\n    --gradient-from-color: #b2f5ea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n  }\n\n  .xl\\:focus\\:from-teal-300:focus {\n    --gradient-from-color: #81e6d9;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n  }\n\n  .xl\\:focus\\:from-teal-400:focus {\n    --gradient-from-color: #4fd1c5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n  }\n\n  .xl\\:focus\\:from-teal-500:focus {\n    --gradient-from-color: #38b2ac;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n  }\n\n  .xl\\:focus\\:from-teal-600:focus {\n    --gradient-from-color: #319795;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n  }\n\n  .xl\\:focus\\:from-teal-700:focus {\n    --gradient-from-color: #2c7a7b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n  }\n\n  .xl\\:focus\\:from-teal-800:focus {\n    --gradient-from-color: #285e61;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n  }\n\n  .xl\\:focus\\:from-teal-900:focus {\n    --gradient-from-color: #234e52;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n  }\n\n  .xl\\:focus\\:from-blue-100:focus {\n    --gradient-from-color: #ebf8ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n  }\n\n  .xl\\:focus\\:from-blue-200:focus {\n    --gradient-from-color: #bee3f8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n  }\n\n  .xl\\:focus\\:from-blue-300:focus {\n    --gradient-from-color: #90cdf4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n  }\n\n  .xl\\:focus\\:from-blue-400:focus {\n    --gradient-from-color: #63b3ed;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n  }\n\n  .xl\\:focus\\:from-blue-500:focus {\n    --gradient-from-color: #4299e1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n  }\n\n  .xl\\:focus\\:from-blue-600:focus {\n    --gradient-from-color: #3182ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n  }\n\n  .xl\\:focus\\:from-blue-700:focus {\n    --gradient-from-color: #2b6cb0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n  }\n\n  .xl\\:focus\\:from-blue-800:focus {\n    --gradient-from-color: #2c5282;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n  }\n\n  .xl\\:focus\\:from-blue-900:focus {\n    --gradient-from-color: #2a4365;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n  }\n\n  .xl\\:focus\\:from-indigo-100:focus {\n    --gradient-from-color: #ebf4ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n  }\n\n  .xl\\:focus\\:from-indigo-200:focus {\n    --gradient-from-color: #c3dafe;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n  }\n\n  .xl\\:focus\\:from-indigo-300:focus {\n    --gradient-from-color: #a3bffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n  }\n\n  .xl\\:focus\\:from-indigo-400:focus {\n    --gradient-from-color: #7f9cf5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n  }\n\n  .xl\\:focus\\:from-indigo-500:focus {\n    --gradient-from-color: #667eea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n  }\n\n  .xl\\:focus\\:from-indigo-600:focus {\n    --gradient-from-color: #5a67d8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n  }\n\n  .xl\\:focus\\:from-indigo-700:focus {\n    --gradient-from-color: #4c51bf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n  }\n\n  .xl\\:focus\\:from-indigo-800:focus {\n    --gradient-from-color: #434190;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n  }\n\n  .xl\\:focus\\:from-indigo-900:focus {\n    --gradient-from-color: #3c366b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n  }\n\n  .xl\\:focus\\:from-purple-100:focus {\n    --gradient-from-color: #faf5ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n  }\n\n  .xl\\:focus\\:from-purple-200:focus {\n    --gradient-from-color: #e9d8fd;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n  }\n\n  .xl\\:focus\\:from-purple-300:focus {\n    --gradient-from-color: #d6bcfa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n  }\n\n  .xl\\:focus\\:from-purple-400:focus {\n    --gradient-from-color: #b794f4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n  }\n\n  .xl\\:focus\\:from-purple-500:focus {\n    --gradient-from-color: #9f7aea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n  }\n\n  .xl\\:focus\\:from-purple-600:focus {\n    --gradient-from-color: #805ad5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n  }\n\n  .xl\\:focus\\:from-purple-700:focus {\n    --gradient-from-color: #6b46c1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n  }\n\n  .xl\\:focus\\:from-purple-800:focus {\n    --gradient-from-color: #553c9a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n  }\n\n  .xl\\:focus\\:from-purple-900:focus {\n    --gradient-from-color: #44337a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n  }\n\n  .xl\\:focus\\:from-pink-100:focus {\n    --gradient-from-color: #fff5f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n  }\n\n  .xl\\:focus\\:from-pink-200:focus {\n    --gradient-from-color: #fed7e2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n  }\n\n  .xl\\:focus\\:from-pink-300:focus {\n    --gradient-from-color: #fbb6ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n  }\n\n  .xl\\:focus\\:from-pink-400:focus {\n    --gradient-from-color: #f687b3;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n  }\n\n  .xl\\:focus\\:from-pink-500:focus {\n    --gradient-from-color: #ed64a6;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n  }\n\n  .xl\\:focus\\:from-pink-600:focus {\n    --gradient-from-color: #d53f8c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n  }\n\n  .xl\\:focus\\:from-pink-700:focus {\n    --gradient-from-color: #b83280;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n  }\n\n  .xl\\:focus\\:from-pink-800:focus {\n    --gradient-from-color: #97266d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n  }\n\n  .xl\\:focus\\:from-pink-900:focus {\n    --gradient-from-color: #702459;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n  }\n\n  .xl\\:focus\\:from-grayscale-80:focus {\n    --gradient-from-color: hsl(0, 0%, 8%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n  }\n\n  .xl\\:focus\\:from-grayscale-100:focus {\n    --gradient-from-color: hsl(0, 0%, 10%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n  }\n\n  .xl\\:focus\\:from-grayscale-200:focus {\n    --gradient-from-color: hsl(0, 0%, 20%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n  }\n\n  .xl\\:focus\\:from-grayscale-300:focus {\n    --gradient-from-color: hsl(0, 0%, 30%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n  }\n\n  .xl\\:focus\\:from-grayscale-400:focus {\n    --gradient-from-color: hsl(0, 0%, 40%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n  }\n\n  .xl\\:focus\\:from-grayscale-500:focus {\n    --gradient-from-color: hsl(0, 0%, 50%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n  }\n\n  .xl\\:focus\\:from-grayscale-600:focus {\n    --gradient-from-color: hsl(0, 0%, 60%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n  }\n\n  .xl\\:focus\\:from-grayscale-700:focus {\n    --gradient-from-color: hsl(0, 0%, 70%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n  }\n\n  .xl\\:focus\\:from-grayscale-800:focus {\n    --gradient-from-color: hsl(0, 0%, 80%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n  }\n\n  .xl\\:focus\\:from-grayscale-840:focus {\n    --gradient-from-color: hsl(0, 0%, 84%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n  }\n\n  .xl\\:focus\\:from-grayscale-870:focus {\n    --gradient-from-color: hsl(0, 0%, 87%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n  }\n\n  .xl\\:focus\\:from-grayscale-900:focus {\n    --gradient-from-color: hsl(0, 0%, 90%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n  }\n\n  .xl\\:focus\\:from-grayscale-930:focus {\n    --gradient-from-color: hsl(0, 0%, 93%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n  }\n\n  .xl\\:focus\\:from-primary:focus {\n    --gradient-from-color: hsl(210, 100%, 52%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n  }\n\n  .xl\\:focus\\:from-background-main:focus {\n    --gradient-from-color: var(--main-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:focus\\:from-background-secondary:focus {\n    --gradient-from-color: var(--secondary-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:focus\\:from-foreground:focus {\n    --gradient-from-color: var(--foreground);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:focus\\:from-panels-bg:focus {\n    --gradient-from-color: var(--panels-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:focus\\:via-transparent:focus {\n    --gradient-via-color: transparent;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .xl\\:focus\\:via-current:focus {\n    --gradient-via-color: currentColor;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:focus\\:via-black:focus {\n    --gradient-via-color: #000;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(0, 0, 0, 0));\n  }\n\n  .xl\\:focus\\:via-white:focus {\n    --gradient-via-color: #fff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:focus\\:via-gray-100:focus {\n    --gradient-via-color: #f7fafc;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(247, 250, 252, 0));\n  }\n\n  .xl\\:focus\\:via-gray-200:focus {\n    --gradient-via-color: #edf2f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 242, 247, 0));\n  }\n\n  .xl\\:focus\\:via-gray-300:focus {\n    --gradient-via-color: #e2e8f0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(226, 232, 240, 0));\n  }\n\n  .xl\\:focus\\:via-gray-400:focus {\n    --gradient-via-color: #cbd5e0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(203, 213, 224, 0));\n  }\n\n  .xl\\:focus\\:via-gray-500:focus {\n    --gradient-via-color: #a0aec0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(160, 174, 192, 0));\n  }\n\n  .xl\\:focus\\:via-gray-600:focus {\n    --gradient-via-color: #718096;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(113, 128, 150, 0));\n  }\n\n  .xl\\:focus\\:via-gray-700:focus {\n    --gradient-via-color: #4a5568;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(74, 85, 104, 0));\n  }\n\n  .xl\\:focus\\:via-gray-800:focus {\n    --gradient-via-color: #2d3748;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(45, 55, 72, 0));\n  }\n\n  .xl\\:focus\\:via-gray-900:focus {\n    --gradient-via-color: #1a202c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(26, 32, 44, 0));\n  }\n\n  .xl\\:focus\\:via-red-100:focus {\n    --gradient-via-color: #fff5f5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 245, 0));\n  }\n\n  .xl\\:focus\\:via-red-200:focus {\n    --gradient-via-color: #fed7d7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 215, 0));\n  }\n\n  .xl\\:focus\\:via-red-300:focus {\n    --gradient-via-color: #feb2b2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 178, 178, 0));\n  }\n\n  .xl\\:focus\\:via-red-400:focus {\n    --gradient-via-color: #fc8181;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(252, 129, 129, 0));\n  }\n\n  .xl\\:focus\\:via-red-500:focus {\n    --gradient-via-color: #f56565;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(245, 101, 101, 0));\n  }\n\n  .xl\\:focus\\:via-red-600:focus {\n    --gradient-via-color: #e53e3e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229, 62, 62, 0));\n  }\n\n  .xl\\:focus\\:via-red-700:focus {\n    --gradient-via-color: #c53030;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(197, 48, 48, 0));\n  }\n\n  .xl\\:focus\\:via-red-800:focus {\n    --gradient-via-color: #9b2c2c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(155, 44, 44, 0));\n  }\n\n  .xl\\:focus\\:via-red-900:focus {\n    --gradient-via-color: #742a2a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 42, 42, 0));\n  }\n\n  .xl\\:focus\\:via-orange-100:focus {\n    --gradient-via-color: #fffaf0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 250, 240, 0));\n  }\n\n  .xl\\:focus\\:via-orange-200:focus {\n    --gradient-via-color: #feebc8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 235, 200, 0));\n  }\n\n  .xl\\:focus\\:via-orange-300:focus {\n    --gradient-via-color: #fbd38d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 211, 141, 0));\n  }\n\n  .xl\\:focus\\:via-orange-400:focus {\n    --gradient-via-color: #f6ad55;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 173, 85, 0));\n  }\n\n  .xl\\:focus\\:via-orange-500:focus {\n    --gradient-via-color: #ed8936;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 137, 54, 0));\n  }\n\n  .xl\\:focus\\:via-orange-600:focus {\n    --gradient-via-color: #dd6b20;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221, 107, 32, 0));\n  }\n\n  .xl\\:focus\\:via-orange-700:focus {\n    --gradient-via-color: #c05621;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(192, 86, 33, 0));\n  }\n\n  .xl\\:focus\\:via-orange-800:focus {\n    --gradient-via-color: #9c4221;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(156, 66, 33, 0));\n  }\n\n  .xl\\:focus\\:via-orange-900:focus {\n    --gradient-via-color: #7b341e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(123, 52, 30, 0));\n  }\n\n  .xl\\:focus\\:via-yellow-100:focus {\n    --gradient-via-color: #fffff0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 240, 0));\n  }\n\n  .xl\\:focus\\:via-yellow-200:focus {\n    --gradient-via-color: #fefcbf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 252, 191, 0));\n  }\n\n  .xl\\:focus\\:via-yellow-300:focus {\n    --gradient-via-color: #faf089;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 240, 137, 0));\n  }\n\n  .xl\\:focus\\:via-yellow-400:focus {\n    --gradient-via-color: #f6e05e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 224, 94, 0));\n  }\n\n  .xl\\:focus\\:via-yellow-500:focus {\n    --gradient-via-color: #ecc94b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(236, 201, 75, 0));\n  }\n\n  .xl\\:focus\\:via-yellow-600:focus {\n    --gradient-via-color: #d69e2e;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 158, 46, 0));\n  }\n\n  .xl\\:focus\\:via-yellow-700:focus {\n    --gradient-via-color: #b7791f;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 121, 31, 0));\n  }\n\n  .xl\\:focus\\:via-yellow-800:focus {\n    --gradient-via-color: #975a16;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 90, 22, 0));\n  }\n\n  .xl\\:focus\\:via-yellow-900:focus {\n    --gradient-via-color: #744210;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(116, 66, 16, 0));\n  }\n\n  .xl\\:focus\\:via-green-100:focus {\n    --gradient-via-color: #f0fff4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(240, 255, 244, 0));\n  }\n\n  .xl\\:focus\\:via-green-200:focus {\n    --gradient-via-color: #c6f6d5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(198, 246, 213, 0));\n  }\n\n  .xl\\:focus\\:via-green-300:focus {\n    --gradient-via-color: #9ae6b4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(154, 230, 180, 0));\n  }\n\n  .xl\\:focus\\:via-green-400:focus {\n    --gradient-via-color: #68d391;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(104, 211, 145, 0));\n  }\n\n  .xl\\:focus\\:via-green-500:focus {\n    --gradient-via-color: #48bb78;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(72, 187, 120, 0));\n  }\n\n  .xl\\:focus\\:via-green-600:focus {\n    --gradient-via-color: #38a169;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 161, 105, 0));\n  }\n\n  .xl\\:focus\\:via-green-700:focus {\n    --gradient-via-color: #2f855a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(47, 133, 90, 0));\n  }\n\n  .xl\\:focus\\:via-green-800:focus {\n    --gradient-via-color: #276749;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(39, 103, 73, 0));\n  }\n\n  .xl\\:focus\\:via-green-900:focus {\n    --gradient-via-color: #22543d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(34, 84, 61, 0));\n  }\n\n  .xl\\:focus\\:via-teal-100:focus {\n    --gradient-via-color: #e6fffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(230, 255, 250, 0));\n  }\n\n  .xl\\:focus\\:via-teal-200:focus {\n    --gradient-via-color: #b2f5ea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178, 245, 234, 0));\n  }\n\n  .xl\\:focus\\:via-teal-300:focus {\n    --gradient-via-color: #81e6d9;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(129, 230, 217, 0));\n  }\n\n  .xl\\:focus\\:via-teal-400:focus {\n    --gradient-via-color: #4fd1c5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(79, 209, 197, 0));\n  }\n\n  .xl\\:focus\\:via-teal-500:focus {\n    --gradient-via-color: #38b2ac;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(56, 178, 172, 0));\n  }\n\n  .xl\\:focus\\:via-teal-600:focus {\n    --gradient-via-color: #319795;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 151, 149, 0));\n  }\n\n  .xl\\:focus\\:via-teal-700:focus {\n    --gradient-via-color: #2c7a7b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 122, 123, 0));\n  }\n\n  .xl\\:focus\\:via-teal-800:focus {\n    --gradient-via-color: #285e61;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(40, 94, 97, 0));\n  }\n\n  .xl\\:focus\\:via-teal-900:focus {\n    --gradient-via-color: #234e52;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(35, 78, 82, 0));\n  }\n\n  .xl\\:focus\\:via-blue-100:focus {\n    --gradient-via-color: #ebf8ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 248, 255, 0));\n  }\n\n  .xl\\:focus\\:via-blue-200:focus {\n    --gradient-via-color: #bee3f8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(190, 227, 248, 0));\n  }\n\n  .xl\\:focus\\:via-blue-300:focus {\n    --gradient-via-color: #90cdf4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(144, 205, 244, 0));\n  }\n\n  .xl\\:focus\\:via-blue-400:focus {\n    --gradient-via-color: #63b3ed;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(99, 179, 237, 0));\n  }\n\n  .xl\\:focus\\:via-blue-500:focus {\n    --gradient-via-color: #4299e1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(66, 153, 225, 0));\n  }\n\n  .xl\\:focus\\:via-blue-600:focus {\n    --gradient-via-color: #3182ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(49, 130, 206, 0));\n  }\n\n  .xl\\:focus\\:via-blue-700:focus {\n    --gradient-via-color: #2b6cb0;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(43, 108, 176, 0));\n  }\n\n  .xl\\:focus\\:via-blue-800:focus {\n    --gradient-via-color: #2c5282;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(44, 82, 130, 0));\n  }\n\n  .xl\\:focus\\:via-blue-900:focus {\n    --gradient-via-color: #2a4365;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(42, 67, 101, 0));\n  }\n\n  .xl\\:focus\\:via-indigo-100:focus {\n    --gradient-via-color: #ebf4ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(235, 244, 255, 0));\n  }\n\n  .xl\\:focus\\:via-indigo-200:focus {\n    --gradient-via-color: #c3dafe;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(195, 218, 254, 0));\n  }\n\n  .xl\\:focus\\:via-indigo-300:focus {\n    --gradient-via-color: #a3bffa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(163, 191, 250, 0));\n  }\n\n  .xl\\:focus\\:via-indigo-400:focus {\n    --gradient-via-color: #7f9cf5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127, 156, 245, 0));\n  }\n\n  .xl\\:focus\\:via-indigo-500:focus {\n    --gradient-via-color: #667eea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 126, 234, 0));\n  }\n\n  .xl\\:focus\\:via-indigo-600:focus {\n    --gradient-via-color: #5a67d8;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(90, 103, 216, 0));\n  }\n\n  .xl\\:focus\\:via-indigo-700:focus {\n    --gradient-via-color: #4c51bf;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76, 81, 191, 0));\n  }\n\n  .xl\\:focus\\:via-indigo-800:focus {\n    --gradient-via-color: #434190;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(67, 65, 144, 0));\n  }\n\n  .xl\\:focus\\:via-indigo-900:focus {\n    --gradient-via-color: #3c366b;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(60, 54, 107, 0));\n  }\n\n  .xl\\:focus\\:via-purple-100:focus {\n    --gradient-via-color: #faf5ff;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(250, 245, 255, 0));\n  }\n\n  .xl\\:focus\\:via-purple-200:focus {\n    --gradient-via-color: #e9d8fd;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(233, 216, 253, 0));\n  }\n\n  .xl\\:focus\\:via-purple-300:focus {\n    --gradient-via-color: #d6bcfa;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214, 188, 250, 0));\n  }\n\n  .xl\\:focus\\:via-purple-400:focus {\n    --gradient-via-color: #b794f4;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(183, 148, 244, 0));\n  }\n\n  .xl\\:focus\\:via-purple-500:focus {\n    --gradient-via-color: #9f7aea;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(159, 122, 234, 0));\n  }\n\n  .xl\\:focus\\:via-purple-600:focus {\n    --gradient-via-color: #805ad5;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(128, 90, 213, 0));\n  }\n\n  .xl\\:focus\\:via-purple-700:focus {\n    --gradient-via-color: #6b46c1;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(107, 70, 193, 0));\n  }\n\n  .xl\\:focus\\:via-purple-800:focus {\n    --gradient-via-color: #553c9a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(85, 60, 154, 0));\n  }\n\n  .xl\\:focus\\:via-purple-900:focus {\n    --gradient-via-color: #44337a;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(68, 51, 122, 0));\n  }\n\n  .xl\\:focus\\:via-pink-100:focus {\n    --gradient-via-color: #fff5f7;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 245, 247, 0));\n  }\n\n  .xl\\:focus\\:via-pink-200:focus {\n    --gradient-via-color: #fed7e2;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(254, 215, 226, 0));\n  }\n\n  .xl\\:focus\\:via-pink-300:focus {\n    --gradient-via-color: #fbb6ce;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(251, 182, 206, 0));\n  }\n\n  .xl\\:focus\\:via-pink-400:focus {\n    --gradient-via-color: #f687b3;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(246, 135, 179, 0));\n  }\n\n  .xl\\:focus\\:via-pink-500:focus {\n    --gradient-via-color: #ed64a6;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237, 100, 166, 0));\n  }\n\n  .xl\\:focus\\:via-pink-600:focus {\n    --gradient-via-color: #d53f8c;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(213, 63, 140, 0));\n  }\n\n  .xl\\:focus\\:via-pink-700:focus {\n    --gradient-via-color: #b83280;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(184, 50, 128, 0));\n  }\n\n  .xl\\:focus\\:via-pink-800:focus {\n    --gradient-via-color: #97266d;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(151, 38, 109, 0));\n  }\n\n  .xl\\:focus\\:via-pink-900:focus {\n    --gradient-via-color: #702459;\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(112, 36, 89, 0));\n  }\n\n  .xl\\:focus\\:via-grayscale-80:focus {\n    --gradient-via-color: hsl(0, 0%, 8%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, 0));\n  }\n\n  .xl\\:focus\\:via-grayscale-100:focus {\n    --gradient-via-color: hsl(0, 0%, 10%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(25.5, 25.5, 25.5, 0));\n  }\n\n  .xl\\:focus\\:via-grayscale-200:focus {\n    --gradient-via-color: hsl(0, 0%, 20%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(51, 51, 51, 0));\n  }\n\n  .xl\\:focus\\:via-grayscale-300:focus {\n    --gradient-via-color: hsl(0, 0%, 30%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(76.5, 76.5, 76.5, 0));\n  }\n\n  .xl\\:focus\\:via-grayscale-400:focus {\n    --gradient-via-color: hsl(0, 0%, 40%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(102, 102, 102, 0));\n  }\n\n  .xl\\:focus\\:via-grayscale-500:focus {\n    --gradient-via-color: hsl(0, 0%, 50%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(127.5, 127.5, 127.5, 0));\n  }\n\n  .xl\\:focus\\:via-grayscale-600:focus {\n    --gradient-via-color: hsl(0, 0%, 60%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(153, 153, 153, 0));\n  }\n\n  .xl\\:focus\\:via-grayscale-700:focus {\n    --gradient-via-color: hsl(0, 0%, 70%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(178.5, 178.5, 178.5, 0));\n  }\n\n  .xl\\:focus\\:via-grayscale-800:focus {\n    --gradient-via-color: hsl(0, 0%, 80%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(204, 204, 204, 0));\n  }\n\n  .xl\\:focus\\:via-grayscale-840:focus {\n    --gradient-via-color: hsl(0, 0%, 84%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(214.2, 214.2, 214.2, 0));\n  }\n\n  .xl\\:focus\\:via-grayscale-870:focus {\n    --gradient-via-color: hsl(0, 0%, 87%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(221.85, 221.85, 221.85, 0));\n  }\n\n  .xl\\:focus\\:via-grayscale-900:focus {\n    --gradient-via-color: hsl(0, 0%, 90%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(229.5, 229.5, 229.5, 0));\n  }\n\n  .xl\\:focus\\:via-grayscale-930:focus {\n    --gradient-via-color: hsl(0, 0%, 93%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(237.15, 237.15, 237.15, 0));\n  }\n\n  .xl\\:focus\\:via-primary:focus {\n    --gradient-via-color: hsl(210, 100%, 52%);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(10.20000000000001, 132.59999999999988, 255, 0));\n  }\n\n  .xl\\:focus\\:via-background-main:focus {\n    --gradient-via-color: var(--main-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:focus\\:via-background-secondary:focus {\n    --gradient-via-color: var(--secondary-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:focus\\:via-foreground:focus {\n    --gradient-via-color: var(--foreground);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:focus\\:via-panels-bg:focus {\n    --gradient-via-color: var(--panels-background);\n    --gradient-color-stops: var(--gradient-from-color), var(--gradient-via-color), var(--gradient-to-color, rgba(255, 255, 255, 0));\n  }\n\n  .xl\\:focus\\:to-transparent:focus {\n    --gradient-to-color: transparent;\n  }\n\n  .xl\\:focus\\:to-current:focus {\n    --gradient-to-color: currentColor;\n  }\n\n  .xl\\:focus\\:to-black:focus {\n    --gradient-to-color: #000;\n  }\n\n  .xl\\:focus\\:to-white:focus {\n    --gradient-to-color: #fff;\n  }\n\n  .xl\\:focus\\:to-gray-100:focus {\n    --gradient-to-color: #f7fafc;\n  }\n\n  .xl\\:focus\\:to-gray-200:focus {\n    --gradient-to-color: #edf2f7;\n  }\n\n  .xl\\:focus\\:to-gray-300:focus {\n    --gradient-to-color: #e2e8f0;\n  }\n\n  .xl\\:focus\\:to-gray-400:focus {\n    --gradient-to-color: #cbd5e0;\n  }\n\n  .xl\\:focus\\:to-gray-500:focus {\n    --gradient-to-color: #a0aec0;\n  }\n\n  .xl\\:focus\\:to-gray-600:focus {\n    --gradient-to-color: #718096;\n  }\n\n  .xl\\:focus\\:to-gray-700:focus {\n    --gradient-to-color: #4a5568;\n  }\n\n  .xl\\:focus\\:to-gray-800:focus {\n    --gradient-to-color: #2d3748;\n  }\n\n  .xl\\:focus\\:to-gray-900:focus {\n    --gradient-to-color: #1a202c;\n  }\n\n  .xl\\:focus\\:to-red-100:focus {\n    --gradient-to-color: #fff5f5;\n  }\n\n  .xl\\:focus\\:to-red-200:focus {\n    --gradient-to-color: #fed7d7;\n  }\n\n  .xl\\:focus\\:to-red-300:focus {\n    --gradient-to-color: #feb2b2;\n  }\n\n  .xl\\:focus\\:to-red-400:focus {\n    --gradient-to-color: #fc8181;\n  }\n\n  .xl\\:focus\\:to-red-500:focus {\n    --gradient-to-color: #f56565;\n  }\n\n  .xl\\:focus\\:to-red-600:focus {\n    --gradient-to-color: #e53e3e;\n  }\n\n  .xl\\:focus\\:to-red-700:focus {\n    --gradient-to-color: #c53030;\n  }\n\n  .xl\\:focus\\:to-red-800:focus {\n    --gradient-to-color: #9b2c2c;\n  }\n\n  .xl\\:focus\\:to-red-900:focus {\n    --gradient-to-color: #742a2a;\n  }\n\n  .xl\\:focus\\:to-orange-100:focus {\n    --gradient-to-color: #fffaf0;\n  }\n\n  .xl\\:focus\\:to-orange-200:focus {\n    --gradient-to-color: #feebc8;\n  }\n\n  .xl\\:focus\\:to-orange-300:focus {\n    --gradient-to-color: #fbd38d;\n  }\n\n  .xl\\:focus\\:to-orange-400:focus {\n    --gradient-to-color: #f6ad55;\n  }\n\n  .xl\\:focus\\:to-orange-500:focus {\n    --gradient-to-color: #ed8936;\n  }\n\n  .xl\\:focus\\:to-orange-600:focus {\n    --gradient-to-color: #dd6b20;\n  }\n\n  .xl\\:focus\\:to-orange-700:focus {\n    --gradient-to-color: #c05621;\n  }\n\n  .xl\\:focus\\:to-orange-800:focus {\n    --gradient-to-color: #9c4221;\n  }\n\n  .xl\\:focus\\:to-orange-900:focus {\n    --gradient-to-color: #7b341e;\n  }\n\n  .xl\\:focus\\:to-yellow-100:focus {\n    --gradient-to-color: #fffff0;\n  }\n\n  .xl\\:focus\\:to-yellow-200:focus {\n    --gradient-to-color: #fefcbf;\n  }\n\n  .xl\\:focus\\:to-yellow-300:focus {\n    --gradient-to-color: #faf089;\n  }\n\n  .xl\\:focus\\:to-yellow-400:focus {\n    --gradient-to-color: #f6e05e;\n  }\n\n  .xl\\:focus\\:to-yellow-500:focus {\n    --gradient-to-color: #ecc94b;\n  }\n\n  .xl\\:focus\\:to-yellow-600:focus {\n    --gradient-to-color: #d69e2e;\n  }\n\n  .xl\\:focus\\:to-yellow-700:focus {\n    --gradient-to-color: #b7791f;\n  }\n\n  .xl\\:focus\\:to-yellow-800:focus {\n    --gradient-to-color: #975a16;\n  }\n\n  .xl\\:focus\\:to-yellow-900:focus {\n    --gradient-to-color: #744210;\n  }\n\n  .xl\\:focus\\:to-green-100:focus {\n    --gradient-to-color: #f0fff4;\n  }\n\n  .xl\\:focus\\:to-green-200:focus {\n    --gradient-to-color: #c6f6d5;\n  }\n\n  .xl\\:focus\\:to-green-300:focus {\n    --gradient-to-color: #9ae6b4;\n  }\n\n  .xl\\:focus\\:to-green-400:focus {\n    --gradient-to-color: #68d391;\n  }\n\n  .xl\\:focus\\:to-green-500:focus {\n    --gradient-to-color: #48bb78;\n  }\n\n  .xl\\:focus\\:to-green-600:focus {\n    --gradient-to-color: #38a169;\n  }\n\n  .xl\\:focus\\:to-green-700:focus {\n    --gradient-to-color: #2f855a;\n  }\n\n  .xl\\:focus\\:to-green-800:focus {\n    --gradient-to-color: #276749;\n  }\n\n  .xl\\:focus\\:to-green-900:focus {\n    --gradient-to-color: #22543d;\n  }\n\n  .xl\\:focus\\:to-teal-100:focus {\n    --gradient-to-color: #e6fffa;\n  }\n\n  .xl\\:focus\\:to-teal-200:focus {\n    --gradient-to-color: #b2f5ea;\n  }\n\n  .xl\\:focus\\:to-teal-300:focus {\n    --gradient-to-color: #81e6d9;\n  }\n\n  .xl\\:focus\\:to-teal-400:focus {\n    --gradient-to-color: #4fd1c5;\n  }\n\n  .xl\\:focus\\:to-teal-500:focus {\n    --gradient-to-color: #38b2ac;\n  }\n\n  .xl\\:focus\\:to-teal-600:focus {\n    --gradient-to-color: #319795;\n  }\n\n  .xl\\:focus\\:to-teal-700:focus {\n    --gradient-to-color: #2c7a7b;\n  }\n\n  .xl\\:focus\\:to-teal-800:focus {\n    --gradient-to-color: #285e61;\n  }\n\n  .xl\\:focus\\:to-teal-900:focus {\n    --gradient-to-color: #234e52;\n  }\n\n  .xl\\:focus\\:to-blue-100:focus {\n    --gradient-to-color: #ebf8ff;\n  }\n\n  .xl\\:focus\\:to-blue-200:focus {\n    --gradient-to-color: #bee3f8;\n  }\n\n  .xl\\:focus\\:to-blue-300:focus {\n    --gradient-to-color: #90cdf4;\n  }\n\n  .xl\\:focus\\:to-blue-400:focus {\n    --gradient-to-color: #63b3ed;\n  }\n\n  .xl\\:focus\\:to-blue-500:focus {\n    --gradient-to-color: #4299e1;\n  }\n\n  .xl\\:focus\\:to-blue-600:focus {\n    --gradient-to-color: #3182ce;\n  }\n\n  .xl\\:focus\\:to-blue-700:focus {\n    --gradient-to-color: #2b6cb0;\n  }\n\n  .xl\\:focus\\:to-blue-800:focus {\n    --gradient-to-color: #2c5282;\n  }\n\n  .xl\\:focus\\:to-blue-900:focus {\n    --gradient-to-color: #2a4365;\n  }\n\n  .xl\\:focus\\:to-indigo-100:focus {\n    --gradient-to-color: #ebf4ff;\n  }\n\n  .xl\\:focus\\:to-indigo-200:focus {\n    --gradient-to-color: #c3dafe;\n  }\n\n  .xl\\:focus\\:to-indigo-300:focus {\n    --gradient-to-color: #a3bffa;\n  }\n\n  .xl\\:focus\\:to-indigo-400:focus {\n    --gradient-to-color: #7f9cf5;\n  }\n\n  .xl\\:focus\\:to-indigo-500:focus {\n    --gradient-to-color: #667eea;\n  }\n\n  .xl\\:focus\\:to-indigo-600:focus {\n    --gradient-to-color: #5a67d8;\n  }\n\n  .xl\\:focus\\:to-indigo-700:focus {\n    --gradient-to-color: #4c51bf;\n  }\n\n  .xl\\:focus\\:to-indigo-800:focus {\n    --gradient-to-color: #434190;\n  }\n\n  .xl\\:focus\\:to-indigo-900:focus {\n    --gradient-to-color: #3c366b;\n  }\n\n  .xl\\:focus\\:to-purple-100:focus {\n    --gradient-to-color: #faf5ff;\n  }\n\n  .xl\\:focus\\:to-purple-200:focus {\n    --gradient-to-color: #e9d8fd;\n  }\n\n  .xl\\:focus\\:to-purple-300:focus {\n    --gradient-to-color: #d6bcfa;\n  }\n\n  .xl\\:focus\\:to-purple-400:focus {\n    --gradient-to-color: #b794f4;\n  }\n\n  .xl\\:focus\\:to-purple-500:focus {\n    --gradient-to-color: #9f7aea;\n  }\n\n  .xl\\:focus\\:to-purple-600:focus {\n    --gradient-to-color: #805ad5;\n  }\n\n  .xl\\:focus\\:to-purple-700:focus {\n    --gradient-to-color: #6b46c1;\n  }\n\n  .xl\\:focus\\:to-purple-800:focus {\n    --gradient-to-color: #553c9a;\n  }\n\n  .xl\\:focus\\:to-purple-900:focus {\n    --gradient-to-color: #44337a;\n  }\n\n  .xl\\:focus\\:to-pink-100:focus {\n    --gradient-to-color: #fff5f7;\n  }\n\n  .xl\\:focus\\:to-pink-200:focus {\n    --gradient-to-color: #fed7e2;\n  }\n\n  .xl\\:focus\\:to-pink-300:focus {\n    --gradient-to-color: #fbb6ce;\n  }\n\n  .xl\\:focus\\:to-pink-400:focus {\n    --gradient-to-color: #f687b3;\n  }\n\n  .xl\\:focus\\:to-pink-500:focus {\n    --gradient-to-color: #ed64a6;\n  }\n\n  .xl\\:focus\\:to-pink-600:focus {\n    --gradient-to-color: #d53f8c;\n  }\n\n  .xl\\:focus\\:to-pink-700:focus {\n    --gradient-to-color: #b83280;\n  }\n\n  .xl\\:focus\\:to-pink-800:focus {\n    --gradient-to-color: #97266d;\n  }\n\n  .xl\\:focus\\:to-pink-900:focus {\n    --gradient-to-color: #702459;\n  }\n\n  .xl\\:focus\\:to-grayscale-80:focus {\n    --gradient-to-color: hsl(0, 0%, 8%);\n  }\n\n  .xl\\:focus\\:to-grayscale-100:focus {\n    --gradient-to-color: hsl(0, 0%, 10%);\n  }\n\n  .xl\\:focus\\:to-grayscale-200:focus {\n    --gradient-to-color: hsl(0, 0%, 20%);\n  }\n\n  .xl\\:focus\\:to-grayscale-300:focus {\n    --gradient-to-color: hsl(0, 0%, 30%);\n  }\n\n  .xl\\:focus\\:to-grayscale-400:focus {\n    --gradient-to-color: hsl(0, 0%, 40%);\n  }\n\n  .xl\\:focus\\:to-grayscale-500:focus {\n    --gradient-to-color: hsl(0, 0%, 50%);\n  }\n\n  .xl\\:focus\\:to-grayscale-600:focus {\n    --gradient-to-color: hsl(0, 0%, 60%);\n  }\n\n  .xl\\:focus\\:to-grayscale-700:focus {\n    --gradient-to-color: hsl(0, 0%, 70%);\n  }\n\n  .xl\\:focus\\:to-grayscale-800:focus {\n    --gradient-to-color: hsl(0, 0%, 80%);\n  }\n\n  .xl\\:focus\\:to-grayscale-840:focus {\n    --gradient-to-color: hsl(0, 0%, 84%);\n  }\n\n  .xl\\:focus\\:to-grayscale-870:focus {\n    --gradient-to-color: hsl(0, 0%, 87%);\n  }\n\n  .xl\\:focus\\:to-grayscale-900:focus {\n    --gradient-to-color: hsl(0, 0%, 90%);\n  }\n\n  .xl\\:focus\\:to-grayscale-930:focus {\n    --gradient-to-color: hsl(0, 0%, 93%);\n  }\n\n  .xl\\:focus\\:to-primary:focus {\n    --gradient-to-color: hsl(210, 100%, 52%);\n  }\n\n  .xl\\:focus\\:to-background-main:focus {\n    --gradient-to-color: var(--main-background);\n  }\n\n  .xl\\:focus\\:to-background-secondary:focus {\n    --gradient-to-color: var(--secondary-background);\n  }\n\n  .xl\\:focus\\:to-foreground:focus {\n    --gradient-to-color: var(--foreground);\n  }\n\n  .xl\\:focus\\:to-panels-bg:focus {\n    --gradient-to-color: var(--panels-background);\n  }\n\n  .xl\\:bg-opacity-0 {\n    --bg-opacity: 0;\n  }\n\n  .xl\\:bg-opacity-25 {\n    --bg-opacity: 0.25;\n  }\n\n  .xl\\:bg-opacity-50 {\n    --bg-opacity: 0.5;\n  }\n\n  .xl\\:bg-opacity-75 {\n    --bg-opacity: 0.75;\n  }\n\n  .xl\\:bg-opacity-100 {\n    --bg-opacity: 1;\n  }\n\n  .xl\\:hover\\:bg-opacity-0:hover {\n    --bg-opacity: 0;\n  }\n\n  .xl\\:hover\\:bg-opacity-25:hover {\n    --bg-opacity: 0.25;\n  }\n\n  .xl\\:hover\\:bg-opacity-50:hover {\n    --bg-opacity: 0.5;\n  }\n\n  .xl\\:hover\\:bg-opacity-75:hover {\n    --bg-opacity: 0.75;\n  }\n\n  .xl\\:hover\\:bg-opacity-100:hover {\n    --bg-opacity: 1;\n  }\n\n  .xl\\:focus\\:bg-opacity-0:focus {\n    --bg-opacity: 0;\n  }\n\n  .xl\\:focus\\:bg-opacity-25:focus {\n    --bg-opacity: 0.25;\n  }\n\n  .xl\\:focus\\:bg-opacity-50:focus {\n    --bg-opacity: 0.5;\n  }\n\n  .xl\\:focus\\:bg-opacity-75:focus {\n    --bg-opacity: 0.75;\n  }\n\n  .xl\\:focus\\:bg-opacity-100:focus {\n    --bg-opacity: 1;\n  }\n\n  .xl\\:bg-bottom {\n    background-position: bottom;\n  }\n\n  .xl\\:bg-center {\n    background-position: center;\n  }\n\n  .xl\\:bg-left {\n    background-position: left;\n  }\n\n  .xl\\:bg-left-bottom {\n    background-position: left bottom;\n  }\n\n  .xl\\:bg-left-top {\n    background-position: left top;\n  }\n\n  .xl\\:bg-right {\n    background-position: right;\n  }\n\n  .xl\\:bg-right-bottom {\n    background-position: right bottom;\n  }\n\n  .xl\\:bg-right-top {\n    background-position: right top;\n  }\n\n  .xl\\:bg-top {\n    background-position: top;\n  }\n\n  .xl\\:bg-repeat {\n    background-repeat: repeat;\n  }\n\n  .xl\\:bg-no-repeat {\n    background-repeat: no-repeat;\n  }\n\n  .xl\\:bg-repeat-x {\n    background-repeat: repeat-x;\n  }\n\n  .xl\\:bg-repeat-y {\n    background-repeat: repeat-y;\n  }\n\n  .xl\\:bg-repeat-round {\n    background-repeat: round;\n  }\n\n  .xl\\:bg-repeat-space {\n    background-repeat: space;\n  }\n\n  .xl\\:bg-auto {\n    background-size: auto;\n  }\n\n  .xl\\:bg-cover {\n    background-size: cover;\n  }\n\n  .xl\\:bg-contain {\n    background-size: contain;\n  }\n\n  .xl\\:border-collapse {\n    border-collapse: collapse;\n  }\n\n  .xl\\:border-separate {\n    border-collapse: separate;\n  }\n\n  .xl\\:border-transparent {\n    border-color: transparent;\n  }\n\n  .xl\\:border-current {\n    border-color: currentColor;\n  }\n\n  .xl\\:border-black {\n    --border-opacity: 1;\n    border-color: #000;\n    border-color: rgba(0, 0, 0, var(--border-opacity));\n  }\n\n  .xl\\:border-white {\n    --border-opacity: 1;\n    border-color: #fff;\n    border-color: rgba(255, 255, 255, var(--border-opacity));\n  }\n\n  .xl\\:border-gray-100 {\n    --border-opacity: 1;\n    border-color: #f7fafc;\n    border-color: rgba(247, 250, 252, var(--border-opacity));\n  }\n\n  .xl\\:border-gray-200 {\n    --border-opacity: 1;\n    border-color: #edf2f7;\n    border-color: rgba(237, 242, 247, var(--border-opacity));\n  }\n\n  .xl\\:border-gray-300 {\n    --border-opacity: 1;\n    border-color: #e2e8f0;\n    border-color: rgba(226, 232, 240, var(--border-opacity));\n  }\n\n  .xl\\:border-gray-400 {\n    --border-opacity: 1;\n    border-color: #cbd5e0;\n    border-color: rgba(203, 213, 224, var(--border-opacity));\n  }\n\n  .xl\\:border-gray-500 {\n    --border-opacity: 1;\n    border-color: #a0aec0;\n    border-color: rgba(160, 174, 192, var(--border-opacity));\n  }\n\n  .xl\\:border-gray-600 {\n    --border-opacity: 1;\n    border-color: #718096;\n    border-color: rgba(113, 128, 150, var(--border-opacity));\n  }\n\n  .xl\\:border-gray-700 {\n    --border-opacity: 1;\n    border-color: #4a5568;\n    border-color: rgba(74, 85, 104, var(--border-opacity));\n  }\n\n  .xl\\:border-gray-800 {\n    --border-opacity: 1;\n    border-color: #2d3748;\n    border-color: rgba(45, 55, 72, var(--border-opacity));\n  }\n\n  .xl\\:border-gray-900 {\n    --border-opacity: 1;\n    border-color: #1a202c;\n    border-color: rgba(26, 32, 44, var(--border-opacity));\n  }\n\n  .xl\\:border-red-100 {\n    --border-opacity: 1;\n    border-color: #fff5f5;\n    border-color: rgba(255, 245, 245, var(--border-opacity));\n  }\n\n  .xl\\:border-red-200 {\n    --border-opacity: 1;\n    border-color: #fed7d7;\n    border-color: rgba(254, 215, 215, var(--border-opacity));\n  }\n\n  .xl\\:border-red-300 {\n    --border-opacity: 1;\n    border-color: #feb2b2;\n    border-color: rgba(254, 178, 178, var(--border-opacity));\n  }\n\n  .xl\\:border-red-400 {\n    --border-opacity: 1;\n    border-color: #fc8181;\n    border-color: rgba(252, 129, 129, var(--border-opacity));\n  }\n\n  .xl\\:border-red-500 {\n    --border-opacity: 1;\n    border-color: #f56565;\n    border-color: rgba(245, 101, 101, var(--border-opacity));\n  }\n\n  .xl\\:border-red-600 {\n    --border-opacity: 1;\n    border-color: #e53e3e;\n    border-color: rgba(229, 62, 62, var(--border-opacity));\n  }\n\n  .xl\\:border-red-700 {\n    --border-opacity: 1;\n    border-color: #c53030;\n    border-color: rgba(197, 48, 48, var(--border-opacity));\n  }\n\n  .xl\\:border-red-800 {\n    --border-opacity: 1;\n    border-color: #9b2c2c;\n    border-color: rgba(155, 44, 44, var(--border-opacity));\n  }\n\n  .xl\\:border-red-900 {\n    --border-opacity: 1;\n    border-color: #742a2a;\n    border-color: rgba(116, 42, 42, var(--border-opacity));\n  }\n\n  .xl\\:border-orange-100 {\n    --border-opacity: 1;\n    border-color: #fffaf0;\n    border-color: rgba(255, 250, 240, var(--border-opacity));\n  }\n\n  .xl\\:border-orange-200 {\n    --border-opacity: 1;\n    border-color: #feebc8;\n    border-color: rgba(254, 235, 200, var(--border-opacity));\n  }\n\n  .xl\\:border-orange-300 {\n    --border-opacity: 1;\n    border-color: #fbd38d;\n    border-color: rgba(251, 211, 141, var(--border-opacity));\n  }\n\n  .xl\\:border-orange-400 {\n    --border-opacity: 1;\n    border-color: #f6ad55;\n    border-color: rgba(246, 173, 85, var(--border-opacity));\n  }\n\n  .xl\\:border-orange-500 {\n    --border-opacity: 1;\n    border-color: #ed8936;\n    border-color: rgba(237, 137, 54, var(--border-opacity));\n  }\n\n  .xl\\:border-orange-600 {\n    --border-opacity: 1;\n    border-color: #dd6b20;\n    border-color: rgba(221, 107, 32, var(--border-opacity));\n  }\n\n  .xl\\:border-orange-700 {\n    --border-opacity: 1;\n    border-color: #c05621;\n    border-color: rgba(192, 86, 33, var(--border-opacity));\n  }\n\n  .xl\\:border-orange-800 {\n    --border-opacity: 1;\n    border-color: #9c4221;\n    border-color: rgba(156, 66, 33, var(--border-opacity));\n  }\n\n  .xl\\:border-orange-900 {\n    --border-opacity: 1;\n    border-color: #7b341e;\n    border-color: rgba(123, 52, 30, var(--border-opacity));\n  }\n\n  .xl\\:border-yellow-100 {\n    --border-opacity: 1;\n    border-color: #fffff0;\n    border-color: rgba(255, 255, 240, var(--border-opacity));\n  }\n\n  .xl\\:border-yellow-200 {\n    --border-opacity: 1;\n    border-color: #fefcbf;\n    border-color: rgba(254, 252, 191, var(--border-opacity));\n  }\n\n  .xl\\:border-yellow-300 {\n    --border-opacity: 1;\n    border-color: #faf089;\n    border-color: rgba(250, 240, 137, var(--border-opacity));\n  }\n\n  .xl\\:border-yellow-400 {\n    --border-opacity: 1;\n    border-color: #f6e05e;\n    border-color: rgba(246, 224, 94, var(--border-opacity));\n  }\n\n  .xl\\:border-yellow-500 {\n    --border-opacity: 1;\n    border-color: #ecc94b;\n    border-color: rgba(236, 201, 75, var(--border-opacity));\n  }\n\n  .xl\\:border-yellow-600 {\n    --border-opacity: 1;\n    border-color: #d69e2e;\n    border-color: rgba(214, 158, 46, var(--border-opacity));\n  }\n\n  .xl\\:border-yellow-700 {\n    --border-opacity: 1;\n    border-color: #b7791f;\n    border-color: rgba(183, 121, 31, var(--border-opacity));\n  }\n\n  .xl\\:border-yellow-800 {\n    --border-opacity: 1;\n    border-color: #975a16;\n    border-color: rgba(151, 90, 22, var(--border-opacity));\n  }\n\n  .xl\\:border-yellow-900 {\n    --border-opacity: 1;\n    border-color: #744210;\n    border-color: rgba(116, 66, 16, var(--border-opacity));\n  }\n\n  .xl\\:border-green-100 {\n    --border-opacity: 1;\n    border-color: #f0fff4;\n    border-color: rgba(240, 255, 244, var(--border-opacity));\n  }\n\n  .xl\\:border-green-200 {\n    --border-opacity: 1;\n    border-color: #c6f6d5;\n    border-color: rgba(198, 246, 213, var(--border-opacity));\n  }\n\n  .xl\\:border-green-300 {\n    --border-opacity: 1;\n    border-color: #9ae6b4;\n    border-color: rgba(154, 230, 180, var(--border-opacity));\n  }\n\n  .xl\\:border-green-400 {\n    --border-opacity: 1;\n    border-color: #68d391;\n    border-color: rgba(104, 211, 145, var(--border-opacity));\n  }\n\n  .xl\\:border-green-500 {\n    --border-opacity: 1;\n    border-color: #48bb78;\n    border-color: rgba(72, 187, 120, var(--border-opacity));\n  }\n\n  .xl\\:border-green-600 {\n    --border-opacity: 1;\n    border-color: #38a169;\n    border-color: rgba(56, 161, 105, var(--border-opacity));\n  }\n\n  .xl\\:border-green-700 {\n    --border-opacity: 1;\n    border-color: #2f855a;\n    border-color: rgba(47, 133, 90, var(--border-opacity));\n  }\n\n  .xl\\:border-green-800 {\n    --border-opacity: 1;\n    border-color: #276749;\n    border-color: rgba(39, 103, 73, var(--border-opacity));\n  }\n\n  .xl\\:border-green-900 {\n    --border-opacity: 1;\n    border-color: #22543d;\n    border-color: rgba(34, 84, 61, var(--border-opacity));\n  }\n\n  .xl\\:border-teal-100 {\n    --border-opacity: 1;\n    border-color: #e6fffa;\n    border-color: rgba(230, 255, 250, var(--border-opacity));\n  }\n\n  .xl\\:border-teal-200 {\n    --border-opacity: 1;\n    border-color: #b2f5ea;\n    border-color: rgba(178, 245, 234, var(--border-opacity));\n  }\n\n  .xl\\:border-teal-300 {\n    --border-opacity: 1;\n    border-color: #81e6d9;\n    border-color: rgba(129, 230, 217, var(--border-opacity));\n  }\n\n  .xl\\:border-teal-400 {\n    --border-opacity: 1;\n    border-color: #4fd1c5;\n    border-color: rgba(79, 209, 197, var(--border-opacity));\n  }\n\n  .xl\\:border-teal-500 {\n    --border-opacity: 1;\n    border-color: #38b2ac;\n    border-color: rgba(56, 178, 172, var(--border-opacity));\n  }\n\n  .xl\\:border-teal-600 {\n    --border-opacity: 1;\n    border-color: #319795;\n    border-color: rgba(49, 151, 149, var(--border-opacity));\n  }\n\n  .xl\\:border-teal-700 {\n    --border-opacity: 1;\n    border-color: #2c7a7b;\n    border-color: rgba(44, 122, 123, var(--border-opacity));\n  }\n\n  .xl\\:border-teal-800 {\n    --border-opacity: 1;\n    border-color: #285e61;\n    border-color: rgba(40, 94, 97, var(--border-opacity));\n  }\n\n  .xl\\:border-teal-900 {\n    --border-opacity: 1;\n    border-color: #234e52;\n    border-color: rgba(35, 78, 82, var(--border-opacity));\n  }\n\n  .xl\\:border-blue-100 {\n    --border-opacity: 1;\n    border-color: #ebf8ff;\n    border-color: rgba(235, 248, 255, var(--border-opacity));\n  }\n\n  .xl\\:border-blue-200 {\n    --border-opacity: 1;\n    border-color: #bee3f8;\n    border-color: rgba(190, 227, 248, var(--border-opacity));\n  }\n\n  .xl\\:border-blue-300 {\n    --border-opacity: 1;\n    border-color: #90cdf4;\n    border-color: rgba(144, 205, 244, var(--border-opacity));\n  }\n\n  .xl\\:border-blue-400 {\n    --border-opacity: 1;\n    border-color: #63b3ed;\n    border-color: rgba(99, 179, 237, var(--border-opacity));\n  }\n\n  .xl\\:border-blue-500 {\n    --border-opacity: 1;\n    border-color: #4299e1;\n    border-color: rgba(66, 153, 225, var(--border-opacity));\n  }\n\n  .xl\\:border-blue-600 {\n    --border-opacity: 1;\n    border-color: #3182ce;\n    border-color: rgba(49, 130, 206, var(--border-opacity));\n  }\n\n  .xl\\:border-blue-700 {\n    --border-opacity: 1;\n    border-color: #2b6cb0;\n    border-color: rgba(43, 108, 176, var(--border-opacity));\n  }\n\n  .xl\\:border-blue-800 {\n    --border-opacity: 1;\n    border-color: #2c5282;\n    border-color: rgba(44, 82, 130, var(--border-opacity));\n  }\n\n  .xl\\:border-blue-900 {\n    --border-opacity: 1;\n    border-color: #2a4365;\n    border-color: rgba(42, 67, 101, var(--border-opacity));\n  }\n\n  .xl\\:border-indigo-100 {\n    --border-opacity: 1;\n    border-color: #ebf4ff;\n    border-color: rgba(235, 244, 255, var(--border-opacity));\n  }\n\n  .xl\\:border-indigo-200 {\n    --border-opacity: 1;\n    border-color: #c3dafe;\n    border-color: rgba(195, 218, 254, var(--border-opacity));\n  }\n\n  .xl\\:border-indigo-300 {\n    --border-opacity: 1;\n    border-color: #a3bffa;\n    border-color: rgba(163, 191, 250, var(--border-opacity));\n  }\n\n  .xl\\:border-indigo-400 {\n    --border-opacity: 1;\n    border-color: #7f9cf5;\n    border-color: rgba(127, 156, 245, var(--border-opacity));\n  }\n\n  .xl\\:border-indigo-500 {\n    --border-opacity: 1;\n    border-color: #667eea;\n    border-color: rgba(102, 126, 234, var(--border-opacity));\n  }\n\n  .xl\\:border-indigo-600 {\n    --border-opacity: 1;\n    border-color: #5a67d8;\n    border-color: rgba(90, 103, 216, var(--border-opacity));\n  }\n\n  .xl\\:border-indigo-700 {\n    --border-opacity: 1;\n    border-color: #4c51bf;\n    border-color: rgba(76, 81, 191, var(--border-opacity));\n  }\n\n  .xl\\:border-indigo-800 {\n    --border-opacity: 1;\n    border-color: #434190;\n    border-color: rgba(67, 65, 144, var(--border-opacity));\n  }\n\n  .xl\\:border-indigo-900 {\n    --border-opacity: 1;\n    border-color: #3c366b;\n    border-color: rgba(60, 54, 107, var(--border-opacity));\n  }\n\n  .xl\\:border-purple-100 {\n    --border-opacity: 1;\n    border-color: #faf5ff;\n    border-color: rgba(250, 245, 255, var(--border-opacity));\n  }\n\n  .xl\\:border-purple-200 {\n    --border-opacity: 1;\n    border-color: #e9d8fd;\n    border-color: rgba(233, 216, 253, var(--border-opacity));\n  }\n\n  .xl\\:border-purple-300 {\n    --border-opacity: 1;\n    border-color: #d6bcfa;\n    border-color: rgba(214, 188, 250, var(--border-opacity));\n  }\n\n  .xl\\:border-purple-400 {\n    --border-opacity: 1;\n    border-color: #b794f4;\n    border-color: rgba(183, 148, 244, var(--border-opacity));\n  }\n\n  .xl\\:border-purple-500 {\n    --border-opacity: 1;\n    border-color: #9f7aea;\n    border-color: rgba(159, 122, 234, var(--border-opacity));\n  }\n\n  .xl\\:border-purple-600 {\n    --border-opacity: 1;\n    border-color: #805ad5;\n    border-color: rgba(128, 90, 213, var(--border-opacity));\n  }\n\n  .xl\\:border-purple-700 {\n    --border-opacity: 1;\n    border-color: #6b46c1;\n    border-color: rgba(107, 70, 193, var(--border-opacity));\n  }\n\n  .xl\\:border-purple-800 {\n    --border-opacity: 1;\n    border-color: #553c9a;\n    border-color: rgba(85, 60, 154, var(--border-opacity));\n  }\n\n  .xl\\:border-purple-900 {\n    --border-opacity: 1;\n    border-color: #44337a;\n    border-color: rgba(68, 51, 122, var(--border-opacity));\n  }\n\n  .xl\\:border-pink-100 {\n    --border-opacity: 1;\n    border-color: #fff5f7;\n    border-color: rgba(255, 245, 247, var(--border-opacity));\n  }\n\n  .xl\\:border-pink-200 {\n    --border-opacity: 1;\n    border-color: #fed7e2;\n    border-color: rgba(254, 215, 226, var(--border-opacity));\n  }\n\n  .xl\\:border-pink-300 {\n    --border-opacity: 1;\n    border-color: #fbb6ce;\n    border-color: rgba(251, 182, 206, var(--border-opacity));\n  }\n\n  .xl\\:border-pink-400 {\n    --border-opacity: 1;\n    border-color: #f687b3;\n    border-color: rgba(246, 135, 179, var(--border-opacity));\n  }\n\n  .xl\\:border-pink-500 {\n    --border-opacity: 1;\n    border-color: #ed64a6;\n    border-color: rgba(237, 100, 166, var(--border-opacity));\n  }\n\n  .xl\\:border-pink-600 {\n    --border-opacity: 1;\n    border-color: #d53f8c;\n    border-color: rgba(213, 63, 140, var(--border-opacity));\n  }\n\n  .xl\\:border-pink-700 {\n    --border-opacity: 1;\n    border-color: #b83280;\n    border-color: rgba(184, 50, 128, var(--border-opacity));\n  }\n\n  .xl\\:border-pink-800 {\n    --border-opacity: 1;\n    border-color: #97266d;\n    border-color: rgba(151, 38, 109, var(--border-opacity));\n  }\n\n  .xl\\:border-pink-900 {\n    --border-opacity: 1;\n    border-color: #702459;\n    border-color: rgba(112, 36, 89, var(--border-opacity));\n  }\n\n  .xl\\:border-grayscale-80 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 8%);\n    border-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--border-opacity));\n  }\n\n  .xl\\:border-grayscale-100 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 10%);\n    border-color: rgba(25.5, 25.5, 25.5, var(--border-opacity));\n  }\n\n  .xl\\:border-grayscale-200 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 20%);\n    border-color: rgba(51, 51, 51, var(--border-opacity));\n  }\n\n  .xl\\:border-grayscale-300 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 30%);\n    border-color: rgba(76.5, 76.5, 76.5, var(--border-opacity));\n  }\n\n  .xl\\:border-grayscale-400 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 40%);\n    border-color: rgba(102, 102, 102, var(--border-opacity));\n  }\n\n  .xl\\:border-grayscale-500 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 50%);\n    border-color: rgba(127.5, 127.5, 127.5, var(--border-opacity));\n  }\n\n  .xl\\:border-grayscale-600 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 60%);\n    border-color: rgba(153, 153, 153, var(--border-opacity));\n  }\n\n  .xl\\:border-grayscale-700 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 70%);\n    border-color: rgba(178.5, 178.5, 178.5, var(--border-opacity));\n  }\n\n  .xl\\:border-grayscale-800 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 80%);\n    border-color: rgba(204, 204, 204, var(--border-opacity));\n  }\n\n  .xl\\:border-grayscale-840 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 84%);\n    border-color: rgba(214.2, 214.2, 214.2, var(--border-opacity));\n  }\n\n  .xl\\:border-grayscale-870 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 87%);\n    border-color: rgba(221.85, 221.85, 221.85, var(--border-opacity));\n  }\n\n  .xl\\:border-grayscale-900 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 90%);\n    border-color: rgba(229.5, 229.5, 229.5, var(--border-opacity));\n  }\n\n  .xl\\:border-grayscale-930 {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 93%);\n    border-color: rgba(237.15, 237.15, 237.15, var(--border-opacity));\n  }\n\n  .xl\\:border-primary {\n    --border-opacity: 1;\n    border-color: hsl(210, 100%, 52%);\n    border-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--border-opacity));\n  }\n\n  .xl\\:border-background-main {\n    border-color: var(--main-background);\n  }\n\n  .xl\\:border-background-secondary {\n    border-color: var(--secondary-background);\n  }\n\n  .xl\\:border-foreground {\n    border-color: var(--foreground);\n  }\n\n  .xl\\:border-panels-bg {\n    border-color: var(--panels-background);\n  }\n\n  .xl\\:hover\\:border-transparent:hover {\n    border-color: transparent;\n  }\n\n  .xl\\:hover\\:border-current:hover {\n    border-color: currentColor;\n  }\n\n  .xl\\:hover\\:border-black:hover {\n    --border-opacity: 1;\n    border-color: #000;\n    border-color: rgba(0, 0, 0, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-white:hover {\n    --border-opacity: 1;\n    border-color: #fff;\n    border-color: rgba(255, 255, 255, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-gray-100:hover {\n    --border-opacity: 1;\n    border-color: #f7fafc;\n    border-color: rgba(247, 250, 252, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-gray-200:hover {\n    --border-opacity: 1;\n    border-color: #edf2f7;\n    border-color: rgba(237, 242, 247, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-gray-300:hover {\n    --border-opacity: 1;\n    border-color: #e2e8f0;\n    border-color: rgba(226, 232, 240, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-gray-400:hover {\n    --border-opacity: 1;\n    border-color: #cbd5e0;\n    border-color: rgba(203, 213, 224, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-gray-500:hover {\n    --border-opacity: 1;\n    border-color: #a0aec0;\n    border-color: rgba(160, 174, 192, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-gray-600:hover {\n    --border-opacity: 1;\n    border-color: #718096;\n    border-color: rgba(113, 128, 150, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-gray-700:hover {\n    --border-opacity: 1;\n    border-color: #4a5568;\n    border-color: rgba(74, 85, 104, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-gray-800:hover {\n    --border-opacity: 1;\n    border-color: #2d3748;\n    border-color: rgba(45, 55, 72, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-gray-900:hover {\n    --border-opacity: 1;\n    border-color: #1a202c;\n    border-color: rgba(26, 32, 44, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-red-100:hover {\n    --border-opacity: 1;\n    border-color: #fff5f5;\n    border-color: rgba(255, 245, 245, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-red-200:hover {\n    --border-opacity: 1;\n    border-color: #fed7d7;\n    border-color: rgba(254, 215, 215, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-red-300:hover {\n    --border-opacity: 1;\n    border-color: #feb2b2;\n    border-color: rgba(254, 178, 178, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-red-400:hover {\n    --border-opacity: 1;\n    border-color: #fc8181;\n    border-color: rgba(252, 129, 129, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-red-500:hover {\n    --border-opacity: 1;\n    border-color: #f56565;\n    border-color: rgba(245, 101, 101, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-red-600:hover {\n    --border-opacity: 1;\n    border-color: #e53e3e;\n    border-color: rgba(229, 62, 62, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-red-700:hover {\n    --border-opacity: 1;\n    border-color: #c53030;\n    border-color: rgba(197, 48, 48, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-red-800:hover {\n    --border-opacity: 1;\n    border-color: #9b2c2c;\n    border-color: rgba(155, 44, 44, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-red-900:hover {\n    --border-opacity: 1;\n    border-color: #742a2a;\n    border-color: rgba(116, 42, 42, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-orange-100:hover {\n    --border-opacity: 1;\n    border-color: #fffaf0;\n    border-color: rgba(255, 250, 240, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-orange-200:hover {\n    --border-opacity: 1;\n    border-color: #feebc8;\n    border-color: rgba(254, 235, 200, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-orange-300:hover {\n    --border-opacity: 1;\n    border-color: #fbd38d;\n    border-color: rgba(251, 211, 141, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-orange-400:hover {\n    --border-opacity: 1;\n    border-color: #f6ad55;\n    border-color: rgba(246, 173, 85, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-orange-500:hover {\n    --border-opacity: 1;\n    border-color: #ed8936;\n    border-color: rgba(237, 137, 54, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-orange-600:hover {\n    --border-opacity: 1;\n    border-color: #dd6b20;\n    border-color: rgba(221, 107, 32, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-orange-700:hover {\n    --border-opacity: 1;\n    border-color: #c05621;\n    border-color: rgba(192, 86, 33, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-orange-800:hover {\n    --border-opacity: 1;\n    border-color: #9c4221;\n    border-color: rgba(156, 66, 33, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-orange-900:hover {\n    --border-opacity: 1;\n    border-color: #7b341e;\n    border-color: rgba(123, 52, 30, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-yellow-100:hover {\n    --border-opacity: 1;\n    border-color: #fffff0;\n    border-color: rgba(255, 255, 240, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-yellow-200:hover {\n    --border-opacity: 1;\n    border-color: #fefcbf;\n    border-color: rgba(254, 252, 191, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-yellow-300:hover {\n    --border-opacity: 1;\n    border-color: #faf089;\n    border-color: rgba(250, 240, 137, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-yellow-400:hover {\n    --border-opacity: 1;\n    border-color: #f6e05e;\n    border-color: rgba(246, 224, 94, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-yellow-500:hover {\n    --border-opacity: 1;\n    border-color: #ecc94b;\n    border-color: rgba(236, 201, 75, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-yellow-600:hover {\n    --border-opacity: 1;\n    border-color: #d69e2e;\n    border-color: rgba(214, 158, 46, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-yellow-700:hover {\n    --border-opacity: 1;\n    border-color: #b7791f;\n    border-color: rgba(183, 121, 31, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-yellow-800:hover {\n    --border-opacity: 1;\n    border-color: #975a16;\n    border-color: rgba(151, 90, 22, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-yellow-900:hover {\n    --border-opacity: 1;\n    border-color: #744210;\n    border-color: rgba(116, 66, 16, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-green-100:hover {\n    --border-opacity: 1;\n    border-color: #f0fff4;\n    border-color: rgba(240, 255, 244, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-green-200:hover {\n    --border-opacity: 1;\n    border-color: #c6f6d5;\n    border-color: rgba(198, 246, 213, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-green-300:hover {\n    --border-opacity: 1;\n    border-color: #9ae6b4;\n    border-color: rgba(154, 230, 180, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-green-400:hover {\n    --border-opacity: 1;\n    border-color: #68d391;\n    border-color: rgba(104, 211, 145, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-green-500:hover {\n    --border-opacity: 1;\n    border-color: #48bb78;\n    border-color: rgba(72, 187, 120, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-green-600:hover {\n    --border-opacity: 1;\n    border-color: #38a169;\n    border-color: rgba(56, 161, 105, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-green-700:hover {\n    --border-opacity: 1;\n    border-color: #2f855a;\n    border-color: rgba(47, 133, 90, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-green-800:hover {\n    --border-opacity: 1;\n    border-color: #276749;\n    border-color: rgba(39, 103, 73, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-green-900:hover {\n    --border-opacity: 1;\n    border-color: #22543d;\n    border-color: rgba(34, 84, 61, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-teal-100:hover {\n    --border-opacity: 1;\n    border-color: #e6fffa;\n    border-color: rgba(230, 255, 250, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-teal-200:hover {\n    --border-opacity: 1;\n    border-color: #b2f5ea;\n    border-color: rgba(178, 245, 234, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-teal-300:hover {\n    --border-opacity: 1;\n    border-color: #81e6d9;\n    border-color: rgba(129, 230, 217, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-teal-400:hover {\n    --border-opacity: 1;\n    border-color: #4fd1c5;\n    border-color: rgba(79, 209, 197, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-teal-500:hover {\n    --border-opacity: 1;\n    border-color: #38b2ac;\n    border-color: rgba(56, 178, 172, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-teal-600:hover {\n    --border-opacity: 1;\n    border-color: #319795;\n    border-color: rgba(49, 151, 149, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-teal-700:hover {\n    --border-opacity: 1;\n    border-color: #2c7a7b;\n    border-color: rgba(44, 122, 123, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-teal-800:hover {\n    --border-opacity: 1;\n    border-color: #285e61;\n    border-color: rgba(40, 94, 97, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-teal-900:hover {\n    --border-opacity: 1;\n    border-color: #234e52;\n    border-color: rgba(35, 78, 82, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-blue-100:hover {\n    --border-opacity: 1;\n    border-color: #ebf8ff;\n    border-color: rgba(235, 248, 255, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-blue-200:hover {\n    --border-opacity: 1;\n    border-color: #bee3f8;\n    border-color: rgba(190, 227, 248, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-blue-300:hover {\n    --border-opacity: 1;\n    border-color: #90cdf4;\n    border-color: rgba(144, 205, 244, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-blue-400:hover {\n    --border-opacity: 1;\n    border-color: #63b3ed;\n    border-color: rgba(99, 179, 237, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-blue-500:hover {\n    --border-opacity: 1;\n    border-color: #4299e1;\n    border-color: rgba(66, 153, 225, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-blue-600:hover {\n    --border-opacity: 1;\n    border-color: #3182ce;\n    border-color: rgba(49, 130, 206, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-blue-700:hover {\n    --border-opacity: 1;\n    border-color: #2b6cb0;\n    border-color: rgba(43, 108, 176, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-blue-800:hover {\n    --border-opacity: 1;\n    border-color: #2c5282;\n    border-color: rgba(44, 82, 130, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-blue-900:hover {\n    --border-opacity: 1;\n    border-color: #2a4365;\n    border-color: rgba(42, 67, 101, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-indigo-100:hover {\n    --border-opacity: 1;\n    border-color: #ebf4ff;\n    border-color: rgba(235, 244, 255, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-indigo-200:hover {\n    --border-opacity: 1;\n    border-color: #c3dafe;\n    border-color: rgba(195, 218, 254, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-indigo-300:hover {\n    --border-opacity: 1;\n    border-color: #a3bffa;\n    border-color: rgba(163, 191, 250, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-indigo-400:hover {\n    --border-opacity: 1;\n    border-color: #7f9cf5;\n    border-color: rgba(127, 156, 245, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-indigo-500:hover {\n    --border-opacity: 1;\n    border-color: #667eea;\n    border-color: rgba(102, 126, 234, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-indigo-600:hover {\n    --border-opacity: 1;\n    border-color: #5a67d8;\n    border-color: rgba(90, 103, 216, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-indigo-700:hover {\n    --border-opacity: 1;\n    border-color: #4c51bf;\n    border-color: rgba(76, 81, 191, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-indigo-800:hover {\n    --border-opacity: 1;\n    border-color: #434190;\n    border-color: rgba(67, 65, 144, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-indigo-900:hover {\n    --border-opacity: 1;\n    border-color: #3c366b;\n    border-color: rgba(60, 54, 107, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-purple-100:hover {\n    --border-opacity: 1;\n    border-color: #faf5ff;\n    border-color: rgba(250, 245, 255, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-purple-200:hover {\n    --border-opacity: 1;\n    border-color: #e9d8fd;\n    border-color: rgba(233, 216, 253, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-purple-300:hover {\n    --border-opacity: 1;\n    border-color: #d6bcfa;\n    border-color: rgba(214, 188, 250, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-purple-400:hover {\n    --border-opacity: 1;\n    border-color: #b794f4;\n    border-color: rgba(183, 148, 244, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-purple-500:hover {\n    --border-opacity: 1;\n    border-color: #9f7aea;\n    border-color: rgba(159, 122, 234, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-purple-600:hover {\n    --border-opacity: 1;\n    border-color: #805ad5;\n    border-color: rgba(128, 90, 213, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-purple-700:hover {\n    --border-opacity: 1;\n    border-color: #6b46c1;\n    border-color: rgba(107, 70, 193, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-purple-800:hover {\n    --border-opacity: 1;\n    border-color: #553c9a;\n    border-color: rgba(85, 60, 154, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-purple-900:hover {\n    --border-opacity: 1;\n    border-color: #44337a;\n    border-color: rgba(68, 51, 122, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-pink-100:hover {\n    --border-opacity: 1;\n    border-color: #fff5f7;\n    border-color: rgba(255, 245, 247, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-pink-200:hover {\n    --border-opacity: 1;\n    border-color: #fed7e2;\n    border-color: rgba(254, 215, 226, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-pink-300:hover {\n    --border-opacity: 1;\n    border-color: #fbb6ce;\n    border-color: rgba(251, 182, 206, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-pink-400:hover {\n    --border-opacity: 1;\n    border-color: #f687b3;\n    border-color: rgba(246, 135, 179, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-pink-500:hover {\n    --border-opacity: 1;\n    border-color: #ed64a6;\n    border-color: rgba(237, 100, 166, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-pink-600:hover {\n    --border-opacity: 1;\n    border-color: #d53f8c;\n    border-color: rgba(213, 63, 140, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-pink-700:hover {\n    --border-opacity: 1;\n    border-color: #b83280;\n    border-color: rgba(184, 50, 128, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-pink-800:hover {\n    --border-opacity: 1;\n    border-color: #97266d;\n    border-color: rgba(151, 38, 109, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-pink-900:hover {\n    --border-opacity: 1;\n    border-color: #702459;\n    border-color: rgba(112, 36, 89, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-grayscale-80:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 8%);\n    border-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-grayscale-100:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 10%);\n    border-color: rgba(25.5, 25.5, 25.5, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-grayscale-200:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 20%);\n    border-color: rgba(51, 51, 51, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-grayscale-300:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 30%);\n    border-color: rgba(76.5, 76.5, 76.5, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-grayscale-400:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 40%);\n    border-color: rgba(102, 102, 102, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-grayscale-500:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 50%);\n    border-color: rgba(127.5, 127.5, 127.5, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-grayscale-600:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 60%);\n    border-color: rgba(153, 153, 153, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-grayscale-700:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 70%);\n    border-color: rgba(178.5, 178.5, 178.5, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-grayscale-800:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 80%);\n    border-color: rgba(204, 204, 204, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-grayscale-840:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 84%);\n    border-color: rgba(214.2, 214.2, 214.2, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-grayscale-870:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 87%);\n    border-color: rgba(221.85, 221.85, 221.85, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-grayscale-900:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 90%);\n    border-color: rgba(229.5, 229.5, 229.5, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-grayscale-930:hover {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 93%);\n    border-color: rgba(237.15, 237.15, 237.15, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-primary:hover {\n    --border-opacity: 1;\n    border-color: hsl(210, 100%, 52%);\n    border-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--border-opacity));\n  }\n\n  .xl\\:hover\\:border-background-main:hover {\n    border-color: var(--main-background);\n  }\n\n  .xl\\:hover\\:border-background-secondary:hover {\n    border-color: var(--secondary-background);\n  }\n\n  .xl\\:hover\\:border-foreground:hover {\n    border-color: var(--foreground);\n  }\n\n  .xl\\:hover\\:border-panels-bg:hover {\n    border-color: var(--panels-background);\n  }\n\n  .xl\\:focus\\:border-transparent:focus {\n    border-color: transparent;\n  }\n\n  .xl\\:focus\\:border-current:focus {\n    border-color: currentColor;\n  }\n\n  .xl\\:focus\\:border-black:focus {\n    --border-opacity: 1;\n    border-color: #000;\n    border-color: rgba(0, 0, 0, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-white:focus {\n    --border-opacity: 1;\n    border-color: #fff;\n    border-color: rgba(255, 255, 255, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-gray-100:focus {\n    --border-opacity: 1;\n    border-color: #f7fafc;\n    border-color: rgba(247, 250, 252, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-gray-200:focus {\n    --border-opacity: 1;\n    border-color: #edf2f7;\n    border-color: rgba(237, 242, 247, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-gray-300:focus {\n    --border-opacity: 1;\n    border-color: #e2e8f0;\n    border-color: rgba(226, 232, 240, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-gray-400:focus {\n    --border-opacity: 1;\n    border-color: #cbd5e0;\n    border-color: rgba(203, 213, 224, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-gray-500:focus {\n    --border-opacity: 1;\n    border-color: #a0aec0;\n    border-color: rgba(160, 174, 192, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-gray-600:focus {\n    --border-opacity: 1;\n    border-color: #718096;\n    border-color: rgba(113, 128, 150, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-gray-700:focus {\n    --border-opacity: 1;\n    border-color: #4a5568;\n    border-color: rgba(74, 85, 104, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-gray-800:focus {\n    --border-opacity: 1;\n    border-color: #2d3748;\n    border-color: rgba(45, 55, 72, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-gray-900:focus {\n    --border-opacity: 1;\n    border-color: #1a202c;\n    border-color: rgba(26, 32, 44, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-red-100:focus {\n    --border-opacity: 1;\n    border-color: #fff5f5;\n    border-color: rgba(255, 245, 245, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-red-200:focus {\n    --border-opacity: 1;\n    border-color: #fed7d7;\n    border-color: rgba(254, 215, 215, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-red-300:focus {\n    --border-opacity: 1;\n    border-color: #feb2b2;\n    border-color: rgba(254, 178, 178, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-red-400:focus {\n    --border-opacity: 1;\n    border-color: #fc8181;\n    border-color: rgba(252, 129, 129, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-red-500:focus {\n    --border-opacity: 1;\n    border-color: #f56565;\n    border-color: rgba(245, 101, 101, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-red-600:focus {\n    --border-opacity: 1;\n    border-color: #e53e3e;\n    border-color: rgba(229, 62, 62, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-red-700:focus {\n    --border-opacity: 1;\n    border-color: #c53030;\n    border-color: rgba(197, 48, 48, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-red-800:focus {\n    --border-opacity: 1;\n    border-color: #9b2c2c;\n    border-color: rgba(155, 44, 44, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-red-900:focus {\n    --border-opacity: 1;\n    border-color: #742a2a;\n    border-color: rgba(116, 42, 42, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-orange-100:focus {\n    --border-opacity: 1;\n    border-color: #fffaf0;\n    border-color: rgba(255, 250, 240, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-orange-200:focus {\n    --border-opacity: 1;\n    border-color: #feebc8;\n    border-color: rgba(254, 235, 200, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-orange-300:focus {\n    --border-opacity: 1;\n    border-color: #fbd38d;\n    border-color: rgba(251, 211, 141, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-orange-400:focus {\n    --border-opacity: 1;\n    border-color: #f6ad55;\n    border-color: rgba(246, 173, 85, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-orange-500:focus {\n    --border-opacity: 1;\n    border-color: #ed8936;\n    border-color: rgba(237, 137, 54, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-orange-600:focus {\n    --border-opacity: 1;\n    border-color: #dd6b20;\n    border-color: rgba(221, 107, 32, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-orange-700:focus {\n    --border-opacity: 1;\n    border-color: #c05621;\n    border-color: rgba(192, 86, 33, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-orange-800:focus {\n    --border-opacity: 1;\n    border-color: #9c4221;\n    border-color: rgba(156, 66, 33, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-orange-900:focus {\n    --border-opacity: 1;\n    border-color: #7b341e;\n    border-color: rgba(123, 52, 30, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-yellow-100:focus {\n    --border-opacity: 1;\n    border-color: #fffff0;\n    border-color: rgba(255, 255, 240, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-yellow-200:focus {\n    --border-opacity: 1;\n    border-color: #fefcbf;\n    border-color: rgba(254, 252, 191, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-yellow-300:focus {\n    --border-opacity: 1;\n    border-color: #faf089;\n    border-color: rgba(250, 240, 137, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-yellow-400:focus {\n    --border-opacity: 1;\n    border-color: #f6e05e;\n    border-color: rgba(246, 224, 94, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-yellow-500:focus {\n    --border-opacity: 1;\n    border-color: #ecc94b;\n    border-color: rgba(236, 201, 75, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-yellow-600:focus {\n    --border-opacity: 1;\n    border-color: #d69e2e;\n    border-color: rgba(214, 158, 46, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-yellow-700:focus {\n    --border-opacity: 1;\n    border-color: #b7791f;\n    border-color: rgba(183, 121, 31, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-yellow-800:focus {\n    --border-opacity: 1;\n    border-color: #975a16;\n    border-color: rgba(151, 90, 22, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-yellow-900:focus {\n    --border-opacity: 1;\n    border-color: #744210;\n    border-color: rgba(116, 66, 16, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-green-100:focus {\n    --border-opacity: 1;\n    border-color: #f0fff4;\n    border-color: rgba(240, 255, 244, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-green-200:focus {\n    --border-opacity: 1;\n    border-color: #c6f6d5;\n    border-color: rgba(198, 246, 213, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-green-300:focus {\n    --border-opacity: 1;\n    border-color: #9ae6b4;\n    border-color: rgba(154, 230, 180, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-green-400:focus {\n    --border-opacity: 1;\n    border-color: #68d391;\n    border-color: rgba(104, 211, 145, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-green-500:focus {\n    --border-opacity: 1;\n    border-color: #48bb78;\n    border-color: rgba(72, 187, 120, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-green-600:focus {\n    --border-opacity: 1;\n    border-color: #38a169;\n    border-color: rgba(56, 161, 105, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-green-700:focus {\n    --border-opacity: 1;\n    border-color: #2f855a;\n    border-color: rgba(47, 133, 90, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-green-800:focus {\n    --border-opacity: 1;\n    border-color: #276749;\n    border-color: rgba(39, 103, 73, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-green-900:focus {\n    --border-opacity: 1;\n    border-color: #22543d;\n    border-color: rgba(34, 84, 61, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-teal-100:focus {\n    --border-opacity: 1;\n    border-color: #e6fffa;\n    border-color: rgba(230, 255, 250, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-teal-200:focus {\n    --border-opacity: 1;\n    border-color: #b2f5ea;\n    border-color: rgba(178, 245, 234, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-teal-300:focus {\n    --border-opacity: 1;\n    border-color: #81e6d9;\n    border-color: rgba(129, 230, 217, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-teal-400:focus {\n    --border-opacity: 1;\n    border-color: #4fd1c5;\n    border-color: rgba(79, 209, 197, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-teal-500:focus {\n    --border-opacity: 1;\n    border-color: #38b2ac;\n    border-color: rgba(56, 178, 172, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-teal-600:focus {\n    --border-opacity: 1;\n    border-color: #319795;\n    border-color: rgba(49, 151, 149, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-teal-700:focus {\n    --border-opacity: 1;\n    border-color: #2c7a7b;\n    border-color: rgba(44, 122, 123, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-teal-800:focus {\n    --border-opacity: 1;\n    border-color: #285e61;\n    border-color: rgba(40, 94, 97, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-teal-900:focus {\n    --border-opacity: 1;\n    border-color: #234e52;\n    border-color: rgba(35, 78, 82, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-blue-100:focus {\n    --border-opacity: 1;\n    border-color: #ebf8ff;\n    border-color: rgba(235, 248, 255, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-blue-200:focus {\n    --border-opacity: 1;\n    border-color: #bee3f8;\n    border-color: rgba(190, 227, 248, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-blue-300:focus {\n    --border-opacity: 1;\n    border-color: #90cdf4;\n    border-color: rgba(144, 205, 244, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-blue-400:focus {\n    --border-opacity: 1;\n    border-color: #63b3ed;\n    border-color: rgba(99, 179, 237, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-blue-500:focus {\n    --border-opacity: 1;\n    border-color: #4299e1;\n    border-color: rgba(66, 153, 225, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-blue-600:focus {\n    --border-opacity: 1;\n    border-color: #3182ce;\n    border-color: rgba(49, 130, 206, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-blue-700:focus {\n    --border-opacity: 1;\n    border-color: #2b6cb0;\n    border-color: rgba(43, 108, 176, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-blue-800:focus {\n    --border-opacity: 1;\n    border-color: #2c5282;\n    border-color: rgba(44, 82, 130, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-blue-900:focus {\n    --border-opacity: 1;\n    border-color: #2a4365;\n    border-color: rgba(42, 67, 101, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-indigo-100:focus {\n    --border-opacity: 1;\n    border-color: #ebf4ff;\n    border-color: rgba(235, 244, 255, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-indigo-200:focus {\n    --border-opacity: 1;\n    border-color: #c3dafe;\n    border-color: rgba(195, 218, 254, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-indigo-300:focus {\n    --border-opacity: 1;\n    border-color: #a3bffa;\n    border-color: rgba(163, 191, 250, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-indigo-400:focus {\n    --border-opacity: 1;\n    border-color: #7f9cf5;\n    border-color: rgba(127, 156, 245, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-indigo-500:focus {\n    --border-opacity: 1;\n    border-color: #667eea;\n    border-color: rgba(102, 126, 234, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-indigo-600:focus {\n    --border-opacity: 1;\n    border-color: #5a67d8;\n    border-color: rgba(90, 103, 216, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-indigo-700:focus {\n    --border-opacity: 1;\n    border-color: #4c51bf;\n    border-color: rgba(76, 81, 191, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-indigo-800:focus {\n    --border-opacity: 1;\n    border-color: #434190;\n    border-color: rgba(67, 65, 144, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-indigo-900:focus {\n    --border-opacity: 1;\n    border-color: #3c366b;\n    border-color: rgba(60, 54, 107, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-purple-100:focus {\n    --border-opacity: 1;\n    border-color: #faf5ff;\n    border-color: rgba(250, 245, 255, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-purple-200:focus {\n    --border-opacity: 1;\n    border-color: #e9d8fd;\n    border-color: rgba(233, 216, 253, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-purple-300:focus {\n    --border-opacity: 1;\n    border-color: #d6bcfa;\n    border-color: rgba(214, 188, 250, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-purple-400:focus {\n    --border-opacity: 1;\n    border-color: #b794f4;\n    border-color: rgba(183, 148, 244, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-purple-500:focus {\n    --border-opacity: 1;\n    border-color: #9f7aea;\n    border-color: rgba(159, 122, 234, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-purple-600:focus {\n    --border-opacity: 1;\n    border-color: #805ad5;\n    border-color: rgba(128, 90, 213, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-purple-700:focus {\n    --border-opacity: 1;\n    border-color: #6b46c1;\n    border-color: rgba(107, 70, 193, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-purple-800:focus {\n    --border-opacity: 1;\n    border-color: #553c9a;\n    border-color: rgba(85, 60, 154, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-purple-900:focus {\n    --border-opacity: 1;\n    border-color: #44337a;\n    border-color: rgba(68, 51, 122, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-pink-100:focus {\n    --border-opacity: 1;\n    border-color: #fff5f7;\n    border-color: rgba(255, 245, 247, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-pink-200:focus {\n    --border-opacity: 1;\n    border-color: #fed7e2;\n    border-color: rgba(254, 215, 226, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-pink-300:focus {\n    --border-opacity: 1;\n    border-color: #fbb6ce;\n    border-color: rgba(251, 182, 206, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-pink-400:focus {\n    --border-opacity: 1;\n    border-color: #f687b3;\n    border-color: rgba(246, 135, 179, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-pink-500:focus {\n    --border-opacity: 1;\n    border-color: #ed64a6;\n    border-color: rgba(237, 100, 166, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-pink-600:focus {\n    --border-opacity: 1;\n    border-color: #d53f8c;\n    border-color: rgba(213, 63, 140, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-pink-700:focus {\n    --border-opacity: 1;\n    border-color: #b83280;\n    border-color: rgba(184, 50, 128, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-pink-800:focus {\n    --border-opacity: 1;\n    border-color: #97266d;\n    border-color: rgba(151, 38, 109, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-pink-900:focus {\n    --border-opacity: 1;\n    border-color: #702459;\n    border-color: rgba(112, 36, 89, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-grayscale-80:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 8%);\n    border-color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-grayscale-100:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 10%);\n    border-color: rgba(25.5, 25.5, 25.5, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-grayscale-200:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 20%);\n    border-color: rgba(51, 51, 51, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-grayscale-300:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 30%);\n    border-color: rgba(76.5, 76.5, 76.5, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-grayscale-400:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 40%);\n    border-color: rgba(102, 102, 102, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-grayscale-500:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 50%);\n    border-color: rgba(127.5, 127.5, 127.5, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-grayscale-600:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 60%);\n    border-color: rgba(153, 153, 153, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-grayscale-700:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 70%);\n    border-color: rgba(178.5, 178.5, 178.5, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-grayscale-800:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 80%);\n    border-color: rgba(204, 204, 204, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-grayscale-840:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 84%);\n    border-color: rgba(214.2, 214.2, 214.2, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-grayscale-870:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 87%);\n    border-color: rgba(221.85, 221.85, 221.85, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-grayscale-900:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 90%);\n    border-color: rgba(229.5, 229.5, 229.5, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-grayscale-930:focus {\n    --border-opacity: 1;\n    border-color: hsl(0, 0%, 93%);\n    border-color: rgba(237.15, 237.15, 237.15, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-primary:focus {\n    --border-opacity: 1;\n    border-color: hsl(210, 100%, 52%);\n    border-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--border-opacity));\n  }\n\n  .xl\\:focus\\:border-background-main:focus {\n    border-color: var(--main-background);\n  }\n\n  .xl\\:focus\\:border-background-secondary:focus {\n    border-color: var(--secondary-background);\n  }\n\n  .xl\\:focus\\:border-foreground:focus {\n    border-color: var(--foreground);\n  }\n\n  .xl\\:focus\\:border-panels-bg:focus {\n    border-color: var(--panels-background);\n  }\n\n  .xl\\:border-opacity-0 {\n    --border-opacity: 0;\n  }\n\n  .xl\\:border-opacity-25 {\n    --border-opacity: 0.25;\n  }\n\n  .xl\\:border-opacity-50 {\n    --border-opacity: 0.5;\n  }\n\n  .xl\\:border-opacity-75 {\n    --border-opacity: 0.75;\n  }\n\n  .xl\\:border-opacity-100 {\n    --border-opacity: 1;\n  }\n\n  .xl\\:hover\\:border-opacity-0:hover {\n    --border-opacity: 0;\n  }\n\n  .xl\\:hover\\:border-opacity-25:hover {\n    --border-opacity: 0.25;\n  }\n\n  .xl\\:hover\\:border-opacity-50:hover {\n    --border-opacity: 0.5;\n  }\n\n  .xl\\:hover\\:border-opacity-75:hover {\n    --border-opacity: 0.75;\n  }\n\n  .xl\\:hover\\:border-opacity-100:hover {\n    --border-opacity: 1;\n  }\n\n  .xl\\:focus\\:border-opacity-0:focus {\n    --border-opacity: 0;\n  }\n\n  .xl\\:focus\\:border-opacity-25:focus {\n    --border-opacity: 0.25;\n  }\n\n  .xl\\:focus\\:border-opacity-50:focus {\n    --border-opacity: 0.5;\n  }\n\n  .xl\\:focus\\:border-opacity-75:focus {\n    --border-opacity: 0.75;\n  }\n\n  .xl\\:focus\\:border-opacity-100:focus {\n    --border-opacity: 1;\n  }\n\n  .xl\\:rounded-none {\n    border-radius: 0;\n  }\n\n  .xl\\:rounded-sm {\n    border-radius: 0.125rem;\n  }\n\n  .xl\\:rounded {\n    border-radius: 0.25rem;\n  }\n\n  .xl\\:rounded-md {\n    border-radius: 0.375rem;\n  }\n\n  .xl\\:rounded-lg {\n    border-radius: 0.5rem;\n  }\n\n  .xl\\:rounded-xl {\n    border-radius: 0.75rem;\n  }\n\n  .xl\\:rounded-2xl {\n    border-radius: 1rem;\n  }\n\n  .xl\\:rounded-3xl {\n    border-radius: 1.5rem;\n  }\n\n  .xl\\:rounded-full {\n    border-radius: 9999px;\n  }\n\n  .xl\\:rounded-t-none {\n    border-top-left-radius: 0;\n    border-top-right-radius: 0;\n  }\n\n  .xl\\:rounded-r-none {\n    border-top-right-radius: 0;\n    border-bottom-right-radius: 0;\n  }\n\n  .xl\\:rounded-b-none {\n    border-bottom-right-radius: 0;\n    border-bottom-left-radius: 0;\n  }\n\n  .xl\\:rounded-l-none {\n    border-top-left-radius: 0;\n    border-bottom-left-radius: 0;\n  }\n\n  .xl\\:rounded-t-sm {\n    border-top-left-radius: 0.125rem;\n    border-top-right-radius: 0.125rem;\n  }\n\n  .xl\\:rounded-r-sm {\n    border-top-right-radius: 0.125rem;\n    border-bottom-right-radius: 0.125rem;\n  }\n\n  .xl\\:rounded-b-sm {\n    border-bottom-right-radius: 0.125rem;\n    border-bottom-left-radius: 0.125rem;\n  }\n\n  .xl\\:rounded-l-sm {\n    border-top-left-radius: 0.125rem;\n    border-bottom-left-radius: 0.125rem;\n  }\n\n  .xl\\:rounded-t {\n    border-top-left-radius: 0.25rem;\n    border-top-right-radius: 0.25rem;\n  }\n\n  .xl\\:rounded-r {\n    border-top-right-radius: 0.25rem;\n    border-bottom-right-radius: 0.25rem;\n  }\n\n  .xl\\:rounded-b {\n    border-bottom-right-radius: 0.25rem;\n    border-bottom-left-radius: 0.25rem;\n  }\n\n  .xl\\:rounded-l {\n    border-top-left-radius: 0.25rem;\n    border-bottom-left-radius: 0.25rem;\n  }\n\n  .xl\\:rounded-t-md {\n    border-top-left-radius: 0.375rem;\n    border-top-right-radius: 0.375rem;\n  }\n\n  .xl\\:rounded-r-md {\n    border-top-right-radius: 0.375rem;\n    border-bottom-right-radius: 0.375rem;\n  }\n\n  .xl\\:rounded-b-md {\n    border-bottom-right-radius: 0.375rem;\n    border-bottom-left-radius: 0.375rem;\n  }\n\n  .xl\\:rounded-l-md {\n    border-top-left-radius: 0.375rem;\n    border-bottom-left-radius: 0.375rem;\n  }\n\n  .xl\\:rounded-t-lg {\n    border-top-left-radius: 0.5rem;\n    border-top-right-radius: 0.5rem;\n  }\n\n  .xl\\:rounded-r-lg {\n    border-top-right-radius: 0.5rem;\n    border-bottom-right-radius: 0.5rem;\n  }\n\n  .xl\\:rounded-b-lg {\n    border-bottom-right-radius: 0.5rem;\n    border-bottom-left-radius: 0.5rem;\n  }\n\n  .xl\\:rounded-l-lg {\n    border-top-left-radius: 0.5rem;\n    border-bottom-left-radius: 0.5rem;\n  }\n\n  .xl\\:rounded-t-xl {\n    border-top-left-radius: 0.75rem;\n    border-top-right-radius: 0.75rem;\n  }\n\n  .xl\\:rounded-r-xl {\n    border-top-right-radius: 0.75rem;\n    border-bottom-right-radius: 0.75rem;\n  }\n\n  .xl\\:rounded-b-xl {\n    border-bottom-right-radius: 0.75rem;\n    border-bottom-left-radius: 0.75rem;\n  }\n\n  .xl\\:rounded-l-xl {\n    border-top-left-radius: 0.75rem;\n    border-bottom-left-radius: 0.75rem;\n  }\n\n  .xl\\:rounded-t-2xl {\n    border-top-left-radius: 1rem;\n    border-top-right-radius: 1rem;\n  }\n\n  .xl\\:rounded-r-2xl {\n    border-top-right-radius: 1rem;\n    border-bottom-right-radius: 1rem;\n  }\n\n  .xl\\:rounded-b-2xl {\n    border-bottom-right-radius: 1rem;\n    border-bottom-left-radius: 1rem;\n  }\n\n  .xl\\:rounded-l-2xl {\n    border-top-left-radius: 1rem;\n    border-bottom-left-radius: 1rem;\n  }\n\n  .xl\\:rounded-t-3xl {\n    border-top-left-radius: 1.5rem;\n    border-top-right-radius: 1.5rem;\n  }\n\n  .xl\\:rounded-r-3xl {\n    border-top-right-radius: 1.5rem;\n    border-bottom-right-radius: 1.5rem;\n  }\n\n  .xl\\:rounded-b-3xl {\n    border-bottom-right-radius: 1.5rem;\n    border-bottom-left-radius: 1.5rem;\n  }\n\n  .xl\\:rounded-l-3xl {\n    border-top-left-radius: 1.5rem;\n    border-bottom-left-radius: 1.5rem;\n  }\n\n  .xl\\:rounded-t-full {\n    border-top-left-radius: 9999px;\n    border-top-right-radius: 9999px;\n  }\n\n  .xl\\:rounded-r-full {\n    border-top-right-radius: 9999px;\n    border-bottom-right-radius: 9999px;\n  }\n\n  .xl\\:rounded-b-full {\n    border-bottom-right-radius: 9999px;\n    border-bottom-left-radius: 9999px;\n  }\n\n  .xl\\:rounded-l-full {\n    border-top-left-radius: 9999px;\n    border-bottom-left-radius: 9999px;\n  }\n\n  .xl\\:rounded-tl-none {\n    border-top-left-radius: 0;\n  }\n\n  .xl\\:rounded-tr-none {\n    border-top-right-radius: 0;\n  }\n\n  .xl\\:rounded-br-none {\n    border-bottom-right-radius: 0;\n  }\n\n  .xl\\:rounded-bl-none {\n    border-bottom-left-radius: 0;\n  }\n\n  .xl\\:rounded-tl-sm {\n    border-top-left-radius: 0.125rem;\n  }\n\n  .xl\\:rounded-tr-sm {\n    border-top-right-radius: 0.125rem;\n  }\n\n  .xl\\:rounded-br-sm {\n    border-bottom-right-radius: 0.125rem;\n  }\n\n  .xl\\:rounded-bl-sm {\n    border-bottom-left-radius: 0.125rem;\n  }\n\n  .xl\\:rounded-tl {\n    border-top-left-radius: 0.25rem;\n  }\n\n  .xl\\:rounded-tr {\n    border-top-right-radius: 0.25rem;\n  }\n\n  .xl\\:rounded-br {\n    border-bottom-right-radius: 0.25rem;\n  }\n\n  .xl\\:rounded-bl {\n    border-bottom-left-radius: 0.25rem;\n  }\n\n  .xl\\:rounded-tl-md {\n    border-top-left-radius: 0.375rem;\n  }\n\n  .xl\\:rounded-tr-md {\n    border-top-right-radius: 0.375rem;\n  }\n\n  .xl\\:rounded-br-md {\n    border-bottom-right-radius: 0.375rem;\n  }\n\n  .xl\\:rounded-bl-md {\n    border-bottom-left-radius: 0.375rem;\n  }\n\n  .xl\\:rounded-tl-lg {\n    border-top-left-radius: 0.5rem;\n  }\n\n  .xl\\:rounded-tr-lg {\n    border-top-right-radius: 0.5rem;\n  }\n\n  .xl\\:rounded-br-lg {\n    border-bottom-right-radius: 0.5rem;\n  }\n\n  .xl\\:rounded-bl-lg {\n    border-bottom-left-radius: 0.5rem;\n  }\n\n  .xl\\:rounded-tl-xl {\n    border-top-left-radius: 0.75rem;\n  }\n\n  .xl\\:rounded-tr-xl {\n    border-top-right-radius: 0.75rem;\n  }\n\n  .xl\\:rounded-br-xl {\n    border-bottom-right-radius: 0.75rem;\n  }\n\n  .xl\\:rounded-bl-xl {\n    border-bottom-left-radius: 0.75rem;\n  }\n\n  .xl\\:rounded-tl-2xl {\n    border-top-left-radius: 1rem;\n  }\n\n  .xl\\:rounded-tr-2xl {\n    border-top-right-radius: 1rem;\n  }\n\n  .xl\\:rounded-br-2xl {\n    border-bottom-right-radius: 1rem;\n  }\n\n  .xl\\:rounded-bl-2xl {\n    border-bottom-left-radius: 1rem;\n  }\n\n  .xl\\:rounded-tl-3xl {\n    border-top-left-radius: 1.5rem;\n  }\n\n  .xl\\:rounded-tr-3xl {\n    border-top-right-radius: 1.5rem;\n  }\n\n  .xl\\:rounded-br-3xl {\n    border-bottom-right-radius: 1.5rem;\n  }\n\n  .xl\\:rounded-bl-3xl {\n    border-bottom-left-radius: 1.5rem;\n  }\n\n  .xl\\:rounded-tl-full {\n    border-top-left-radius: 9999px;\n  }\n\n  .xl\\:rounded-tr-full {\n    border-top-right-radius: 9999px;\n  }\n\n  .xl\\:rounded-br-full {\n    border-bottom-right-radius: 9999px;\n  }\n\n  .xl\\:rounded-bl-full {\n    border-bottom-left-radius: 9999px;\n  }\n\n  .xl\\:border-solid {\n    border-style: solid;\n  }\n\n  .xl\\:border-dashed {\n    border-style: dashed;\n  }\n\n  .xl\\:border-dotted {\n    border-style: dotted;\n  }\n\n  .xl\\:border-double {\n    border-style: double;\n  }\n\n  .xl\\:border-none {\n    border-style: none;\n  }\n\n  .xl\\:border-0 {\n    border-width: 0;\n  }\n\n  .xl\\:border-2 {\n    border-width: 2px;\n  }\n\n  .xl\\:border-4 {\n    border-width: 4px;\n  }\n\n  .xl\\:border-8 {\n    border-width: 8px;\n  }\n\n  .xl\\:border {\n    border-width: 1px;\n  }\n\n  .xl\\:border-t-0 {\n    border-top-width: 0;\n  }\n\n  .xl\\:border-r-0 {\n    border-right-width: 0;\n  }\n\n  .xl\\:border-b-0 {\n    border-bottom-width: 0;\n  }\n\n  .xl\\:border-l-0 {\n    border-left-width: 0;\n  }\n\n  .xl\\:border-t-2 {\n    border-top-width: 2px;\n  }\n\n  .xl\\:border-r-2 {\n    border-right-width: 2px;\n  }\n\n  .xl\\:border-b-2 {\n    border-bottom-width: 2px;\n  }\n\n  .xl\\:border-l-2 {\n    border-left-width: 2px;\n  }\n\n  .xl\\:border-t-4 {\n    border-top-width: 4px;\n  }\n\n  .xl\\:border-r-4 {\n    border-right-width: 4px;\n  }\n\n  .xl\\:border-b-4 {\n    border-bottom-width: 4px;\n  }\n\n  .xl\\:border-l-4 {\n    border-left-width: 4px;\n  }\n\n  .xl\\:border-t-8 {\n    border-top-width: 8px;\n  }\n\n  .xl\\:border-r-8 {\n    border-right-width: 8px;\n  }\n\n  .xl\\:border-b-8 {\n    border-bottom-width: 8px;\n  }\n\n  .xl\\:border-l-8 {\n    border-left-width: 8px;\n  }\n\n  .xl\\:border-t {\n    border-top-width: 1px;\n  }\n\n  .xl\\:border-r {\n    border-right-width: 1px;\n  }\n\n  .xl\\:border-b {\n    border-bottom-width: 1px;\n  }\n\n  .xl\\:border-l {\n    border-left-width: 1px;\n  }\n\n  .xl\\:box-border {\n    box-sizing: border-box;\n  }\n\n  .xl\\:box-content {\n    box-sizing: content-box;\n  }\n\n  .xl\\:cursor-auto {\n    cursor: auto;\n  }\n\n  .xl\\:cursor-default {\n    cursor: default;\n  }\n\n  .xl\\:cursor-pointer {\n    cursor: pointer;\n  }\n\n  .xl\\:cursor-wait {\n    cursor: wait;\n  }\n\n  .xl\\:cursor-text {\n    cursor: text;\n  }\n\n  .xl\\:cursor-move {\n    cursor: move;\n  }\n\n  .xl\\:cursor-not-allowed {\n    cursor: not-allowed;\n  }\n\n  .xl\\:block {\n    display: block;\n  }\n\n  .xl\\:inline-block {\n    display: inline-block;\n  }\n\n  .xl\\:inline {\n    display: inline;\n  }\n\n  .xl\\:flex {\n    display: flex;\n  }\n\n  .xl\\:inline-flex {\n    display: inline-flex;\n  }\n\n  .xl\\:table {\n    display: table;\n  }\n\n  .xl\\:table-caption {\n    display: table-caption;\n  }\n\n  .xl\\:table-cell {\n    display: table-cell;\n  }\n\n  .xl\\:table-column {\n    display: table-column;\n  }\n\n  .xl\\:table-column-group {\n    display: table-column-group;\n  }\n\n  .xl\\:table-footer-group {\n    display: table-footer-group;\n  }\n\n  .xl\\:table-header-group {\n    display: table-header-group;\n  }\n\n  .xl\\:table-row-group {\n    display: table-row-group;\n  }\n\n  .xl\\:table-row {\n    display: table-row;\n  }\n\n  .xl\\:flow-root {\n    display: flow-root;\n  }\n\n  .xl\\:grid {\n    display: grid;\n  }\n\n  .xl\\:inline-grid {\n    display: inline-grid;\n  }\n\n  .xl\\:contents {\n    display: contents;\n  }\n\n  .xl\\:hidden {\n    display: none;\n  }\n\n  .xl\\:flex-row {\n    flex-direction: row;\n  }\n\n  .xl\\:flex-row-reverse {\n    flex-direction: row-reverse;\n  }\n\n  .xl\\:flex-col {\n    flex-direction: column;\n  }\n\n  .xl\\:flex-col-reverse {\n    flex-direction: column-reverse;\n  }\n\n  .xl\\:flex-wrap {\n    flex-wrap: wrap;\n  }\n\n  .xl\\:flex-wrap-reverse {\n    flex-wrap: wrap-reverse;\n  }\n\n  .xl\\:flex-no-wrap {\n    flex-wrap: nowrap;\n  }\n\n  .xl\\:place-items-auto {\n    place-items: auto;\n  }\n\n  .xl\\:place-items-start {\n    place-items: start;\n  }\n\n  .xl\\:place-items-end {\n    place-items: end;\n  }\n\n  .xl\\:place-items-center {\n    place-items: center;\n  }\n\n  .xl\\:place-items-stretch {\n    place-items: stretch;\n  }\n\n  .xl\\:place-content-center {\n    place-content: center;\n  }\n\n  .xl\\:place-content-start {\n    place-content: start;\n  }\n\n  .xl\\:place-content-end {\n    place-content: end;\n  }\n\n  .xl\\:place-content-between {\n    place-content: space-between;\n  }\n\n  .xl\\:place-content-around {\n    place-content: space-around;\n  }\n\n  .xl\\:place-content-evenly {\n    place-content: space-evenly;\n  }\n\n  .xl\\:place-content-stretch {\n    place-content: stretch;\n  }\n\n  .xl\\:place-self-auto {\n    place-self: auto;\n  }\n\n  .xl\\:place-self-start {\n    place-self: start;\n  }\n\n  .xl\\:place-self-end {\n    place-self: end;\n  }\n\n  .xl\\:place-self-center {\n    place-self: center;\n  }\n\n  .xl\\:place-self-stretch {\n    place-self: stretch;\n  }\n\n  .xl\\:items-start {\n    align-items: flex-start;\n  }\n\n  .xl\\:items-end {\n    align-items: flex-end;\n  }\n\n  .xl\\:items-center {\n    align-items: center;\n  }\n\n  .xl\\:items-baseline {\n    align-items: baseline;\n  }\n\n  .xl\\:items-stretch {\n    align-items: stretch;\n  }\n\n  .xl\\:content-center {\n    align-content: center;\n  }\n\n  .xl\\:content-start {\n    align-content: flex-start;\n  }\n\n  .xl\\:content-end {\n    align-content: flex-end;\n  }\n\n  .xl\\:content-between {\n    align-content: space-between;\n  }\n\n  .xl\\:content-around {\n    align-content: space-around;\n  }\n\n  .xl\\:content-evenly {\n    align-content: space-evenly;\n  }\n\n  .xl\\:self-auto {\n    align-self: auto;\n  }\n\n  .xl\\:self-start {\n    align-self: flex-start;\n  }\n\n  .xl\\:self-end {\n    align-self: flex-end;\n  }\n\n  .xl\\:self-center {\n    align-self: center;\n  }\n\n  .xl\\:self-stretch {\n    align-self: stretch;\n  }\n\n  .xl\\:justify-items-auto {\n    justify-items: auto;\n  }\n\n  .xl\\:justify-items-start {\n    justify-items: start;\n  }\n\n  .xl\\:justify-items-end {\n    justify-items: end;\n  }\n\n  .xl\\:justify-items-center {\n    justify-items: center;\n  }\n\n  .xl\\:justify-items-stretch {\n    justify-items: stretch;\n  }\n\n  .xl\\:justify-start {\n    justify-content: flex-start;\n  }\n\n  .xl\\:justify-end {\n    justify-content: flex-end;\n  }\n\n  .xl\\:justify-center {\n    justify-content: center;\n  }\n\n  .xl\\:justify-between {\n    justify-content: space-between;\n  }\n\n  .xl\\:justify-around {\n    justify-content: space-around;\n  }\n\n  .xl\\:justify-evenly {\n    justify-content: space-evenly;\n  }\n\n  .xl\\:justify-self-auto {\n    justify-self: auto;\n  }\n\n  .xl\\:justify-self-start {\n    justify-self: start;\n  }\n\n  .xl\\:justify-self-end {\n    justify-self: end;\n  }\n\n  .xl\\:justify-self-center {\n    justify-self: center;\n  }\n\n  .xl\\:justify-self-stretch {\n    justify-self: stretch;\n  }\n\n  .xl\\:flex-1 {\n    flex: 1 1 0%;\n  }\n\n  .xl\\:flex-auto {\n    flex: 1 1 auto;\n  }\n\n  .xl\\:flex-initial {\n    flex: 0 1 auto;\n  }\n\n  .xl\\:flex-none {\n    flex: none;\n  }\n\n  .xl\\:flex-grow-0 {\n    flex-grow: 0;\n  }\n\n  .xl\\:flex-grow {\n    flex-grow: 1;\n  }\n\n  .xl\\:flex-shrink-0 {\n    flex-shrink: 0;\n  }\n\n  .xl\\:flex-shrink {\n    flex-shrink: 1;\n  }\n\n  .xl\\:order-1 {\n    order: 1;\n  }\n\n  .xl\\:order-2 {\n    order: 2;\n  }\n\n  .xl\\:order-3 {\n    order: 3;\n  }\n\n  .xl\\:order-4 {\n    order: 4;\n  }\n\n  .xl\\:order-5 {\n    order: 5;\n  }\n\n  .xl\\:order-6 {\n    order: 6;\n  }\n\n  .xl\\:order-7 {\n    order: 7;\n  }\n\n  .xl\\:order-8 {\n    order: 8;\n  }\n\n  .xl\\:order-9 {\n    order: 9;\n  }\n\n  .xl\\:order-10 {\n    order: 10;\n  }\n\n  .xl\\:order-11 {\n    order: 11;\n  }\n\n  .xl\\:order-12 {\n    order: 12;\n  }\n\n  .xl\\:order-first {\n    order: -9999;\n  }\n\n  .xl\\:order-last {\n    order: 9999;\n  }\n\n  .xl\\:order-none {\n    order: 0;\n  }\n\n  .xl\\:float-right {\n    float: right;\n  }\n\n  .xl\\:float-left {\n    float: left;\n  }\n\n  .xl\\:float-none {\n    float: none;\n  }\n\n  .xl\\:clearfix:after {\n    content: \"\";\n    display: table;\n    clear: both;\n  }\n\n  .xl\\:clear-left {\n    clear: left;\n  }\n\n  .xl\\:clear-right {\n    clear: right;\n  }\n\n  .xl\\:clear-both {\n    clear: both;\n  }\n\n  .xl\\:clear-none {\n    clear: none;\n  }\n\n  .xl\\:font-sans {\n    font-family: system-ui, -apple-system, BlinkMacSystemFont, \"Segoe UI\", Roboto, \"Helvetica Neue\", Arial, \"Noto Sans\", sans-serif, \"Apple Color Emoji\", \"Segoe UI Emoji\", \"Segoe UI Symbol\", \"Noto Color Emoji\";\n  }\n\n  .xl\\:font-serif {\n    font-family: Georgia, Cambria, \"Times New Roman\", Times, serif;\n  }\n\n  .xl\\:font-mono {\n    font-family: Menlo, Monaco, Consolas, \"Liberation Mono\", \"Courier New\", monospace;\n  }\n\n  .xl\\:font-hairline {\n    font-weight: 100;\n  }\n\n  .xl\\:font-thin {\n    font-weight: 200;\n  }\n\n  .xl\\:font-light {\n    font-weight: 300;\n  }\n\n  .xl\\:font-normal {\n    font-weight: 400;\n  }\n\n  .xl\\:font-medium {\n    font-weight: 500;\n  }\n\n  .xl\\:font-semibold {\n    font-weight: 600;\n  }\n\n  .xl\\:font-bold {\n    font-weight: 700;\n  }\n\n  .xl\\:font-extrabold {\n    font-weight: 800;\n  }\n\n  .xl\\:font-black {\n    font-weight: 900;\n  }\n\n  .xl\\:hover\\:font-hairline:hover {\n    font-weight: 100;\n  }\n\n  .xl\\:hover\\:font-thin:hover {\n    font-weight: 200;\n  }\n\n  .xl\\:hover\\:font-light:hover {\n    font-weight: 300;\n  }\n\n  .xl\\:hover\\:font-normal:hover {\n    font-weight: 400;\n  }\n\n  .xl\\:hover\\:font-medium:hover {\n    font-weight: 500;\n  }\n\n  .xl\\:hover\\:font-semibold:hover {\n    font-weight: 600;\n  }\n\n  .xl\\:hover\\:font-bold:hover {\n    font-weight: 700;\n  }\n\n  .xl\\:hover\\:font-extrabold:hover {\n    font-weight: 800;\n  }\n\n  .xl\\:hover\\:font-black:hover {\n    font-weight: 900;\n  }\n\n  .xl\\:focus\\:font-hairline:focus {\n    font-weight: 100;\n  }\n\n  .xl\\:focus\\:font-thin:focus {\n    font-weight: 200;\n  }\n\n  .xl\\:focus\\:font-light:focus {\n    font-weight: 300;\n  }\n\n  .xl\\:focus\\:font-normal:focus {\n    font-weight: 400;\n  }\n\n  .xl\\:focus\\:font-medium:focus {\n    font-weight: 500;\n  }\n\n  .xl\\:focus\\:font-semibold:focus {\n    font-weight: 600;\n  }\n\n  .xl\\:focus\\:font-bold:focus {\n    font-weight: 700;\n  }\n\n  .xl\\:focus\\:font-extrabold:focus {\n    font-weight: 800;\n  }\n\n  .xl\\:focus\\:font-black:focus {\n    font-weight: 900;\n  }\n\n  .xl\\:h-0 {\n    height: 0;\n  }\n\n  .xl\\:h-1 {\n    height: 0.25rem;\n  }\n\n  .xl\\:h-2 {\n    height: 0.5rem;\n  }\n\n  .xl\\:h-3 {\n    height: 0.75rem;\n  }\n\n  .xl\\:h-4 {\n    height: 1rem;\n  }\n\n  .xl\\:h-5 {\n    height: 1.25rem;\n  }\n\n  .xl\\:h-6 {\n    height: 1.5rem;\n  }\n\n  .xl\\:h-8 {\n    height: 2rem;\n  }\n\n  .xl\\:h-10 {\n    height: 2.5rem;\n  }\n\n  .xl\\:h-12 {\n    height: 3rem;\n  }\n\n  .xl\\:h-16 {\n    height: 4rem;\n  }\n\n  .xl\\:h-20 {\n    height: 5rem;\n  }\n\n  .xl\\:h-24 {\n    height: 6rem;\n  }\n\n  .xl\\:h-32 {\n    height: 8rem;\n  }\n\n  .xl\\:h-40 {\n    height: 10rem;\n  }\n\n  .xl\\:h-48 {\n    height: 12rem;\n  }\n\n  .xl\\:h-56 {\n    height: 14rem;\n  }\n\n  .xl\\:h-64 {\n    height: 16rem;\n  }\n\n  .xl\\:h-auto {\n    height: auto;\n  }\n\n  .xl\\:h-px {\n    height: 1px;\n  }\n\n  .xl\\:h-full {\n    height: 100%;\n  }\n\n  .xl\\:h-screen {\n    height: 100vh;\n  }\n\n  .xl\\:text-xs {\n    font-size: 0.75rem;\n  }\n\n  .xl\\:text-sm {\n    font-size: 0.875rem;\n  }\n\n  .xl\\:text-base {\n    font-size: 1rem;\n  }\n\n  .xl\\:text-lg {\n    font-size: 1.125rem;\n  }\n\n  .xl\\:text-xl {\n    font-size: 1.25rem;\n  }\n\n  .xl\\:text-2xl {\n    font-size: 1.5rem;\n  }\n\n  .xl\\:text-3xl {\n    font-size: 1.875rem;\n  }\n\n  .xl\\:text-4xl {\n    font-size: 2.25rem;\n  }\n\n  .xl\\:text-5xl {\n    font-size: 3rem;\n  }\n\n  .xl\\:text-6xl {\n    font-size: 4rem;\n  }\n\n  .xl\\:leading-3 {\n    line-height: .75rem;\n  }\n\n  .xl\\:leading-4 {\n    line-height: 1rem;\n  }\n\n  .xl\\:leading-5 {\n    line-height: 1.25rem;\n  }\n\n  .xl\\:leading-6 {\n    line-height: 1.5rem;\n  }\n\n  .xl\\:leading-7 {\n    line-height: 1.75rem;\n  }\n\n  .xl\\:leading-8 {\n    line-height: 2rem;\n  }\n\n  .xl\\:leading-9 {\n    line-height: 2.25rem;\n  }\n\n  .xl\\:leading-10 {\n    line-height: 2.5rem;\n  }\n\n  .xl\\:leading-none {\n    line-height: 1;\n  }\n\n  .xl\\:leading-tight {\n    line-height: 1.25;\n  }\n\n  .xl\\:leading-snug {\n    line-height: 1.375;\n  }\n\n  .xl\\:leading-normal {\n    line-height: 1.5;\n  }\n\n  .xl\\:leading-relaxed {\n    line-height: 1.625;\n  }\n\n  .xl\\:leading-loose {\n    line-height: 2;\n  }\n\n  .xl\\:list-inside {\n    list-style-position: inside;\n  }\n\n  .xl\\:list-outside {\n    list-style-position: outside;\n  }\n\n  .xl\\:list-none {\n    list-style-type: none;\n  }\n\n  .xl\\:list-disc {\n    list-style-type: disc;\n  }\n\n  .xl\\:list-decimal {\n    list-style-type: decimal;\n  }\n\n  .xl\\:m-0 {\n    margin: 0;\n  }\n\n  .xl\\:m-1 {\n    margin: 0.25rem;\n  }\n\n  .xl\\:m-2 {\n    margin: 0.5rem;\n  }\n\n  .xl\\:m-3 {\n    margin: 0.75rem;\n  }\n\n  .xl\\:m-4 {\n    margin: 1rem;\n  }\n\n  .xl\\:m-5 {\n    margin: 1.25rem;\n  }\n\n  .xl\\:m-6 {\n    margin: 1.5rem;\n  }\n\n  .xl\\:m-8 {\n    margin: 2rem;\n  }\n\n  .xl\\:m-10 {\n    margin: 2.5rem;\n  }\n\n  .xl\\:m-12 {\n    margin: 3rem;\n  }\n\n  .xl\\:m-16 {\n    margin: 4rem;\n  }\n\n  .xl\\:m-20 {\n    margin: 5rem;\n  }\n\n  .xl\\:m-24 {\n    margin: 6rem;\n  }\n\n  .xl\\:m-32 {\n    margin: 8rem;\n  }\n\n  .xl\\:m-40 {\n    margin: 10rem;\n  }\n\n  .xl\\:m-48 {\n    margin: 12rem;\n  }\n\n  .xl\\:m-56 {\n    margin: 14rem;\n  }\n\n  .xl\\:m-64 {\n    margin: 16rem;\n  }\n\n  .xl\\:m-auto {\n    margin: auto;\n  }\n\n  .xl\\:m-px {\n    margin: 1px;\n  }\n\n  .xl\\:-m-1 {\n    margin: -0.25rem;\n  }\n\n  .xl\\:-m-2 {\n    margin: -0.5rem;\n  }\n\n  .xl\\:-m-3 {\n    margin: -0.75rem;\n  }\n\n  .xl\\:-m-4 {\n    margin: -1rem;\n  }\n\n  .xl\\:-m-5 {\n    margin: -1.25rem;\n  }\n\n  .xl\\:-m-6 {\n    margin: -1.5rem;\n  }\n\n  .xl\\:-m-8 {\n    margin: -2rem;\n  }\n\n  .xl\\:-m-10 {\n    margin: -2.5rem;\n  }\n\n  .xl\\:-m-12 {\n    margin: -3rem;\n  }\n\n  .xl\\:-m-16 {\n    margin: -4rem;\n  }\n\n  .xl\\:-m-20 {\n    margin: -5rem;\n  }\n\n  .xl\\:-m-24 {\n    margin: -6rem;\n  }\n\n  .xl\\:-m-32 {\n    margin: -8rem;\n  }\n\n  .xl\\:-m-40 {\n    margin: -10rem;\n  }\n\n  .xl\\:-m-48 {\n    margin: -12rem;\n  }\n\n  .xl\\:-m-56 {\n    margin: -14rem;\n  }\n\n  .xl\\:-m-64 {\n    margin: -16rem;\n  }\n\n  .xl\\:-m-px {\n    margin: -1px;\n  }\n\n  .xl\\:my-0 {\n    margin-top: 0;\n    margin-bottom: 0;\n  }\n\n  .xl\\:mx-0 {\n    margin-left: 0;\n    margin-right: 0;\n  }\n\n  .xl\\:my-1 {\n    margin-top: 0.25rem;\n    margin-bottom: 0.25rem;\n  }\n\n  .xl\\:mx-1 {\n    margin-left: 0.25rem;\n    margin-right: 0.25rem;\n  }\n\n  .xl\\:my-2 {\n    margin-top: 0.5rem;\n    margin-bottom: 0.5rem;\n  }\n\n  .xl\\:mx-2 {\n    margin-left: 0.5rem;\n    margin-right: 0.5rem;\n  }\n\n  .xl\\:my-3 {\n    margin-top: 0.75rem;\n    margin-bottom: 0.75rem;\n  }\n\n  .xl\\:mx-3 {\n    margin-left: 0.75rem;\n    margin-right: 0.75rem;\n  }\n\n  .xl\\:my-4 {\n    margin-top: 1rem;\n    margin-bottom: 1rem;\n  }\n\n  .xl\\:mx-4 {\n    margin-left: 1rem;\n    margin-right: 1rem;\n  }\n\n  .xl\\:my-5 {\n    margin-top: 1.25rem;\n    margin-bottom: 1.25rem;\n  }\n\n  .xl\\:mx-5 {\n    margin-left: 1.25rem;\n    margin-right: 1.25rem;\n  }\n\n  .xl\\:my-6 {\n    margin-top: 1.5rem;\n    margin-bottom: 1.5rem;\n  }\n\n  .xl\\:mx-6 {\n    margin-left: 1.5rem;\n    margin-right: 1.5rem;\n  }\n\n  .xl\\:my-8 {\n    margin-top: 2rem;\n    margin-bottom: 2rem;\n  }\n\n  .xl\\:mx-8 {\n    margin-left: 2rem;\n    margin-right: 2rem;\n  }\n\n  .xl\\:my-10 {\n    margin-top: 2.5rem;\n    margin-bottom: 2.5rem;\n  }\n\n  .xl\\:mx-10 {\n    margin-left: 2.5rem;\n    margin-right: 2.5rem;\n  }\n\n  .xl\\:my-12 {\n    margin-top: 3rem;\n    margin-bottom: 3rem;\n  }\n\n  .xl\\:mx-12 {\n    margin-left: 3rem;\n    margin-right: 3rem;\n  }\n\n  .xl\\:my-16 {\n    margin-top: 4rem;\n    margin-bottom: 4rem;\n  }\n\n  .xl\\:mx-16 {\n    margin-left: 4rem;\n    margin-right: 4rem;\n  }\n\n  .xl\\:my-20 {\n    margin-top: 5rem;\n    margin-bottom: 5rem;\n  }\n\n  .xl\\:mx-20 {\n    margin-left: 5rem;\n    margin-right: 5rem;\n  }\n\n  .xl\\:my-24 {\n    margin-top: 6rem;\n    margin-bottom: 6rem;\n  }\n\n  .xl\\:mx-24 {\n    margin-left: 6rem;\n    margin-right: 6rem;\n  }\n\n  .xl\\:my-32 {\n    margin-top: 8rem;\n    margin-bottom: 8rem;\n  }\n\n  .xl\\:mx-32 {\n    margin-left: 8rem;\n    margin-right: 8rem;\n  }\n\n  .xl\\:my-40 {\n    margin-top: 10rem;\n    margin-bottom: 10rem;\n  }\n\n  .xl\\:mx-40 {\n    margin-left: 10rem;\n    margin-right: 10rem;\n  }\n\n  .xl\\:my-48 {\n    margin-top: 12rem;\n    margin-bottom: 12rem;\n  }\n\n  .xl\\:mx-48 {\n    margin-left: 12rem;\n    margin-right: 12rem;\n  }\n\n  .xl\\:my-56 {\n    margin-top: 14rem;\n    margin-bottom: 14rem;\n  }\n\n  .xl\\:mx-56 {\n    margin-left: 14rem;\n    margin-right: 14rem;\n  }\n\n  .xl\\:my-64 {\n    margin-top: 16rem;\n    margin-bottom: 16rem;\n  }\n\n  .xl\\:mx-64 {\n    margin-left: 16rem;\n    margin-right: 16rem;\n  }\n\n  .xl\\:my-auto {\n    margin-top: auto;\n    margin-bottom: auto;\n  }\n\n  .xl\\:mx-auto {\n    margin-left: auto;\n    margin-right: auto;\n  }\n\n  .xl\\:my-px {\n    margin-top: 1px;\n    margin-bottom: 1px;\n  }\n\n  .xl\\:mx-px {\n    margin-left: 1px;\n    margin-right: 1px;\n  }\n\n  .xl\\:-my-1 {\n    margin-top: -0.25rem;\n    margin-bottom: -0.25rem;\n  }\n\n  .xl\\:-mx-1 {\n    margin-left: -0.25rem;\n    margin-right: -0.25rem;\n  }\n\n  .xl\\:-my-2 {\n    margin-top: -0.5rem;\n    margin-bottom: -0.5rem;\n  }\n\n  .xl\\:-mx-2 {\n    margin-left: -0.5rem;\n    margin-right: -0.5rem;\n  }\n\n  .xl\\:-my-3 {\n    margin-top: -0.75rem;\n    margin-bottom: -0.75rem;\n  }\n\n  .xl\\:-mx-3 {\n    margin-left: -0.75rem;\n    margin-right: -0.75rem;\n  }\n\n  .xl\\:-my-4 {\n    margin-top: -1rem;\n    margin-bottom: -1rem;\n  }\n\n  .xl\\:-mx-4 {\n    margin-left: -1rem;\n    margin-right: -1rem;\n  }\n\n  .xl\\:-my-5 {\n    margin-top: -1.25rem;\n    margin-bottom: -1.25rem;\n  }\n\n  .xl\\:-mx-5 {\n    margin-left: -1.25rem;\n    margin-right: -1.25rem;\n  }\n\n  .xl\\:-my-6 {\n    margin-top: -1.5rem;\n    margin-bottom: -1.5rem;\n  }\n\n  .xl\\:-mx-6 {\n    margin-left: -1.5rem;\n    margin-right: -1.5rem;\n  }\n\n  .xl\\:-my-8 {\n    margin-top: -2rem;\n    margin-bottom: -2rem;\n  }\n\n  .xl\\:-mx-8 {\n    margin-left: -2rem;\n    margin-right: -2rem;\n  }\n\n  .xl\\:-my-10 {\n    margin-top: -2.5rem;\n    margin-bottom: -2.5rem;\n  }\n\n  .xl\\:-mx-10 {\n    margin-left: -2.5rem;\n    margin-right: -2.5rem;\n  }\n\n  .xl\\:-my-12 {\n    margin-top: -3rem;\n    margin-bottom: -3rem;\n  }\n\n  .xl\\:-mx-12 {\n    margin-left: -3rem;\n    margin-right: -3rem;\n  }\n\n  .xl\\:-my-16 {\n    margin-top: -4rem;\n    margin-bottom: -4rem;\n  }\n\n  .xl\\:-mx-16 {\n    margin-left: -4rem;\n    margin-right: -4rem;\n  }\n\n  .xl\\:-my-20 {\n    margin-top: -5rem;\n    margin-bottom: -5rem;\n  }\n\n  .xl\\:-mx-20 {\n    margin-left: -5rem;\n    margin-right: -5rem;\n  }\n\n  .xl\\:-my-24 {\n    margin-top: -6rem;\n    margin-bottom: -6rem;\n  }\n\n  .xl\\:-mx-24 {\n    margin-left: -6rem;\n    margin-right: -6rem;\n  }\n\n  .xl\\:-my-32 {\n    margin-top: -8rem;\n    margin-bottom: -8rem;\n  }\n\n  .xl\\:-mx-32 {\n    margin-left: -8rem;\n    margin-right: -8rem;\n  }\n\n  .xl\\:-my-40 {\n    margin-top: -10rem;\n    margin-bottom: -10rem;\n  }\n\n  .xl\\:-mx-40 {\n    margin-left: -10rem;\n    margin-right: -10rem;\n  }\n\n  .xl\\:-my-48 {\n    margin-top: -12rem;\n    margin-bottom: -12rem;\n  }\n\n  .xl\\:-mx-48 {\n    margin-left: -12rem;\n    margin-right: -12rem;\n  }\n\n  .xl\\:-my-56 {\n    margin-top: -14rem;\n    margin-bottom: -14rem;\n  }\n\n  .xl\\:-mx-56 {\n    margin-left: -14rem;\n    margin-right: -14rem;\n  }\n\n  .xl\\:-my-64 {\n    margin-top: -16rem;\n    margin-bottom: -16rem;\n  }\n\n  .xl\\:-mx-64 {\n    margin-left: -16rem;\n    margin-right: -16rem;\n  }\n\n  .xl\\:-my-px {\n    margin-top: -1px;\n    margin-bottom: -1px;\n  }\n\n  .xl\\:-mx-px {\n    margin-left: -1px;\n    margin-right: -1px;\n  }\n\n  .xl\\:mt-0 {\n    margin-top: 0;\n  }\n\n  .xl\\:mr-0 {\n    margin-right: 0;\n  }\n\n  .xl\\:mb-0 {\n    margin-bottom: 0;\n  }\n\n  .xl\\:ml-0 {\n    margin-left: 0;\n  }\n\n  .xl\\:mt-1 {\n    margin-top: 0.25rem;\n  }\n\n  .xl\\:mr-1 {\n    margin-right: 0.25rem;\n  }\n\n  .xl\\:mb-1 {\n    margin-bottom: 0.25rem;\n  }\n\n  .xl\\:ml-1 {\n    margin-left: 0.25rem;\n  }\n\n  .xl\\:mt-2 {\n    margin-top: 0.5rem;\n  }\n\n  .xl\\:mr-2 {\n    margin-right: 0.5rem;\n  }\n\n  .xl\\:mb-2 {\n    margin-bottom: 0.5rem;\n  }\n\n  .xl\\:ml-2 {\n    margin-left: 0.5rem;\n  }\n\n  .xl\\:mt-3 {\n    margin-top: 0.75rem;\n  }\n\n  .xl\\:mr-3 {\n    margin-right: 0.75rem;\n  }\n\n  .xl\\:mb-3 {\n    margin-bottom: 0.75rem;\n  }\n\n  .xl\\:ml-3 {\n    margin-left: 0.75rem;\n  }\n\n  .xl\\:mt-4 {\n    margin-top: 1rem;\n  }\n\n  .xl\\:mr-4 {\n    margin-right: 1rem;\n  }\n\n  .xl\\:mb-4 {\n    margin-bottom: 1rem;\n  }\n\n  .xl\\:ml-4 {\n    margin-left: 1rem;\n  }\n\n  .xl\\:mt-5 {\n    margin-top: 1.25rem;\n  }\n\n  .xl\\:mr-5 {\n    margin-right: 1.25rem;\n  }\n\n  .xl\\:mb-5 {\n    margin-bottom: 1.25rem;\n  }\n\n  .xl\\:ml-5 {\n    margin-left: 1.25rem;\n  }\n\n  .xl\\:mt-6 {\n    margin-top: 1.5rem;\n  }\n\n  .xl\\:mr-6 {\n    margin-right: 1.5rem;\n  }\n\n  .xl\\:mb-6 {\n    margin-bottom: 1.5rem;\n  }\n\n  .xl\\:ml-6 {\n    margin-left: 1.5rem;\n  }\n\n  .xl\\:mt-8 {\n    margin-top: 2rem;\n  }\n\n  .xl\\:mr-8 {\n    margin-right: 2rem;\n  }\n\n  .xl\\:mb-8 {\n    margin-bottom: 2rem;\n  }\n\n  .xl\\:ml-8 {\n    margin-left: 2rem;\n  }\n\n  .xl\\:mt-10 {\n    margin-top: 2.5rem;\n  }\n\n  .xl\\:mr-10 {\n    margin-right: 2.5rem;\n  }\n\n  .xl\\:mb-10 {\n    margin-bottom: 2.5rem;\n  }\n\n  .xl\\:ml-10 {\n    margin-left: 2.5rem;\n  }\n\n  .xl\\:mt-12 {\n    margin-top: 3rem;\n  }\n\n  .xl\\:mr-12 {\n    margin-right: 3rem;\n  }\n\n  .xl\\:mb-12 {\n    margin-bottom: 3rem;\n  }\n\n  .xl\\:ml-12 {\n    margin-left: 3rem;\n  }\n\n  .xl\\:mt-16 {\n    margin-top: 4rem;\n  }\n\n  .xl\\:mr-16 {\n    margin-right: 4rem;\n  }\n\n  .xl\\:mb-16 {\n    margin-bottom: 4rem;\n  }\n\n  .xl\\:ml-16 {\n    margin-left: 4rem;\n  }\n\n  .xl\\:mt-20 {\n    margin-top: 5rem;\n  }\n\n  .xl\\:mr-20 {\n    margin-right: 5rem;\n  }\n\n  .xl\\:mb-20 {\n    margin-bottom: 5rem;\n  }\n\n  .xl\\:ml-20 {\n    margin-left: 5rem;\n  }\n\n  .xl\\:mt-24 {\n    margin-top: 6rem;\n  }\n\n  .xl\\:mr-24 {\n    margin-right: 6rem;\n  }\n\n  .xl\\:mb-24 {\n    margin-bottom: 6rem;\n  }\n\n  .xl\\:ml-24 {\n    margin-left: 6rem;\n  }\n\n  .xl\\:mt-32 {\n    margin-top: 8rem;\n  }\n\n  .xl\\:mr-32 {\n    margin-right: 8rem;\n  }\n\n  .xl\\:mb-32 {\n    margin-bottom: 8rem;\n  }\n\n  .xl\\:ml-32 {\n    margin-left: 8rem;\n  }\n\n  .xl\\:mt-40 {\n    margin-top: 10rem;\n  }\n\n  .xl\\:mr-40 {\n    margin-right: 10rem;\n  }\n\n  .xl\\:mb-40 {\n    margin-bottom: 10rem;\n  }\n\n  .xl\\:ml-40 {\n    margin-left: 10rem;\n  }\n\n  .xl\\:mt-48 {\n    margin-top: 12rem;\n  }\n\n  .xl\\:mr-48 {\n    margin-right: 12rem;\n  }\n\n  .xl\\:mb-48 {\n    margin-bottom: 12rem;\n  }\n\n  .xl\\:ml-48 {\n    margin-left: 12rem;\n  }\n\n  .xl\\:mt-56 {\n    margin-top: 14rem;\n  }\n\n  .xl\\:mr-56 {\n    margin-right: 14rem;\n  }\n\n  .xl\\:mb-56 {\n    margin-bottom: 14rem;\n  }\n\n  .xl\\:ml-56 {\n    margin-left: 14rem;\n  }\n\n  .xl\\:mt-64 {\n    margin-top: 16rem;\n  }\n\n  .xl\\:mr-64 {\n    margin-right: 16rem;\n  }\n\n  .xl\\:mb-64 {\n    margin-bottom: 16rem;\n  }\n\n  .xl\\:ml-64 {\n    margin-left: 16rem;\n  }\n\n  .xl\\:mt-auto {\n    margin-top: auto;\n  }\n\n  .xl\\:mr-auto {\n    margin-right: auto;\n  }\n\n  .xl\\:mb-auto {\n    margin-bottom: auto;\n  }\n\n  .xl\\:ml-auto {\n    margin-left: auto;\n  }\n\n  .xl\\:mt-px {\n    margin-top: 1px;\n  }\n\n  .xl\\:mr-px {\n    margin-right: 1px;\n  }\n\n  .xl\\:mb-px {\n    margin-bottom: 1px;\n  }\n\n  .xl\\:ml-px {\n    margin-left: 1px;\n  }\n\n  .xl\\:-mt-1 {\n    margin-top: -0.25rem;\n  }\n\n  .xl\\:-mr-1 {\n    margin-right: -0.25rem;\n  }\n\n  .xl\\:-mb-1 {\n    margin-bottom: -0.25rem;\n  }\n\n  .xl\\:-ml-1 {\n    margin-left: -0.25rem;\n  }\n\n  .xl\\:-mt-2 {\n    margin-top: -0.5rem;\n  }\n\n  .xl\\:-mr-2 {\n    margin-right: -0.5rem;\n  }\n\n  .xl\\:-mb-2 {\n    margin-bottom: -0.5rem;\n  }\n\n  .xl\\:-ml-2 {\n    margin-left: -0.5rem;\n  }\n\n  .xl\\:-mt-3 {\n    margin-top: -0.75rem;\n  }\n\n  .xl\\:-mr-3 {\n    margin-right: -0.75rem;\n  }\n\n  .xl\\:-mb-3 {\n    margin-bottom: -0.75rem;\n  }\n\n  .xl\\:-ml-3 {\n    margin-left: -0.75rem;\n  }\n\n  .xl\\:-mt-4 {\n    margin-top: -1rem;\n  }\n\n  .xl\\:-mr-4 {\n    margin-right: -1rem;\n  }\n\n  .xl\\:-mb-4 {\n    margin-bottom: -1rem;\n  }\n\n  .xl\\:-ml-4 {\n    margin-left: -1rem;\n  }\n\n  .xl\\:-mt-5 {\n    margin-top: -1.25rem;\n  }\n\n  .xl\\:-mr-5 {\n    margin-right: -1.25rem;\n  }\n\n  .xl\\:-mb-5 {\n    margin-bottom: -1.25rem;\n  }\n\n  .xl\\:-ml-5 {\n    margin-left: -1.25rem;\n  }\n\n  .xl\\:-mt-6 {\n    margin-top: -1.5rem;\n  }\n\n  .xl\\:-mr-6 {\n    margin-right: -1.5rem;\n  }\n\n  .xl\\:-mb-6 {\n    margin-bottom: -1.5rem;\n  }\n\n  .xl\\:-ml-6 {\n    margin-left: -1.5rem;\n  }\n\n  .xl\\:-mt-8 {\n    margin-top: -2rem;\n  }\n\n  .xl\\:-mr-8 {\n    margin-right: -2rem;\n  }\n\n  .xl\\:-mb-8 {\n    margin-bottom: -2rem;\n  }\n\n  .xl\\:-ml-8 {\n    margin-left: -2rem;\n  }\n\n  .xl\\:-mt-10 {\n    margin-top: -2.5rem;\n  }\n\n  .xl\\:-mr-10 {\n    margin-right: -2.5rem;\n  }\n\n  .xl\\:-mb-10 {\n    margin-bottom: -2.5rem;\n  }\n\n  .xl\\:-ml-10 {\n    margin-left: -2.5rem;\n  }\n\n  .xl\\:-mt-12 {\n    margin-top: -3rem;\n  }\n\n  .xl\\:-mr-12 {\n    margin-right: -3rem;\n  }\n\n  .xl\\:-mb-12 {\n    margin-bottom: -3rem;\n  }\n\n  .xl\\:-ml-12 {\n    margin-left: -3rem;\n  }\n\n  .xl\\:-mt-16 {\n    margin-top: -4rem;\n  }\n\n  .xl\\:-mr-16 {\n    margin-right: -4rem;\n  }\n\n  .xl\\:-mb-16 {\n    margin-bottom: -4rem;\n  }\n\n  .xl\\:-ml-16 {\n    margin-left: -4rem;\n  }\n\n  .xl\\:-mt-20 {\n    margin-top: -5rem;\n  }\n\n  .xl\\:-mr-20 {\n    margin-right: -5rem;\n  }\n\n  .xl\\:-mb-20 {\n    margin-bottom: -5rem;\n  }\n\n  .xl\\:-ml-20 {\n    margin-left: -5rem;\n  }\n\n  .xl\\:-mt-24 {\n    margin-top: -6rem;\n  }\n\n  .xl\\:-mr-24 {\n    margin-right: -6rem;\n  }\n\n  .xl\\:-mb-24 {\n    margin-bottom: -6rem;\n  }\n\n  .xl\\:-ml-24 {\n    margin-left: -6rem;\n  }\n\n  .xl\\:-mt-32 {\n    margin-top: -8rem;\n  }\n\n  .xl\\:-mr-32 {\n    margin-right: -8rem;\n  }\n\n  .xl\\:-mb-32 {\n    margin-bottom: -8rem;\n  }\n\n  .xl\\:-ml-32 {\n    margin-left: -8rem;\n  }\n\n  .xl\\:-mt-40 {\n    margin-top: -10rem;\n  }\n\n  .xl\\:-mr-40 {\n    margin-right: -10rem;\n  }\n\n  .xl\\:-mb-40 {\n    margin-bottom: -10rem;\n  }\n\n  .xl\\:-ml-40 {\n    margin-left: -10rem;\n  }\n\n  .xl\\:-mt-48 {\n    margin-top: -12rem;\n  }\n\n  .xl\\:-mr-48 {\n    margin-right: -12rem;\n  }\n\n  .xl\\:-mb-48 {\n    margin-bottom: -12rem;\n  }\n\n  .xl\\:-ml-48 {\n    margin-left: -12rem;\n  }\n\n  .xl\\:-mt-56 {\n    margin-top: -14rem;\n  }\n\n  .xl\\:-mr-56 {\n    margin-right: -14rem;\n  }\n\n  .xl\\:-mb-56 {\n    margin-bottom: -14rem;\n  }\n\n  .xl\\:-ml-56 {\n    margin-left: -14rem;\n  }\n\n  .xl\\:-mt-64 {\n    margin-top: -16rem;\n  }\n\n  .xl\\:-mr-64 {\n    margin-right: -16rem;\n  }\n\n  .xl\\:-mb-64 {\n    margin-bottom: -16rem;\n  }\n\n  .xl\\:-ml-64 {\n    margin-left: -16rem;\n  }\n\n  .xl\\:-mt-px {\n    margin-top: -1px;\n  }\n\n  .xl\\:-mr-px {\n    margin-right: -1px;\n  }\n\n  .xl\\:-mb-px {\n    margin-bottom: -1px;\n  }\n\n  .xl\\:-ml-px {\n    margin-left: -1px;\n  }\n\n  .xl\\:max-h-full {\n    max-height: 100%;\n  }\n\n  .xl\\:max-h-screen {\n    max-height: 100vh;\n  }\n\n  .xl\\:max-w-none {\n    max-width: none;\n  }\n\n  .xl\\:max-w-xs {\n    max-width: 20rem;\n  }\n\n  .xl\\:max-w-sm {\n    max-width: 24rem;\n  }\n\n  .xl\\:max-w-md {\n    max-width: 28rem;\n  }\n\n  .xl\\:max-w-lg {\n    max-width: 32rem;\n  }\n\n  .xl\\:max-w-xl {\n    max-width: 36rem;\n  }\n\n  .xl\\:max-w-2xl {\n    max-width: 42rem;\n  }\n\n  .xl\\:max-w-3xl {\n    max-width: 48rem;\n  }\n\n  .xl\\:max-w-4xl {\n    max-width: 56rem;\n  }\n\n  .xl\\:max-w-5xl {\n    max-width: 64rem;\n  }\n\n  .xl\\:max-w-6xl {\n    max-width: 72rem;\n  }\n\n  .xl\\:max-w-full {\n    max-width: 100%;\n  }\n\n  .xl\\:max-w-screen-sm {\n    max-width: 640px;\n  }\n\n  .xl\\:max-w-screen-md {\n    max-width: 768px;\n  }\n\n  .xl\\:max-w-screen-lg {\n    max-width: 1024px;\n  }\n\n  .xl\\:max-w-screen-xl {\n    max-width: 1280px;\n  }\n\n  .xl\\:min-h-0 {\n    min-height: 0;\n  }\n\n  .xl\\:min-h-full {\n    min-height: 100%;\n  }\n\n  .xl\\:min-h-screen {\n    min-height: 100vh;\n  }\n\n  .xl\\:min-w-0 {\n    min-width: 0;\n  }\n\n  .xl\\:min-w-full {\n    min-width: 100%;\n  }\n\n  .xl\\:object-contain {\n    -o-object-fit: contain;\n       object-fit: contain;\n  }\n\n  .xl\\:object-cover {\n    -o-object-fit: cover;\n       object-fit: cover;\n  }\n\n  .xl\\:object-fill {\n    -o-object-fit: fill;\n       object-fit: fill;\n  }\n\n  .xl\\:object-none {\n    -o-object-fit: none;\n       object-fit: none;\n  }\n\n  .xl\\:object-scale-down {\n    -o-object-fit: scale-down;\n       object-fit: scale-down;\n  }\n\n  .xl\\:object-bottom {\n    -o-object-position: bottom;\n       object-position: bottom;\n  }\n\n  .xl\\:object-center {\n    -o-object-position: center;\n       object-position: center;\n  }\n\n  .xl\\:object-left {\n    -o-object-position: left;\n       object-position: left;\n  }\n\n  .xl\\:object-left-bottom {\n    -o-object-position: left bottom;\n       object-position: left bottom;\n  }\n\n  .xl\\:object-left-top {\n    -o-object-position: left top;\n       object-position: left top;\n  }\n\n  .xl\\:object-right {\n    -o-object-position: right;\n       object-position: right;\n  }\n\n  .xl\\:object-right-bottom {\n    -o-object-position: right bottom;\n       object-position: right bottom;\n  }\n\n  .xl\\:object-right-top {\n    -o-object-position: right top;\n       object-position: right top;\n  }\n\n  .xl\\:object-top {\n    -o-object-position: top;\n       object-position: top;\n  }\n\n  .xl\\:opacity-0 {\n    opacity: 0;\n  }\n\n  .xl\\:opacity-25 {\n    opacity: 0.25;\n  }\n\n  .xl\\:opacity-50 {\n    opacity: 0.5;\n  }\n\n  .xl\\:opacity-75 {\n    opacity: 0.75;\n  }\n\n  .xl\\:opacity-100 {\n    opacity: 1;\n  }\n\n  .xl\\:hover\\:opacity-0:hover {\n    opacity: 0;\n  }\n\n  .xl\\:hover\\:opacity-25:hover {\n    opacity: 0.25;\n  }\n\n  .xl\\:hover\\:opacity-50:hover {\n    opacity: 0.5;\n  }\n\n  .xl\\:hover\\:opacity-75:hover {\n    opacity: 0.75;\n  }\n\n  .xl\\:hover\\:opacity-100:hover {\n    opacity: 1;\n  }\n\n  .xl\\:focus\\:opacity-0:focus {\n    opacity: 0;\n  }\n\n  .xl\\:focus\\:opacity-25:focus {\n    opacity: 0.25;\n  }\n\n  .xl\\:focus\\:opacity-50:focus {\n    opacity: 0.5;\n  }\n\n  .xl\\:focus\\:opacity-75:focus {\n    opacity: 0.75;\n  }\n\n  .xl\\:focus\\:opacity-100:focus {\n    opacity: 1;\n  }\n\n  .xl\\:outline-none {\n    outline: 2px solid transparent;\n    outline-offset: 2px;\n  }\n\n  .xl\\:outline-white {\n    outline: 2px dotted white;\n    outline-offset: 2px;\n  }\n\n  .xl\\:outline-black {\n    outline: 2px dotted black;\n    outline-offset: 2px;\n  }\n\n  .xl\\:focus\\:outline-none:focus {\n    outline: 2px solid transparent;\n    outline-offset: 2px;\n  }\n\n  .xl\\:focus\\:outline-white:focus {\n    outline: 2px dotted white;\n    outline-offset: 2px;\n  }\n\n  .xl\\:focus\\:outline-black:focus {\n    outline: 2px dotted black;\n    outline-offset: 2px;\n  }\n\n  .xl\\:overflow-auto {\n    overflow: auto;\n  }\n\n  .xl\\:overflow-hidden {\n    overflow: hidden;\n  }\n\n  .xl\\:overflow-visible {\n    overflow: visible;\n  }\n\n  .xl\\:overflow-scroll {\n    overflow: scroll;\n  }\n\n  .xl\\:overflow-x-auto {\n    overflow-x: auto;\n  }\n\n  .xl\\:overflow-y-auto {\n    overflow-y: auto;\n  }\n\n  .xl\\:overflow-x-hidden {\n    overflow-x: hidden;\n  }\n\n  .xl\\:overflow-y-hidden {\n    overflow-y: hidden;\n  }\n\n  .xl\\:overflow-x-visible {\n    overflow-x: visible;\n  }\n\n  .xl\\:overflow-y-visible {\n    overflow-y: visible;\n  }\n\n  .xl\\:overflow-x-scroll {\n    overflow-x: scroll;\n  }\n\n  .xl\\:overflow-y-scroll {\n    overflow-y: scroll;\n  }\n\n  .xl\\:scrolling-touch {\n    -webkit-overflow-scrolling: touch;\n  }\n\n  .xl\\:scrolling-auto {\n    -webkit-overflow-scrolling: auto;\n  }\n\n  .xl\\:overscroll-auto {\n    -ms-scroll-chaining: chained;\n        overscroll-behavior: auto;\n  }\n\n  .xl\\:overscroll-contain {\n    -ms-scroll-chaining: none;\n        overscroll-behavior: contain;\n  }\n\n  .xl\\:overscroll-none {\n    -ms-scroll-chaining: none;\n        overscroll-behavior: none;\n  }\n\n  .xl\\:overscroll-y-auto {\n    overscroll-behavior-y: auto;\n  }\n\n  .xl\\:overscroll-y-contain {\n    overscroll-behavior-y: contain;\n  }\n\n  .xl\\:overscroll-y-none {\n    overscroll-behavior-y: none;\n  }\n\n  .xl\\:overscroll-x-auto {\n    overscroll-behavior-x: auto;\n  }\n\n  .xl\\:overscroll-x-contain {\n    overscroll-behavior-x: contain;\n  }\n\n  .xl\\:overscroll-x-none {\n    overscroll-behavior-x: none;\n  }\n\n  .xl\\:p-0 {\n    padding: 0;\n  }\n\n  .xl\\:p-1 {\n    padding: 0.25rem;\n  }\n\n  .xl\\:p-2 {\n    padding: 0.5rem;\n  }\n\n  .xl\\:p-3 {\n    padding: 0.75rem;\n  }\n\n  .xl\\:p-4 {\n    padding: 1rem;\n  }\n\n  .xl\\:p-5 {\n    padding: 1.25rem;\n  }\n\n  .xl\\:p-6 {\n    padding: 1.5rem;\n  }\n\n  .xl\\:p-8 {\n    padding: 2rem;\n  }\n\n  .xl\\:p-10 {\n    padding: 2.5rem;\n  }\n\n  .xl\\:p-12 {\n    padding: 3rem;\n  }\n\n  .xl\\:p-16 {\n    padding: 4rem;\n  }\n\n  .xl\\:p-20 {\n    padding: 5rem;\n  }\n\n  .xl\\:p-24 {\n    padding: 6rem;\n  }\n\n  .xl\\:p-32 {\n    padding: 8rem;\n  }\n\n  .xl\\:p-40 {\n    padding: 10rem;\n  }\n\n  .xl\\:p-48 {\n    padding: 12rem;\n  }\n\n  .xl\\:p-56 {\n    padding: 14rem;\n  }\n\n  .xl\\:p-64 {\n    padding: 16rem;\n  }\n\n  .xl\\:p-px {\n    padding: 1px;\n  }\n\n  .xl\\:py-0 {\n    padding-top: 0;\n    padding-bottom: 0;\n  }\n\n  .xl\\:px-0 {\n    padding-left: 0;\n    padding-right: 0;\n  }\n\n  .xl\\:py-1 {\n    padding-top: 0.25rem;\n    padding-bottom: 0.25rem;\n  }\n\n  .xl\\:px-1 {\n    padding-left: 0.25rem;\n    padding-right: 0.25rem;\n  }\n\n  .xl\\:py-2 {\n    padding-top: 0.5rem;\n    padding-bottom: 0.5rem;\n  }\n\n  .xl\\:px-2 {\n    padding-left: 0.5rem;\n    padding-right: 0.5rem;\n  }\n\n  .xl\\:py-3 {\n    padding-top: 0.75rem;\n    padding-bottom: 0.75rem;\n  }\n\n  .xl\\:px-3 {\n    padding-left: 0.75rem;\n    padding-right: 0.75rem;\n  }\n\n  .xl\\:py-4 {\n    padding-top: 1rem;\n    padding-bottom: 1rem;\n  }\n\n  .xl\\:px-4 {\n    padding-left: 1rem;\n    padding-right: 1rem;\n  }\n\n  .xl\\:py-5 {\n    padding-top: 1.25rem;\n    padding-bottom: 1.25rem;\n  }\n\n  .xl\\:px-5 {\n    padding-left: 1.25rem;\n    padding-right: 1.25rem;\n  }\n\n  .xl\\:py-6 {\n    padding-top: 1.5rem;\n    padding-bottom: 1.5rem;\n  }\n\n  .xl\\:px-6 {\n    padding-left: 1.5rem;\n    padding-right: 1.5rem;\n  }\n\n  .xl\\:py-8 {\n    padding-top: 2rem;\n    padding-bottom: 2rem;\n  }\n\n  .xl\\:px-8 {\n    padding-left: 2rem;\n    padding-right: 2rem;\n  }\n\n  .xl\\:py-10 {\n    padding-top: 2.5rem;\n    padding-bottom: 2.5rem;\n  }\n\n  .xl\\:px-10 {\n    padding-left: 2.5rem;\n    padding-right: 2.5rem;\n  }\n\n  .xl\\:py-12 {\n    padding-top: 3rem;\n    padding-bottom: 3rem;\n  }\n\n  .xl\\:px-12 {\n    padding-left: 3rem;\n    padding-right: 3rem;\n  }\n\n  .xl\\:py-16 {\n    padding-top: 4rem;\n    padding-bottom: 4rem;\n  }\n\n  .xl\\:px-16 {\n    padding-left: 4rem;\n    padding-right: 4rem;\n  }\n\n  .xl\\:py-20 {\n    padding-top: 5rem;\n    padding-bottom: 5rem;\n  }\n\n  .xl\\:px-20 {\n    padding-left: 5rem;\n    padding-right: 5rem;\n  }\n\n  .xl\\:py-24 {\n    padding-top: 6rem;\n    padding-bottom: 6rem;\n  }\n\n  .xl\\:px-24 {\n    padding-left: 6rem;\n    padding-right: 6rem;\n  }\n\n  .xl\\:py-32 {\n    padding-top: 8rem;\n    padding-bottom: 8rem;\n  }\n\n  .xl\\:px-32 {\n    padding-left: 8rem;\n    padding-right: 8rem;\n  }\n\n  .xl\\:py-40 {\n    padding-top: 10rem;\n    padding-bottom: 10rem;\n  }\n\n  .xl\\:px-40 {\n    padding-left: 10rem;\n    padding-right: 10rem;\n  }\n\n  .xl\\:py-48 {\n    padding-top: 12rem;\n    padding-bottom: 12rem;\n  }\n\n  .xl\\:px-48 {\n    padding-left: 12rem;\n    padding-right: 12rem;\n  }\n\n  .xl\\:py-56 {\n    padding-top: 14rem;\n    padding-bottom: 14rem;\n  }\n\n  .xl\\:px-56 {\n    padding-left: 14rem;\n    padding-right: 14rem;\n  }\n\n  .xl\\:py-64 {\n    padding-top: 16rem;\n    padding-bottom: 16rem;\n  }\n\n  .xl\\:px-64 {\n    padding-left: 16rem;\n    padding-right: 16rem;\n  }\n\n  .xl\\:py-px {\n    padding-top: 1px;\n    padding-bottom: 1px;\n  }\n\n  .xl\\:px-px {\n    padding-left: 1px;\n    padding-right: 1px;\n  }\n\n  .xl\\:pt-0 {\n    padding-top: 0;\n  }\n\n  .xl\\:pr-0 {\n    padding-right: 0;\n  }\n\n  .xl\\:pb-0 {\n    padding-bottom: 0;\n  }\n\n  .xl\\:pl-0 {\n    padding-left: 0;\n  }\n\n  .xl\\:pt-1 {\n    padding-top: 0.25rem;\n  }\n\n  .xl\\:pr-1 {\n    padding-right: 0.25rem;\n  }\n\n  .xl\\:pb-1 {\n    padding-bottom: 0.25rem;\n  }\n\n  .xl\\:pl-1 {\n    padding-left: 0.25rem;\n  }\n\n  .xl\\:pt-2 {\n    padding-top: 0.5rem;\n  }\n\n  .xl\\:pr-2 {\n    padding-right: 0.5rem;\n  }\n\n  .xl\\:pb-2 {\n    padding-bottom: 0.5rem;\n  }\n\n  .xl\\:pl-2 {\n    padding-left: 0.5rem;\n  }\n\n  .xl\\:pt-3 {\n    padding-top: 0.75rem;\n  }\n\n  .xl\\:pr-3 {\n    padding-right: 0.75rem;\n  }\n\n  .xl\\:pb-3 {\n    padding-bottom: 0.75rem;\n  }\n\n  .xl\\:pl-3 {\n    padding-left: 0.75rem;\n  }\n\n  .xl\\:pt-4 {\n    padding-top: 1rem;\n  }\n\n  .xl\\:pr-4 {\n    padding-right: 1rem;\n  }\n\n  .xl\\:pb-4 {\n    padding-bottom: 1rem;\n  }\n\n  .xl\\:pl-4 {\n    padding-left: 1rem;\n  }\n\n  .xl\\:pt-5 {\n    padding-top: 1.25rem;\n  }\n\n  .xl\\:pr-5 {\n    padding-right: 1.25rem;\n  }\n\n  .xl\\:pb-5 {\n    padding-bottom: 1.25rem;\n  }\n\n  .xl\\:pl-5 {\n    padding-left: 1.25rem;\n  }\n\n  .xl\\:pt-6 {\n    padding-top: 1.5rem;\n  }\n\n  .xl\\:pr-6 {\n    padding-right: 1.5rem;\n  }\n\n  .xl\\:pb-6 {\n    padding-bottom: 1.5rem;\n  }\n\n  .xl\\:pl-6 {\n    padding-left: 1.5rem;\n  }\n\n  .xl\\:pt-8 {\n    padding-top: 2rem;\n  }\n\n  .xl\\:pr-8 {\n    padding-right: 2rem;\n  }\n\n  .xl\\:pb-8 {\n    padding-bottom: 2rem;\n  }\n\n  .xl\\:pl-8 {\n    padding-left: 2rem;\n  }\n\n  .xl\\:pt-10 {\n    padding-top: 2.5rem;\n  }\n\n  .xl\\:pr-10 {\n    padding-right: 2.5rem;\n  }\n\n  .xl\\:pb-10 {\n    padding-bottom: 2.5rem;\n  }\n\n  .xl\\:pl-10 {\n    padding-left: 2.5rem;\n  }\n\n  .xl\\:pt-12 {\n    padding-top: 3rem;\n  }\n\n  .xl\\:pr-12 {\n    padding-right: 3rem;\n  }\n\n  .xl\\:pb-12 {\n    padding-bottom: 3rem;\n  }\n\n  .xl\\:pl-12 {\n    padding-left: 3rem;\n  }\n\n  .xl\\:pt-16 {\n    padding-top: 4rem;\n  }\n\n  .xl\\:pr-16 {\n    padding-right: 4rem;\n  }\n\n  .xl\\:pb-16 {\n    padding-bottom: 4rem;\n  }\n\n  .xl\\:pl-16 {\n    padding-left: 4rem;\n  }\n\n  .xl\\:pt-20 {\n    padding-top: 5rem;\n  }\n\n  .xl\\:pr-20 {\n    padding-right: 5rem;\n  }\n\n  .xl\\:pb-20 {\n    padding-bottom: 5rem;\n  }\n\n  .xl\\:pl-20 {\n    padding-left: 5rem;\n  }\n\n  .xl\\:pt-24 {\n    padding-top: 6rem;\n  }\n\n  .xl\\:pr-24 {\n    padding-right: 6rem;\n  }\n\n  .xl\\:pb-24 {\n    padding-bottom: 6rem;\n  }\n\n  .xl\\:pl-24 {\n    padding-left: 6rem;\n  }\n\n  .xl\\:pt-32 {\n    padding-top: 8rem;\n  }\n\n  .xl\\:pr-32 {\n    padding-right: 8rem;\n  }\n\n  .xl\\:pb-32 {\n    padding-bottom: 8rem;\n  }\n\n  .xl\\:pl-32 {\n    padding-left: 8rem;\n  }\n\n  .xl\\:pt-40 {\n    padding-top: 10rem;\n  }\n\n  .xl\\:pr-40 {\n    padding-right: 10rem;\n  }\n\n  .xl\\:pb-40 {\n    padding-bottom: 10rem;\n  }\n\n  .xl\\:pl-40 {\n    padding-left: 10rem;\n  }\n\n  .xl\\:pt-48 {\n    padding-top: 12rem;\n  }\n\n  .xl\\:pr-48 {\n    padding-right: 12rem;\n  }\n\n  .xl\\:pb-48 {\n    padding-bottom: 12rem;\n  }\n\n  .xl\\:pl-48 {\n    padding-left: 12rem;\n  }\n\n  .xl\\:pt-56 {\n    padding-top: 14rem;\n  }\n\n  .xl\\:pr-56 {\n    padding-right: 14rem;\n  }\n\n  .xl\\:pb-56 {\n    padding-bottom: 14rem;\n  }\n\n  .xl\\:pl-56 {\n    padding-left: 14rem;\n  }\n\n  .xl\\:pt-64 {\n    padding-top: 16rem;\n  }\n\n  .xl\\:pr-64 {\n    padding-right: 16rem;\n  }\n\n  .xl\\:pb-64 {\n    padding-bottom: 16rem;\n  }\n\n  .xl\\:pl-64 {\n    padding-left: 16rem;\n  }\n\n  .xl\\:pt-px {\n    padding-top: 1px;\n  }\n\n  .xl\\:pr-px {\n    padding-right: 1px;\n  }\n\n  .xl\\:pb-px {\n    padding-bottom: 1px;\n  }\n\n  .xl\\:pl-px {\n    padding-left: 1px;\n  }\n\n  .xl\\:placeholder-transparent::-moz-placeholder {\n    color: transparent;\n  }\n\n  .xl\\:placeholder-transparent:-ms-input-placeholder {\n    color: transparent;\n  }\n\n  .xl\\:placeholder-transparent::placeholder {\n    color: transparent;\n  }\n\n  .xl\\:placeholder-current::-moz-placeholder {\n    color: currentColor;\n  }\n\n  .xl\\:placeholder-current:-ms-input-placeholder {\n    color: currentColor;\n  }\n\n  .xl\\:placeholder-current::placeholder {\n    color: currentColor;\n  }\n\n  .xl\\:placeholder-black::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-black:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-black::placeholder {\n    --placeholder-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-white::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-white:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-white::placeholder {\n    --placeholder-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-gray-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-red-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-orange-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-yellow-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-green-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-teal-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-blue-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-indigo-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-purple-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-100::placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-200::placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-300::placeholder {\n    --placeholder-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-400::placeholder {\n    --placeholder-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-500::placeholder {\n    --placeholder-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-600::placeholder {\n    --placeholder-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-700::placeholder {\n    --placeholder-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-800::placeholder {\n    --placeholder-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-pink-900::placeholder {\n    --placeholder-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-80::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-80:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-80::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-100::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-200::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-200:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-200::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-300::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-300:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-300::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-400::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-400:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-400::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-500::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-500:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-500::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-600::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-600:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-600::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-700::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-700:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-700::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-800::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-800:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-800::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-840::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-840:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-840::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-870::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-870:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-870::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-900::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-900:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-900::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-930::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-930:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-grayscale-930::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-primary::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-primary:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-primary::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:placeholder-background-main::-moz-placeholder {\n    color: var(--main-background);\n  }\n\n  .xl\\:placeholder-background-main:-ms-input-placeholder {\n    color: var(--main-background);\n  }\n\n  .xl\\:placeholder-background-main::placeholder {\n    color: var(--main-background);\n  }\n\n  .xl\\:placeholder-background-secondary::-moz-placeholder {\n    color: var(--secondary-background);\n  }\n\n  .xl\\:placeholder-background-secondary:-ms-input-placeholder {\n    color: var(--secondary-background);\n  }\n\n  .xl\\:placeholder-background-secondary::placeholder {\n    color: var(--secondary-background);\n  }\n\n  .xl\\:placeholder-foreground::-moz-placeholder {\n    color: var(--foreground);\n  }\n\n  .xl\\:placeholder-foreground:-ms-input-placeholder {\n    color: var(--foreground);\n  }\n\n  .xl\\:placeholder-foreground::placeholder {\n    color: var(--foreground);\n  }\n\n  .xl\\:placeholder-panels-bg::-moz-placeholder {\n    color: var(--panels-background);\n  }\n\n  .xl\\:placeholder-panels-bg:-ms-input-placeholder {\n    color: var(--panels-background);\n  }\n\n  .xl\\:placeholder-panels-bg::placeholder {\n    color: var(--panels-background);\n  }\n\n  .xl\\:focus\\:placeholder-transparent:focus::-moz-placeholder {\n    color: transparent;\n  }\n\n  .xl\\:focus\\:placeholder-transparent:focus:-ms-input-placeholder {\n    color: transparent;\n  }\n\n  .xl\\:focus\\:placeholder-transparent:focus::placeholder {\n    color: transparent;\n  }\n\n  .xl\\:focus\\:placeholder-current:focus::-moz-placeholder {\n    color: currentColor;\n  }\n\n  .xl\\:focus\\:placeholder-current:focus:-ms-input-placeholder {\n    color: currentColor;\n  }\n\n  .xl\\:focus\\:placeholder-current:focus::placeholder {\n    color: currentColor;\n  }\n\n  .xl\\:focus\\:placeholder-black:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-black:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-black:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-white:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-white:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-white:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-gray-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-red-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-orange-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-yellow-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-green-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-teal-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-blue-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-indigo-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-purple-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-pink-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-80:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-80:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-80:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-100:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-200:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-200:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-200:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-300:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-300:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-300:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-400:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-400:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-400:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-500:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-500:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-500:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-600:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-600:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-600:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-700:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-700:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-700:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-800:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-800:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-800:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-840:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-840:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-840:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-870:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-870:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-870:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-900:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-900:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-900:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-930:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-930:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-grayscale-930:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-primary:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-primary:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-primary:focus::placeholder {\n    --placeholder-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--placeholder-opacity));\n  }\n\n  .xl\\:focus\\:placeholder-background-main:focus::-moz-placeholder {\n    color: var(--main-background);\n  }\n\n  .xl\\:focus\\:placeholder-background-main:focus:-ms-input-placeholder {\n    color: var(--main-background);\n  }\n\n  .xl\\:focus\\:placeholder-background-main:focus::placeholder {\n    color: var(--main-background);\n  }\n\n  .xl\\:focus\\:placeholder-background-secondary:focus::-moz-placeholder {\n    color: var(--secondary-background);\n  }\n\n  .xl\\:focus\\:placeholder-background-secondary:focus:-ms-input-placeholder {\n    color: var(--secondary-background);\n  }\n\n  .xl\\:focus\\:placeholder-background-secondary:focus::placeholder {\n    color: var(--secondary-background);\n  }\n\n  .xl\\:focus\\:placeholder-foreground:focus::-moz-placeholder {\n    color: var(--foreground);\n  }\n\n  .xl\\:focus\\:placeholder-foreground:focus:-ms-input-placeholder {\n    color: var(--foreground);\n  }\n\n  .xl\\:focus\\:placeholder-foreground:focus::placeholder {\n    color: var(--foreground);\n  }\n\n  .xl\\:focus\\:placeholder-panels-bg:focus::-moz-placeholder {\n    color: var(--panels-background);\n  }\n\n  .xl\\:focus\\:placeholder-panels-bg:focus:-ms-input-placeholder {\n    color: var(--panels-background);\n  }\n\n  .xl\\:focus\\:placeholder-panels-bg:focus::placeholder {\n    color: var(--panels-background);\n  }\n\n  .xl\\:placeholder-opacity-0::-moz-placeholder {\n    --placeholder-opacity: 0;\n  }\n\n  .xl\\:placeholder-opacity-0:-ms-input-placeholder {\n    --placeholder-opacity: 0;\n  }\n\n  .xl\\:placeholder-opacity-0::placeholder {\n    --placeholder-opacity: 0;\n  }\n\n  .xl\\:placeholder-opacity-25::-moz-placeholder {\n    --placeholder-opacity: 0.25;\n  }\n\n  .xl\\:placeholder-opacity-25:-ms-input-placeholder {\n    --placeholder-opacity: 0.25;\n  }\n\n  .xl\\:placeholder-opacity-25::placeholder {\n    --placeholder-opacity: 0.25;\n  }\n\n  .xl\\:placeholder-opacity-50::-moz-placeholder {\n    --placeholder-opacity: 0.5;\n  }\n\n  .xl\\:placeholder-opacity-50:-ms-input-placeholder {\n    --placeholder-opacity: 0.5;\n  }\n\n  .xl\\:placeholder-opacity-50::placeholder {\n    --placeholder-opacity: 0.5;\n  }\n\n  .xl\\:placeholder-opacity-75::-moz-placeholder {\n    --placeholder-opacity: 0.75;\n  }\n\n  .xl\\:placeholder-opacity-75:-ms-input-placeholder {\n    --placeholder-opacity: 0.75;\n  }\n\n  .xl\\:placeholder-opacity-75::placeholder {\n    --placeholder-opacity: 0.75;\n  }\n\n  .xl\\:placeholder-opacity-100::-moz-placeholder {\n    --placeholder-opacity: 1;\n  }\n\n  .xl\\:placeholder-opacity-100:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n  }\n\n  .xl\\:placeholder-opacity-100::placeholder {\n    --placeholder-opacity: 1;\n  }\n\n  .xl\\:focus\\:placeholder-opacity-0:focus::-moz-placeholder {\n    --placeholder-opacity: 0;\n  }\n\n  .xl\\:focus\\:placeholder-opacity-0:focus:-ms-input-placeholder {\n    --placeholder-opacity: 0;\n  }\n\n  .xl\\:focus\\:placeholder-opacity-0:focus::placeholder {\n    --placeholder-opacity: 0;\n  }\n\n  .xl\\:focus\\:placeholder-opacity-25:focus::-moz-placeholder {\n    --placeholder-opacity: 0.25;\n  }\n\n  .xl\\:focus\\:placeholder-opacity-25:focus:-ms-input-placeholder {\n    --placeholder-opacity: 0.25;\n  }\n\n  .xl\\:focus\\:placeholder-opacity-25:focus::placeholder {\n    --placeholder-opacity: 0.25;\n  }\n\n  .xl\\:focus\\:placeholder-opacity-50:focus::-moz-placeholder {\n    --placeholder-opacity: 0.5;\n  }\n\n  .xl\\:focus\\:placeholder-opacity-50:focus:-ms-input-placeholder {\n    --placeholder-opacity: 0.5;\n  }\n\n  .xl\\:focus\\:placeholder-opacity-50:focus::placeholder {\n    --placeholder-opacity: 0.5;\n  }\n\n  .xl\\:focus\\:placeholder-opacity-75:focus::-moz-placeholder {\n    --placeholder-opacity: 0.75;\n  }\n\n  .xl\\:focus\\:placeholder-opacity-75:focus:-ms-input-placeholder {\n    --placeholder-opacity: 0.75;\n  }\n\n  .xl\\:focus\\:placeholder-opacity-75:focus::placeholder {\n    --placeholder-opacity: 0.75;\n  }\n\n  .xl\\:focus\\:placeholder-opacity-100:focus::-moz-placeholder {\n    --placeholder-opacity: 1;\n  }\n\n  .xl\\:focus\\:placeholder-opacity-100:focus:-ms-input-placeholder {\n    --placeholder-opacity: 1;\n  }\n\n  .xl\\:focus\\:placeholder-opacity-100:focus::placeholder {\n    --placeholder-opacity: 1;\n  }\n\n  .xl\\:pointer-events-none {\n    pointer-events: none;\n  }\n\n  .xl\\:pointer-events-auto {\n    pointer-events: auto;\n  }\n\n  .xl\\:static {\n    position: static;\n  }\n\n  .xl\\:fixed {\n    position: fixed;\n  }\n\n  .xl\\:absolute {\n    position: absolute;\n  }\n\n  .xl\\:relative {\n    position: relative;\n  }\n\n  .xl\\:sticky {\n    position: -webkit-sticky;\n    position: sticky;\n  }\n\n  .xl\\:inset-0 {\n    top: 0;\n    right: 0;\n    bottom: 0;\n    left: 0;\n  }\n\n  .xl\\:inset-auto {\n    top: auto;\n    right: auto;\n    bottom: auto;\n    left: auto;\n  }\n\n  .xl\\:inset-y-0 {\n    top: 0;\n    bottom: 0;\n  }\n\n  .xl\\:inset-x-0 {\n    right: 0;\n    left: 0;\n  }\n\n  .xl\\:inset-y-auto {\n    top: auto;\n    bottom: auto;\n  }\n\n  .xl\\:inset-x-auto {\n    right: auto;\n    left: auto;\n  }\n\n  .xl\\:top-0 {\n    top: 0;\n  }\n\n  .xl\\:right-0 {\n    right: 0;\n  }\n\n  .xl\\:bottom-0 {\n    bottom: 0;\n  }\n\n  .xl\\:left-0 {\n    left: 0;\n  }\n\n  .xl\\:top-auto {\n    top: auto;\n  }\n\n  .xl\\:right-auto {\n    right: auto;\n  }\n\n  .xl\\:bottom-auto {\n    bottom: auto;\n  }\n\n  .xl\\:left-auto {\n    left: auto;\n  }\n\n  .xl\\:resize-none {\n    resize: none;\n  }\n\n  .xl\\:resize-y {\n    resize: vertical;\n  }\n\n  .xl\\:resize-x {\n    resize: horizontal;\n  }\n\n  .xl\\:resize {\n    resize: both;\n  }\n\n  .xl\\:shadow-xs {\n    box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.05);\n  }\n\n  .xl\\:shadow-sm {\n    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);\n  }\n\n  .xl\\:shadow {\n    box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);\n  }\n\n  .xl\\:shadow-md {\n    box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);\n  }\n\n  .xl\\:shadow-lg {\n    box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);\n  }\n\n  .xl\\:shadow-xl {\n    box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04);\n  }\n\n  .xl\\:shadow-2xl {\n    box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);\n  }\n\n  .xl\\:shadow-inner {\n    box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);\n  }\n\n  .xl\\:shadow-outline {\n    box-shadow: 0 0 0 3px rgba(66, 153, 225, 0.5);\n  }\n\n  .xl\\:shadow-none {\n    box-shadow: none;\n  }\n\n  .xl\\:hover\\:shadow-xs:hover {\n    box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.05);\n  }\n\n  .xl\\:hover\\:shadow-sm:hover {\n    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);\n  }\n\n  .xl\\:hover\\:shadow:hover {\n    box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);\n  }\n\n  .xl\\:hover\\:shadow-md:hover {\n    box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);\n  }\n\n  .xl\\:hover\\:shadow-lg:hover {\n    box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);\n  }\n\n  .xl\\:hover\\:shadow-xl:hover {\n    box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04);\n  }\n\n  .xl\\:hover\\:shadow-2xl:hover {\n    box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);\n  }\n\n  .xl\\:hover\\:shadow-inner:hover {\n    box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);\n  }\n\n  .xl\\:hover\\:shadow-outline:hover {\n    box-shadow: 0 0 0 3px rgba(66, 153, 225, 0.5);\n  }\n\n  .xl\\:hover\\:shadow-none:hover {\n    box-shadow: none;\n  }\n\n  .xl\\:focus\\:shadow-xs:focus {\n    box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.05);\n  }\n\n  .xl\\:focus\\:shadow-sm:focus {\n    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);\n  }\n\n  .xl\\:focus\\:shadow:focus {\n    box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);\n  }\n\n  .xl\\:focus\\:shadow-md:focus {\n    box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);\n  }\n\n  .xl\\:focus\\:shadow-lg:focus {\n    box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);\n  }\n\n  .xl\\:focus\\:shadow-xl:focus {\n    box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04);\n  }\n\n  .xl\\:focus\\:shadow-2xl:focus {\n    box-shadow: 0 25px 50px -12px rgba(0, 0, 0, 0.25);\n  }\n\n  .xl\\:focus\\:shadow-inner:focus {\n    box-shadow: inset 0 2px 4px 0 rgba(0, 0, 0, 0.06);\n  }\n\n  .xl\\:focus\\:shadow-outline:focus {\n    box-shadow: 0 0 0 3px rgba(66, 153, 225, 0.5);\n  }\n\n  .xl\\:focus\\:shadow-none:focus {\n    box-shadow: none;\n  }\n\n  .xl\\:fill-current {\n    fill: currentColor;\n  }\n\n  .xl\\:stroke-current {\n    stroke: currentColor;\n  }\n\n  .xl\\:stroke-0 {\n    stroke-width: 0;\n  }\n\n  .xl\\:stroke-1 {\n    stroke-width: 1;\n  }\n\n  .xl\\:stroke-2 {\n    stroke-width: 2;\n  }\n\n  .xl\\:table-auto {\n    table-layout: auto;\n  }\n\n  .xl\\:table-fixed {\n    table-layout: fixed;\n  }\n\n  .xl\\:text-left {\n    text-align: left;\n  }\n\n  .xl\\:text-center {\n    text-align: center;\n  }\n\n  .xl\\:text-right {\n    text-align: right;\n  }\n\n  .xl\\:text-justify {\n    text-align: justify;\n  }\n\n  .xl\\:text-transparent {\n    color: transparent;\n  }\n\n  .xl\\:text-current {\n    color: currentColor;\n  }\n\n  .xl\\:text-black {\n    --text-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--text-opacity));\n  }\n\n  .xl\\:text-white {\n    --text-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--text-opacity));\n  }\n\n  .xl\\:text-gray-100 {\n    --text-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--text-opacity));\n  }\n\n  .xl\\:text-gray-200 {\n    --text-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--text-opacity));\n  }\n\n  .xl\\:text-gray-300 {\n    --text-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--text-opacity));\n  }\n\n  .xl\\:text-gray-400 {\n    --text-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--text-opacity));\n  }\n\n  .xl\\:text-gray-500 {\n    --text-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--text-opacity));\n  }\n\n  .xl\\:text-gray-600 {\n    --text-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--text-opacity));\n  }\n\n  .xl\\:text-gray-700 {\n    --text-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--text-opacity));\n  }\n\n  .xl\\:text-gray-800 {\n    --text-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--text-opacity));\n  }\n\n  .xl\\:text-gray-900 {\n    --text-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--text-opacity));\n  }\n\n  .xl\\:text-red-100 {\n    --text-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--text-opacity));\n  }\n\n  .xl\\:text-red-200 {\n    --text-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--text-opacity));\n  }\n\n  .xl\\:text-red-300 {\n    --text-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--text-opacity));\n  }\n\n  .xl\\:text-red-400 {\n    --text-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--text-opacity));\n  }\n\n  .xl\\:text-red-500 {\n    --text-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--text-opacity));\n  }\n\n  .xl\\:text-red-600 {\n    --text-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--text-opacity));\n  }\n\n  .xl\\:text-red-700 {\n    --text-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--text-opacity));\n  }\n\n  .xl\\:text-red-800 {\n    --text-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--text-opacity));\n  }\n\n  .xl\\:text-red-900 {\n    --text-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--text-opacity));\n  }\n\n  .xl\\:text-orange-100 {\n    --text-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--text-opacity));\n  }\n\n  .xl\\:text-orange-200 {\n    --text-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--text-opacity));\n  }\n\n  .xl\\:text-orange-300 {\n    --text-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--text-opacity));\n  }\n\n  .xl\\:text-orange-400 {\n    --text-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--text-opacity));\n  }\n\n  .xl\\:text-orange-500 {\n    --text-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--text-opacity));\n  }\n\n  .xl\\:text-orange-600 {\n    --text-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--text-opacity));\n  }\n\n  .xl\\:text-orange-700 {\n    --text-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--text-opacity));\n  }\n\n  .xl\\:text-orange-800 {\n    --text-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--text-opacity));\n  }\n\n  .xl\\:text-orange-900 {\n    --text-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--text-opacity));\n  }\n\n  .xl\\:text-yellow-100 {\n    --text-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--text-opacity));\n  }\n\n  .xl\\:text-yellow-200 {\n    --text-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--text-opacity));\n  }\n\n  .xl\\:text-yellow-300 {\n    --text-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--text-opacity));\n  }\n\n  .xl\\:text-yellow-400 {\n    --text-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--text-opacity));\n  }\n\n  .xl\\:text-yellow-500 {\n    --text-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--text-opacity));\n  }\n\n  .xl\\:text-yellow-600 {\n    --text-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--text-opacity));\n  }\n\n  .xl\\:text-yellow-700 {\n    --text-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--text-opacity));\n  }\n\n  .xl\\:text-yellow-800 {\n    --text-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--text-opacity));\n  }\n\n  .xl\\:text-yellow-900 {\n    --text-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--text-opacity));\n  }\n\n  .xl\\:text-green-100 {\n    --text-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--text-opacity));\n  }\n\n  .xl\\:text-green-200 {\n    --text-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--text-opacity));\n  }\n\n  .xl\\:text-green-300 {\n    --text-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--text-opacity));\n  }\n\n  .xl\\:text-green-400 {\n    --text-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--text-opacity));\n  }\n\n  .xl\\:text-green-500 {\n    --text-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--text-opacity));\n  }\n\n  .xl\\:text-green-600 {\n    --text-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--text-opacity));\n  }\n\n  .xl\\:text-green-700 {\n    --text-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--text-opacity));\n  }\n\n  .xl\\:text-green-800 {\n    --text-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--text-opacity));\n  }\n\n  .xl\\:text-green-900 {\n    --text-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--text-opacity));\n  }\n\n  .xl\\:text-teal-100 {\n    --text-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--text-opacity));\n  }\n\n  .xl\\:text-teal-200 {\n    --text-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--text-opacity));\n  }\n\n  .xl\\:text-teal-300 {\n    --text-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--text-opacity));\n  }\n\n  .xl\\:text-teal-400 {\n    --text-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--text-opacity));\n  }\n\n  .xl\\:text-teal-500 {\n    --text-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--text-opacity));\n  }\n\n  .xl\\:text-teal-600 {\n    --text-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--text-opacity));\n  }\n\n  .xl\\:text-teal-700 {\n    --text-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--text-opacity));\n  }\n\n  .xl\\:text-teal-800 {\n    --text-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--text-opacity));\n  }\n\n  .xl\\:text-teal-900 {\n    --text-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--text-opacity));\n  }\n\n  .xl\\:text-blue-100 {\n    --text-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--text-opacity));\n  }\n\n  .xl\\:text-blue-200 {\n    --text-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--text-opacity));\n  }\n\n  .xl\\:text-blue-300 {\n    --text-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--text-opacity));\n  }\n\n  .xl\\:text-blue-400 {\n    --text-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--text-opacity));\n  }\n\n  .xl\\:text-blue-500 {\n    --text-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--text-opacity));\n  }\n\n  .xl\\:text-blue-600 {\n    --text-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--text-opacity));\n  }\n\n  .xl\\:text-blue-700 {\n    --text-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--text-opacity));\n  }\n\n  .xl\\:text-blue-800 {\n    --text-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--text-opacity));\n  }\n\n  .xl\\:text-blue-900 {\n    --text-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--text-opacity));\n  }\n\n  .xl\\:text-indigo-100 {\n    --text-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--text-opacity));\n  }\n\n  .xl\\:text-indigo-200 {\n    --text-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--text-opacity));\n  }\n\n  .xl\\:text-indigo-300 {\n    --text-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--text-opacity));\n  }\n\n  .xl\\:text-indigo-400 {\n    --text-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--text-opacity));\n  }\n\n  .xl\\:text-indigo-500 {\n    --text-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--text-opacity));\n  }\n\n  .xl\\:text-indigo-600 {\n    --text-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--text-opacity));\n  }\n\n  .xl\\:text-indigo-700 {\n    --text-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--text-opacity));\n  }\n\n  .xl\\:text-indigo-800 {\n    --text-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--text-opacity));\n  }\n\n  .xl\\:text-indigo-900 {\n    --text-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--text-opacity));\n  }\n\n  .xl\\:text-purple-100 {\n    --text-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--text-opacity));\n  }\n\n  .xl\\:text-purple-200 {\n    --text-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--text-opacity));\n  }\n\n  .xl\\:text-purple-300 {\n    --text-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--text-opacity));\n  }\n\n  .xl\\:text-purple-400 {\n    --text-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--text-opacity));\n  }\n\n  .xl\\:text-purple-500 {\n    --text-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--text-opacity));\n  }\n\n  .xl\\:text-purple-600 {\n    --text-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--text-opacity));\n  }\n\n  .xl\\:text-purple-700 {\n    --text-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--text-opacity));\n  }\n\n  .xl\\:text-purple-800 {\n    --text-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--text-opacity));\n  }\n\n  .xl\\:text-purple-900 {\n    --text-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--text-opacity));\n  }\n\n  .xl\\:text-pink-100 {\n    --text-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--text-opacity));\n  }\n\n  .xl\\:text-pink-200 {\n    --text-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--text-opacity));\n  }\n\n  .xl\\:text-pink-300 {\n    --text-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--text-opacity));\n  }\n\n  .xl\\:text-pink-400 {\n    --text-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--text-opacity));\n  }\n\n  .xl\\:text-pink-500 {\n    --text-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--text-opacity));\n  }\n\n  .xl\\:text-pink-600 {\n    --text-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--text-opacity));\n  }\n\n  .xl\\:text-pink-700 {\n    --text-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--text-opacity));\n  }\n\n  .xl\\:text-pink-800 {\n    --text-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--text-opacity));\n  }\n\n  .xl\\:text-pink-900 {\n    --text-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--text-opacity));\n  }\n\n  .xl\\:text-grayscale-80 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--text-opacity));\n  }\n\n  .xl\\:text-grayscale-100 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--text-opacity));\n  }\n\n  .xl\\:text-grayscale-200 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--text-opacity));\n  }\n\n  .xl\\:text-grayscale-300 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--text-opacity));\n  }\n\n  .xl\\:text-grayscale-400 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--text-opacity));\n  }\n\n  .xl\\:text-grayscale-500 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--text-opacity));\n  }\n\n  .xl\\:text-grayscale-600 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--text-opacity));\n  }\n\n  .xl\\:text-grayscale-700 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--text-opacity));\n  }\n\n  .xl\\:text-grayscale-800 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--text-opacity));\n  }\n\n  .xl\\:text-grayscale-840 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--text-opacity));\n  }\n\n  .xl\\:text-grayscale-870 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--text-opacity));\n  }\n\n  .xl\\:text-grayscale-900 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--text-opacity));\n  }\n\n  .xl\\:text-grayscale-930 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--text-opacity));\n  }\n\n  .xl\\:text-primary {\n    --text-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--text-opacity));\n  }\n\n  .xl\\:text-background-main {\n    color: var(--main-background);\n  }\n\n  .xl\\:text-background-secondary {\n    color: var(--secondary-background);\n  }\n\n  .xl\\:text-foreground {\n    color: var(--foreground);\n  }\n\n  .xl\\:text-panels-bg {\n    color: var(--panels-background);\n  }\n\n  .xl\\:hover\\:text-transparent:hover {\n    color: transparent;\n  }\n\n  .xl\\:hover\\:text-current:hover {\n    color: currentColor;\n  }\n\n  .xl\\:hover\\:text-black:hover {\n    --text-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-white:hover {\n    --text-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-gray-100:hover {\n    --text-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-gray-200:hover {\n    --text-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-gray-300:hover {\n    --text-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-gray-400:hover {\n    --text-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-gray-500:hover {\n    --text-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-gray-600:hover {\n    --text-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-gray-700:hover {\n    --text-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-gray-800:hover {\n    --text-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-gray-900:hover {\n    --text-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-red-100:hover {\n    --text-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-red-200:hover {\n    --text-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-red-300:hover {\n    --text-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-red-400:hover {\n    --text-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-red-500:hover {\n    --text-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-red-600:hover {\n    --text-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-red-700:hover {\n    --text-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-red-800:hover {\n    --text-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-red-900:hover {\n    --text-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-orange-100:hover {\n    --text-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-orange-200:hover {\n    --text-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-orange-300:hover {\n    --text-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-orange-400:hover {\n    --text-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-orange-500:hover {\n    --text-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-orange-600:hover {\n    --text-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-orange-700:hover {\n    --text-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-orange-800:hover {\n    --text-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-orange-900:hover {\n    --text-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-yellow-100:hover {\n    --text-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-yellow-200:hover {\n    --text-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-yellow-300:hover {\n    --text-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-yellow-400:hover {\n    --text-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-yellow-500:hover {\n    --text-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-yellow-600:hover {\n    --text-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-yellow-700:hover {\n    --text-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-yellow-800:hover {\n    --text-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-yellow-900:hover {\n    --text-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-green-100:hover {\n    --text-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-green-200:hover {\n    --text-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-green-300:hover {\n    --text-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-green-400:hover {\n    --text-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-green-500:hover {\n    --text-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-green-600:hover {\n    --text-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-green-700:hover {\n    --text-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-green-800:hover {\n    --text-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-green-900:hover {\n    --text-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-teal-100:hover {\n    --text-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-teal-200:hover {\n    --text-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-teal-300:hover {\n    --text-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-teal-400:hover {\n    --text-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-teal-500:hover {\n    --text-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-teal-600:hover {\n    --text-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-teal-700:hover {\n    --text-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-teal-800:hover {\n    --text-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-teal-900:hover {\n    --text-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-blue-100:hover {\n    --text-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-blue-200:hover {\n    --text-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-blue-300:hover {\n    --text-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-blue-400:hover {\n    --text-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-blue-500:hover {\n    --text-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-blue-600:hover {\n    --text-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-blue-700:hover {\n    --text-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-blue-800:hover {\n    --text-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-blue-900:hover {\n    --text-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-indigo-100:hover {\n    --text-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-indigo-200:hover {\n    --text-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-indigo-300:hover {\n    --text-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-indigo-400:hover {\n    --text-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-indigo-500:hover {\n    --text-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-indigo-600:hover {\n    --text-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-indigo-700:hover {\n    --text-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-indigo-800:hover {\n    --text-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-indigo-900:hover {\n    --text-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-purple-100:hover {\n    --text-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-purple-200:hover {\n    --text-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-purple-300:hover {\n    --text-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-purple-400:hover {\n    --text-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-purple-500:hover {\n    --text-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-purple-600:hover {\n    --text-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-purple-700:hover {\n    --text-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-purple-800:hover {\n    --text-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-purple-900:hover {\n    --text-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-pink-100:hover {\n    --text-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-pink-200:hover {\n    --text-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-pink-300:hover {\n    --text-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-pink-400:hover {\n    --text-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-pink-500:hover {\n    --text-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-pink-600:hover {\n    --text-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-pink-700:hover {\n    --text-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-pink-800:hover {\n    --text-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-pink-900:hover {\n    --text-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-grayscale-80:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-grayscale-100:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-grayscale-200:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-grayscale-300:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-grayscale-400:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-grayscale-500:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-grayscale-600:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-grayscale-700:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-grayscale-800:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-grayscale-840:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-grayscale-870:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-grayscale-900:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-grayscale-930:hover {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-primary:hover {\n    --text-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--text-opacity));\n  }\n\n  .xl\\:hover\\:text-background-main:hover {\n    color: var(--main-background);\n  }\n\n  .xl\\:hover\\:text-background-secondary:hover {\n    color: var(--secondary-background);\n  }\n\n  .xl\\:hover\\:text-foreground:hover {\n    color: var(--foreground);\n  }\n\n  .xl\\:hover\\:text-panels-bg:hover {\n    color: var(--panels-background);\n  }\n\n  .xl\\:focus\\:text-transparent:focus {\n    color: transparent;\n  }\n\n  .xl\\:focus\\:text-current:focus {\n    color: currentColor;\n  }\n\n  .xl\\:focus\\:text-black:focus {\n    --text-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-white:focus {\n    --text-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-gray-100:focus {\n    --text-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-gray-200:focus {\n    --text-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-gray-300:focus {\n    --text-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-gray-400:focus {\n    --text-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-gray-500:focus {\n    --text-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-gray-600:focus {\n    --text-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-gray-700:focus {\n    --text-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-gray-800:focus {\n    --text-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-gray-900:focus {\n    --text-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-red-100:focus {\n    --text-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-red-200:focus {\n    --text-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-red-300:focus {\n    --text-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-red-400:focus {\n    --text-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-red-500:focus {\n    --text-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-red-600:focus {\n    --text-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-red-700:focus {\n    --text-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-red-800:focus {\n    --text-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-red-900:focus {\n    --text-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-orange-100:focus {\n    --text-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-orange-200:focus {\n    --text-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-orange-300:focus {\n    --text-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-orange-400:focus {\n    --text-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-orange-500:focus {\n    --text-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-orange-600:focus {\n    --text-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-orange-700:focus {\n    --text-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-orange-800:focus {\n    --text-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-orange-900:focus {\n    --text-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-yellow-100:focus {\n    --text-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-yellow-200:focus {\n    --text-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-yellow-300:focus {\n    --text-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-yellow-400:focus {\n    --text-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-yellow-500:focus {\n    --text-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-yellow-600:focus {\n    --text-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-yellow-700:focus {\n    --text-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-yellow-800:focus {\n    --text-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-yellow-900:focus {\n    --text-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-green-100:focus {\n    --text-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-green-200:focus {\n    --text-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-green-300:focus {\n    --text-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-green-400:focus {\n    --text-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-green-500:focus {\n    --text-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-green-600:focus {\n    --text-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-green-700:focus {\n    --text-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-green-800:focus {\n    --text-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-green-900:focus {\n    --text-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-teal-100:focus {\n    --text-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-teal-200:focus {\n    --text-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-teal-300:focus {\n    --text-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-teal-400:focus {\n    --text-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-teal-500:focus {\n    --text-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-teal-600:focus {\n    --text-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-teal-700:focus {\n    --text-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-teal-800:focus {\n    --text-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-teal-900:focus {\n    --text-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-blue-100:focus {\n    --text-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-blue-200:focus {\n    --text-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-blue-300:focus {\n    --text-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-blue-400:focus {\n    --text-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-blue-500:focus {\n    --text-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-blue-600:focus {\n    --text-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-blue-700:focus {\n    --text-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-blue-800:focus {\n    --text-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-blue-900:focus {\n    --text-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-indigo-100:focus {\n    --text-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-indigo-200:focus {\n    --text-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-indigo-300:focus {\n    --text-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-indigo-400:focus {\n    --text-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-indigo-500:focus {\n    --text-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-indigo-600:focus {\n    --text-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-indigo-700:focus {\n    --text-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-indigo-800:focus {\n    --text-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-indigo-900:focus {\n    --text-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-purple-100:focus {\n    --text-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-purple-200:focus {\n    --text-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-purple-300:focus {\n    --text-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-purple-400:focus {\n    --text-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-purple-500:focus {\n    --text-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-purple-600:focus {\n    --text-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-purple-700:focus {\n    --text-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-purple-800:focus {\n    --text-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-purple-900:focus {\n    --text-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-pink-100:focus {\n    --text-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-pink-200:focus {\n    --text-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-pink-300:focus {\n    --text-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-pink-400:focus {\n    --text-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-pink-500:focus {\n    --text-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-pink-600:focus {\n    --text-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-pink-700:focus {\n    --text-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-pink-800:focus {\n    --text-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-pink-900:focus {\n    --text-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-grayscale-80:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-grayscale-100:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-grayscale-200:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-grayscale-300:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-grayscale-400:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-grayscale-500:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-grayscale-600:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-grayscale-700:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-grayscale-800:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-grayscale-840:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-grayscale-870:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-grayscale-900:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-grayscale-930:focus {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-primary:focus {\n    --text-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--text-opacity));\n  }\n\n  .xl\\:focus\\:text-background-main:focus {\n    color: var(--main-background);\n  }\n\n  .xl\\:focus\\:text-background-secondary:focus {\n    color: var(--secondary-background);\n  }\n\n  .xl\\:focus\\:text-foreground:focus {\n    color: var(--foreground);\n  }\n\n  .xl\\:focus\\:text-panels-bg:focus {\n    color: var(--panels-background);\n  }\n\n  .group:hover .xl\\:group-hover\\:text-transparent {\n    color: transparent;\n  }\n\n  .group:hover .xl\\:group-hover\\:text-current {\n    color: currentColor;\n  }\n\n  .group:hover .xl\\:group-hover\\:text-black {\n    --text-opacity: 1;\n    color: #000;\n    color: rgba(0, 0, 0, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-white {\n    --text-opacity: 1;\n    color: #fff;\n    color: rgba(255, 255, 255, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-gray-100 {\n    --text-opacity: 1;\n    color: #f7fafc;\n    color: rgba(247, 250, 252, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-gray-200 {\n    --text-opacity: 1;\n    color: #edf2f7;\n    color: rgba(237, 242, 247, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-gray-300 {\n    --text-opacity: 1;\n    color: #e2e8f0;\n    color: rgba(226, 232, 240, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-gray-400 {\n    --text-opacity: 1;\n    color: #cbd5e0;\n    color: rgba(203, 213, 224, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-gray-500 {\n    --text-opacity: 1;\n    color: #a0aec0;\n    color: rgba(160, 174, 192, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-gray-600 {\n    --text-opacity: 1;\n    color: #718096;\n    color: rgba(113, 128, 150, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-gray-700 {\n    --text-opacity: 1;\n    color: #4a5568;\n    color: rgba(74, 85, 104, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-gray-800 {\n    --text-opacity: 1;\n    color: #2d3748;\n    color: rgba(45, 55, 72, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-gray-900 {\n    --text-opacity: 1;\n    color: #1a202c;\n    color: rgba(26, 32, 44, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-red-100 {\n    --text-opacity: 1;\n    color: #fff5f5;\n    color: rgba(255, 245, 245, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-red-200 {\n    --text-opacity: 1;\n    color: #fed7d7;\n    color: rgba(254, 215, 215, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-red-300 {\n    --text-opacity: 1;\n    color: #feb2b2;\n    color: rgba(254, 178, 178, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-red-400 {\n    --text-opacity: 1;\n    color: #fc8181;\n    color: rgba(252, 129, 129, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-red-500 {\n    --text-opacity: 1;\n    color: #f56565;\n    color: rgba(245, 101, 101, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-red-600 {\n    --text-opacity: 1;\n    color: #e53e3e;\n    color: rgba(229, 62, 62, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-red-700 {\n    --text-opacity: 1;\n    color: #c53030;\n    color: rgba(197, 48, 48, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-red-800 {\n    --text-opacity: 1;\n    color: #9b2c2c;\n    color: rgba(155, 44, 44, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-red-900 {\n    --text-opacity: 1;\n    color: #742a2a;\n    color: rgba(116, 42, 42, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-orange-100 {\n    --text-opacity: 1;\n    color: #fffaf0;\n    color: rgba(255, 250, 240, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-orange-200 {\n    --text-opacity: 1;\n    color: #feebc8;\n    color: rgba(254, 235, 200, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-orange-300 {\n    --text-opacity: 1;\n    color: #fbd38d;\n    color: rgba(251, 211, 141, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-orange-400 {\n    --text-opacity: 1;\n    color: #f6ad55;\n    color: rgba(246, 173, 85, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-orange-500 {\n    --text-opacity: 1;\n    color: #ed8936;\n    color: rgba(237, 137, 54, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-orange-600 {\n    --text-opacity: 1;\n    color: #dd6b20;\n    color: rgba(221, 107, 32, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-orange-700 {\n    --text-opacity: 1;\n    color: #c05621;\n    color: rgba(192, 86, 33, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-orange-800 {\n    --text-opacity: 1;\n    color: #9c4221;\n    color: rgba(156, 66, 33, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-orange-900 {\n    --text-opacity: 1;\n    color: #7b341e;\n    color: rgba(123, 52, 30, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-yellow-100 {\n    --text-opacity: 1;\n    color: #fffff0;\n    color: rgba(255, 255, 240, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-yellow-200 {\n    --text-opacity: 1;\n    color: #fefcbf;\n    color: rgba(254, 252, 191, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-yellow-300 {\n    --text-opacity: 1;\n    color: #faf089;\n    color: rgba(250, 240, 137, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-yellow-400 {\n    --text-opacity: 1;\n    color: #f6e05e;\n    color: rgba(246, 224, 94, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-yellow-500 {\n    --text-opacity: 1;\n    color: #ecc94b;\n    color: rgba(236, 201, 75, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-yellow-600 {\n    --text-opacity: 1;\n    color: #d69e2e;\n    color: rgba(214, 158, 46, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-yellow-700 {\n    --text-opacity: 1;\n    color: #b7791f;\n    color: rgba(183, 121, 31, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-yellow-800 {\n    --text-opacity: 1;\n    color: #975a16;\n    color: rgba(151, 90, 22, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-yellow-900 {\n    --text-opacity: 1;\n    color: #744210;\n    color: rgba(116, 66, 16, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-green-100 {\n    --text-opacity: 1;\n    color: #f0fff4;\n    color: rgba(240, 255, 244, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-green-200 {\n    --text-opacity: 1;\n    color: #c6f6d5;\n    color: rgba(198, 246, 213, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-green-300 {\n    --text-opacity: 1;\n    color: #9ae6b4;\n    color: rgba(154, 230, 180, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-green-400 {\n    --text-opacity: 1;\n    color: #68d391;\n    color: rgba(104, 211, 145, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-green-500 {\n    --text-opacity: 1;\n    color: #48bb78;\n    color: rgba(72, 187, 120, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-green-600 {\n    --text-opacity: 1;\n    color: #38a169;\n    color: rgba(56, 161, 105, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-green-700 {\n    --text-opacity: 1;\n    color: #2f855a;\n    color: rgba(47, 133, 90, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-green-800 {\n    --text-opacity: 1;\n    color: #276749;\n    color: rgba(39, 103, 73, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-green-900 {\n    --text-opacity: 1;\n    color: #22543d;\n    color: rgba(34, 84, 61, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-teal-100 {\n    --text-opacity: 1;\n    color: #e6fffa;\n    color: rgba(230, 255, 250, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-teal-200 {\n    --text-opacity: 1;\n    color: #b2f5ea;\n    color: rgba(178, 245, 234, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-teal-300 {\n    --text-opacity: 1;\n    color: #81e6d9;\n    color: rgba(129, 230, 217, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-teal-400 {\n    --text-opacity: 1;\n    color: #4fd1c5;\n    color: rgba(79, 209, 197, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-teal-500 {\n    --text-opacity: 1;\n    color: #38b2ac;\n    color: rgba(56, 178, 172, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-teal-600 {\n    --text-opacity: 1;\n    color: #319795;\n    color: rgba(49, 151, 149, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-teal-700 {\n    --text-opacity: 1;\n    color: #2c7a7b;\n    color: rgba(44, 122, 123, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-teal-800 {\n    --text-opacity: 1;\n    color: #285e61;\n    color: rgba(40, 94, 97, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-teal-900 {\n    --text-opacity: 1;\n    color: #234e52;\n    color: rgba(35, 78, 82, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-blue-100 {\n    --text-opacity: 1;\n    color: #ebf8ff;\n    color: rgba(235, 248, 255, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-blue-200 {\n    --text-opacity: 1;\n    color: #bee3f8;\n    color: rgba(190, 227, 248, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-blue-300 {\n    --text-opacity: 1;\n    color: #90cdf4;\n    color: rgba(144, 205, 244, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-blue-400 {\n    --text-opacity: 1;\n    color: #63b3ed;\n    color: rgba(99, 179, 237, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-blue-500 {\n    --text-opacity: 1;\n    color: #4299e1;\n    color: rgba(66, 153, 225, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-blue-600 {\n    --text-opacity: 1;\n    color: #3182ce;\n    color: rgba(49, 130, 206, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-blue-700 {\n    --text-opacity: 1;\n    color: #2b6cb0;\n    color: rgba(43, 108, 176, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-blue-800 {\n    --text-opacity: 1;\n    color: #2c5282;\n    color: rgba(44, 82, 130, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-blue-900 {\n    --text-opacity: 1;\n    color: #2a4365;\n    color: rgba(42, 67, 101, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-indigo-100 {\n    --text-opacity: 1;\n    color: #ebf4ff;\n    color: rgba(235, 244, 255, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-indigo-200 {\n    --text-opacity: 1;\n    color: #c3dafe;\n    color: rgba(195, 218, 254, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-indigo-300 {\n    --text-opacity: 1;\n    color: #a3bffa;\n    color: rgba(163, 191, 250, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-indigo-400 {\n    --text-opacity: 1;\n    color: #7f9cf5;\n    color: rgba(127, 156, 245, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-indigo-500 {\n    --text-opacity: 1;\n    color: #667eea;\n    color: rgba(102, 126, 234, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-indigo-600 {\n    --text-opacity: 1;\n    color: #5a67d8;\n    color: rgba(90, 103, 216, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-indigo-700 {\n    --text-opacity: 1;\n    color: #4c51bf;\n    color: rgba(76, 81, 191, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-indigo-800 {\n    --text-opacity: 1;\n    color: #434190;\n    color: rgba(67, 65, 144, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-indigo-900 {\n    --text-opacity: 1;\n    color: #3c366b;\n    color: rgba(60, 54, 107, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-purple-100 {\n    --text-opacity: 1;\n    color: #faf5ff;\n    color: rgba(250, 245, 255, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-purple-200 {\n    --text-opacity: 1;\n    color: #e9d8fd;\n    color: rgba(233, 216, 253, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-purple-300 {\n    --text-opacity: 1;\n    color: #d6bcfa;\n    color: rgba(214, 188, 250, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-purple-400 {\n    --text-opacity: 1;\n    color: #b794f4;\n    color: rgba(183, 148, 244, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-purple-500 {\n    --text-opacity: 1;\n    color: #9f7aea;\n    color: rgba(159, 122, 234, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-purple-600 {\n    --text-opacity: 1;\n    color: #805ad5;\n    color: rgba(128, 90, 213, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-purple-700 {\n    --text-opacity: 1;\n    color: #6b46c1;\n    color: rgba(107, 70, 193, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-purple-800 {\n    --text-opacity: 1;\n    color: #553c9a;\n    color: rgba(85, 60, 154, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-purple-900 {\n    --text-opacity: 1;\n    color: #44337a;\n    color: rgba(68, 51, 122, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-pink-100 {\n    --text-opacity: 1;\n    color: #fff5f7;\n    color: rgba(255, 245, 247, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-pink-200 {\n    --text-opacity: 1;\n    color: #fed7e2;\n    color: rgba(254, 215, 226, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-pink-300 {\n    --text-opacity: 1;\n    color: #fbb6ce;\n    color: rgba(251, 182, 206, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-pink-400 {\n    --text-opacity: 1;\n    color: #f687b3;\n    color: rgba(246, 135, 179, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-pink-500 {\n    --text-opacity: 1;\n    color: #ed64a6;\n    color: rgba(237, 100, 166, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-pink-600 {\n    --text-opacity: 1;\n    color: #d53f8c;\n    color: rgba(213, 63, 140, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-pink-700 {\n    --text-opacity: 1;\n    color: #b83280;\n    color: rgba(184, 50, 128, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-pink-800 {\n    --text-opacity: 1;\n    color: #97266d;\n    color: rgba(151, 38, 109, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-pink-900 {\n    --text-opacity: 1;\n    color: #702459;\n    color: rgba(112, 36, 89, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-grayscale-80 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 8%);\n    color: rgba(20.400000000000002, 20.400000000000002, 20.400000000000002, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-grayscale-100 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 10%);\n    color: rgba(25.5, 25.5, 25.5, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-grayscale-200 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 20%);\n    color: rgba(51, 51, 51, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-grayscale-300 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 30%);\n    color: rgba(76.5, 76.5, 76.5, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-grayscale-400 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 40%);\n    color: rgba(102, 102, 102, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-grayscale-500 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 50%);\n    color: rgba(127.5, 127.5, 127.5, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-grayscale-600 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 60%);\n    color: rgba(153, 153, 153, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-grayscale-700 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 70%);\n    color: rgba(178.5, 178.5, 178.5, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-grayscale-800 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 80%);\n    color: rgba(204, 204, 204, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-grayscale-840 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 84%);\n    color: rgba(214.2, 214.2, 214.2, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-grayscale-870 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 87%);\n    color: rgba(221.85, 221.85, 221.85, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-grayscale-900 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 90%);\n    color: rgba(229.5, 229.5, 229.5, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-grayscale-930 {\n    --text-opacity: 1;\n    color: hsl(0, 0%, 93%);\n    color: rgba(237.15, 237.15, 237.15, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-primary {\n    --text-opacity: 1;\n    color: hsl(210, 100%, 52%);\n    color: rgba(10.20000000000001, 132.59999999999988, 255, var(--text-opacity));\n  }\n\n  .group:hover .xl\\:group-hover\\:text-background-main {\n    color: var(--main-background);\n  }\n\n  .group:hover .xl\\:group-hover\\:text-background-secondary {\n    color: var(--secondary-background);\n  }\n\n  .group:hover .xl\\:group-hover\\:text-foreground {\n    color: var(--foreground);\n  }\n\n  .group:hover .xl\\:group-hover\\:text-panels-bg {\n    color: var(--panels-background);\n  }\n\n  .xl\\:text-opacity-0 {\n    --text-opacity: 0;\n  }\n\n  .xl\\:text-opacity-25 {\n    --text-opacity: 0.25;\n  }\n\n  .xl\\:text-opacity-50 {\n    --text-opacity: 0.5;\n  }\n\n  .xl\\:text-opacity-75 {\n    --text-opacity: 0.75;\n  }\n\n  .xl\\:text-opacity-100 {\n    --text-opacity: 1;\n  }\n\n  .xl\\:hover\\:text-opacity-0:hover {\n    --text-opacity: 0;\n  }\n\n  .xl\\:hover\\:text-opacity-25:hover {\n    --text-opacity: 0.25;\n  }\n\n  .xl\\:hover\\:text-opacity-50:hover {\n    --text-opacity: 0.5;\n  }\n\n  .xl\\:hover\\:text-opacity-75:hover {\n    --text-opacity: 0.75;\n  }\n\n  .xl\\:hover\\:text-opacity-100:hover {\n    --text-opacity: 1;\n  }\n\n  .xl\\:focus\\:text-opacity-0:focus {\n    --text-opacity: 0;\n  }\n\n  .xl\\:focus\\:text-opacity-25:focus {\n    --text-opacity: 0.25;\n  }\n\n  .xl\\:focus\\:text-opacity-50:focus {\n    --text-opacity: 0.5;\n  }\n\n  .xl\\:focus\\:text-opacity-75:focus {\n    --text-opacity: 0.75;\n  }\n\n  .xl\\:focus\\:text-opacity-100:focus {\n    --text-opacity: 1;\n  }\n\n  .xl\\:italic {\n    font-style: italic;\n  }\n\n  .xl\\:not-italic {\n    font-style: normal;\n  }\n\n  .xl\\:uppercase {\n    text-transform: uppercase;\n  }\n\n  .xl\\:lowercase {\n    text-transform: lowercase;\n  }\n\n  .xl\\:capitalize {\n    text-transform: capitalize;\n  }\n\n  .xl\\:normal-case {\n    text-transform: none;\n  }\n\n  .xl\\:underline {\n    text-decoration: underline;\n  }\n\n  .xl\\:line-through {\n    text-decoration: line-through;\n  }\n\n  .xl\\:no-underline {\n    text-decoration: none;\n  }\n\n  .xl\\:hover\\:underline:hover {\n    text-decoration: underline;\n  }\n\n  .xl\\:hover\\:line-through:hover {\n    text-decoration: line-through;\n  }\n\n  .xl\\:hover\\:no-underline:hover {\n    text-decoration: none;\n  }\n\n  .xl\\:focus\\:underline:focus {\n    text-decoration: underline;\n  }\n\n  .xl\\:focus\\:line-through:focus {\n    text-decoration: line-through;\n  }\n\n  .xl\\:focus\\:no-underline:focus {\n    text-decoration: none;\n  }\n\n  .xl\\:antialiased {\n    -webkit-font-smoothing: antialiased;\n    -moz-osx-font-smoothing: grayscale;\n  }\n\n  .xl\\:subpixel-antialiased {\n    -webkit-font-smoothing: auto;\n    -moz-osx-font-smoothing: auto;\n  }\n\n  .xl\\:ordinal, .xl\\:slashed-zero, .xl\\:lining-nums, .xl\\:oldstyle-nums, .xl\\:proportional-nums, .xl\\:tabular-nums, .xl\\:diagonal-fractions, .xl\\:stacked-fractions {\n    --font-variant-numeric-ordinal: var(--tailwind-empty,/*!*/ /*!*/);\n    --font-variant-numeric-slashed-zero: var(--tailwind-empty,/*!*/ /*!*/);\n    --font-variant-numeric-figure: var(--tailwind-empty,/*!*/ /*!*/);\n    --font-variant-numeric-spacing: var(--tailwind-empty,/*!*/ /*!*/);\n    --font-variant-numeric-fraction: var(--tailwind-empty,/*!*/ /*!*/);\n    font-variant-numeric: var(--font-variant-numeric-ordinal) var(--font-variant-numeric-slashed-zero) var(--font-variant-numeric-figure) var(--font-variant-numeric-spacing) var(--font-variant-numeric-fraction);\n  }\n\n  .xl\\:normal-nums {\n    font-variant-numeric: normal;\n  }\n\n  .xl\\:ordinal {\n    --font-variant-numeric-ordinal: ordinal;\n  }\n\n  .xl\\:slashed-zero {\n    --font-variant-numeric-slashed-zero: slashed-zero;\n  }\n\n  .xl\\:lining-nums {\n    --font-variant-numeric-figure: lining-nums;\n  }\n\n  .xl\\:oldstyle-nums {\n    --font-variant-numeric-figure: oldstyle-nums;\n  }\n\n  .xl\\:proportional-nums {\n    --font-variant-numeric-spacing: proportional-nums;\n  }\n\n  .xl\\:tabular-nums {\n    --font-variant-numeric-spacing: tabular-nums;\n  }\n\n  .xl\\:diagonal-fractions {\n    --font-variant-numeric-fraction: diagonal-fractions;\n  }\n\n  .xl\\:stacked-fractions {\n    --font-variant-numeric-fraction: stacked-fractions;\n  }\n\n  .xl\\:tracking-tighter {\n    letter-spacing: -0.05em;\n  }\n\n  .xl\\:tracking-tight {\n    letter-spacing: -0.025em;\n  }\n\n  .xl\\:tracking-normal {\n    letter-spacing: 0;\n  }\n\n  .xl\\:tracking-wide {\n    letter-spacing: 0.025em;\n  }\n\n  .xl\\:tracking-wider {\n    letter-spacing: 0.05em;\n  }\n\n  .xl\\:tracking-widest {\n    letter-spacing: 0.1em;\n  }\n\n  .xl\\:select-none {\n    -webkit-user-select: none;\n       -moz-user-select: none;\n        -ms-user-select: none;\n            user-select: none;\n  }\n\n  .xl\\:select-text {\n    -webkit-user-select: text;\n       -moz-user-select: text;\n        -ms-user-select: text;\n            user-select: text;\n  }\n\n  .xl\\:select-all {\n    -webkit-user-select: all;\n       -moz-user-select: all;\n        -ms-user-select: all;\n            user-select: all;\n  }\n\n  .xl\\:select-auto {\n    -webkit-user-select: auto;\n       -moz-user-select: auto;\n        -ms-user-select: auto;\n            user-select: auto;\n  }\n\n  .xl\\:align-baseline {\n    vertical-align: baseline;\n  }\n\n  .xl\\:align-top {\n    vertical-align: top;\n  }\n\n  .xl\\:align-middle {\n    vertical-align: middle;\n  }\n\n  .xl\\:align-bottom {\n    vertical-align: bottom;\n  }\n\n  .xl\\:align-text-top {\n    vertical-align: text-top;\n  }\n\n  .xl\\:align-text-bottom {\n    vertical-align: text-bottom;\n  }\n\n  .xl\\:visible {\n    visibility: visible;\n  }\n\n  .xl\\:invisible {\n    visibility: hidden;\n  }\n\n  .xl\\:whitespace-normal {\n    white-space: normal;\n  }\n\n  .xl\\:whitespace-no-wrap {\n    white-space: nowrap;\n  }\n\n  .xl\\:whitespace-pre {\n    white-space: pre;\n  }\n\n  .xl\\:whitespace-pre-line {\n    white-space: pre-line;\n  }\n\n  .xl\\:whitespace-pre-wrap {\n    white-space: pre-wrap;\n  }\n\n  .xl\\:break-normal {\n    word-wrap: normal;\n    overflow-wrap: normal;\n    word-break: normal;\n  }\n\n  .xl\\:break-words {\n    word-wrap: break-word;\n    overflow-wrap: break-word;\n  }\n\n  .xl\\:break-all {\n    word-break: break-all;\n  }\n\n  .xl\\:truncate {\n    overflow: hidden;\n    text-overflow: ellipsis;\n    white-space: nowrap;\n  }\n\n  .xl\\:w-0 {\n    width: 0;\n  }\n\n  .xl\\:w-1 {\n    width: 0.25rem;\n  }\n\n  .xl\\:w-2 {\n    width: 0.5rem;\n  }\n\n  .xl\\:w-3 {\n    width: 0.75rem;\n  }\n\n  .xl\\:w-4 {\n    width: 1rem;\n  }\n\n  .xl\\:w-5 {\n    width: 1.25rem;\n  }\n\n  .xl\\:w-6 {\n    width: 1.5rem;\n  }\n\n  .xl\\:w-8 {\n    width: 2rem;\n  }\n\n  .xl\\:w-10 {\n    width: 2.5rem;\n  }\n\n  .xl\\:w-12 {\n    width: 3rem;\n  }\n\n  .xl\\:w-16 {\n    width: 4rem;\n  }\n\n  .xl\\:w-20 {\n    width: 5rem;\n  }\n\n  .xl\\:w-24 {\n    width: 6rem;\n  }\n\n  .xl\\:w-32 {\n    width: 8rem;\n  }\n\n  .xl\\:w-40 {\n    width: 10rem;\n  }\n\n  .xl\\:w-48 {\n    width: 12rem;\n  }\n\n  .xl\\:w-56 {\n    width: 14rem;\n  }\n\n  .xl\\:w-64 {\n    width: 16rem;\n  }\n\n  .xl\\:w-auto {\n    width: auto;\n  }\n\n  .xl\\:w-px {\n    width: 1px;\n  }\n\n  .xl\\:w-1\\/2 {\n    width: 50%;\n  }\n\n  .xl\\:w-1\\/3 {\n    width: 33.333333%;\n  }\n\n  .xl\\:w-2\\/3 {\n    width: 66.666667%;\n  }\n\n  .xl\\:w-1\\/4 {\n    width: 25%;\n  }\n\n  .xl\\:w-2\\/4 {\n    width: 50%;\n  }\n\n  .xl\\:w-3\\/4 {\n    width: 75%;\n  }\n\n  .xl\\:w-1\\/5 {\n    width: 20%;\n  }\n\n  .xl\\:w-2\\/5 {\n    width: 40%;\n  }\n\n  .xl\\:w-3\\/5 {\n    width: 60%;\n  }\n\n  .xl\\:w-4\\/5 {\n    width: 80%;\n  }\n\n  .xl\\:w-1\\/6 {\n    width: 16.666667%;\n  }\n\n  .xl\\:w-2\\/6 {\n    width: 33.333333%;\n  }\n\n  .xl\\:w-3\\/6 {\n    width: 50%;\n  }\n\n  .xl\\:w-4\\/6 {\n    width: 66.666667%;\n  }\n\n  .xl\\:w-5\\/6 {\n    width: 83.333333%;\n  }\n\n  .xl\\:w-1\\/12 {\n    width: 8.333333%;\n  }\n\n  .xl\\:w-2\\/12 {\n    width: 16.666667%;\n  }\n\n  .xl\\:w-3\\/12 {\n    width: 25%;\n  }\n\n  .xl\\:w-4\\/12 {\n    width: 33.333333%;\n  }\n\n  .xl\\:w-5\\/12 {\n    width: 41.666667%;\n  }\n\n  .xl\\:w-6\\/12 {\n    width: 50%;\n  }\n\n  .xl\\:w-7\\/12 {\n    width: 58.333333%;\n  }\n\n  .xl\\:w-8\\/12 {\n    width: 66.666667%;\n  }\n\n  .xl\\:w-9\\/12 {\n    width: 75%;\n  }\n\n  .xl\\:w-10\\/12 {\n    width: 83.333333%;\n  }\n\n  .xl\\:w-11\\/12 {\n    width: 91.666667%;\n  }\n\n  .xl\\:w-full {\n    width: 100%;\n  }\n\n  .xl\\:w-screen {\n    width: 100vw;\n  }\n\n  .xl\\:z-0 {\n    z-index: 0;\n  }\n\n  .xl\\:z-10 {\n    z-index: 10;\n  }\n\n  .xl\\:z-20 {\n    z-index: 20;\n  }\n\n  .xl\\:z-30 {\n    z-index: 30;\n  }\n\n  .xl\\:z-40 {\n    z-index: 40;\n  }\n\n  .xl\\:z-50 {\n    z-index: 50;\n  }\n\n  .xl\\:z-auto {\n    z-index: auto;\n  }\n\n  .xl\\:gap-0 {\n    grid-gap: 0;\n    gap: 0;\n  }\n\n  .xl\\:gap-1 {\n    grid-gap: 0.25rem;\n    gap: 0.25rem;\n  }\n\n  .xl\\:gap-2 {\n    grid-gap: 0.5rem;\n    gap: 0.5rem;\n  }\n\n  .xl\\:gap-3 {\n    grid-gap: 0.75rem;\n    gap: 0.75rem;\n  }\n\n  .xl\\:gap-4 {\n    grid-gap: 1rem;\n    gap: 1rem;\n  }\n\n  .xl\\:gap-5 {\n    grid-gap: 1.25rem;\n    gap: 1.25rem;\n  }\n\n  .xl\\:gap-6 {\n    grid-gap: 1.5rem;\n    gap: 1.5rem;\n  }\n\n  .xl\\:gap-8 {\n    grid-gap: 2rem;\n    gap: 2rem;\n  }\n\n  .xl\\:gap-10 {\n    grid-gap: 2.5rem;\n    gap: 2.5rem;\n  }\n\n  .xl\\:gap-12 {\n    grid-gap: 3rem;\n    gap: 3rem;\n  }\n\n  .xl\\:gap-16 {\n    grid-gap: 4rem;\n    gap: 4rem;\n  }\n\n  .xl\\:gap-20 {\n    grid-gap: 5rem;\n    gap: 5rem;\n  }\n\n  .xl\\:gap-24 {\n    grid-gap: 6rem;\n    gap: 6rem;\n  }\n\n  .xl\\:gap-32 {\n    grid-gap: 8rem;\n    gap: 8rem;\n  }\n\n  .xl\\:gap-40 {\n    grid-gap: 10rem;\n    gap: 10rem;\n  }\n\n  .xl\\:gap-48 {\n    grid-gap: 12rem;\n    gap: 12rem;\n  }\n\n  .xl\\:gap-56 {\n    grid-gap: 14rem;\n    gap: 14rem;\n  }\n\n  .xl\\:gap-64 {\n    grid-gap: 16rem;\n    gap: 16rem;\n  }\n\n  .xl\\:gap-px {\n    grid-gap: 1px;\n    gap: 1px;\n  }\n\n  .xl\\:gap-x-0 {\n    grid-column-gap: 0;\n    -moz-column-gap: 0;\n         column-gap: 0;\n  }\n\n  .xl\\:gap-x-1 {\n    grid-column-gap: 0.25rem;\n    -moz-column-gap: 0.25rem;\n         column-gap: 0.25rem;\n  }\n\n  .xl\\:gap-x-2 {\n    grid-column-gap: 0.5rem;\n    -moz-column-gap: 0.5rem;\n         column-gap: 0.5rem;\n  }\n\n  .xl\\:gap-x-3 {\n    grid-column-gap: 0.75rem;\n    -moz-column-gap: 0.75rem;\n         column-gap: 0.75rem;\n  }\n\n  .xl\\:gap-x-4 {\n    grid-column-gap: 1rem;\n    -moz-column-gap: 1rem;\n         column-gap: 1rem;\n  }\n\n  .xl\\:gap-x-5 {\n    grid-column-gap: 1.25rem;\n    -moz-column-gap: 1.25rem;\n         column-gap: 1.25rem;\n  }\n\n  .xl\\:gap-x-6 {\n    grid-column-gap: 1.5rem;\n    -moz-column-gap: 1.5rem;\n         column-gap: 1.5rem;\n  }\n\n  .xl\\:gap-x-8 {\n    grid-column-gap: 2rem;\n    -moz-column-gap: 2rem;\n         column-gap: 2rem;\n  }\n\n  .xl\\:gap-x-10 {\n    grid-column-gap: 2.5rem;\n    -moz-column-gap: 2.5rem;\n         column-gap: 2.5rem;\n  }\n\n  .xl\\:gap-x-12 {\n    grid-column-gap: 3rem;\n    -moz-column-gap: 3rem;\n         column-gap: 3rem;\n  }\n\n  .xl\\:gap-x-16 {\n    grid-column-gap: 4rem;\n    -moz-column-gap: 4rem;\n         column-gap: 4rem;\n  }\n\n  .xl\\:gap-x-20 {\n    grid-column-gap: 5rem;\n    -moz-column-gap: 5rem;\n         column-gap: 5rem;\n  }\n\n  .xl\\:gap-x-24 {\n    grid-column-gap: 6rem;\n    -moz-column-gap: 6rem;\n         column-gap: 6rem;\n  }\n\n  .xl\\:gap-x-32 {\n    grid-column-gap: 8rem;\n    -moz-column-gap: 8rem;\n         column-gap: 8rem;\n  }\n\n  .xl\\:gap-x-40 {\n    grid-column-gap: 10rem;\n    -moz-column-gap: 10rem;\n         column-gap: 10rem;\n  }\n\n  .xl\\:gap-x-48 {\n    grid-column-gap: 12rem;\n    -moz-column-gap: 12rem;\n         column-gap: 12rem;\n  }\n\n  .xl\\:gap-x-56 {\n    grid-column-gap: 14rem;\n    -moz-column-gap: 14rem;\n         column-gap: 14rem;\n  }\n\n  .xl\\:gap-x-64 {\n    grid-column-gap: 16rem;\n    -moz-column-gap: 16rem;\n         column-gap: 16rem;\n  }\n\n  .xl\\:gap-x-px {\n    grid-column-gap: 1px;\n    -moz-column-gap: 1px;\n         column-gap: 1px;\n  }\n\n  .xl\\:gap-y-0 {\n    grid-row-gap: 0;\n    row-gap: 0;\n  }\n\n  .xl\\:gap-y-1 {\n    grid-row-gap: 0.25rem;\n    row-gap: 0.25rem;\n  }\n\n  .xl\\:gap-y-2 {\n    grid-row-gap: 0.5rem;\n    row-gap: 0.5rem;\n  }\n\n  .xl\\:gap-y-3 {\n    grid-row-gap: 0.75rem;\n    row-gap: 0.75rem;\n  }\n\n  .xl\\:gap-y-4 {\n    grid-row-gap: 1rem;\n    row-gap: 1rem;\n  }\n\n  .xl\\:gap-y-5 {\n    grid-row-gap: 1.25rem;\n    row-gap: 1.25rem;\n  }\n\n  .xl\\:gap-y-6 {\n    grid-row-gap: 1.5rem;\n    row-gap: 1.5rem;\n  }\n\n  .xl\\:gap-y-8 {\n    grid-row-gap: 2rem;\n    row-gap: 2rem;\n  }\n\n  .xl\\:gap-y-10 {\n    grid-row-gap: 2.5rem;\n    row-gap: 2.5rem;\n  }\n\n  .xl\\:gap-y-12 {\n    grid-row-gap: 3rem;\n    row-gap: 3rem;\n  }\n\n  .xl\\:gap-y-16 {\n    grid-row-gap: 4rem;\n    row-gap: 4rem;\n  }\n\n  .xl\\:gap-y-20 {\n    grid-row-gap: 5rem;\n    row-gap: 5rem;\n  }\n\n  .xl\\:gap-y-24 {\n    grid-row-gap: 6rem;\n    row-gap: 6rem;\n  }\n\n  .xl\\:gap-y-32 {\n    grid-row-gap: 8rem;\n    row-gap: 8rem;\n  }\n\n  .xl\\:gap-y-40 {\n    grid-row-gap: 10rem;\n    row-gap: 10rem;\n  }\n\n  .xl\\:gap-y-48 {\n    grid-row-gap: 12rem;\n    row-gap: 12rem;\n  }\n\n  .xl\\:gap-y-56 {\n    grid-row-gap: 14rem;\n    row-gap: 14rem;\n  }\n\n  .xl\\:gap-y-64 {\n    grid-row-gap: 16rem;\n    row-gap: 16rem;\n  }\n\n  .xl\\:gap-y-px {\n    grid-row-gap: 1px;\n    row-gap: 1px;\n  }\n\n  .xl\\:grid-flow-row {\n    grid-auto-flow: row;\n  }\n\n  .xl\\:grid-flow-col {\n    grid-auto-flow: column;\n  }\n\n  .xl\\:grid-flow-row-dense {\n    grid-auto-flow: row dense;\n  }\n\n  .xl\\:grid-flow-col-dense {\n    grid-auto-flow: column dense;\n  }\n\n  .xl\\:grid-cols-1 {\n    grid-template-columns: repeat(1, minmax(0, 1fr));\n  }\n\n  .xl\\:grid-cols-2 {\n    grid-template-columns: repeat(2, minmax(0, 1fr));\n  }\n\n  .xl\\:grid-cols-3 {\n    grid-template-columns: repeat(3, minmax(0, 1fr));\n  }\n\n  .xl\\:grid-cols-4 {\n    grid-template-columns: repeat(4, minmax(0, 1fr));\n  }\n\n  .xl\\:grid-cols-5 {\n    grid-template-columns: repeat(5, minmax(0, 1fr));\n  }\n\n  .xl\\:grid-cols-6 {\n    grid-template-columns: repeat(6, minmax(0, 1fr));\n  }\n\n  .xl\\:grid-cols-7 {\n    grid-template-columns: repeat(7, minmax(0, 1fr));\n  }\n\n  .xl\\:grid-cols-8 {\n    grid-template-columns: repeat(8, minmax(0, 1fr));\n  }\n\n  .xl\\:grid-cols-9 {\n    grid-template-columns: repeat(9, minmax(0, 1fr));\n  }\n\n  .xl\\:grid-cols-10 {\n    grid-template-columns: repeat(10, minmax(0, 1fr));\n  }\n\n  .xl\\:grid-cols-11 {\n    grid-template-columns: repeat(11, minmax(0, 1fr));\n  }\n\n  .xl\\:grid-cols-12 {\n    grid-template-columns: repeat(12, minmax(0, 1fr));\n  }\n\n  .xl\\:grid-cols-none {\n    grid-template-columns: none;\n  }\n\n  .xl\\:auto-cols-auto {\n    grid-auto-columns: auto;\n  }\n\n  .xl\\:auto-cols-min {\n    grid-auto-columns: -webkit-min-content;\n    grid-auto-columns: min-content;\n  }\n\n  .xl\\:auto-cols-max {\n    grid-auto-columns: -webkit-max-content;\n    grid-auto-columns: max-content;\n  }\n\n  .xl\\:auto-cols-fr {\n    grid-auto-columns: minmax(0, 1fr);\n  }\n\n  .xl\\:col-auto {\n    grid-column: auto;\n  }\n\n  .xl\\:col-span-1 {\n    grid-column: span 1 / span 1;\n  }\n\n  .xl\\:col-span-2 {\n    grid-column: span 2 / span 2;\n  }\n\n  .xl\\:col-span-3 {\n    grid-column: span 3 / span 3;\n  }\n\n  .xl\\:col-span-4 {\n    grid-column: span 4 / span 4;\n  }\n\n  .xl\\:col-span-5 {\n    grid-column: span 5 / span 5;\n  }\n\n  .xl\\:col-span-6 {\n    grid-column: span 6 / span 6;\n  }\n\n  .xl\\:col-span-7 {\n    grid-column: span 7 / span 7;\n  }\n\n  .xl\\:col-span-8 {\n    grid-column: span 8 / span 8;\n  }\n\n  .xl\\:col-span-9 {\n    grid-column: span 9 / span 9;\n  }\n\n  .xl\\:col-span-10 {\n    grid-column: span 10 / span 10;\n  }\n\n  .xl\\:col-span-11 {\n    grid-column: span 11 / span 11;\n  }\n\n  .xl\\:col-span-12 {\n    grid-column: span 12 / span 12;\n  }\n\n  .xl\\:col-span-full {\n    grid-column: 1 / -1;\n  }\n\n  .xl\\:col-start-1 {\n    grid-column-start: 1;\n  }\n\n  .xl\\:col-start-2 {\n    grid-column-start: 2;\n  }\n\n  .xl\\:col-start-3 {\n    grid-column-start: 3;\n  }\n\n  .xl\\:col-start-4 {\n    grid-column-start: 4;\n  }\n\n  .xl\\:col-start-5 {\n    grid-column-start: 5;\n  }\n\n  .xl\\:col-start-6 {\n    grid-column-start: 6;\n  }\n\n  .xl\\:col-start-7 {\n    grid-column-start: 7;\n  }\n\n  .xl\\:col-start-8 {\n    grid-column-start: 8;\n  }\n\n  .xl\\:col-start-9 {\n    grid-column-start: 9;\n  }\n\n  .xl\\:col-start-10 {\n    grid-column-start: 10;\n  }\n\n  .xl\\:col-start-11 {\n    grid-column-start: 11;\n  }\n\n  .xl\\:col-start-12 {\n    grid-column-start: 12;\n  }\n\n  .xl\\:col-start-13 {\n    grid-column-start: 13;\n  }\n\n  .xl\\:col-start-auto {\n    grid-column-start: auto;\n  }\n\n  .xl\\:col-end-1 {\n    grid-column-end: 1;\n  }\n\n  .xl\\:col-end-2 {\n    grid-column-end: 2;\n  }\n\n  .xl\\:col-end-3 {\n    grid-column-end: 3;\n  }\n\n  .xl\\:col-end-4 {\n    grid-column-end: 4;\n  }\n\n  .xl\\:col-end-5 {\n    grid-column-end: 5;\n  }\n\n  .xl\\:col-end-6 {\n    grid-column-end: 6;\n  }\n\n  .xl\\:col-end-7 {\n    grid-column-end: 7;\n  }\n\n  .xl\\:col-end-8 {\n    grid-column-end: 8;\n  }\n\n  .xl\\:col-end-9 {\n    grid-column-end: 9;\n  }\n\n  .xl\\:col-end-10 {\n    grid-column-end: 10;\n  }\n\n  .xl\\:col-end-11 {\n    grid-column-end: 11;\n  }\n\n  .xl\\:col-end-12 {\n    grid-column-end: 12;\n  }\n\n  .xl\\:col-end-13 {\n    grid-column-end: 13;\n  }\n\n  .xl\\:col-end-auto {\n    grid-column-end: auto;\n  }\n\n  .xl\\:grid-rows-1 {\n    grid-template-rows: repeat(1, minmax(0, 1fr));\n  }\n\n  .xl\\:grid-rows-2 {\n    grid-template-rows: repeat(2, minmax(0, 1fr));\n  }\n\n  .xl\\:grid-rows-3 {\n    grid-template-rows: repeat(3, minmax(0, 1fr));\n  }\n\n  .xl\\:grid-rows-4 {\n    grid-template-rows: repeat(4, minmax(0, 1fr));\n  }\n\n  .xl\\:grid-rows-5 {\n    grid-template-rows: repeat(5, minmax(0, 1fr));\n  }\n\n  .xl\\:grid-rows-6 {\n    grid-template-rows: repeat(6, minmax(0, 1fr));\n  }\n\n  .xl\\:grid-rows-none {\n    grid-template-rows: none;\n  }\n\n  .xl\\:auto-rows-auto {\n    grid-auto-rows: auto;\n  }\n\n  .xl\\:auto-rows-min {\n    grid-auto-rows: -webkit-min-content;\n    grid-auto-rows: min-content;\n  }\n\n  .xl\\:auto-rows-max {\n    grid-auto-rows: -webkit-max-content;\n    grid-auto-rows: max-content;\n  }\n\n  .xl\\:auto-rows-fr {\n    grid-auto-rows: minmax(0, 1fr);\n  }\n\n  .xl\\:row-auto {\n    grid-row: auto;\n  }\n\n  .xl\\:row-span-1 {\n    grid-row: span 1 / span 1;\n  }\n\n  .xl\\:row-span-2 {\n    grid-row: span 2 / span 2;\n  }\n\n  .xl\\:row-span-3 {\n    grid-row: span 3 / span 3;\n  }\n\n  .xl\\:row-span-4 {\n    grid-row: span 4 / span 4;\n  }\n\n  .xl\\:row-span-5 {\n    grid-row: span 5 / span 5;\n  }\n\n  .xl\\:row-span-6 {\n    grid-row: span 6 / span 6;\n  }\n\n  .xl\\:row-span-full {\n    grid-row: 1 / -1;\n  }\n\n  .xl\\:row-start-1 {\n    grid-row-start: 1;\n  }\n\n  .xl\\:row-start-2 {\n    grid-row-start: 2;\n  }\n\n  .xl\\:row-start-3 {\n    grid-row-start: 3;\n  }\n\n  .xl\\:row-start-4 {\n    grid-row-start: 4;\n  }\n\n  .xl\\:row-start-5 {\n    grid-row-start: 5;\n  }\n\n  .xl\\:row-start-6 {\n    grid-row-start: 6;\n  }\n\n  .xl\\:row-start-7 {\n    grid-row-start: 7;\n  }\n\n  .xl\\:row-start-auto {\n    grid-row-start: auto;\n  }\n\n  .xl\\:row-end-1 {\n    grid-row-end: 1;\n  }\n\n  .xl\\:row-end-2 {\n    grid-row-end: 2;\n  }\n\n  .xl\\:row-end-3 {\n    grid-row-end: 3;\n  }\n\n  .xl\\:row-end-4 {\n    grid-row-end: 4;\n  }\n\n  .xl\\:row-end-5 {\n    grid-row-end: 5;\n  }\n\n  .xl\\:row-end-6 {\n    grid-row-end: 6;\n  }\n\n  .xl\\:row-end-7 {\n    grid-row-end: 7;\n  }\n\n  .xl\\:row-end-auto {\n    grid-row-end: auto;\n  }\n\n  .xl\\:transform {\n    --transform-translate-x: 0;\n    --transform-translate-y: 0;\n    --transform-rotate: 0;\n    --transform-skew-x: 0;\n    --transform-skew-y: 0;\n    --transform-scale-x: 1;\n    --transform-scale-y: 1;\n    transform: translateX(var(--transform-translate-x)) translateY(var(--transform-translate-y)) rotate(var(--transform-rotate)) skewX(var(--transform-skew-x)) skewY(var(--transform-skew-y)) scaleX(var(--transform-scale-x)) scaleY(var(--transform-scale-y));\n  }\n\n  .xl\\:transform-none {\n    transform: none;\n  }\n\n  .xl\\:origin-center {\n    transform-origin: center;\n  }\n\n  .xl\\:origin-top {\n    transform-origin: top;\n  }\n\n  .xl\\:origin-top-right {\n    transform-origin: top right;\n  }\n\n  .xl\\:origin-right {\n    transform-origin: right;\n  }\n\n  .xl\\:origin-bottom-right {\n    transform-origin: bottom right;\n  }\n\n  .xl\\:origin-bottom {\n    transform-origin: bottom;\n  }\n\n  .xl\\:origin-bottom-left {\n    transform-origin: bottom left;\n  }\n\n  .xl\\:origin-left {\n    transform-origin: left;\n  }\n\n  .xl\\:origin-top-left {\n    transform-origin: top left;\n  }\n\n  .xl\\:scale-0 {\n    --transform-scale-x: 0;\n    --transform-scale-y: 0;\n  }\n\n  .xl\\:scale-50 {\n    --transform-scale-x: .5;\n    --transform-scale-y: .5;\n  }\n\n  .xl\\:scale-75 {\n    --transform-scale-x: .75;\n    --transform-scale-y: .75;\n  }\n\n  .xl\\:scale-90 {\n    --transform-scale-x: .9;\n    --transform-scale-y: .9;\n  }\n\n  .xl\\:scale-95 {\n    --transform-scale-x: .95;\n    --transform-scale-y: .95;\n  }\n\n  .xl\\:scale-100 {\n    --transform-scale-x: 1;\n    --transform-scale-y: 1;\n  }\n\n  .xl\\:scale-105 {\n    --transform-scale-x: 1.05;\n    --transform-scale-y: 1.05;\n  }\n\n  .xl\\:scale-110 {\n    --transform-scale-x: 1.1;\n    --transform-scale-y: 1.1;\n  }\n\n  .xl\\:scale-125 {\n    --transform-scale-x: 1.25;\n    --transform-scale-y: 1.25;\n  }\n\n  .xl\\:scale-150 {\n    --transform-scale-x: 1.5;\n    --transform-scale-y: 1.5;\n  }\n\n  .xl\\:scale-x-0 {\n    --transform-scale-x: 0;\n  }\n\n  .xl\\:scale-x-50 {\n    --transform-scale-x: .5;\n  }\n\n  .xl\\:scale-x-75 {\n    --transform-scale-x: .75;\n  }\n\n  .xl\\:scale-x-90 {\n    --transform-scale-x: .9;\n  }\n\n  .xl\\:scale-x-95 {\n    --transform-scale-x: .95;\n  }\n\n  .xl\\:scale-x-100 {\n    --transform-scale-x: 1;\n  }\n\n  .xl\\:scale-x-105 {\n    --transform-scale-x: 1.05;\n  }\n\n  .xl\\:scale-x-110 {\n    --transform-scale-x: 1.1;\n  }\n\n  .xl\\:scale-x-125 {\n    --transform-scale-x: 1.25;\n  }\n\n  .xl\\:scale-x-150 {\n    --transform-scale-x: 1.5;\n  }\n\n  .xl\\:scale-y-0 {\n    --transform-scale-y: 0;\n  }\n\n  .xl\\:scale-y-50 {\n    --transform-scale-y: .5;\n  }\n\n  .xl\\:scale-y-75 {\n    --transform-scale-y: .75;\n  }\n\n  .xl\\:scale-y-90 {\n    --transform-scale-y: .9;\n  }\n\n  .xl\\:scale-y-95 {\n    --transform-scale-y: .95;\n  }\n\n  .xl\\:scale-y-100 {\n    --transform-scale-y: 1;\n  }\n\n  .xl\\:scale-y-105 {\n    --transform-scale-y: 1.05;\n  }\n\n  .xl\\:scale-y-110 {\n    --transform-scale-y: 1.1;\n  }\n\n  .xl\\:scale-y-125 {\n    --transform-scale-y: 1.25;\n  }\n\n  .xl\\:scale-y-150 {\n    --transform-scale-y: 1.5;\n  }\n\n  .xl\\:hover\\:scale-0:hover {\n    --transform-scale-x: 0;\n    --transform-scale-y: 0;\n  }\n\n  .xl\\:hover\\:scale-50:hover {\n    --transform-scale-x: .5;\n    --transform-scale-y: .5;\n  }\n\n  .xl\\:hover\\:scale-75:hover {\n    --transform-scale-x: .75;\n    --transform-scale-y: .75;\n  }\n\n  .xl\\:hover\\:scale-90:hover {\n    --transform-scale-x: .9;\n    --transform-scale-y: .9;\n  }\n\n  .xl\\:hover\\:scale-95:hover {\n    --transform-scale-x: .95;\n    --transform-scale-y: .95;\n  }\n\n  .xl\\:hover\\:scale-100:hover {\n    --transform-scale-x: 1;\n    --transform-scale-y: 1;\n  }\n\n  .xl\\:hover\\:scale-105:hover {\n    --transform-scale-x: 1.05;\n    --transform-scale-y: 1.05;\n  }\n\n  .xl\\:hover\\:scale-110:hover {\n    --transform-scale-x: 1.1;\n    --transform-scale-y: 1.1;\n  }\n\n  .xl\\:hover\\:scale-125:hover {\n    --transform-scale-x: 1.25;\n    --transform-scale-y: 1.25;\n  }\n\n  .xl\\:hover\\:scale-150:hover {\n    --transform-scale-x: 1.5;\n    --transform-scale-y: 1.5;\n  }\n\n  .xl\\:hover\\:scale-x-0:hover {\n    --transform-scale-x: 0;\n  }\n\n  .xl\\:hover\\:scale-x-50:hover {\n    --transform-scale-x: .5;\n  }\n\n  .xl\\:hover\\:scale-x-75:hover {\n    --transform-scale-x: .75;\n  }\n\n  .xl\\:hover\\:scale-x-90:hover {\n    --transform-scale-x: .9;\n  }\n\n  .xl\\:hover\\:scale-x-95:hover {\n    --transform-scale-x: .95;\n  }\n\n  .xl\\:hover\\:scale-x-100:hover {\n    --transform-scale-x: 1;\n  }\n\n  .xl\\:hover\\:scale-x-105:hover {\n    --transform-scale-x: 1.05;\n  }\n\n  .xl\\:hover\\:scale-x-110:hover {\n    --transform-scale-x: 1.1;\n  }\n\n  .xl\\:hover\\:scale-x-125:hover {\n    --transform-scale-x: 1.25;\n  }\n\n  .xl\\:hover\\:scale-x-150:hover {\n    --transform-scale-x: 1.5;\n  }\n\n  .xl\\:hover\\:scale-y-0:hover {\n    --transform-scale-y: 0;\n  }\n\n  .xl\\:hover\\:scale-y-50:hover {\n    --transform-scale-y: .5;\n  }\n\n  .xl\\:hover\\:scale-y-75:hover {\n    --transform-scale-y: .75;\n  }\n\n  .xl\\:hover\\:scale-y-90:hover {\n    --transform-scale-y: .9;\n  }\n\n  .xl\\:hover\\:scale-y-95:hover {\n    --transform-scale-y: .95;\n  }\n\n  .xl\\:hover\\:scale-y-100:hover {\n    --transform-scale-y: 1;\n  }\n\n  .xl\\:hover\\:scale-y-105:hover {\n    --transform-scale-y: 1.05;\n  }\n\n  .xl\\:hover\\:scale-y-110:hover {\n    --transform-scale-y: 1.1;\n  }\n\n  .xl\\:hover\\:scale-y-125:hover {\n    --transform-scale-y: 1.25;\n  }\n\n  .xl\\:hover\\:scale-y-150:hover {\n    --transform-scale-y: 1.5;\n  }\n\n  .xl\\:focus\\:scale-0:focus {\n    --transform-scale-x: 0;\n    --transform-scale-y: 0;\n  }\n\n  .xl\\:focus\\:scale-50:focus {\n    --transform-scale-x: .5;\n    --transform-scale-y: .5;\n  }\n\n  .xl\\:focus\\:scale-75:focus {\n    --transform-scale-x: .75;\n    --transform-scale-y: .75;\n  }\n\n  .xl\\:focus\\:scale-90:focus {\n    --transform-scale-x: .9;\n    --transform-scale-y: .9;\n  }\n\n  .xl\\:focus\\:scale-95:focus {\n    --transform-scale-x: .95;\n    --transform-scale-y: .95;\n  }\n\n  .xl\\:focus\\:scale-100:focus {\n    --transform-scale-x: 1;\n    --transform-scale-y: 1;\n  }\n\n  .xl\\:focus\\:scale-105:focus {\n    --transform-scale-x: 1.05;\n    --transform-scale-y: 1.05;\n  }\n\n  .xl\\:focus\\:scale-110:focus {\n    --transform-scale-x: 1.1;\n    --transform-scale-y: 1.1;\n  }\n\n  .xl\\:focus\\:scale-125:focus {\n    --transform-scale-x: 1.25;\n    --transform-scale-y: 1.25;\n  }\n\n  .xl\\:focus\\:scale-150:focus {\n    --transform-scale-x: 1.5;\n    --transform-scale-y: 1.5;\n  }\n\n  .xl\\:focus\\:scale-x-0:focus {\n    --transform-scale-x: 0;\n  }\n\n  .xl\\:focus\\:scale-x-50:focus {\n    --transform-scale-x: .5;\n  }\n\n  .xl\\:focus\\:scale-x-75:focus {\n    --transform-scale-x: .75;\n  }\n\n  .xl\\:focus\\:scale-x-90:focus {\n    --transform-scale-x: .9;\n  }\n\n  .xl\\:focus\\:scale-x-95:focus {\n    --transform-scale-x: .95;\n  }\n\n  .xl\\:focus\\:scale-x-100:focus {\n    --transform-scale-x: 1;\n  }\n\n  .xl\\:focus\\:scale-x-105:focus {\n    --transform-scale-x: 1.05;\n  }\n\n  .xl\\:focus\\:scale-x-110:focus {\n    --transform-scale-x: 1.1;\n  }\n\n  .xl\\:focus\\:scale-x-125:focus {\n    --transform-scale-x: 1.25;\n  }\n\n  .xl\\:focus\\:scale-x-150:focus {\n    --transform-scale-x: 1.5;\n  }\n\n  .xl\\:focus\\:scale-y-0:focus {\n    --transform-scale-y: 0;\n  }\n\n  .xl\\:focus\\:scale-y-50:focus {\n    --transform-scale-y: .5;\n  }\n\n  .xl\\:focus\\:scale-y-75:focus {\n    --transform-scale-y: .75;\n  }\n\n  .xl\\:focus\\:scale-y-90:focus {\n    --transform-scale-y: .9;\n  }\n\n  .xl\\:focus\\:scale-y-95:focus {\n    --transform-scale-y: .95;\n  }\n\n  .xl\\:focus\\:scale-y-100:focus {\n    --transform-scale-y: 1;\n  }\n\n  .xl\\:focus\\:scale-y-105:focus {\n    --transform-scale-y: 1.05;\n  }\n\n  .xl\\:focus\\:scale-y-110:focus {\n    --transform-scale-y: 1.1;\n  }\n\n  .xl\\:focus\\:scale-y-125:focus {\n    --transform-scale-y: 1.25;\n  }\n\n  .xl\\:focus\\:scale-y-150:focus {\n    --transform-scale-y: 1.5;\n  }\n\n  .xl\\:rotate-0 {\n    --transform-rotate: 0;\n  }\n\n  .xl\\:rotate-1 {\n    --transform-rotate: 1deg;\n  }\n\n  .xl\\:rotate-2 {\n    --transform-rotate: 2deg;\n  }\n\n  .xl\\:rotate-3 {\n    --transform-rotate: 3deg;\n  }\n\n  .xl\\:rotate-6 {\n    --transform-rotate: 6deg;\n  }\n\n  .xl\\:rotate-12 {\n    --transform-rotate: 12deg;\n  }\n\n  .xl\\:rotate-45 {\n    --transform-rotate: 45deg;\n  }\n\n  .xl\\:rotate-90 {\n    --transform-rotate: 90deg;\n  }\n\n  .xl\\:rotate-180 {\n    --transform-rotate: 180deg;\n  }\n\n  .xl\\:-rotate-180 {\n    --transform-rotate: -180deg;\n  }\n\n  .xl\\:-rotate-90 {\n    --transform-rotate: -90deg;\n  }\n\n  .xl\\:-rotate-45 {\n    --transform-rotate: -45deg;\n  }\n\n  .xl\\:-rotate-12 {\n    --transform-rotate: -12deg;\n  }\n\n  .xl\\:-rotate-6 {\n    --transform-rotate: -6deg;\n  }\n\n  .xl\\:-rotate-3 {\n    --transform-rotate: -3deg;\n  }\n\n  .xl\\:-rotate-2 {\n    --transform-rotate: -2deg;\n  }\n\n  .xl\\:-rotate-1 {\n    --transform-rotate: -1deg;\n  }\n\n  .xl\\:hover\\:rotate-0:hover {\n    --transform-rotate: 0;\n  }\n\n  .xl\\:hover\\:rotate-1:hover {\n    --transform-rotate: 1deg;\n  }\n\n  .xl\\:hover\\:rotate-2:hover {\n    --transform-rotate: 2deg;\n  }\n\n  .xl\\:hover\\:rotate-3:hover {\n    --transform-rotate: 3deg;\n  }\n\n  .xl\\:hover\\:rotate-6:hover {\n    --transform-rotate: 6deg;\n  }\n\n  .xl\\:hover\\:rotate-12:hover {\n    --transform-rotate: 12deg;\n  }\n\n  .xl\\:hover\\:rotate-45:hover {\n    --transform-rotate: 45deg;\n  }\n\n  .xl\\:hover\\:rotate-90:hover {\n    --transform-rotate: 90deg;\n  }\n\n  .xl\\:hover\\:rotate-180:hover {\n    --transform-rotate: 180deg;\n  }\n\n  .xl\\:hover\\:-rotate-180:hover {\n    --transform-rotate: -180deg;\n  }\n\n  .xl\\:hover\\:-rotate-90:hover {\n    --transform-rotate: -90deg;\n  }\n\n  .xl\\:hover\\:-rotate-45:hover {\n    --transform-rotate: -45deg;\n  }\n\n  .xl\\:hover\\:-rotate-12:hover {\n    --transform-rotate: -12deg;\n  }\n\n  .xl\\:hover\\:-rotate-6:hover {\n    --transform-rotate: -6deg;\n  }\n\n  .xl\\:hover\\:-rotate-3:hover {\n    --transform-rotate: -3deg;\n  }\n\n  .xl\\:hover\\:-rotate-2:hover {\n    --transform-rotate: -2deg;\n  }\n\n  .xl\\:hover\\:-rotate-1:hover {\n    --transform-rotate: -1deg;\n  }\n\n  .xl\\:focus\\:rotate-0:focus {\n    --transform-rotate: 0;\n  }\n\n  .xl\\:focus\\:rotate-1:focus {\n    --transform-rotate: 1deg;\n  }\n\n  .xl\\:focus\\:rotate-2:focus {\n    --transform-rotate: 2deg;\n  }\n\n  .xl\\:focus\\:rotate-3:focus {\n    --transform-rotate: 3deg;\n  }\n\n  .xl\\:focus\\:rotate-6:focus {\n    --transform-rotate: 6deg;\n  }\n\n  .xl\\:focus\\:rotate-12:focus {\n    --transform-rotate: 12deg;\n  }\n\n  .xl\\:focus\\:rotate-45:focus {\n    --transform-rotate: 45deg;\n  }\n\n  .xl\\:focus\\:rotate-90:focus {\n    --transform-rotate: 90deg;\n  }\n\n  .xl\\:focus\\:rotate-180:focus {\n    --transform-rotate: 180deg;\n  }\n\n  .xl\\:focus\\:-rotate-180:focus {\n    --transform-rotate: -180deg;\n  }\n\n  .xl\\:focus\\:-rotate-90:focus {\n    --transform-rotate: -90deg;\n  }\n\n  .xl\\:focus\\:-rotate-45:focus {\n    --transform-rotate: -45deg;\n  }\n\n  .xl\\:focus\\:-rotate-12:focus {\n    --transform-rotate: -12deg;\n  }\n\n  .xl\\:focus\\:-rotate-6:focus {\n    --transform-rotate: -6deg;\n  }\n\n  .xl\\:focus\\:-rotate-3:focus {\n    --transform-rotate: -3deg;\n  }\n\n  .xl\\:focus\\:-rotate-2:focus {\n    --transform-rotate: -2deg;\n  }\n\n  .xl\\:focus\\:-rotate-1:focus {\n    --transform-rotate: -1deg;\n  }\n\n  .xl\\:translate-x-0 {\n    --transform-translate-x: 0;\n  }\n\n  .xl\\:translate-x-1 {\n    --transform-translate-x: 0.25rem;\n  }\n\n  .xl\\:translate-x-2 {\n    --transform-translate-x: 0.5rem;\n  }\n\n  .xl\\:translate-x-3 {\n    --transform-translate-x: 0.75rem;\n  }\n\n  .xl\\:translate-x-4 {\n    --transform-translate-x: 1rem;\n  }\n\n  .xl\\:translate-x-5 {\n    --transform-translate-x: 1.25rem;\n  }\n\n  .xl\\:translate-x-6 {\n    --transform-translate-x: 1.5rem;\n  }\n\n  .xl\\:translate-x-8 {\n    --transform-translate-x: 2rem;\n  }\n\n  .xl\\:translate-x-10 {\n    --transform-translate-x: 2.5rem;\n  }\n\n  .xl\\:translate-x-12 {\n    --transform-translate-x: 3rem;\n  }\n\n  .xl\\:translate-x-16 {\n    --transform-translate-x: 4rem;\n  }\n\n  .xl\\:translate-x-20 {\n    --transform-translate-x: 5rem;\n  }\n\n  .xl\\:translate-x-24 {\n    --transform-translate-x: 6rem;\n  }\n\n  .xl\\:translate-x-32 {\n    --transform-translate-x: 8rem;\n  }\n\n  .xl\\:translate-x-40 {\n    --transform-translate-x: 10rem;\n  }\n\n  .xl\\:translate-x-48 {\n    --transform-translate-x: 12rem;\n  }\n\n  .xl\\:translate-x-56 {\n    --transform-translate-x: 14rem;\n  }\n\n  .xl\\:translate-x-64 {\n    --transform-translate-x: 16rem;\n  }\n\n  .xl\\:translate-x-px {\n    --transform-translate-x: 1px;\n  }\n\n  .xl\\:-translate-x-1 {\n    --transform-translate-x: -0.25rem;\n  }\n\n  .xl\\:-translate-x-2 {\n    --transform-translate-x: -0.5rem;\n  }\n\n  .xl\\:-translate-x-3 {\n    --transform-translate-x: -0.75rem;\n  }\n\n  .xl\\:-translate-x-4 {\n    --transform-translate-x: -1rem;\n  }\n\n  .xl\\:-translate-x-5 {\n    --transform-translate-x: -1.25rem;\n  }\n\n  .xl\\:-translate-x-6 {\n    --transform-translate-x: -1.5rem;\n  }\n\n  .xl\\:-translate-x-8 {\n    --transform-translate-x: -2rem;\n  }\n\n  .xl\\:-translate-x-10 {\n    --transform-translate-x: -2.5rem;\n  }\n\n  .xl\\:-translate-x-12 {\n    --transform-translate-x: -3rem;\n  }\n\n  .xl\\:-translate-x-16 {\n    --transform-translate-x: -4rem;\n  }\n\n  .xl\\:-translate-x-20 {\n    --transform-translate-x: -5rem;\n  }\n\n  .xl\\:-translate-x-24 {\n    --transform-translate-x: -6rem;\n  }\n\n  .xl\\:-translate-x-32 {\n    --transform-translate-x: -8rem;\n  }\n\n  .xl\\:-translate-x-40 {\n    --transform-translate-x: -10rem;\n  }\n\n  .xl\\:-translate-x-48 {\n    --transform-translate-x: -12rem;\n  }\n\n  .xl\\:-translate-x-56 {\n    --transform-translate-x: -14rem;\n  }\n\n  .xl\\:-translate-x-64 {\n    --transform-translate-x: -16rem;\n  }\n\n  .xl\\:-translate-x-px {\n    --transform-translate-x: -1px;\n  }\n\n  .xl\\:-translate-x-full {\n    --transform-translate-x: -100%;\n  }\n\n  .xl\\:-translate-x-1\\/2 {\n    --transform-translate-x: -50%;\n  }\n\n  .xl\\:translate-x-1\\/2 {\n    --transform-translate-x: 50%;\n  }\n\n  .xl\\:translate-x-full {\n    --transform-translate-x: 100%;\n  }\n\n  .xl\\:translate-y-0 {\n    --transform-translate-y: 0;\n  }\n\n  .xl\\:translate-y-1 {\n    --transform-translate-y: 0.25rem;\n  }\n\n  .xl\\:translate-y-2 {\n    --transform-translate-y: 0.5rem;\n  }\n\n  .xl\\:translate-y-3 {\n    --transform-translate-y: 0.75rem;\n  }\n\n  .xl\\:translate-y-4 {\n    --transform-translate-y: 1rem;\n  }\n\n  .xl\\:translate-y-5 {\n    --transform-translate-y: 1.25rem;\n  }\n\n  .xl\\:translate-y-6 {\n    --transform-translate-y: 1.5rem;\n  }\n\n  .xl\\:translate-y-8 {\n    --transform-translate-y: 2rem;\n  }\n\n  .xl\\:translate-y-10 {\n    --transform-translate-y: 2.5rem;\n  }\n\n  .xl\\:translate-y-12 {\n    --transform-translate-y: 3rem;\n  }\n\n  .xl\\:translate-y-16 {\n    --transform-translate-y: 4rem;\n  }\n\n  .xl\\:translate-y-20 {\n    --transform-translate-y: 5rem;\n  }\n\n  .xl\\:translate-y-24 {\n    --transform-translate-y: 6rem;\n  }\n\n  .xl\\:translate-y-32 {\n    --transform-translate-y: 8rem;\n  }\n\n  .xl\\:translate-y-40 {\n    --transform-translate-y: 10rem;\n  }\n\n  .xl\\:translate-y-48 {\n    --transform-translate-y: 12rem;\n  }\n\n  .xl\\:translate-y-56 {\n    --transform-translate-y: 14rem;\n  }\n\n  .xl\\:translate-y-64 {\n    --transform-translate-y: 16rem;\n  }\n\n  .xl\\:translate-y-px {\n    --transform-translate-y: 1px;\n  }\n\n  .xl\\:-translate-y-1 {\n    --transform-translate-y: -0.25rem;\n  }\n\n  .xl\\:-translate-y-2 {\n    --transform-translate-y: -0.5rem;\n  }\n\n  .xl\\:-translate-y-3 {\n    --transform-translate-y: -0.75rem;\n  }\n\n  .xl\\:-translate-y-4 {\n    --transform-translate-y: -1rem;\n  }\n\n  .xl\\:-translate-y-5 {\n    --transform-translate-y: -1.25rem;\n  }\n\n  .xl\\:-translate-y-6 {\n    --transform-translate-y: -1.5rem;\n  }\n\n  .xl\\:-translate-y-8 {\n    --transform-translate-y: -2rem;\n  }\n\n  .xl\\:-translate-y-10 {\n    --transform-translate-y: -2.5rem;\n  }\n\n  .xl\\:-translate-y-12 {\n    --transform-translate-y: -3rem;\n  }\n\n  .xl\\:-translate-y-16 {\n    --transform-translate-y: -4rem;\n  }\n\n  .xl\\:-translate-y-20 {\n    --transform-translate-y: -5rem;\n  }\n\n  .xl\\:-translate-y-24 {\n    --transform-translate-y: -6rem;\n  }\n\n  .xl\\:-translate-y-32 {\n    --transform-translate-y: -8rem;\n  }\n\n  .xl\\:-translate-y-40 {\n    --transform-translate-y: -10rem;\n  }\n\n  .xl\\:-translate-y-48 {\n    --transform-translate-y: -12rem;\n  }\n\n  .xl\\:-translate-y-56 {\n    --transform-translate-y: -14rem;\n  }\n\n  .xl\\:-translate-y-64 {\n    --transform-translate-y: -16rem;\n  }\n\n  .xl\\:-translate-y-px {\n    --transform-translate-y: -1px;\n  }\n\n  .xl\\:-translate-y-full {\n    --transform-translate-y: -100%;\n  }\n\n  .xl\\:-translate-y-1\\/2 {\n    --transform-translate-y: -50%;\n  }\n\n  .xl\\:translate-y-1\\/2 {\n    --transform-translate-y: 50%;\n  }\n\n  .xl\\:translate-y-full {\n    --transform-translate-y: 100%;\n  }\n\n  .xl\\:hover\\:translate-x-0:hover {\n    --transform-translate-x: 0;\n  }\n\n  .xl\\:hover\\:translate-x-1:hover {\n    --transform-translate-x: 0.25rem;\n  }\n\n  .xl\\:hover\\:translate-x-2:hover {\n    --transform-translate-x: 0.5rem;\n  }\n\n  .xl\\:hover\\:translate-x-3:hover {\n    --transform-translate-x: 0.75rem;\n  }\n\n  .xl\\:hover\\:translate-x-4:hover {\n    --transform-translate-x: 1rem;\n  }\n\n  .xl\\:hover\\:translate-x-5:hover {\n    --transform-translate-x: 1.25rem;\n  }\n\n  .xl\\:hover\\:translate-x-6:hover {\n    --transform-translate-x: 1.5rem;\n  }\n\n  .xl\\:hover\\:translate-x-8:hover {\n    --transform-translate-x: 2rem;\n  }\n\n  .xl\\:hover\\:translate-x-10:hover {\n    --transform-translate-x: 2.5rem;\n  }\n\n  .xl\\:hover\\:translate-x-12:hover {\n    --transform-translate-x: 3rem;\n  }\n\n  .xl\\:hover\\:translate-x-16:hover {\n    --transform-translate-x: 4rem;\n  }\n\n  .xl\\:hover\\:translate-x-20:hover {\n    --transform-translate-x: 5rem;\n  }\n\n  .xl\\:hover\\:translate-x-24:hover {\n    --transform-translate-x: 6rem;\n  }\n\n  .xl\\:hover\\:translate-x-32:hover {\n    --transform-translate-x: 8rem;\n  }\n\n  .xl\\:hover\\:translate-x-40:hover {\n    --transform-translate-x: 10rem;\n  }\n\n  .xl\\:hover\\:translate-x-48:hover {\n    --transform-translate-x: 12rem;\n  }\n\n  .xl\\:hover\\:translate-x-56:hover {\n    --transform-translate-x: 14rem;\n  }\n\n  .xl\\:hover\\:translate-x-64:hover {\n    --transform-translate-x: 16rem;\n  }\n\n  .xl\\:hover\\:translate-x-px:hover {\n    --transform-translate-x: 1px;\n  }\n\n  .xl\\:hover\\:-translate-x-1:hover {\n    --transform-translate-x: -0.25rem;\n  }\n\n  .xl\\:hover\\:-translate-x-2:hover {\n    --transform-translate-x: -0.5rem;\n  }\n\n  .xl\\:hover\\:-translate-x-3:hover {\n    --transform-translate-x: -0.75rem;\n  }\n\n  .xl\\:hover\\:-translate-x-4:hover {\n    --transform-translate-x: -1rem;\n  }\n\n  .xl\\:hover\\:-translate-x-5:hover {\n    --transform-translate-x: -1.25rem;\n  }\n\n  .xl\\:hover\\:-translate-x-6:hover {\n    --transform-translate-x: -1.5rem;\n  }\n\n  .xl\\:hover\\:-translate-x-8:hover {\n    --transform-translate-x: -2rem;\n  }\n\n  .xl\\:hover\\:-translate-x-10:hover {\n    --transform-translate-x: -2.5rem;\n  }\n\n  .xl\\:hover\\:-translate-x-12:hover {\n    --transform-translate-x: -3rem;\n  }\n\n  .xl\\:hover\\:-translate-x-16:hover {\n    --transform-translate-x: -4rem;\n  }\n\n  .xl\\:hover\\:-translate-x-20:hover {\n    --transform-translate-x: -5rem;\n  }\n\n  .xl\\:hover\\:-translate-x-24:hover {\n    --transform-translate-x: -6rem;\n  }\n\n  .xl\\:hover\\:-translate-x-32:hover {\n    --transform-translate-x: -8rem;\n  }\n\n  .xl\\:hover\\:-translate-x-40:hover {\n    --transform-translate-x: -10rem;\n  }\n\n  .xl\\:hover\\:-translate-x-48:hover {\n    --transform-translate-x: -12rem;\n  }\n\n  .xl\\:hover\\:-translate-x-56:hover {\n    --transform-translate-x: -14rem;\n  }\n\n  .xl\\:hover\\:-translate-x-64:hover {\n    --transform-translate-x: -16rem;\n  }\n\n  .xl\\:hover\\:-translate-x-px:hover {\n    --transform-translate-x: -1px;\n  }\n\n  .xl\\:hover\\:-translate-x-full:hover {\n    --transform-translate-x: -100%;\n  }\n\n  .xl\\:hover\\:-translate-x-1\\/2:hover {\n    --transform-translate-x: -50%;\n  }\n\n  .xl\\:hover\\:translate-x-1\\/2:hover {\n    --transform-translate-x: 50%;\n  }\n\n  .xl\\:hover\\:translate-x-full:hover {\n    --transform-translate-x: 100%;\n  }\n\n  .xl\\:hover\\:translate-y-0:hover {\n    --transform-translate-y: 0;\n  }\n\n  .xl\\:hover\\:translate-y-1:hover {\n    --transform-translate-y: 0.25rem;\n  }\n\n  .xl\\:hover\\:translate-y-2:hover {\n    --transform-translate-y: 0.5rem;\n  }\n\n  .xl\\:hover\\:translate-y-3:hover {\n    --transform-translate-y: 0.75rem;\n  }\n\n  .xl\\:hover\\:translate-y-4:hover {\n    --transform-translate-y: 1rem;\n  }\n\n  .xl\\:hover\\:translate-y-5:hover {\n    --transform-translate-y: 1.25rem;\n  }\n\n  .xl\\:hover\\:translate-y-6:hover {\n    --transform-translate-y: 1.5rem;\n  }\n\n  .xl\\:hover\\:translate-y-8:hover {\n    --transform-translate-y: 2rem;\n  }\n\n  .xl\\:hover\\:translate-y-10:hover {\n    --transform-translate-y: 2.5rem;\n  }\n\n  .xl\\:hover\\:translate-y-12:hover {\n    --transform-translate-y: 3rem;\n  }\n\n  .xl\\:hover\\:translate-y-16:hover {\n    --transform-translate-y: 4rem;\n  }\n\n  .xl\\:hover\\:translate-y-20:hover {\n    --transform-translate-y: 5rem;\n  }\n\n  .xl\\:hover\\:translate-y-24:hover {\n    --transform-translate-y: 6rem;\n  }\n\n  .xl\\:hover\\:translate-y-32:hover {\n    --transform-translate-y: 8rem;\n  }\n\n  .xl\\:hover\\:translate-y-40:hover {\n    --transform-translate-y: 10rem;\n  }\n\n  .xl\\:hover\\:translate-y-48:hover {\n    --transform-translate-y: 12rem;\n  }\n\n  .xl\\:hover\\:translate-y-56:hover {\n    --transform-translate-y: 14rem;\n  }\n\n  .xl\\:hover\\:translate-y-64:hover {\n    --transform-translate-y: 16rem;\n  }\n\n  .xl\\:hover\\:translate-y-px:hover {\n    --transform-translate-y: 1px;\n  }\n\n  .xl\\:hover\\:-translate-y-1:hover {\n    --transform-translate-y: -0.25rem;\n  }\n\n  .xl\\:hover\\:-translate-y-2:hover {\n    --transform-translate-y: -0.5rem;\n  }\n\n  .xl\\:hover\\:-translate-y-3:hover {\n    --transform-translate-y: -0.75rem;\n  }\n\n  .xl\\:hover\\:-translate-y-4:hover {\n    --transform-translate-y: -1rem;\n  }\n\n  .xl\\:hover\\:-translate-y-5:hover {\n    --transform-translate-y: -1.25rem;\n  }\n\n  .xl\\:hover\\:-translate-y-6:hover {\n    --transform-translate-y: -1.5rem;\n  }\n\n  .xl\\:hover\\:-translate-y-8:hover {\n    --transform-translate-y: -2rem;\n  }\n\n  .xl\\:hover\\:-translate-y-10:hover {\n    --transform-translate-y: -2.5rem;\n  }\n\n  .xl\\:hover\\:-translate-y-12:hover {\n    --transform-translate-y: -3rem;\n  }\n\n  .xl\\:hover\\:-translate-y-16:hover {\n    --transform-translate-y: -4rem;\n  }\n\n  .xl\\:hover\\:-translate-y-20:hover {\n    --transform-translate-y: -5rem;\n  }\n\n  .xl\\:hover\\:-translate-y-24:hover {\n    --transform-translate-y: -6rem;\n  }\n\n  .xl\\:hover\\:-translate-y-32:hover {\n    --transform-translate-y: -8rem;\n  }\n\n  .xl\\:hover\\:-translate-y-40:hover {\n    --transform-translate-y: -10rem;\n  }\n\n  .xl\\:hover\\:-translate-y-48:hover {\n    --transform-translate-y: -12rem;\n  }\n\n  .xl\\:hover\\:-translate-y-56:hover {\n    --transform-translate-y: -14rem;\n  }\n\n  .xl\\:hover\\:-translate-y-64:hover {\n    --transform-translate-y: -16rem;\n  }\n\n  .xl\\:hover\\:-translate-y-px:hover {\n    --transform-translate-y: -1px;\n  }\n\n  .xl\\:hover\\:-translate-y-full:hover {\n    --transform-translate-y: -100%;\n  }\n\n  .xl\\:hover\\:-translate-y-1\\/2:hover {\n    --transform-translate-y: -50%;\n  }\n\n  .xl\\:hover\\:translate-y-1\\/2:hover {\n    --transform-translate-y: 50%;\n  }\n\n  .xl\\:hover\\:translate-y-full:hover {\n    --transform-translate-y: 100%;\n  }\n\n  .xl\\:focus\\:translate-x-0:focus {\n    --transform-translate-x: 0;\n  }\n\n  .xl\\:focus\\:translate-x-1:focus {\n    --transform-translate-x: 0.25rem;\n  }\n\n  .xl\\:focus\\:translate-x-2:focus {\n    --transform-translate-x: 0.5rem;\n  }\n\n  .xl\\:focus\\:translate-x-3:focus {\n    --transform-translate-x: 0.75rem;\n  }\n\n  .xl\\:focus\\:translate-x-4:focus {\n    --transform-translate-x: 1rem;\n  }\n\n  .xl\\:focus\\:translate-x-5:focus {\n    --transform-translate-x: 1.25rem;\n  }\n\n  .xl\\:focus\\:translate-x-6:focus {\n    --transform-translate-x: 1.5rem;\n  }\n\n  .xl\\:focus\\:translate-x-8:focus {\n    --transform-translate-x: 2rem;\n  }\n\n  .xl\\:focus\\:translate-x-10:focus {\n    --transform-translate-x: 2.5rem;\n  }\n\n  .xl\\:focus\\:translate-x-12:focus {\n    --transform-translate-x: 3rem;\n  }\n\n  .xl\\:focus\\:translate-x-16:focus {\n    --transform-translate-x: 4rem;\n  }\n\n  .xl\\:focus\\:translate-x-20:focus {\n    --transform-translate-x: 5rem;\n  }\n\n  .xl\\:focus\\:translate-x-24:focus {\n    --transform-translate-x: 6rem;\n  }\n\n  .xl\\:focus\\:translate-x-32:focus {\n    --transform-translate-x: 8rem;\n  }\n\n  .xl\\:focus\\:translate-x-40:focus {\n    --transform-translate-x: 10rem;\n  }\n\n  .xl\\:focus\\:translate-x-48:focus {\n    --transform-translate-x: 12rem;\n  }\n\n  .xl\\:focus\\:translate-x-56:focus {\n    --transform-translate-x: 14rem;\n  }\n\n  .xl\\:focus\\:translate-x-64:focus {\n    --transform-translate-x: 16rem;\n  }\n\n  .xl\\:focus\\:translate-x-px:focus {\n    --transform-translate-x: 1px;\n  }\n\n  .xl\\:focus\\:-translate-x-1:focus {\n    --transform-translate-x: -0.25rem;\n  }\n\n  .xl\\:focus\\:-translate-x-2:focus {\n    --transform-translate-x: -0.5rem;\n  }\n\n  .xl\\:focus\\:-translate-x-3:focus {\n    --transform-translate-x: -0.75rem;\n  }\n\n  .xl\\:focus\\:-translate-x-4:focus {\n    --transform-translate-x: -1rem;\n  }\n\n  .xl\\:focus\\:-translate-x-5:focus {\n    --transform-translate-x: -1.25rem;\n  }\n\n  .xl\\:focus\\:-translate-x-6:focus {\n    --transform-translate-x: -1.5rem;\n  }\n\n  .xl\\:focus\\:-translate-x-8:focus {\n    --transform-translate-x: -2rem;\n  }\n\n  .xl\\:focus\\:-translate-x-10:focus {\n    --transform-translate-x: -2.5rem;\n  }\n\n  .xl\\:focus\\:-translate-x-12:focus {\n    --transform-translate-x: -3rem;\n  }\n\n  .xl\\:focus\\:-translate-x-16:focus {\n    --transform-translate-x: -4rem;\n  }\n\n  .xl\\:focus\\:-translate-x-20:focus {\n    --transform-translate-x: -5rem;\n  }\n\n  .xl\\:focus\\:-translate-x-24:focus {\n    --transform-translate-x: -6rem;\n  }\n\n  .xl\\:focus\\:-translate-x-32:focus {\n    --transform-translate-x: -8rem;\n  }\n\n  .xl\\:focus\\:-translate-x-40:focus {\n    --transform-translate-x: -10rem;\n  }\n\n  .xl\\:focus\\:-translate-x-48:focus {\n    --transform-translate-x: -12rem;\n  }\n\n  .xl\\:focus\\:-translate-x-56:focus {\n    --transform-translate-x: -14rem;\n  }\n\n  .xl\\:focus\\:-translate-x-64:focus {\n    --transform-translate-x: -16rem;\n  }\n\n  .xl\\:focus\\:-translate-x-px:focus {\n    --transform-translate-x: -1px;\n  }\n\n  .xl\\:focus\\:-translate-x-full:focus {\n    --transform-translate-x: -100%;\n  }\n\n  .xl\\:focus\\:-translate-x-1\\/2:focus {\n    --transform-translate-x: -50%;\n  }\n\n  .xl\\:focus\\:translate-x-1\\/2:focus {\n    --transform-translate-x: 50%;\n  }\n\n  .xl\\:focus\\:translate-x-full:focus {\n    --transform-translate-x: 100%;\n  }\n\n  .xl\\:focus\\:translate-y-0:focus {\n    --transform-translate-y: 0;\n  }\n\n  .xl\\:focus\\:translate-y-1:focus {\n    --transform-translate-y: 0.25rem;\n  }\n\n  .xl\\:focus\\:translate-y-2:focus {\n    --transform-translate-y: 0.5rem;\n  }\n\n  .xl\\:focus\\:translate-y-3:focus {\n    --transform-translate-y: 0.75rem;\n  }\n\n  .xl\\:focus\\:translate-y-4:focus {\n    --transform-translate-y: 1rem;\n  }\n\n  .xl\\:focus\\:translate-y-5:focus {\n    --transform-translate-y: 1.25rem;\n  }\n\n  .xl\\:focus\\:translate-y-6:focus {\n    --transform-translate-y: 1.5rem;\n  }\n\n  .xl\\:focus\\:translate-y-8:focus {\n    --transform-translate-y: 2rem;\n  }\n\n  .xl\\:focus\\:translate-y-10:focus {\n    --transform-translate-y: 2.5rem;\n  }\n\n  .xl\\:focus\\:translate-y-12:focus {\n    --transform-translate-y: 3rem;\n  }\n\n  .xl\\:focus\\:translate-y-16:focus {\n    --transform-translate-y: 4rem;\n  }\n\n  .xl\\:focus\\:translate-y-20:focus {\n    --transform-translate-y: 5rem;\n  }\n\n  .xl\\:focus\\:translate-y-24:focus {\n    --transform-translate-y: 6rem;\n  }\n\n  .xl\\:focus\\:translate-y-32:focus {\n    --transform-translate-y: 8rem;\n  }\n\n  .xl\\:focus\\:translate-y-40:focus {\n    --transform-translate-y: 10rem;\n  }\n\n  .xl\\:focus\\:translate-y-48:focus {\n    --transform-translate-y: 12rem;\n  }\n\n  .xl\\:focus\\:translate-y-56:focus {\n    --transform-translate-y: 14rem;\n  }\n\n  .xl\\:focus\\:translate-y-64:focus {\n    --transform-translate-y: 16rem;\n  }\n\n  .xl\\:focus\\:translate-y-px:focus {\n    --transform-translate-y: 1px;\n  }\n\n  .xl\\:focus\\:-translate-y-1:focus {\n    --transform-translate-y: -0.25rem;\n  }\n\n  .xl\\:focus\\:-translate-y-2:focus {\n    --transform-translate-y: -0.5rem;\n  }\n\n  .xl\\:focus\\:-translate-y-3:focus {\n    --transform-translate-y: -0.75rem;\n  }\n\n  .xl\\:focus\\:-translate-y-4:focus {\n    --transform-translate-y: -1rem;\n  }\n\n  .xl\\:focus\\:-translate-y-5:focus {\n    --transform-translate-y: -1.25rem;\n  }\n\n  .xl\\:focus\\:-translate-y-6:focus {\n    --transform-translate-y: -1.5rem;\n  }\n\n  .xl\\:focus\\:-translate-y-8:focus {\n    --transform-translate-y: -2rem;\n  }\n\n  .xl\\:focus\\:-translate-y-10:focus {\n    --transform-translate-y: -2.5rem;\n  }\n\n  .xl\\:focus\\:-translate-y-12:focus {\n    --transform-translate-y: -3rem;\n  }\n\n  .xl\\:focus\\:-translate-y-16:focus {\n    --transform-translate-y: -4rem;\n  }\n\n  .xl\\:focus\\:-translate-y-20:focus {\n    --transform-translate-y: -5rem;\n  }\n\n  .xl\\:focus\\:-translate-y-24:focus {\n    --transform-translate-y: -6rem;\n  }\n\n  .xl\\:focus\\:-translate-y-32:focus {\n    --transform-translate-y: -8rem;\n  }\n\n  .xl\\:focus\\:-translate-y-40:focus {\n    --transform-translate-y: -10rem;\n  }\n\n  .xl\\:focus\\:-translate-y-48:focus {\n    --transform-translate-y: -12rem;\n  }\n\n  .xl\\:focus\\:-translate-y-56:focus {\n    --transform-translate-y: -14rem;\n  }\n\n  .xl\\:focus\\:-translate-y-64:focus {\n    --transform-translate-y: -16rem;\n  }\n\n  .xl\\:focus\\:-translate-y-px:focus {\n    --transform-translate-y: -1px;\n  }\n\n  .xl\\:focus\\:-translate-y-full:focus {\n    --transform-translate-y: -100%;\n  }\n\n  .xl\\:focus\\:-translate-y-1\\/2:focus {\n    --transform-translate-y: -50%;\n  }\n\n  .xl\\:focus\\:translate-y-1\\/2:focus {\n    --transform-translate-y: 50%;\n  }\n\n  .xl\\:focus\\:translate-y-full:focus {\n    --transform-translate-y: 100%;\n  }\n\n  .xl\\:skew-x-0 {\n    --transform-skew-x: 0;\n  }\n\n  .xl\\:skew-x-1 {\n    --transform-skew-x: 1deg;\n  }\n\n  .xl\\:skew-x-2 {\n    --transform-skew-x: 2deg;\n  }\n\n  .xl\\:skew-x-3 {\n    --transform-skew-x: 3deg;\n  }\n\n  .xl\\:skew-x-6 {\n    --transform-skew-x: 6deg;\n  }\n\n  .xl\\:skew-x-12 {\n    --transform-skew-x: 12deg;\n  }\n\n  .xl\\:-skew-x-12 {\n    --transform-skew-x: -12deg;\n  }\n\n  .xl\\:-skew-x-6 {\n    --transform-skew-x: -6deg;\n  }\n\n  .xl\\:-skew-x-3 {\n    --transform-skew-x: -3deg;\n  }\n\n  .xl\\:-skew-x-2 {\n    --transform-skew-x: -2deg;\n  }\n\n  .xl\\:-skew-x-1 {\n    --transform-skew-x: -1deg;\n  }\n\n  .xl\\:skew-y-0 {\n    --transform-skew-y: 0;\n  }\n\n  .xl\\:skew-y-1 {\n    --transform-skew-y: 1deg;\n  }\n\n  .xl\\:skew-y-2 {\n    --transform-skew-y: 2deg;\n  }\n\n  .xl\\:skew-y-3 {\n    --transform-skew-y: 3deg;\n  }\n\n  .xl\\:skew-y-6 {\n    --transform-skew-y: 6deg;\n  }\n\n  .xl\\:skew-y-12 {\n    --transform-skew-y: 12deg;\n  }\n\n  .xl\\:-skew-y-12 {\n    --transform-skew-y: -12deg;\n  }\n\n  .xl\\:-skew-y-6 {\n    --transform-skew-y: -6deg;\n  }\n\n  .xl\\:-skew-y-3 {\n    --transform-skew-y: -3deg;\n  }\n\n  .xl\\:-skew-y-2 {\n    --transform-skew-y: -2deg;\n  }\n\n  .xl\\:-skew-y-1 {\n    --transform-skew-y: -1deg;\n  }\n\n  .xl\\:hover\\:skew-x-0:hover {\n    --transform-skew-x: 0;\n  }\n\n  .xl\\:hover\\:skew-x-1:hover {\n    --transform-skew-x: 1deg;\n  }\n\n  .xl\\:hover\\:skew-x-2:hover {\n    --transform-skew-x: 2deg;\n  }\n\n  .xl\\:hover\\:skew-x-3:hover {\n    --transform-skew-x: 3deg;\n  }\n\n  .xl\\:hover\\:skew-x-6:hover {\n    --transform-skew-x: 6deg;\n  }\n\n  .xl\\:hover\\:skew-x-12:hover {\n    --transform-skew-x: 12deg;\n  }\n\n  .xl\\:hover\\:-skew-x-12:hover {\n    --transform-skew-x: -12deg;\n  }\n\n  .xl\\:hover\\:-skew-x-6:hover {\n    --transform-skew-x: -6deg;\n  }\n\n  .xl\\:hover\\:-skew-x-3:hover {\n    --transform-skew-x: -3deg;\n  }\n\n  .xl\\:hover\\:-skew-x-2:hover {\n    --transform-skew-x: -2deg;\n  }\n\n  .xl\\:hover\\:-skew-x-1:hover {\n    --transform-skew-x: -1deg;\n  }\n\n  .xl\\:hover\\:skew-y-0:hover {\n    --transform-skew-y: 0;\n  }\n\n  .xl\\:hover\\:skew-y-1:hover {\n    --transform-skew-y: 1deg;\n  }\n\n  .xl\\:hover\\:skew-y-2:hover {\n    --transform-skew-y: 2deg;\n  }\n\n  .xl\\:hover\\:skew-y-3:hover {\n    --transform-skew-y: 3deg;\n  }\n\n  .xl\\:hover\\:skew-y-6:hover {\n    --transform-skew-y: 6deg;\n  }\n\n  .xl\\:hover\\:skew-y-12:hover {\n    --transform-skew-y: 12deg;\n  }\n\n  .xl\\:hover\\:-skew-y-12:hover {\n    --transform-skew-y: -12deg;\n  }\n\n  .xl\\:hover\\:-skew-y-6:hover {\n    --transform-skew-y: -6deg;\n  }\n\n  .xl\\:hover\\:-skew-y-3:hover {\n    --transform-skew-y: -3deg;\n  }\n\n  .xl\\:hover\\:-skew-y-2:hover {\n    --transform-skew-y: -2deg;\n  }\n\n  .xl\\:hover\\:-skew-y-1:hover {\n    --transform-skew-y: -1deg;\n  }\n\n  .xl\\:focus\\:skew-x-0:focus {\n    --transform-skew-x: 0;\n  }\n\n  .xl\\:focus\\:skew-x-1:focus {\n    --transform-skew-x: 1deg;\n  }\n\n  .xl\\:focus\\:skew-x-2:focus {\n    --transform-skew-x: 2deg;\n  }\n\n  .xl\\:focus\\:skew-x-3:focus {\n    --transform-skew-x: 3deg;\n  }\n\n  .xl\\:focus\\:skew-x-6:focus {\n    --transform-skew-x: 6deg;\n  }\n\n  .xl\\:focus\\:skew-x-12:focus {\n    --transform-skew-x: 12deg;\n  }\n\n  .xl\\:focus\\:-skew-x-12:focus {\n    --transform-skew-x: -12deg;\n  }\n\n  .xl\\:focus\\:-skew-x-6:focus {\n    --transform-skew-x: -6deg;\n  }\n\n  .xl\\:focus\\:-skew-x-3:focus {\n    --transform-skew-x: -3deg;\n  }\n\n  .xl\\:focus\\:-skew-x-2:focus {\n    --transform-skew-x: -2deg;\n  }\n\n  .xl\\:focus\\:-skew-x-1:focus {\n    --transform-skew-x: -1deg;\n  }\n\n  .xl\\:focus\\:skew-y-0:focus {\n    --transform-skew-y: 0;\n  }\n\n  .xl\\:focus\\:skew-y-1:focus {\n    --transform-skew-y: 1deg;\n  }\n\n  .xl\\:focus\\:skew-y-2:focus {\n    --transform-skew-y: 2deg;\n  }\n\n  .xl\\:focus\\:skew-y-3:focus {\n    --transform-skew-y: 3deg;\n  }\n\n  .xl\\:focus\\:skew-y-6:focus {\n    --transform-skew-y: 6deg;\n  }\n\n  .xl\\:focus\\:skew-y-12:focus {\n    --transform-skew-y: 12deg;\n  }\n\n  .xl\\:focus\\:-skew-y-12:focus {\n    --transform-skew-y: -12deg;\n  }\n\n  .xl\\:focus\\:-skew-y-6:focus {\n    --transform-skew-y: -6deg;\n  }\n\n  .xl\\:focus\\:-skew-y-3:focus {\n    --transform-skew-y: -3deg;\n  }\n\n  .xl\\:focus\\:-skew-y-2:focus {\n    --transform-skew-y: -2deg;\n  }\n\n  .xl\\:focus\\:-skew-y-1:focus {\n    --transform-skew-y: -1deg;\n  }\n\n  .xl\\:transition-none {\n    transition-property: none;\n  }\n\n  .xl\\:transition-all {\n    transition-property: all;\n  }\n\n  .xl\\:transition {\n    transition-property: background-color, border-color, color, fill, stroke, opacity, box-shadow, transform;\n  }\n\n  .xl\\:transition-colors {\n    transition-property: background-color, border-color, color, fill, stroke;\n  }\n\n  .xl\\:transition-opacity {\n    transition-property: opacity;\n  }\n\n  .xl\\:transition-shadow {\n    transition-property: box-shadow;\n  }\n\n  .xl\\:transition-transform {\n    transition-property: transform;\n  }\n\n  .xl\\:ease-linear {\n    transition-timing-function: linear;\n  }\n\n  .xl\\:ease-in {\n    transition-timing-function: cubic-bezier(0.4, 0, 1, 1);\n  }\n\n  .xl\\:ease-out {\n    transition-timing-function: cubic-bezier(0, 0, 0.2, 1);\n  }\n\n  .xl\\:ease-in-out {\n    transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);\n  }\n\n  .xl\\:duration-75 {\n    transition-duration: 75ms;\n  }\n\n  .xl\\:duration-100 {\n    transition-duration: 100ms;\n  }\n\n  .xl\\:duration-150 {\n    transition-duration: 150ms;\n  }\n\n  .xl\\:duration-200 {\n    transition-duration: 200ms;\n  }\n\n  .xl\\:duration-300 {\n    transition-duration: 300ms;\n  }\n\n  .xl\\:duration-500 {\n    transition-duration: 500ms;\n  }\n\n  .xl\\:duration-700 {\n    transition-duration: 700ms;\n  }\n\n  .xl\\:duration-1000 {\n    transition-duration: 1000ms;\n  }\n\n  .xl\\:delay-75 {\n    transition-delay: 75ms;\n  }\n\n  .xl\\:delay-100 {\n    transition-delay: 100ms;\n  }\n\n  .xl\\:delay-150 {\n    transition-delay: 150ms;\n  }\n\n  .xl\\:delay-200 {\n    transition-delay: 200ms;\n  }\n\n  .xl\\:delay-300 {\n    transition-delay: 300ms;\n  }\n\n  .xl\\:delay-500 {\n    transition-delay: 500ms;\n  }\n\n  .xl\\:delay-700 {\n    transition-delay: 700ms;\n  }\n\n  .xl\\:delay-1000 {\n    transition-delay: 1000ms;\n  }\n\n  .xl\\:animate-none {\n    -webkit-animation: none;\n            animation: none;\n  }\n\n  .xl\\:animate-spin {\n    -webkit-animation: spin 1s linear infinite;\n            animation: spin 1s linear infinite;\n  }\n\n  .xl\\:animate-ping {\n    -webkit-animation: ping 1s cubic-bezier(0, 0, 0.2, 1) infinite;\n            animation: ping 1s cubic-bezier(0, 0, 0.2, 1) infinite;\n  }\n\n  .xl\\:animate-pulse {\n    -webkit-animation: pulse 2s cubic-bezier(0.4, 0, 0.6, 1) infinite;\n            animation: pulse 2s cubic-bezier(0.4, 0, 0.6, 1) infinite;\n  }\n\n  .xl\\:animate-bounce {\n    -webkit-animation: bounce 1s infinite;\n            animation: bounce 1s infinite;\n  }\n}\n";
styleInject(css_248z);

var css_248z$1 = "/* Button */\n\n.btn {\n  position: relative;\n  height: 2rem;\n  padding-left: 0.5rem;\n  padding-right: 0.5rem;\n  padding-top: 0;\n  padding-bottom: 0;\n  font-size: 0.875rem;\n  font-weight: 600;\n  text-transform: uppercase;\n  border-width: 1px;\n  border-color: transparent;\n  border-style: solid;\n  border-radius: 0.25rem;\n  --text-opacity: 1;\n  color: hsl(0, 0%, 90%);\n  color: rgba(229.5, 229.5, 229.5, var(--text-opacity));\n  font-family: inherit;\n  transition: transform 50ms ease-in-out;\n}\n\n.btn:active {\n  transform: scale(0.98);\n}\n\n.btn[disabled] {\n  --text-opacity: 1;\n  color: #e2e8f0;\n  color: rgba(226, 232, 240, var(--text-opacity));\n  --bg-opacity: 1;\n  background-color: #718096;\n  background-color: rgba(113, 128, 150, var(--bg-opacity));\n  opacity: 0.75;\n  cursor: not-allowed;\n}\n\n.btn-only-icon {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  width: 3rem;\n  padding-left: 0.25rem;\n  padding-right: 0.25rem;\n  padding-top: 0;\n  padding-bottom: 0;\n  min-width: 24px;\n}\n\n.btn-primary {\n  --bg-opacity: 1;\n  background-color: hsl(210, 100%, 52%);\n  background-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--bg-opacity));\n}\n\n.btn-primary:hover {\n  --bg-opacity: 1;\n  background-color: #3182ce;\n  background-color: rgba(49, 130, 206, var(--bg-opacity));\n  border-color: var(--foreground);\n}\n\n/* Section tabs */\n\n.section-tabs {\n  display: flex;\n  margin-top: 1rem;\n  margin-bottom: 1.5rem;\n  list-style-type: none;\n  cursor: pointer;\n}\n\n.section-tabs__tab {\n  flex: 1 1 0%;\n  padding: 0.75rem;\n  font-size: 1.25rem;\n  text-align: center;\n  text-transform: capitalize;\n  border-top-width: 4px;\n  border-bottom-right-radius: 0.25rem;\n  border-bottom-left-radius: 0.25rem;\n  border-color: var(--foreground);\n  background-color: var(--main-background);\n}\n\n.section-tabs__tab.active {\n  --text-opacity: 1;\n  color: hsl(210, 100%, 52%);\n  color: rgba(10.20000000000001, 132.59999999999988, 255, var(--text-opacity));\n  --border-opacity: 1;\n  border-color: hsl(210, 100%, 52%);\n  border-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--border-opacity));\n  background-color: var(--main-background);\n}\n\n.section-tabs__tab:hover {\n  --text-opacity: 1;\n  color: hsl(210, 100%, 52%);\n  color: rgba(10.20000000000001, 132.59999999999988, 255, var(--text-opacity));\n  --border-opacity: 1;\n  border-color: hsl(210, 100%, 52%);\n  border-color: rgba(10.20000000000001, 132.59999999999988, 255, var(--border-opacity));\n  background-color: var(--secondary-background);\n  --bg-opacity: 0.25;\n}\r\n";
styleInject(css_248z$1);

/*!
 * vuex v3.5.1
 * (c) 2020 Evan You
 * @license MIT
 */
function applyMixin (Vue) {
  var version = Number(Vue.version.split('.')[0]);

  if (version >= 2) {
    Vue.mixin({ beforeCreate: vuexInit });
  } else {
    // override init and inject vuex init procedure
    // for 1.x backwards compatibility.
    var _init = Vue.prototype._init;
    Vue.prototype._init = function (options) {
      if ( options === void 0 ) options = {};

      options.init = options.init
        ? [vuexInit].concat(options.init)
        : vuexInit;
      _init.call(this, options);
    };
  }

  /**
   * Vuex init hook, injected into each instances init hooks list.
   */

  function vuexInit () {
    var options = this.$options;
    // store injection
    if (options.store) {
      this.$store = typeof options.store === 'function'
        ? options.store()
        : options.store;
    } else if (options.parent && options.parent.$store) {
      this.$store = options.parent.$store;
    }
  }
}

var target$2 = typeof window !== 'undefined'
  ? window
  : typeof global !== 'undefined'
    ? global
    : {};
var devtoolHook = target$2.__VUE_DEVTOOLS_GLOBAL_HOOK__;

function devtoolPlugin (store) {
  if (!devtoolHook) { return }

  store._devtoolHook = devtoolHook;

  devtoolHook.emit('vuex:init', store);

  devtoolHook.on('vuex:travel-to-state', function (targetState) {
    store.replaceState(targetState);
  });

  store.subscribe(function (mutation, state) {
    devtoolHook.emit('vuex:mutation', mutation, state);
  }, { prepend: true });

  store.subscribeAction(function (action, state) {
    devtoolHook.emit('vuex:action', action, state);
  }, { prepend: true });
}

/**
 * Get the first item that pass the test
 * by second argument function
 *
 * @param {Array} list
 * @param {Function} f
 * @return {*}
 */
function find (list, f) {
  return list.filter(f)[0]
}

/**
 * Deep copy the given object considering circular structure.
 * This function caches all nested objects and its copies.
 * If it detects circular structure, use cached copy to avoid infinite loop.
 *
 * @param {*} obj
 * @param {Array<Object>} cache
 * @return {*}
 */
function deepCopy (obj, cache) {
  if ( cache === void 0 ) cache = [];

  // just return if obj is immutable value
  if (obj === null || typeof obj !== 'object') {
    return obj
  }

  // if obj is hit, it is in circular structure
  var hit = find(cache, function (c) { return c.original === obj; });
  if (hit) {
    return hit.copy
  }

  var copy = Array.isArray(obj) ? [] : {};
  // put the copy into cache at first
  // because we want to refer it in recursive deepCopy
  cache.push({
    original: obj,
    copy: copy
  });

  Object.keys(obj).forEach(function (key) {
    copy[key] = deepCopy(obj[key], cache);
  });

  return copy
}

/**
 * forEach for object
 */
function forEachValue (obj, fn) {
  Object.keys(obj).forEach(function (key) { return fn(obj[key], key); });
}

function isObject$1 (obj) {
  return obj !== null && typeof obj === 'object'
}

function isPromise$1 (val) {
  return val && typeof val.then === 'function'
}

function assert (condition, msg) {
  if (!condition) { throw new Error(("[vuex] " + msg)) }
}

function partial (fn, arg) {
  return function () {
    return fn(arg)
  }
}

// Base data struct for store's module, package with some attribute and method
var Module = function Module (rawModule, runtime) {
  this.runtime = runtime;
  // Store some children item
  this._children = Object.create(null);
  // Store the origin module object which passed by programmer
  this._rawModule = rawModule;
  var rawState = rawModule.state;

  // Store the origin module's state
  this.state = (typeof rawState === 'function' ? rawState() : rawState) || {};
};

var prototypeAccessors$1 = { namespaced: { configurable: true } };

prototypeAccessors$1.namespaced.get = function () {
  return !!this._rawModule.namespaced
};

Module.prototype.addChild = function addChild (key, module) {
  this._children[key] = module;
};

Module.prototype.removeChild = function removeChild (key) {
  delete this._children[key];
};

Module.prototype.getChild = function getChild (key) {
  return this._children[key]
};

Module.prototype.hasChild = function hasChild (key) {
  return key in this._children
};

Module.prototype.update = function update (rawModule) {
  this._rawModule.namespaced = rawModule.namespaced;
  if (rawModule.actions) {
    this._rawModule.actions = rawModule.actions;
  }
  if (rawModule.mutations) {
    this._rawModule.mutations = rawModule.mutations;
  }
  if (rawModule.getters) {
    this._rawModule.getters = rawModule.getters;
  }
};

Module.prototype.forEachChild = function forEachChild (fn) {
  forEachValue(this._children, fn);
};

Module.prototype.forEachGetter = function forEachGetter (fn) {
  if (this._rawModule.getters) {
    forEachValue(this._rawModule.getters, fn);
  }
};

Module.prototype.forEachAction = function forEachAction (fn) {
  if (this._rawModule.actions) {
    forEachValue(this._rawModule.actions, fn);
  }
};

Module.prototype.forEachMutation = function forEachMutation (fn) {
  if (this._rawModule.mutations) {
    forEachValue(this._rawModule.mutations, fn);
  }
};

Object.defineProperties( Module.prototype, prototypeAccessors$1 );

var ModuleCollection = function ModuleCollection (rawRootModule) {
  // register root module (Vuex.Store options)
  this.register([], rawRootModule, false);
};

ModuleCollection.prototype.get = function get (path) {
  return path.reduce(function (module, key) {
    return module.getChild(key)
  }, this.root)
};

ModuleCollection.prototype.getNamespace = function getNamespace (path) {
  var module = this.root;
  return path.reduce(function (namespace, key) {
    module = module.getChild(key);
    return namespace + (module.namespaced ? key + '/' : '')
  }, '')
};

ModuleCollection.prototype.update = function update$1 (rawRootModule) {
  update([], this.root, rawRootModule);
};

ModuleCollection.prototype.register = function register (path, rawModule, runtime) {
    var this$1 = this;
    if ( runtime === void 0 ) runtime = true;

  {
    assertRawModule(path, rawModule);
  }

  var newModule = new Module(rawModule, runtime);
  if (path.length === 0) {
    this.root = newModule;
  } else {
    var parent = this.get(path.slice(0, -1));
    parent.addChild(path[path.length - 1], newModule);
  }

  // register nested modules
  if (rawModule.modules) {
    forEachValue(rawModule.modules, function (rawChildModule, key) {
      this$1.register(path.concat(key), rawChildModule, runtime);
    });
  }
};

ModuleCollection.prototype.unregister = function unregister (path) {
  var parent = this.get(path.slice(0, -1));
  var key = path[path.length - 1];
  var child = parent.getChild(key);

  if (!child) {
    {
      console.warn(
        "[vuex] trying to unregister module '" + key + "', which is " +
        "not registered"
      );
    }
    return
  }

  if (!child.runtime) {
    return
  }

  parent.removeChild(key);
};

ModuleCollection.prototype.isRegistered = function isRegistered (path) {
  var parent = this.get(path.slice(0, -1));
  var key = path[path.length - 1];

  return parent.hasChild(key)
};

function update (path, targetModule, newModule) {
  {
    assertRawModule(path, newModule);
  }

  // update target module
  targetModule.update(newModule);

  // update nested modules
  if (newModule.modules) {
    for (var key in newModule.modules) {
      if (!targetModule.getChild(key)) {
        {
          console.warn(
            "[vuex] trying to add a new module '" + key + "' on hot reloading, " +
            'manual reload is needed'
          );
        }
        return
      }
      update(
        path.concat(key),
        targetModule.getChild(key),
        newModule.modules[key]
      );
    }
  }
}

var functionAssert = {
  assert: function (value) { return typeof value === 'function'; },
  expected: 'function'
};

var objectAssert = {
  assert: function (value) { return typeof value === 'function' ||
    (typeof value === 'object' && typeof value.handler === 'function'); },
  expected: 'function or object with "handler" function'
};

var assertTypes = {
  getters: functionAssert,
  mutations: functionAssert,
  actions: objectAssert
};

function assertRawModule (path, rawModule) {
  Object.keys(assertTypes).forEach(function (key) {
    if (!rawModule[key]) { return }

    var assertOptions = assertTypes[key];

    forEachValue(rawModule[key], function (value, type) {
      assert(
        assertOptions.assert(value),
        makeAssertionMessage(path, key, type, value, assertOptions.expected)
      );
    });
  });
}

function makeAssertionMessage (path, key, type, value, expected) {
  var buf = key + " should be " + expected + " but \"" + key + "." + type + "\"";
  if (path.length > 0) {
    buf += " in module \"" + (path.join('.')) + "\"";
  }
  buf += " is " + (JSON.stringify(value)) + ".";
  return buf
}

var Vue$1; // bind on install

var Store = function Store (options) {
  var this$1 = this;
  if ( options === void 0 ) options = {};

  // Auto install if it is not done yet and `window` has `Vue`.
  // To allow users to avoid auto-installation in some cases,
  // this code should be placed here. See #731
  if (!Vue$1 && typeof window !== 'undefined' && window.Vue) {
    install(window.Vue);
  }

  {
    assert(Vue$1, "must call Vue.use(Vuex) before creating a store instance.");
    assert(typeof Promise !== 'undefined', "vuex requires a Promise polyfill in this browser.");
    assert(this instanceof Store, "store must be called with the new operator.");
  }

  var plugins = options.plugins; if ( plugins === void 0 ) plugins = [];
  var strict = options.strict; if ( strict === void 0 ) strict = false;

  // store internal state
  this._committing = false;
  this._actions = Object.create(null);
  this._actionSubscribers = [];
  this._mutations = Object.create(null);
  this._wrappedGetters = Object.create(null);
  this._modules = new ModuleCollection(options);
  this._modulesNamespaceMap = Object.create(null);
  this._subscribers = [];
  this._watcherVM = new Vue$1();
  this._makeLocalGettersCache = Object.create(null);

  // bind commit and dispatch to self
  var store = this;
  var ref = this;
  var dispatch = ref.dispatch;
  var commit = ref.commit;
  this.dispatch = function boundDispatch (type, payload) {
    return dispatch.call(store, type, payload)
  };
  this.commit = function boundCommit (type, payload, options) {
    return commit.call(store, type, payload, options)
  };

  // strict mode
  this.strict = strict;

  var state = this._modules.root.state;

  // init root module.
  // this also recursively registers all sub-modules
  // and collects all module getters inside this._wrappedGetters
  installModule(this, state, [], this._modules.root);

  // initialize the store vm, which is responsible for the reactivity
  // (also registers _wrappedGetters as computed properties)
  resetStoreVM(this, state);

  // apply plugins
  plugins.forEach(function (plugin) { return plugin(this$1); });

  var useDevtools = options.devtools !== undefined ? options.devtools : Vue$1.config.devtools;
  if (useDevtools) {
    devtoolPlugin(this);
  }
};

var prototypeAccessors$1$1 = { state: { configurable: true } };

prototypeAccessors$1$1.state.get = function () {
  return this._vm._data.$$state
};

prototypeAccessors$1$1.state.set = function (v) {
  {
    assert(false, "use store.replaceState() to explicit replace store state.");
  }
};

Store.prototype.commit = function commit (_type, _payload, _options) {
    var this$1 = this;

  // check object-style commit
  var ref = unifyObjectStyle(_type, _payload, _options);
    var type = ref.type;
    var payload = ref.payload;
    var options = ref.options;

  var mutation = { type: type, payload: payload };
  var entry = this._mutations[type];
  if (!entry) {
    {
      console.error(("[vuex] unknown mutation type: " + type));
    }
    return
  }
  this._withCommit(function () {
    entry.forEach(function commitIterator (handler) {
      handler(payload);
    });
  });

  this._subscribers
    .slice() // shallow copy to prevent iterator invalidation if subscriber synchronously calls unsubscribe
    .forEach(function (sub) { return sub(mutation, this$1.state); });

  if (
    
    options && options.silent
  ) {
    console.warn(
      "[vuex] mutation type: " + type + ". Silent option has been removed. " +
      'Use the filter functionality in the vue-devtools'
    );
  }
};

Store.prototype.dispatch = function dispatch (_type, _payload) {
    var this$1 = this;

  // check object-style dispatch
  var ref = unifyObjectStyle(_type, _payload);
    var type = ref.type;
    var payload = ref.payload;

  var action = { type: type, payload: payload };
  var entry = this._actions[type];
  if (!entry) {
    {
      console.error(("[vuex] unknown action type: " + type));
    }
    return
  }

  try {
    this._actionSubscribers
      .slice() // shallow copy to prevent iterator invalidation if subscriber synchronously calls unsubscribe
      .filter(function (sub) { return sub.before; })
      .forEach(function (sub) { return sub.before(action, this$1.state); });
  } catch (e) {
    {
      console.warn("[vuex] error in before action subscribers: ");
      console.error(e);
    }
  }

  var result = entry.length > 1
    ? Promise.all(entry.map(function (handler) { return handler(payload); }))
    : entry[0](payload);

  return new Promise(function (resolve, reject) {
    result.then(function (res) {
      try {
        this$1._actionSubscribers
          .filter(function (sub) { return sub.after; })
          .forEach(function (sub) { return sub.after(action, this$1.state); });
      } catch (e) {
        {
          console.warn("[vuex] error in after action subscribers: ");
          console.error(e);
        }
      }
      resolve(res);
    }, function (error) {
      try {
        this$1._actionSubscribers
          .filter(function (sub) { return sub.error; })
          .forEach(function (sub) { return sub.error(action, this$1.state, error); });
      } catch (e) {
        {
          console.warn("[vuex] error in error action subscribers: ");
          console.error(e);
        }
      }
      reject(error);
    });
  })
};

Store.prototype.subscribe = function subscribe (fn, options) {
  return genericSubscribe(fn, this._subscribers, options)
};

Store.prototype.subscribeAction = function subscribeAction (fn, options) {
  var subs = typeof fn === 'function' ? { before: fn } : fn;
  return genericSubscribe(subs, this._actionSubscribers, options)
};

Store.prototype.watch = function watch (getter, cb, options) {
    var this$1 = this;

  {
    assert(typeof getter === 'function', "store.watch only accepts a function.");
  }
  return this._watcherVM.$watch(function () { return getter(this$1.state, this$1.getters); }, cb, options)
};

Store.prototype.replaceState = function replaceState (state) {
    var this$1 = this;

  this._withCommit(function () {
    this$1._vm._data.$$state = state;
  });
};

Store.prototype.registerModule = function registerModule (path, rawModule, options) {
    if ( options === void 0 ) options = {};

  if (typeof path === 'string') { path = [path]; }

  {
    assert(Array.isArray(path), "module path must be a string or an Array.");
    assert(path.length > 0, 'cannot register the root module by using registerModule.');
  }

  this._modules.register(path, rawModule);
  installModule(this, this.state, path, this._modules.get(path), options.preserveState);
  // reset store to update getters...
  resetStoreVM(this, this.state);
};

Store.prototype.unregisterModule = function unregisterModule (path) {
    var this$1 = this;

  if (typeof path === 'string') { path = [path]; }

  {
    assert(Array.isArray(path), "module path must be a string or an Array.");
  }

  this._modules.unregister(path);
  this._withCommit(function () {
    var parentState = getNestedState(this$1.state, path.slice(0, -1));
    Vue$1.delete(parentState, path[path.length - 1]);
  });
  resetStore(this);
};

Store.prototype.hasModule = function hasModule (path) {
  if (typeof path === 'string') { path = [path]; }

  {
    assert(Array.isArray(path), "module path must be a string or an Array.");
  }

  return this._modules.isRegistered(path)
};

Store.prototype.hotUpdate = function hotUpdate (newOptions) {
  this._modules.update(newOptions);
  resetStore(this, true);
};

Store.prototype._withCommit = function _withCommit (fn) {
  var committing = this._committing;
  this._committing = true;
  fn();
  this._committing = committing;
};

Object.defineProperties( Store.prototype, prototypeAccessors$1$1 );

function genericSubscribe (fn, subs, options) {
  if (subs.indexOf(fn) < 0) {
    options && options.prepend
      ? subs.unshift(fn)
      : subs.push(fn);
  }
  return function () {
    var i = subs.indexOf(fn);
    if (i > -1) {
      subs.splice(i, 1);
    }
  }
}

function resetStore (store, hot) {
  store._actions = Object.create(null);
  store._mutations = Object.create(null);
  store._wrappedGetters = Object.create(null);
  store._modulesNamespaceMap = Object.create(null);
  var state = store.state;
  // init all modules
  installModule(store, state, [], store._modules.root, true);
  // reset vm
  resetStoreVM(store, state, hot);
}

function resetStoreVM (store, state, hot) {
  var oldVm = store._vm;

  // bind store public getters
  store.getters = {};
  // reset local getters cache
  store._makeLocalGettersCache = Object.create(null);
  var wrappedGetters = store._wrappedGetters;
  var computed = {};
  forEachValue(wrappedGetters, function (fn, key) {
    // use computed to leverage its lazy-caching mechanism
    // direct inline function use will lead to closure preserving oldVm.
    // using partial to return function with only arguments preserved in closure environment.
    computed[key] = partial(fn, store);
    Object.defineProperty(store.getters, key, {
      get: function () { return store._vm[key]; },
      enumerable: true // for local getters
    });
  });

  // use a Vue instance to store the state tree
  // suppress warnings just in case the user has added
  // some funky global mixins
  var silent = Vue$1.config.silent;
  Vue$1.config.silent = true;
  store._vm = new Vue$1({
    data: {
      $$state: state
    },
    computed: computed
  });
  Vue$1.config.silent = silent;

  // enable strict mode for new vm
  if (store.strict) {
    enableStrictMode(store);
  }

  if (oldVm) {
    if (hot) {
      // dispatch changes in all subscribed watchers
      // to force getter re-evaluation for hot reloading.
      store._withCommit(function () {
        oldVm._data.$$state = null;
      });
    }
    Vue$1.nextTick(function () { return oldVm.$destroy(); });
  }
}

function installModule (store, rootState, path, module, hot) {
  var isRoot = !path.length;
  var namespace = store._modules.getNamespace(path);

  // register in namespace map
  if (module.namespaced) {
    if (store._modulesNamespaceMap[namespace] && ("development" !== 'production')) {
      console.error(("[vuex] duplicate namespace " + namespace + " for the namespaced module " + (path.join('/'))));
    }
    store._modulesNamespaceMap[namespace] = module;
  }

  // set state
  if (!isRoot && !hot) {
    var parentState = getNestedState(rootState, path.slice(0, -1));
    var moduleName = path[path.length - 1];
    store._withCommit(function () {
      {
        if (moduleName in parentState) {
          console.warn(
            ("[vuex] state field \"" + moduleName + "\" was overridden by a module with the same name at \"" + (path.join('.')) + "\"")
          );
        }
      }
      Vue$1.set(parentState, moduleName, module.state);
    });
  }

  var local = module.context = makeLocalContext(store, namespace, path);

  module.forEachMutation(function (mutation, key) {
    var namespacedType = namespace + key;
    registerMutation(store, namespacedType, mutation, local);
  });

  module.forEachAction(function (action, key) {
    var type = action.root ? key : namespace + key;
    var handler = action.handler || action;
    registerAction(store, type, handler, local);
  });

  module.forEachGetter(function (getter, key) {
    var namespacedType = namespace + key;
    registerGetter(store, namespacedType, getter, local);
  });

  module.forEachChild(function (child, key) {
    installModule(store, rootState, path.concat(key), child, hot);
  });
}

/**
 * make localized dispatch, commit, getters and state
 * if there is no namespace, just use root ones
 */
function makeLocalContext (store, namespace, path) {
  var noNamespace = namespace === '';

  var local = {
    dispatch: noNamespace ? store.dispatch : function (_type, _payload, _options) {
      var args = unifyObjectStyle(_type, _payload, _options);
      var payload = args.payload;
      var options = args.options;
      var type = args.type;

      if (!options || !options.root) {
        type = namespace + type;
        if ( !store._actions[type]) {
          console.error(("[vuex] unknown local action type: " + (args.type) + ", global type: " + type));
          return
        }
      }

      return store.dispatch(type, payload)
    },

    commit: noNamespace ? store.commit : function (_type, _payload, _options) {
      var args = unifyObjectStyle(_type, _payload, _options);
      var payload = args.payload;
      var options = args.options;
      var type = args.type;

      if (!options || !options.root) {
        type = namespace + type;
        if ( !store._mutations[type]) {
          console.error(("[vuex] unknown local mutation type: " + (args.type) + ", global type: " + type));
          return
        }
      }

      store.commit(type, payload, options);
    }
  };

  // getters and state object must be gotten lazily
  // because they will be changed by vm update
  Object.defineProperties(local, {
    getters: {
      get: noNamespace
        ? function () { return store.getters; }
        : function () { return makeLocalGetters(store, namespace); }
    },
    state: {
      get: function () { return getNestedState(store.state, path); }
    }
  });

  return local
}

function makeLocalGetters (store, namespace) {
  if (!store._makeLocalGettersCache[namespace]) {
    var gettersProxy = {};
    var splitPos = namespace.length;
    Object.keys(store.getters).forEach(function (type) {
      // skip if the target getter is not match this namespace
      if (type.slice(0, splitPos) !== namespace) { return }

      // extract local getter type
      var localType = type.slice(splitPos);

      // Add a port to the getters proxy.
      // Define as getter property because
      // we do not want to evaluate the getters in this time.
      Object.defineProperty(gettersProxy, localType, {
        get: function () { return store.getters[type]; },
        enumerable: true
      });
    });
    store._makeLocalGettersCache[namespace] = gettersProxy;
  }

  return store._makeLocalGettersCache[namespace]
}

function registerMutation (store, type, handler, local) {
  var entry = store._mutations[type] || (store._mutations[type] = []);
  entry.push(function wrappedMutationHandler (payload) {
    handler.call(store, local.state, payload);
  });
}

function registerAction (store, type, handler, local) {
  var entry = store._actions[type] || (store._actions[type] = []);
  entry.push(function wrappedActionHandler (payload) {
    var res = handler.call(store, {
      dispatch: local.dispatch,
      commit: local.commit,
      getters: local.getters,
      state: local.state,
      rootGetters: store.getters,
      rootState: store.state
    }, payload);
    if (!isPromise$1(res)) {
      res = Promise.resolve(res);
    }
    if (store._devtoolHook) {
      return res.catch(function (err) {
        store._devtoolHook.emit('vuex:error', err);
        throw err
      })
    } else {
      return res
    }
  });
}

function registerGetter (store, type, rawGetter, local) {
  if (store._wrappedGetters[type]) {
    {
      console.error(("[vuex] duplicate getter key: " + type));
    }
    return
  }
  store._wrappedGetters[type] = function wrappedGetter (store) {
    return rawGetter(
      local.state, // local state
      local.getters, // local getters
      store.state, // root state
      store.getters // root getters
    )
  };
}

function enableStrictMode (store) {
  store._vm.$watch(function () { return this._data.$$state }, function () {
    {
      assert(store._committing, "do not mutate vuex store state outside mutation handlers.");
    }
  }, { deep: true, sync: true });
}

function getNestedState (state, path) {
  return path.reduce(function (state, key) { return state[key]; }, state)
}

function unifyObjectStyle (type, payload, options) {
  if (isObject$1(type) && type.type) {
    options = payload;
    payload = type;
    type = type.type;
  }

  {
    assert(typeof type === 'string', ("expects string as the type, but found " + (typeof type) + "."));
  }

  return { type: type, payload: payload, options: options }
}

function install (_Vue) {
  if (Vue$1 && _Vue === Vue$1) {
    {
      console.error(
        '[vuex] already installed. Vue.use(Vuex) should be called only once.'
      );
    }
    return
  }
  Vue$1 = _Vue;
  applyMixin(Vue$1);
}

/**
 * Reduce the code which written in Vue.js for getting the state.
 * @param {String} [namespace] - Module's namespace
 * @param {Object|Array} states # Object's item can be a function which accept state and getters for param, you can do something for state and getters in it.
 * @param {Object}
 */
var mapState = normalizeNamespace(function (namespace, states) {
  var res = {};
  if ( !isValidMap(states)) {
    console.error('[vuex] mapState: mapper parameter must be either an Array or an Object');
  }
  normalizeMap(states).forEach(function (ref) {
    var key = ref.key;
    var val = ref.val;

    res[key] = function mappedState () {
      var state = this.$store.state;
      var getters = this.$store.getters;
      if (namespace) {
        var module = getModuleByNamespace(this.$store, 'mapState', namespace);
        if (!module) {
          return
        }
        state = module.context.state;
        getters = module.context.getters;
      }
      return typeof val === 'function'
        ? val.call(this, state, getters)
        : state[val]
    };
    // mark vuex getter for devtools
    res[key].vuex = true;
  });
  return res
});

/**
 * Reduce the code which written in Vue.js for committing the mutation
 * @param {String} [namespace] - Module's namespace
 * @param {Object|Array} mutations # Object's item can be a function which accept `commit` function as the first param, it can accept anthor params. You can commit mutation and do any other things in this function. specially, You need to pass anthor params from the mapped function.
 * @return {Object}
 */
var mapMutations = normalizeNamespace(function (namespace, mutations) {
  var res = {};
  if ( !isValidMap(mutations)) {
    console.error('[vuex] mapMutations: mapper parameter must be either an Array or an Object');
  }
  normalizeMap(mutations).forEach(function (ref) {
    var key = ref.key;
    var val = ref.val;

    res[key] = function mappedMutation () {
      var args = [], len = arguments.length;
      while ( len-- ) args[ len ] = arguments[ len ];

      // Get the commit method from store
      var commit = this.$store.commit;
      if (namespace) {
        var module = getModuleByNamespace(this.$store, 'mapMutations', namespace);
        if (!module) {
          return
        }
        commit = module.context.commit;
      }
      return typeof val === 'function'
        ? val.apply(this, [commit].concat(args))
        : commit.apply(this.$store, [val].concat(args))
    };
  });
  return res
});

/**
 * Reduce the code which written in Vue.js for getting the getters
 * @param {String} [namespace] - Module's namespace
 * @param {Object|Array} getters
 * @return {Object}
 */
var mapGetters = normalizeNamespace(function (namespace, getters) {
  var res = {};
  if ( !isValidMap(getters)) {
    console.error('[vuex] mapGetters: mapper parameter must be either an Array or an Object');
  }
  normalizeMap(getters).forEach(function (ref) {
    var key = ref.key;
    var val = ref.val;

    // The namespace has been mutated by normalizeNamespace
    val = namespace + val;
    res[key] = function mappedGetter () {
      if (namespace && !getModuleByNamespace(this.$store, 'mapGetters', namespace)) {
        return
      }
      if ( !(val in this.$store.getters)) {
        console.error(("[vuex] unknown getter: " + val));
        return
      }
      return this.$store.getters[val]
    };
    // mark vuex getter for devtools
    res[key].vuex = true;
  });
  return res
});

/**
 * Reduce the code which written in Vue.js for dispatch the action
 * @param {String} [namespace] - Module's namespace
 * @param {Object|Array} actions # Object's item can be a function which accept `dispatch` function as the first param, it can accept anthor params. You can dispatch action and do any other things in this function. specially, You need to pass anthor params from the mapped function.
 * @return {Object}
 */
var mapActions = normalizeNamespace(function (namespace, actions) {
  var res = {};
  if ( !isValidMap(actions)) {
    console.error('[vuex] mapActions: mapper parameter must be either an Array or an Object');
  }
  normalizeMap(actions).forEach(function (ref) {
    var key = ref.key;
    var val = ref.val;

    res[key] = function mappedAction () {
      var args = [], len = arguments.length;
      while ( len-- ) args[ len ] = arguments[ len ];

      // get dispatch function from store
      var dispatch = this.$store.dispatch;
      if (namespace) {
        var module = getModuleByNamespace(this.$store, 'mapActions', namespace);
        if (!module) {
          return
        }
        dispatch = module.context.dispatch;
      }
      return typeof val === 'function'
        ? val.apply(this, [dispatch].concat(args))
        : dispatch.apply(this.$store, [val].concat(args))
    };
  });
  return res
});

/**
 * Rebinding namespace param for mapXXX function in special scoped, and return them by simple object
 * @param {String} namespace
 * @return {Object}
 */
var createNamespacedHelpers = function (namespace) { return ({
  mapState: mapState.bind(null, namespace),
  mapGetters: mapGetters.bind(null, namespace),
  mapMutations: mapMutations.bind(null, namespace),
  mapActions: mapActions.bind(null, namespace)
}); };

/**
 * Normalize the map
 * normalizeMap([1, 2, 3]) => [ { key: 1, val: 1 }, { key: 2, val: 2 }, { key: 3, val: 3 } ]
 * normalizeMap({a: 1, b: 2, c: 3}) => [ { key: 'a', val: 1 }, { key: 'b', val: 2 }, { key: 'c', val: 3 } ]
 * @param {Array|Object} map
 * @return {Object}
 */
function normalizeMap (map) {
  if (!isValidMap(map)) {
    return []
  }
  return Array.isArray(map)
    ? map.map(function (key) { return ({ key: key, val: key }); })
    : Object.keys(map).map(function (key) { return ({ key: key, val: map[key] }); })
}

/**
 * Validate whether given map is valid or not
 * @param {*} map
 * @return {Boolean}
 */
function isValidMap (map) {
  return Array.isArray(map) || isObject$1(map)
}

/**
 * Return a function expect two param contains namespace and map. it will normalize the namespace and then the param's function will handle the new namespace and the map.
 * @param {Function} fn
 * @return {Function}
 */
function normalizeNamespace (fn) {
  return function (namespace, map) {
    if (typeof namespace !== 'string') {
      map = namespace;
      namespace = '';
    } else if (namespace.charAt(namespace.length - 1) !== '/') {
      namespace += '/';
    }
    return fn(namespace, map)
  }
}

/**
 * Search a special module from store by namespace. if module not exist, print error message.
 * @param {Object} store
 * @param {String} helper
 * @param {String} namespace
 * @return {Object}
 */
function getModuleByNamespace (store, helper, namespace) {
  var module = store._modulesNamespaceMap[namespace];
  if ( !module) {
    console.error(("[vuex] module namespace not found in " + helper + "(): " + namespace));
  }
  return module
}

// Credits: borrowed code from fcomb/redux-logger

function createLogger (ref) {
  if ( ref === void 0 ) ref = {};
  var collapsed = ref.collapsed; if ( collapsed === void 0 ) collapsed = true;
  var filter = ref.filter; if ( filter === void 0 ) filter = function (mutation, stateBefore, stateAfter) { return true; };
  var transformer = ref.transformer; if ( transformer === void 0 ) transformer = function (state) { return state; };
  var mutationTransformer = ref.mutationTransformer; if ( mutationTransformer === void 0 ) mutationTransformer = function (mut) { return mut; };
  var actionFilter = ref.actionFilter; if ( actionFilter === void 0 ) actionFilter = function (action, state) { return true; };
  var actionTransformer = ref.actionTransformer; if ( actionTransformer === void 0 ) actionTransformer = function (act) { return act; };
  var logMutations = ref.logMutations; if ( logMutations === void 0 ) logMutations = true;
  var logActions = ref.logActions; if ( logActions === void 0 ) logActions = true;
  var logger = ref.logger; if ( logger === void 0 ) logger = console;

  return function (store) {
    var prevState = deepCopy(store.state);

    if (typeof logger === 'undefined') {
      return
    }

    if (logMutations) {
      store.subscribe(function (mutation, state) {
        var nextState = deepCopy(state);

        if (filter(mutation, prevState, nextState)) {
          var formattedTime = getFormattedTime();
          var formattedMutation = mutationTransformer(mutation);
          var message = "mutation " + (mutation.type) + formattedTime;

          startMessage(logger, message, collapsed);
          logger.log('%c prev state', 'color: #9E9E9E; font-weight: bold', transformer(prevState));
          logger.log('%c mutation', 'color: #03A9F4; font-weight: bold', formattedMutation);
          logger.log('%c next state', 'color: #4CAF50; font-weight: bold', transformer(nextState));
          endMessage(logger);
        }

        prevState = nextState;
      });
    }

    if (logActions) {
      store.subscribeAction(function (action, state) {
        if (actionFilter(action, state)) {
          var formattedTime = getFormattedTime();
          var formattedAction = actionTransformer(action);
          var message = "action " + (action.type) + formattedTime;

          startMessage(logger, message, collapsed);
          logger.log('%c action', 'color: #03A9F4; font-weight: bold', formattedAction);
          endMessage(logger);
        }
      });
    }
  }
}

function startMessage (logger, message, collapsed) {
  var startMessage = collapsed
    ? logger.groupCollapsed
    : logger.group;

  // render
  try {
    startMessage.call(logger, message);
  } catch (e) {
    logger.log(message);
  }
}

function endMessage (logger) {
  try {
    logger.groupEnd();
  } catch (e) {
    logger.log('—— log end ——');
  }
}

function getFormattedTime () {
  var time = new Date();
  return (" @ " + (pad(time.getHours(), 2)) + ":" + (pad(time.getMinutes(), 2)) + ":" + (pad(time.getSeconds(), 2)) + "." + (pad(time.getMilliseconds(), 3)))
}

function repeat$2 (str, times) {
  return (new Array(times + 1)).join(str)
}

function pad (num, maxLength) {
  return repeat$2('0', maxLength - num.toString().length) + num
}

var index$2 = {
  Store: Store,
  install: install,
  version: '3.5.1',
  mapState: mapState,
  mapMutations: mapMutations,
  mapGetters: mapGetters,
  mapActions: mapActions,
  createNamespacedHelpers: createNamespacedHelpers,
  createLogger: createLogger
};

//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//

const possibleStates = ['converting', 'downloading', 'download finished'];

var script = {
	data() {
		return {
			isLoading: false
		}
	},
	props: {
		queueItem: Object
	},
	computed: {
		hasFails() {
			return this.queueItem.failed >= 1
		},
		allFailed() {
			let allFailed = false;

			if (this.queueItem.status === 'download finished') {
				allFailed = this.queueItem.failed === this.queueItem.size;
			}

			return allFailed
		},
		finishedWithFails() {
			return this.queueItem.status === 'download finished' && this.hasFails
		},
		isDeterminateStatus() {
			return possibleStates.indexOf(this.queueItem.status) !== -1
		},
		barClass() {
			return {
				converting: this.queueItem.status === 'converting',
				indeterminate: !this.isDeterminateStatus,
				determinate: this.isDeterminateStatus
			}
		},
		barStyle() {
			let width = 0;
			let backgroundColor = 'var(--primary-color)';

			if (this.hasFails) {
				// Orange
				backgroundColor = 'hsl(33, 100%, 47%)';
			} else {
				// Green
				backgroundColor = 'hsl(150, 76%, 34%)';
			}

			if (this.allFailed) {
				// Red
				backgroundColor = 'hsl(360, 100%, 35%)';
			}

			if (this.queueItem.status === 'download finished') {
				width = 100;
			}

			if (this.queueItem.status === 'downloading') {
				width = this.queueItem.progress;
			}

			if (this.queueItem.status === 'converting') {
				width = 100 - this.queueItem.conversion;
			}

			return {
				width: `${width}%`,
				backgroundColor
			}
		},
		resultIconText() {
			let text = 'delete_forever';

			if (this.queueItem.status === 'download finished') {
				if (!this.hasFails) {
					text = 'done';
				} else {
					if (this.queueItem.failed >= this.queueItem.size) {
						text = 'error';
					} else {
						text = 'warning';
					}
				}
			}

			return text
		}
	},
	methods: {
		onResultIconClick() {
			if (this.isDeterminateStatus) {
				if (this.finishedWithFails) {
					this.$emit('show-errors', this.queueItem);
				}

				if (this.queueItem.status === 'downloading') {
					this.isLoading = true;
					this.$emit('remove-item', this.queueItem.uuid);
				}
			} else {
				this.isLoading = true;
				this.$emit('remove-item', this.queueItem.uuid);
			}
		}
	}
};

function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier
/* server only */
, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
  if (typeof shadowMode !== 'boolean') {
    createInjectorSSR = createInjector;
    createInjector = shadowMode;
    shadowMode = false;
  } // Vue.extend constructor export interop.


  var options = typeof script === 'function' ? script.options : script; // render functions

  if (template && template.render) {
    options.render = template.render;
    options.staticRenderFns = template.staticRenderFns;
    options._compiled = true; // functional template

    if (isFunctionalTemplate) {
      options.functional = true;
    }
  } // scopedId


  if (scopeId) {
    options._scopeId = scopeId;
  }

  var hook;

  if (moduleIdentifier) {
    // server build
    hook = function hook(context) {
      // 2.3 injection
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext; // functional
      // 2.2 with runInNewContext: true

      if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
        context = __VUE_SSR_CONTEXT__;
      } // inject component styles


      if (style) {
        style.call(this, createInjectorSSR(context));
      } // register component module identifier for async chunk inference


      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    }; // used by ssr in case component is cached and beforeCreate
    // never gets called


    options._ssrRegister = hook;
  } else if (style) {
    hook = shadowMode ? function () {
      style.call(this, createInjectorShadow(this.$root.$options.shadowRoot));
    } : function (context) {
      style.call(this, createInjector(context));
    };
  }

  if (hook) {
    if (options.functional) {
      // register for functional component in vue file
      var originalRender = options.render;

      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      // inject component registration as beforeCreate hook
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }

  return script;
}

var normalizeComponent_1 = normalizeComponent;

var isOldIE = typeof navigator !== 'undefined' && /msie [6-9]\\b/.test(navigator.userAgent.toLowerCase());
function createInjector(context) {
  return function (id, style) {
    return addStyle(id, style);
  };
}
var HEAD = document.head || document.getElementsByTagName('head')[0];
var styles = {};

function addStyle(id, css) {
  var group = isOldIE ? css.media || 'default' : id;
  var style = styles[group] || (styles[group] = {
    ids: new Set(),
    styles: []
  });

  if (!style.ids.has(id)) {
    style.ids.add(id);
    var code = css.source;

    if (css.map) {
      // https://developer.chrome.com/devtools/docs/javascript-debugging
      // this makes source maps inside style tags work properly in Chrome
      code += '\n/*# sourceURL=' + css.map.sources[0] + ' */'; // http://stackoverflow.com/a/26603875

      code += '\n/*# sourceMappingURL=data:application/json;base64,' + btoa(unescape(encodeURIComponent(JSON.stringify(css.map)))) + ' */';
    }

    if (!style.element) {
      style.element = document.createElement('style');
      style.element.type = 'text/css';
      if (css.media) style.element.setAttribute('media', css.media);
      HEAD.appendChild(style.element);
    }

    if ('styleSheet' in style.element) {
      style.styles.push(code);
      style.element.styleSheet.cssText = style.styles.filter(Boolean).join('\n');
    } else {
      var index = style.ids.size - 1;
      var textNode = document.createTextNode(code);
      var nodes = style.element.childNodes;
      if (nodes[index]) style.element.removeChild(nodes[index]);
      if (nodes.length) style.element.insertBefore(textNode, nodes[index]);else style.element.appendChild(textNode);
    }
  }
}

var browser = createInjector;

/* script */
const __vue_script__ = script;

/* template */
var __vue_render__ = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", { staticClass: "download-object" }, [
    _c("div", { staticClass: "download-info" }, [
      _c("img", {
        staticClass: "rounded coverart",
        attrs: {
          width: "75px",
          src: _vm.queueItem.cover,
          alt: "Cover " + _vm.queueItem.title
        }
      }),
      _vm._v(" "),
      _c("div", { staticClass: "download-info-data" }, [
        _c("span", { staticClass: "download-line" }, [
          _vm._v(_vm._s(_vm.queueItem.title))
        ]),
        _vm._v(" "),
        _c("span", { staticClass: "download-slim-separator" }, [_vm._v(" - ")]),
        _vm._v(" "),
        _c("span", [_vm._v(_vm._s(_vm.queueItem.artist))])
      ]),
      _vm._v(" "),
      _c(
        "div",
        {
          staticClass: "download-info-status",
          staticStyle: { "text-align": "center" }
        },
        [
          _c("span", { staticClass: "download-line" }, [
            _vm._v(
              " " +
                _vm._s(_vm.queueItem.downloaded + _vm.queueItem.failed) +
                "/" +
                _vm._s(_vm.queueItem.size) +
                " "
            )
          ]),
          _vm._v(" "),
          _vm.hasFails
            ? _c(
                "span",
                {
                  staticClass: "inline-flex",
                  class: { clickable: _vm.finishedWithFails },
                  staticStyle: { "justify-content": "center" },
                  on: {
                    click: function($event) {
                      _vm.finishedWithFails
                        ? _vm.$emit("show-errors", _vm.queueItem)
                        : null;
                    }
                  }
                },
                [
                  _vm._v(
                    "\n\t\t\t\t" + _vm._s(_vm.queueItem.failed) + "\n\t\t\t\t"
                  ),
                  _c("i", { staticClass: "material-icons" }, [
                    _vm._v("error_outline")
                  ])
                ]
              )
            : _vm._e()
        ]
      )
    ]),
    _vm._v(" "),
    _c("div", { staticClass: "download-bar" }, [
      _c("div", { staticClass: "progress" }, [
        _c("div", { class: _vm.barClass, style: _vm.barStyle })
      ]),
      _vm._v(" "),
      !_vm.isLoading
        ? _c(
            "i",
            {
              staticClass: "material-icons queue_icon",
              class: {
                clickable:
                  _vm.finishedWithFails ||
                  _vm.resultIconText === "delete_forever"
              },
              on: { click: _vm.onResultIconClick }
            },
            [_vm._v("\n\t\t\t" + _vm._s(_vm.resultIconText) + "\n\t\t")]
          )
        : _c("div", { staticClass: "circle-loader" })
    ])
  ])
};
var __vue_staticRenderFns__ = [];
__vue_render__._withStripped = true;

  /* style */
  const __vue_inject_styles__ = function (inject) {
    if (!inject) return
    inject("data-v-6a7e4f7e_0", { source: ".download-object {\n  padding-bottom: 8px;\n}\n.download-object .download-info {\n    display: flex;\n    align-items: center;\n}\n.download-object .download-info img {\n      height: 75px;\n      flex-shrink: 0;\n      flex: 0 0 75px;\n}\n.download-object .download-info .download-line {\n      display: block;\n}\n.download-object .download-info .download-slim-separator {\n      display: none;\n}\n.download-object .download-info-data {\n    flex: 1 50%;\n    margin-left: 8px;\n    overflow: hidden;\n}\n.download-object .download-info-status {\n    flex: 1 15%;\n    margin-left: 8px;\n    width: 80px;\n}\n.download-object > .download-bar {\n    display: flex;\n    align-items: center;\n    height: 24px;\n}\n.download-object > .download-bar > .queue_icon {\n      cursor: default;\n      margin-left: 8px;\n}\n.download-object > .download-bar > .progress {\n      margin: 0px;\n}\n#download_list:not(.slim) .download-line {\n  overflow: hidden;\n  white-space: nowrap;\n  text-overflow: ellipsis;\n}\n#download_list.slim > .download-object .download-info {\n  display: block;\n}\n#download_list.slim > .download-object .download-info img {\n    display: none;\n}\n#download_list.slim > .download-object .download-info .download-line {\n    display: inline-block;\n}\n#download_list.slim > .download-object .download-info .download-slim-separator {\n    display: inline-block;\n}\n#download_list.slim > .download-object .download-info-data {\n  width: calc(80% - 16px);\n  display: inline-block;\n  padding-left: 0px;\n}\n#download_list.slim > .download-object .download-info-status {\n  width: 20%;\n  display: inline-block;\n  float: right;\n}\n.progress {\n  position: relative;\n  height: 4px;\n  display: block;\n  width: 100%;\n  background-color: var(--secondary-background);\n  border-radius: 2px;\n  margin: 0.5rem 0 1rem 0;\n  overflow: hidden;\n}\n.progress .determinate {\n    position: absolute;\n    top: 0;\n    left: 0;\n    bottom: 0;\n    background-color: var(--primary-color);\n    transition: width 0.3s linear;\n}\n.progress .converting {\n    background-color: var(--secondary-color);\n    transition: none !important;\n}\n.progress .indeterminate {\n    background-color: var(--primary-color);\n}\n.progress .indeterminate::before {\n      content: '';\n      position: absolute;\n      background-color: inherit;\n      top: 0;\n      left: 0;\n      bottom: 0;\n      will-change: left, right;\n      animation: indeterminate 2.1s cubic-bezier(0.65, 0.815, 0.735, 0.395) infinite;\n}\n.progress .indeterminate::after {\n      content: '';\n      position: absolute;\n      background-color: inherit;\n      top: 0;\n      left: 0;\n      bottom: 0;\n      will-change: left, right;\n      animation: indeterminate-short 2.1s cubic-bezier(0.165, 0.84, 0.44, 1) infinite;\n      animation-delay: 1.15s;\n}\n\n/*# sourceMappingURL=QueueItem.vue.map */", map: {"version":3,"sources":["C:\\Users\\Roberto\\Dev\\repos\\deemix-pyweb\\webui\\src\\components\\downloads\\QueueItem.vue","QueueItem.vue"],"names":[],"mappings":"AA4CA;EACA,mBAAA;AAAA;AADA;IAIA,aAAA;IACA,mBAAA;AAAA;AALA;MAQA,YAAA;MACA,cAAA;MACA,cAAA;AAAA;AAVA;MAcA,cAAA;AAAA;AAdA;MAkBA,aAAA;AAAA;AAlBA;IAuBA,WAAA;IACA,gBAAA;IACA,gBAAA;AAAA;AAzBA;IA6BA,WAAA;IACA,gBAAA;IACA,WAAA;AAAA;AA/BA;IAmCA,aAAA;IACA,mBAAA;IACA,YAAA;AAAA;AArCA;MAwCA,eAAA;MACA,gBAAA;AAAA;AAzCA;MA6CA,WAAA;AAAA;AAKA;EACA,gBAAA;EACA,mBAAA;EACA,uBAAA;AAAA;AAGA;EAGA,cAAA;AAAA;AAHA;IAMA,aAAA;AAAA;AANA;IAUA,qBAAA;AAAA;AAVA;IAcA,qBAAA;AAAA;AAdA;EAmBA,uBAAA;EACA,qBAAA;EACA,iBAAA;AAAA;AArBA;EAyBA,UAAA;EACA,qBAAA;EACA,YAAA;AAAA;AAKA;EACA,kBAAA;EACA,WAAA;EACA,cAAA;EACA,WAAA;EACA,6CAAA;EACA,kBAAA;EACA,uBAAA;EACA,gBAAA;AAAA;AARA;IAWA,kBAAA;IACA,MAAA;IACA,OAAA;IACA,SAAA;IACA,sCAAA;IACA,6BAAA;AAAA;AAhBA;IAoBA,wCAAA;IACA,2BAAA;AAAA;AArBA;IAyBA,sCAAA;AAAA;AAzBA;MA4BA,WAAA;MACA,kBAAA;MACA,yBAAA;MACA,MAAA;MACA,OAAA;MACA,SAAA;MACA,wBAAA;MACA,8EAAA;AAAA;AAnCA;MAuCA,WAAA;MACA,kBAAA;MACA,yBAAA;MACA,MAAA;MACA,OAAA;MACA,SAAA;MACA,wBAAA;MACA,+EAAA;MACA,sBAAA;AAAA;;ACnFA,wCAAwC","file":"QueueItem.vue","sourcesContent":["<template>\r\n\t<div class=\"download-object\">\r\n\t\t<div class=\"download-info\">\r\n\t\t\t<img width=\"75px\" class=\"rounded coverart\" :src=\"queueItem.cover\" :alt=\"`Cover ${queueItem.title}`\" />\r\n\r\n\t\t\t<div class=\"download-info-data\">\r\n\t\t\t\t<span class=\"download-line\">{{ queueItem.title }}</span> <span class=\"download-slim-separator\"> - </span>\r\n\t\t\t\t<span>{{ queueItem.artist }}</span>\r\n\t\t\t</div>\r\n\r\n\t\t\t<div class=\"download-info-status\" style=\"text-align: center\">\r\n\t\t\t\t<span class=\"download-line\"> {{ queueItem.downloaded + queueItem.failed }}/{{ queueItem.size }} </span>\r\n\r\n\t\t\t\t<span\r\n\t\t\t\t\tv-if=\"hasFails\"\r\n\t\t\t\t\tclass=\"inline-flex\"\r\n\t\t\t\t\t:class=\"{ clickable: finishedWithFails }\"\r\n\t\t\t\t\tstyle=\"justify-content: center\"\r\n\t\t\t\t\t@click=\"finishedWithFails ? $emit('show-errors', queueItem) : null\"\r\n\t\t\t\t>\r\n\t\t\t\t\t{{ queueItem.failed }}\r\n\t\t\t\t\t<i class=\"material-icons\">error_outline</i>\r\n\t\t\t\t</span>\r\n\t\t\t</div>\r\n\t\t</div>\r\n\r\n\t\t<div class=\"download-bar\">\r\n\t\t\t<div class=\"progress\">\r\n\t\t\t\t<div :class=\"barClass\" :style=\"barStyle\"></div>\r\n\t\t\t</div>\r\n\t\t\t<i\r\n\t\t\t\tv-if=\"!isLoading\"\r\n\t\t\t\tclass=\"material-icons queue_icon\"\r\n\t\t\t\t:class=\"{ clickable: finishedWithFails || resultIconText === 'delete_forever' }\"\r\n\t\t\t\t@click=\"onResultIconClick\"\r\n\t\t\t>\r\n\t\t\t\t{{ resultIconText }}\r\n\t\t\t</i>\r\n\t\t\t<div v-else class=\"circle-loader\"></div>\r\n\t\t</div>\r\n\t</div>\r\n</template>\r\n\r\n<style lang=\"scss\">\r\n.download-object {\r\n\tpadding-bottom: 8px;\r\n\r\n\t.download-info {\r\n\t\tdisplay: flex;\r\n\t\talign-items: center;\r\n\r\n\t\timg {\r\n\t\t\theight: 75px;\r\n\t\t\tflex-shrink: 0;\r\n\t\t\tflex: 0 0 75px;\r\n\t\t}\r\n\r\n\t\t.download-line {\r\n\t\t\tdisplay: block;\r\n\t\t}\r\n\r\n\t\t.download-slim-separator {\r\n\t\t\tdisplay: none;\r\n\t\t}\r\n\t}\r\n\r\n\t.download-info-data {\r\n\t\tflex: 1 50%;\r\n\t\tmargin-left: 8px;\r\n\t\toverflow: hidden;\r\n\t}\r\n\r\n\t.download-info-status {\r\n\t\tflex: 1 15%;\r\n\t\tmargin-left: 8px;\r\n\t\twidth: 80px;\r\n\t}\r\n\r\n\t> .download-bar {\r\n\t\tdisplay: flex;\r\n\t\talign-items: center;\r\n\t\theight: 24px;\r\n\r\n\t\t> .queue_icon {\r\n\t\t\tcursor: default;\r\n\t\t\tmargin-left: 8px;\r\n\t\t}\r\n\r\n\t\t> .progress {\r\n\t\t\tmargin: 0px;\r\n\t\t}\r\n\t}\r\n}\r\n\r\n#download_list:not(.slim) .download-line {\r\n\toverflow: hidden;\r\n\twhite-space: nowrap;\r\n\ttext-overflow: ellipsis;\r\n}\r\n\r\n#download_list.slim {\r\n\t> .download-object {\r\n\t\t.download-info {\r\n\t\t\tdisplay: block;\r\n\r\n\t\t\timg {\r\n\t\t\t\tdisplay: none;\r\n\t\t\t}\r\n\r\n\t\t\t.download-line {\r\n\t\t\t\tdisplay: inline-block;\r\n\t\t\t}\r\n\r\n\t\t\t.download-slim-separator {\r\n\t\t\t\tdisplay: inline-block;\r\n\t\t\t}\r\n\t\t}\r\n\r\n\t\t.download-info-data {\r\n\t\t\twidth: calc(80% - 16px);\r\n\t\t\tdisplay: inline-block;\r\n\t\t\tpadding-left: 0px;\r\n\t\t}\r\n\r\n\t\t.download-info-status {\r\n\t\t\twidth: 20%;\r\n\t\t\tdisplay: inline-block; // ignored due to float\r\n\t\t\tfloat: right;\r\n\t\t}\r\n\t}\r\n}\r\n\r\n.progress {\r\n\tposition: relative;\r\n\theight: 4px;\r\n\tdisplay: block;\r\n\twidth: 100%;\r\n\tbackground-color: var(--secondary-background);\r\n\tborder-radius: 2px;\r\n\tmargin: 0.5rem 0 1rem 0;\r\n\toverflow: hidden;\r\n\r\n\t.determinate {\r\n\t\tposition: absolute;\r\n\t\ttop: 0;\r\n\t\tleft: 0;\r\n\t\tbottom: 0;\r\n\t\tbackground-color: var(--primary-color);\r\n\t\ttransition: width 0.3s linear;\r\n\t}\r\n\r\n\t.converting {\r\n\t\tbackground-color: var(--secondary-color);\r\n\t\ttransition: none !important;\r\n\t}\r\n\r\n\t.indeterminate {\r\n\t\tbackground-color: var(--primary-color);\r\n\r\n\t\t&::before {\r\n\t\t\tcontent: '';\r\n\t\t\tposition: absolute;\r\n\t\t\tbackground-color: inherit;\r\n\t\t\ttop: 0;\r\n\t\t\tleft: 0;\r\n\t\t\tbottom: 0;\r\n\t\t\twill-change: left, right;\r\n\t\t\tanimation: indeterminate 2.1s cubic-bezier(0.65, 0.815, 0.735, 0.395) infinite;\r\n\t\t}\r\n\r\n\t\t&::after {\r\n\t\t\tcontent: '';\r\n\t\t\tposition: absolute;\r\n\t\t\tbackground-color: inherit;\r\n\t\t\ttop: 0;\r\n\t\t\tleft: 0;\r\n\t\t\tbottom: 0;\r\n\t\t\twill-change: left, right;\r\n\t\t\tanimation: indeterminate-short 2.1s cubic-bezier(0.165, 0.84, 0.44, 1) infinite;\r\n\t\t\tanimation-delay: 1.15s;\r\n\t\t}\r\n\t}\r\n}\r\n</style>\r\n\r\n<script>\r\nconst possibleStates = ['converting', 'downloading', 'download finished']\r\n\r\nexport default {\r\n\tdata() {\r\n\t\treturn {\r\n\t\t\tisLoading: false\r\n\t\t}\r\n\t},\r\n\tprops: {\r\n\t\tqueueItem: Object\r\n\t},\r\n\tcomputed: {\r\n\t\thasFails() {\r\n\t\t\treturn this.queueItem.failed >= 1\r\n\t\t},\r\n\t\tallFailed() {\r\n\t\t\tlet allFailed = false\r\n\r\n\t\t\tif (this.queueItem.status === 'download finished') {\r\n\t\t\t\tallFailed = this.queueItem.failed === this.queueItem.size\r\n\t\t\t}\r\n\r\n\t\t\treturn allFailed\r\n\t\t},\r\n\t\tfinishedWithFails() {\r\n\t\t\treturn this.queueItem.status === 'download finished' && this.hasFails\r\n\t\t},\r\n\t\tisDeterminateStatus() {\r\n\t\t\treturn possibleStates.indexOf(this.queueItem.status) !== -1\r\n\t\t},\r\n\t\tbarClass() {\r\n\t\t\treturn {\r\n\t\t\t\tconverting: this.queueItem.status === 'converting',\r\n\t\t\t\tindeterminate: !this.isDeterminateStatus,\r\n\t\t\t\tdeterminate: this.isDeterminateStatus\r\n\t\t\t}\r\n\t\t},\r\n\t\tbarStyle() {\r\n\t\t\tlet width = 0\r\n\t\t\tlet backgroundColor = 'var(--primary-color)'\r\n\r\n\t\t\tif (this.hasFails) {\r\n\t\t\t\t// Orange\r\n\t\t\t\tbackgroundColor = 'hsl(33, 100%, 47%)'\r\n\t\t\t} else {\r\n\t\t\t\t// Green\r\n\t\t\t\tbackgroundColor = 'hsl(150, 76%, 34%)'\r\n\t\t\t}\r\n\r\n\t\t\tif (this.allFailed) {\r\n\t\t\t\t// Red\r\n\t\t\t\tbackgroundColor = 'hsl(360, 100%, 35%)'\r\n\t\t\t}\r\n\r\n\t\t\tif (this.queueItem.status === 'download finished') {\r\n\t\t\t\twidth = 100\r\n\t\t\t}\r\n\r\n\t\t\tif (this.queueItem.status === 'downloading') {\r\n\t\t\t\twidth = this.queueItem.progress\r\n\t\t\t}\r\n\r\n\t\t\tif (this.queueItem.status === 'converting') {\r\n\t\t\t\twidth = 100 - this.queueItem.conversion\r\n\t\t\t}\r\n\r\n\t\t\treturn {\r\n\t\t\t\twidth: `${width}%`,\r\n\t\t\t\tbackgroundColor\r\n\t\t\t}\r\n\t\t},\r\n\t\tresultIconText() {\r\n\t\t\tlet text = 'delete_forever'\r\n\r\n\t\t\tif (this.queueItem.status === 'download finished') {\r\n\t\t\t\tif (!this.hasFails) {\r\n\t\t\t\t\ttext = 'done'\r\n\t\t\t\t} else {\r\n\t\t\t\t\tif (this.queueItem.failed >= this.queueItem.size) {\r\n\t\t\t\t\t\ttext = 'error'\r\n\t\t\t\t\t} else {\r\n\t\t\t\t\t\ttext = 'warning'\r\n\t\t\t\t\t}\r\n\t\t\t\t}\r\n\t\t\t}\r\n\r\n\t\t\treturn text\r\n\t\t}\r\n\t},\r\n\tmethods: {\r\n\t\tonResultIconClick() {\r\n\t\t\tif (this.isDeterminateStatus) {\r\n\t\t\t\tif (this.finishedWithFails) {\r\n\t\t\t\t\tthis.$emit('show-errors', this.queueItem)\r\n\t\t\t\t}\r\n\r\n\t\t\t\tif (this.queueItem.status === 'downloading') {\r\n\t\t\t\t\tthis.isLoading = true\r\n\t\t\t\t\tthis.$emit('remove-item', this.queueItem.uuid)\r\n\t\t\t\t}\r\n\t\t\t} else {\r\n\t\t\t\tthis.isLoading = true\r\n\t\t\t\tthis.$emit('remove-item', this.queueItem.uuid)\r\n\t\t\t}\r\n\t\t}\r\n\t}\r\n}\r\n</script>",".download-object {\n  padding-bottom: 8px; }\n  .download-object .download-info {\n    display: flex;\n    align-items: center; }\n    .download-object .download-info img {\n      height: 75px;\n      flex-shrink: 0;\n      flex: 0 0 75px; }\n    .download-object .download-info .download-line {\n      display: block; }\n    .download-object .download-info .download-slim-separator {\n      display: none; }\n  .download-object .download-info-data {\n    flex: 1 50%;\n    margin-left: 8px;\n    overflow: hidden; }\n  .download-object .download-info-status {\n    flex: 1 15%;\n    margin-left: 8px;\n    width: 80px; }\n  .download-object > .download-bar {\n    display: flex;\n    align-items: center;\n    height: 24px; }\n    .download-object > .download-bar > .queue_icon {\n      cursor: default;\n      margin-left: 8px; }\n    .download-object > .download-bar > .progress {\n      margin: 0px; }\n\n#download_list:not(.slim) .download-line {\n  overflow: hidden;\n  white-space: nowrap;\n  text-overflow: ellipsis; }\n\n#download_list.slim > .download-object .download-info {\n  display: block; }\n  #download_list.slim > .download-object .download-info img {\n    display: none; }\n  #download_list.slim > .download-object .download-info .download-line {\n    display: inline-block; }\n  #download_list.slim > .download-object .download-info .download-slim-separator {\n    display: inline-block; }\n\n#download_list.slim > .download-object .download-info-data {\n  width: calc(80% - 16px);\n  display: inline-block;\n  padding-left: 0px; }\n\n#download_list.slim > .download-object .download-info-status {\n  width: 20%;\n  display: inline-block;\n  float: right; }\n\n.progress {\n  position: relative;\n  height: 4px;\n  display: block;\n  width: 100%;\n  background-color: var(--secondary-background);\n  border-radius: 2px;\n  margin: 0.5rem 0 1rem 0;\n  overflow: hidden; }\n  .progress .determinate {\n    position: absolute;\n    top: 0;\n    left: 0;\n    bottom: 0;\n    background-color: var(--primary-color);\n    transition: width 0.3s linear; }\n  .progress .converting {\n    background-color: var(--secondary-color);\n    transition: none !important; }\n  .progress .indeterminate {\n    background-color: var(--primary-color); }\n    .progress .indeterminate::before {\n      content: '';\n      position: absolute;\n      background-color: inherit;\n      top: 0;\n      left: 0;\n      bottom: 0;\n      will-change: left, right;\n      animation: indeterminate 2.1s cubic-bezier(0.65, 0.815, 0.735, 0.395) infinite; }\n    .progress .indeterminate::after {\n      content: '';\n      position: absolute;\n      background-color: inherit;\n      top: 0;\n      left: 0;\n      bottom: 0;\n      will-change: left, right;\n      animation: indeterminate-short 2.1s cubic-bezier(0.165, 0.84, 0.44, 1) infinite;\n      animation-delay: 1.15s; }\n\n/*# sourceMappingURL=QueueItem.vue.map */"]}, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__ = undefined;
  /* module identifier */
  const __vue_module_identifier__ = undefined;
  /* functional template */
  const __vue_is_functional_template__ = false;
  /* style inject SSR */
  

  
  var QueueItem = normalizeComponent_1(
    { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
    __vue_inject_styles__,
    __vue_script__,
    __vue_scope_id__,
    __vue_is_functional_template__,
    __vue_module_identifier__,
    browser,
    undefined
  );

const state = {
	currentCommit: null,
	latestCommit: null,
	updateAvailable: false,
	deemixVersion: null
};

const actions = {
	setAboutInfo({ commit }, payload) {
		commit('SET_CURRENT_COMMIT', payload.currentCommit);
		commit('SET_LATEST_COMMIT', payload.latestCommit);
		commit('SET_UPDATE_AVAILABLE', payload.updateAvailable);
		commit('SET_DEEMIX_VERSION', payload.deemixVersion);
	}
};

const getters = {
	getAboutInfo: state => state
};

const mutations = {
	SET_CURRENT_COMMIT: (state, payload) => {
		state.currentCommit = payload;
	},
	SET_LATEST_COMMIT: (state, payload) => {
		state.latestCommit = payload;
	},
	SET_UPDATE_AVAILABLE: (state, payload) => {
		state.updateAvailable = payload;
	},
	SET_DEEMIX_VERSION: (state, payload) => {
		state.deemixVersion = payload;
	}
};

var about = {
	state,
	getters,
	actions,
	mutations
};

const getDefaultState = () => {
	return {
		arl: localStorage.getItem('arl') || '',
		status: null,
		user: {
			id: null,
			name: '',
			picture: ''
		},
		clientMode: false
	}
};

const state$1 = getDefaultState();

const actions$1 = {
	login({ commit, dispatch }, payload) {
		const { arl, user, status } = payload;

		dispatch('setARL', { arl });
		commit('SET_USER', user);
		commit('SET_STATUS', status);
	},
	logout({ commit }) {
		localStorage.removeItem('arl');

		commit('RESET_LOGIN');
	},
	setARL({ commit }, payload) {
		let { arl, saveOnLocalStorage } = payload;

		saveOnLocalStorage = typeof saveOnLocalStorage === 'undefined' ? true : saveOnLocalStorage;

		commit('SET_ARL', arl);

		if (saveOnLocalStorage) {
			localStorage.setItem('arl', arl);
		}
	},
	removeARL({ commit }) {
		commit('SET_ARL', '');

		localStorage.removeItem('arl');
	},
	setUser({ commit }, payload) {
		commit('SET_USER', payload);
	},
	setClientMode({ commit }, payload) {
		commit('SET_CLIENT_MODE', payload);
	}
};

const getters$1 = {
	getARL: state => state.arl,
	getUser: state => state.user,
	getClientMode: state => state.clientMode,
	isLoggedIn: state => !!state.arl
};

const mutations$1 = {
	SET_ARL(state, payload) {
		state.arl = payload;
	},
	SET_STATUS(state, payload) {
		state.status = payload;
	},
	SET_USER(state, payload) {
		state.user = payload;
	},
	SET_CLIENT_MODE(state, payload) {
		state.clientMode = payload;
	},
	RESET_LOGIN(state) {
		// Needed for reactivity
		let clientMode = state.clientMode;
		Object.assign(state, getDefaultState());
		state.clientMode = clientMode;
	}
};

var login = {
	state: state$1,
	getters: getters$1,
	actions: actions$1,
	mutations: mutations$1
};

const state$2 = {
	artist: '',
	bitrate: '',
	cover: '',
	downloaded: 0,
	errors: [],
	failed: 0,
	id: '',
	progress: 0,
	silent: true,
	size: 0,
	title: '',
	type: '',
	uuid: ''
};

const actions$2 = {
	setErrors({ commit }, payload) {
		commit('SET_ERRORS', payload);
	}
};

const getters$2 = {
	getErrors: state => state
};

const mutations$2 = {
	SET_ERRORS(state, payload) {
		// The payload has useless data for the GUI, so only the needed data is saved in the store
		for (const errorName in state) {
			if (state.hasOwnProperty(errorName)) {
				const error = payload[errorName];

				state[errorName] = error;
			}
		}
	}
};

var errors = {
	state: state$2,
	getters: getters$2,
	actions: actions$2,
	mutations: mutations$2
};

// Load Vuex
Vue.use(index$2);

// Create store
var store = new index$2.Store({
	modules: {
		about,
		login,
		errors
	},
	strict: "development" !== 'production'
});

const socket = io.connect(window.location.href);

socket.on('connect', () => {
	document.getElementById('start_app_placeholder').classList.add('loading_placeholder--hidden');
});

socket.on('init_update', data => {
	store.dispatch('setAboutInfo', data);
});

var commonjsGlobal = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

function createCommonjsModule(fn, basedir, module) {
	return module = {
		path: basedir,
		exports: {},
		require: function (path, base) {
			return commonjsRequire(path, (base === undefined || base === null) ? module.path : base);
		}
	}, fn(module, module.exports), module.exports;
}

function commonjsRequire () {
	throw new Error('Dynamic requires are not currently supported by @rollup/plugin-commonjs');
}

var toastify = createCommonjsModule(function (module) {
/*!
 * Toastify js 1.9.3
 * https://github.com/apvarun/toastify-js
 * @license MIT licensed
 *
 * Copyright (C) 2018 Varun A P
 */
(function(root, factory) {
  if ( module.exports) {
    module.exports = factory();
  } else {
    root.Toastify = factory();
  }
})(commonjsGlobal, function(global) {
  // Object initialization
  var Toastify = function(options) {
      // Returning a new init object
      return new Toastify.lib.init(options);
    },
    // Library version
    version = "1.9.3";

  // Defining the prototype of the object
  Toastify.lib = Toastify.prototype = {
    toastify: version,

    constructor: Toastify,

    // Initializing the object with required parameters
    init: function(options) {
      // Verifying and validating the input object
      if (!options) {
        options = {};
      }

      // Creating the options object
      this.options = {};

      this.toastElement = null;

      // Validating the options
      this.options.text = options.text || "Hi there!"; // Display message
      this.options.node = options.node; // Display content as node
      this.options.duration = options.duration === 0 ? 0 : options.duration || 3000; // Display duration
      this.options.selector = options.selector; // Parent selector
      this.options.callback = options.callback || function() {}; // Callback after display
      this.options.destination = options.destination; // On-click destination
      this.options.newWindow = options.newWindow || false; // Open destination in new window
      this.options.close = options.close || false; // Show toast close icon
      this.options.gravity = options.gravity === "bottom" ? "toastify-bottom" : "toastify-top"; // toast position - top or bottom
      this.options.positionLeft = options.positionLeft || false; // toast position - left or right
      this.options.position = options.position || ''; // toast position - left or right
      this.options.backgroundColor = options.backgroundColor; // toast background color
      this.options.avatar = options.avatar || ""; // img element src - url or a path
      this.options.className = options.className || ""; // additional class names for the toast
      this.options.stopOnFocus = options.stopOnFocus === undefined? true: options.stopOnFocus; // stop timeout on focus
      this.options.onClick = options.onClick; // Callback after click

      this.options.offset = options.offset || { x: 0, y: 0 }; // toast offset

      // Returning the current object for chaining functions
      return this;
    },

    // Building the DOM element
    buildToast: function() {
      // Validating if the options are defined
      if (!this.options) {
        throw "Toastify is not initialized";
      }

      // Creating the DOM object
      var divElement = document.createElement("div");
      divElement.className = "toastify on " + this.options.className;

      // Positioning toast to left or right or center
      if (!!this.options.position) {
        divElement.className += " toastify-" + this.options.position;
      } else {
        // To be depreciated in further versions
        if (this.options.positionLeft === true) {
          divElement.className += " toastify-left";
          console.warn('Property `positionLeft` will be depreciated in further versions. Please use `position` instead.');
        } else {
          // Default position
          divElement.className += " toastify-right";
        }
      }

      // Assigning gravity of element
      divElement.className += " " + this.options.gravity;

      if (this.options.backgroundColor) {
        divElement.style.background = this.options.backgroundColor;
      }

      // Adding the toast message/node
      if (this.options.node && this.options.node.nodeType === Node.ELEMENT_NODE) {
        // If we have a valid node, we insert it
        divElement.appendChild(this.options.node);
      } else {
        divElement.innerHTML = this.options.text;

        if (this.options.avatar !== "") {
          var avatarElement = document.createElement("img");
          avatarElement.src = this.options.avatar;

          avatarElement.className = "toastify-avatar";

          if (this.options.position == "left" || this.options.positionLeft === true) {
            // Adding close icon on the left of content
            divElement.appendChild(avatarElement);
          } else {
            // Adding close icon on the right of content
            divElement.insertAdjacentElement("afterbegin", avatarElement);
          }
        }
      }

      // Adding a close icon to the toast
      if (this.options.close === true) {
        // Create a span for close element
        var closeElement = document.createElement("span");
        closeElement.innerHTML = "&#10006;";

        closeElement.className = "toast-close";

        // Triggering the removal of toast from DOM on close click
        closeElement.addEventListener(
          "click",
          function(event) {
            event.stopPropagation();
            this.removeElement(this.toastElement);
            window.clearTimeout(this.toastElement.timeOutValue);
          }.bind(this)
        );

        //Calculating screen width
        var width = window.innerWidth > 0 ? window.innerWidth : screen.width;

        // Adding the close icon to the toast element
        // Display on the right if screen width is less than or equal to 360px
        if ((this.options.position == "left" || this.options.positionLeft === true) && width > 360) {
          // Adding close icon on the left of content
          divElement.insertAdjacentElement("afterbegin", closeElement);
        } else {
          // Adding close icon on the right of content
          divElement.appendChild(closeElement);
        }
      }

      // Clear timeout while toast is focused
      if (this.options.stopOnFocus && this.options.duration > 0) {
        var self = this;
        // stop countdown
        divElement.addEventListener(
          "mouseover",
          function(event) {
            window.clearTimeout(divElement.timeOutValue);
          }
        );
        // add back the timeout
        divElement.addEventListener(
          "mouseleave",
          function() {
            divElement.timeOutValue = window.setTimeout(
              function() {
                // Remove the toast from DOM
                self.removeElement(divElement);
              },
              self.options.duration
            );
          }
        );
      }
      
      // Adding an on-click destination path
      if (typeof this.options.destination !== "undefined") {
        divElement.addEventListener(
          "click",
          function(event) {
            event.stopPropagation();
            if (this.options.newWindow === true) {
              window.open(this.options.destination, "_blank");
            } else {
              window.location = this.options.destination;
            }
          }.bind(this)
        );
      }

      if (typeof this.options.onClick === "function" && typeof this.options.destination === "undefined") {
        divElement.addEventListener(
          "click",
          function(event) {
            event.stopPropagation();
            this.options.onClick();            
          }.bind(this)
        );
      }

      // Adding offset
      if(typeof this.options.offset === "object") {

        var x = getAxisOffsetAValue("x", this.options);
        var y = getAxisOffsetAValue("y", this.options);
        
        var xOffset = this.options.position == "left" ? x : "-" + x;
        var yOffset = this.options.gravity == "toastify-top" ? y : "-" + y;

        divElement.style.transform = "translate(" + xOffset + "," + yOffset + ")";

      }

      // Returning the generated element
      return divElement;
    },

    // Displaying the toast
    showToast: function() {
      // Creating the DOM object for the toast
      this.toastElement = this.buildToast();

      // Getting the root element to with the toast needs to be added
      var rootElement;
      if (typeof this.options.selector === "undefined") {
        rootElement = document.body;
      } else {
        rootElement = document.getElementById(this.options.selector);
      }

      // Validating if root element is present in DOM
      if (!rootElement) {
        throw "Root element is not defined";
      }

      // Adding the DOM element
      rootElement.insertBefore(this.toastElement, rootElement.firstChild);

      // Repositioning the toasts in case multiple toasts are present
      Toastify.reposition();

      if (this.options.duration > 0) {
        this.toastElement.timeOutValue = window.setTimeout(
          function() {
            // Remove the toast from DOM
            this.removeElement(this.toastElement);
          }.bind(this),
          this.options.duration
        ); // Binding `this` for function invocation
      }

      // Supporting function chaining
      return this;
    },

    hideToast: function() {
      if (this.toastElement.timeOutValue) {
        clearTimeout(this.toastElement.timeOutValue);
      }
      this.removeElement(this.toastElement);
    },

    // Removing the element from the DOM
    removeElement: function(toastElement) {
      // Hiding the element
      // toastElement.classList.remove("on");
      toastElement.className = toastElement.className.replace(" on", "");

      // Removing the element from DOM after transition end
      window.setTimeout(
        function() {
          // remove options node if any
          if (this.options.node && this.options.node.parentNode) {
            this.options.node.parentNode.removeChild(this.options.node);
          }

          // Remove the elemenf from the DOM, only when the parent node was not removed before.
          if (toastElement.parentNode) {
            toastElement.parentNode.removeChild(toastElement);
          }

          // Calling the callback function
          this.options.callback.call(toastElement);

          // Repositioning the toasts again
          Toastify.reposition();
        }.bind(this),
        400
      ); // Binding `this` for function invocation
    },
  };

  // Positioning the toasts on the DOM
  Toastify.reposition = function() {

    // Top margins with gravity
    var topLeftOffsetSize = {
      top: 15,
      bottom: 15,
    };
    var topRightOffsetSize = {
      top: 15,
      bottom: 15,
    };
    var offsetSize = {
      top: 15,
      bottom: 15,
    };

    // Get all toast messages on the DOM
    var allToasts = document.getElementsByClassName("toastify");

    var classUsed;

    // Modifying the position of each toast element
    for (var i = 0; i < allToasts.length; i++) {
      // Getting the applied gravity
      if (containsClass(allToasts[i], "toastify-top") === true) {
        classUsed = "toastify-top";
      } else {
        classUsed = "toastify-bottom";
      }

      var height = allToasts[i].offsetHeight;
      classUsed = classUsed.substr(9, classUsed.length-1);
      // Spacing between toasts
      var offset = 15;

      var width = window.innerWidth > 0 ? window.innerWidth : screen.width;

      // Show toast in center if screen with less than or qual to 360px
      if (width <= 360) {
        // Setting the position
        allToasts[i].style[classUsed] = offsetSize[classUsed] + "px";

        offsetSize[classUsed] += height + offset;
      } else {
        if (containsClass(allToasts[i], "toastify-left") === true) {
          // Setting the position
          allToasts[i].style[classUsed] = topLeftOffsetSize[classUsed] + "px";

          topLeftOffsetSize[classUsed] += height + offset;
        } else {
          // Setting the position
          allToasts[i].style[classUsed] = topRightOffsetSize[classUsed] + "px";

          topRightOffsetSize[classUsed] += height + offset;
        }
      }
    }

    // Supporting function chaining
    return this;
  };

  // Helper function to get offset.
  function getAxisOffsetAValue(axis, options) {

    if(options.offset[axis]) {
      if(isNaN(options.offset[axis])) {
        return options.offset[axis];
      }
      else {
        return options.offset[axis] + 'px';
      }
    }

    return '0px';

  }

  function containsClass(elem, yourClass) {
    if (!elem || typeof yourClass !== "string") {
      return false;
    } else if (
      elem.className &&
      elem.className
        .trim()
        .split(/\s+/gi)
        .indexOf(yourClass) > -1
    ) {
      return true;
    } else {
      return false;
    }
  }

  // Setting up the prototype for the init object
  Toastify.lib.init.prototype = Toastify.lib;

  // Returning the Toastify function to be assigned to the window object/module
  return Toastify;
});
});

var css_248z$2 = "/*!\n * Toastify js 1.9.3\n * https://github.com/apvarun/toastify-js\n * @license MIT licensed\n *\n * Copyright (C) 2018 Varun A P\n */\n\n.toastify {\n  padding: 12px 20px;\n  color: #ffffff;\n  display: inline-block;\n  box-shadow: 0 3px 6px -1px rgba(0, 0, 0, 0.12), 0 10px 36px -4px rgba(77, 96, 232, 0.3);\n  background: linear-gradient(135deg, #73a5ff, #5477f5);\n  position: fixed;\n  opacity: 0;\n  transition: all 0.4s cubic-bezier(0.215, 0.61, 0.355, 1);\n  border-radius: 2px;\n  cursor: pointer;\n  text-decoration: none;\n  max-width: calc(50% - 20px);\n  z-index: 2147483647;\n}\n\n.toastify.on {\n  opacity: 1;\n}\n\n.toast-close {\n  opacity: 0.4;\n  padding: 0 5px;\n}\n\n.toastify-right {\n  right: 15px;\n}\n\n.toastify-left {\n  left: 15px;\n}\n\n.toastify-top {\n  top: -150px;\n}\n\n.toastify-bottom {\n  bottom: -150px;\n}\n\n.toastify-rounded {\n  border-radius: 25px;\n}\n\n.toastify-avatar {\n  width: 1.5em;\n  height: 1.5em;\n  margin: -7px 5px;\n  border-radius: 2px;\n}\n\n.toastify-center {\n  margin-left: auto;\n  margin-right: auto;\n  left: 0;\n  right: 0;\n  max-width: -webkit-fit-content;\n  max-width: fit-content;\n  max-width: -moz-fit-content;\n}\n\n@media only screen and (max-width: 360px) {\n  .toastify-right, .toastify-left {\n    margin-left: auto;\n    margin-right: auto;\n    left: 0;\n    right: 0;\n    max-width: -webkit-fit-content;\n    max-width: -moz-fit-content;\n    max-width: fit-content;\n  }\n}\n";
styleInject(css_248z$2);

var css_248z$3 = ".toast-icon {\n  display: inline-block;\n  margin-right: 0.5rem;\n}\n\n.circle-loader {\n  display: inline-block;\n  width: 1rem;\n  height: 1rem;\n  border: 2px solid var(--primary-color);\n  border-radius: 50%;\n  border-bottom: 2px solid var(--secondary-background);\n  -webkit-animation: spin 1s linear infinite;\n          animation: spin 1s linear infinite;\n}\n\n.toastify {\n  display: flex;\n  align-items: center;\n  box-shadow: 0 3px 6px -1px rgba(0, 0, 0, 0.12), 0 10px 36px -4px rgba(0, 0, 0, 0.3);\n  background: var(--toast-background);\n  color: var(--toast-text);\n}\n\n.toastify .circle-loader {\n  border-bottom-color: var(--toast-secondary);\n}\r\n";
styleInject(css_248z$3);

const sharedOptions = {
	gravity: 'bottom',
	position: 'left',
	offset: {
		x: '14rem'
	}
};

let toastsWithId = {};

const toast = function(msg, icon = null, dismiss = true, id = null) {
	if (toastsWithId[id]) {
		let toastObj = toastsWithId[id];

		let toastElement = document.querySelectorAll(`div.toastify[toast_id=${id}]`);

		if (msg) {
			toastElement.forEach(toast => {
				const messages = toast.querySelectorAll('.toast-message');

				messages.forEach(message => {
					message.innerHTML = msg;
				});
			});
		}

		if (icon) {
			if (icon == 'loading') {
				icon = `<div class="circle-loader"></div>`;
			} else {
				icon = `<i class="material-icons">${icon}</i>`;
			}

			toastElement.forEach(toast => {
				const icons = toast.querySelectorAll('.toast-icon');

				icons.forEach(toastIcon => {
					toastIcon.innerHTML = icon;
				});
			});
		}
		if (dismiss !== null && dismiss) {
			toastElement.forEach(toast => {
				toast.classList.add('dismissable');
			});

			setTimeout(() => {
				toastObj.hideToast();

				delete toastsWithId[id];
			}, 3000);
		}
	} else {
		if (icon == null) {
			icon = '';
		} else if (icon == 'loading') {
			icon = `<div class="circle-loader"></div>`;
		} else {
			icon = `<i class="material-icons">${icon}</i>`;
		}

		let toastObj = toastify({
			...sharedOptions,
			text: `<span class="toast-icon">${icon}</span><span class="toast-message">${msg}</toast>`,
			duration: dismiss ? 3000 : 0,
			className: dismiss ? 'dismissable' : '',
			onClick: function() {
				let dismissable = true;

				if (id) {
					let toastClasses = document.querySelector(`div.toastify[toast_id=${id}]`).classList;

					if (toastClasses) {
						dismissable = Array.prototype.slice.call(toastClasses).indexOf('dismissable') != -1;
					}
				}
				if (toastObj && dismissable) {
					toastObj.hideToast();

					if (id) {
						delete toastsWithId[id];
					}
				}
			}
		}).showToast();
		if (id) {
			toastsWithId[id] = toastObj;

			toastObj.toastElement.setAttribute('toast_id', id);
		}
	}
};

socket.on('toast', data => {
	const { msg, icon, dismiss, id } = data;

	toast(msg, icon || null, dismiss !== undefined ? dismiss : true, id || null);
});

//

const tabMinWidth = 250;
const tabMaxWidth = 500;

var script$1 = {
	components: {
		QueueItem
	},
	data() {
		return {
			cachedTabWidth: parseInt(localStorage.getItem('downloadTabWidth')) || 300,
			queue: [],
			queueList: {},
			queueComplete: [],
			isExpanded: localStorage.getItem('downloadTabOpen') === 'true'
		}
	},
	computed: {
		...mapGetters({
			clientMode: 'getClientMode'
		})
	},
	created() {
		const checkIfToggleBar = keyEvent => {
			if (!(keyEvent.ctrlKey && keyEvent.key === 'b')) return

			this.toggleDownloadTab();
		};

		document.addEventListener('keyup', checkIfToggleBar);

		this.$on('hook:destroyed', () => {
			document.removeEventListener('keyup', checkIfToggleBar);
		});
	},
	mounted() {
		socket.on('startDownload', this.startDownload);
		socket.on('startConversion', this.startConversion);
		socket.on('init_downloadQueue', this.initQueue);
		socket.on('addedToQueue', this.addToQueue);
		socket.on('updateQueue', this.updateQueue);
		socket.on('removedFromQueue', this.removeFromQueue);
		socket.on('finishDownload', this.finishDownload);
		socket.on('removedAllDownloads', this.removeAllDownloads);
		socket.on('removedFinishedDownloads', this.removedFinishedDownloads);

		// Check if download tab has slim entries
		if ('true' === localStorage.getItem('slimDownloads')) {
			this.$refs.list.classList.add('slim');
		}

		if ('true' === localStorage.getItem('downloadTabOpen')) {
			this.$refs.container.classList.remove('tab_hidden');

			this.setTabWidth(this.cachedTabWidth);
		}

		document.addEventListener('mouseup', () => {
			document.removeEventListener('mousemove', this.handleDrag);
		});

		window.addEventListener('beforeunload', () => {
			localStorage.setItem('downloadTabWidth', this.cachedTabWidth);
		});
	},
	methods: {
		...mapActions(['setErrors']),
		onRemoveItem(uuid) {
			socket.emit('removeFromQueue', uuid);
		},
		setTabWidth(newWidth) {
			if (undefined === newWidth) {
				this.$refs.container.style.width = '';
				this.$refs.list.style.width = '';
			} else {
				this.$refs.container.style.width = newWidth + 'px';
				this.$refs.list.style.width = newWidth + 'px';
			}
		},
		initQueue(data) {
			const {
				queue: initQueue,
				queueComplete: initQueueComplete,
				currentItem,
				queueList: initQueueList,
				restored
			} = data;

			if (initQueueComplete.length) {
				initQueueComplete.forEach(item => {
					initQueueList[item].silent = true;
					this.addToQueue(initQueueList[item]);
				});
			}

			if (currentItem) {
				initQueueList[currentItem].silent = true;
				this.addToQueue(initQueueList[currentItem], true);
			}

			initQueue.forEach(item => {
				initQueueList[item].silent = true;
				this.addToQueue(initQueueList[item]);
			});

			if (restored) {
				toast(this.$t('toasts.queueRestored'), 'done', true, 'restoring_queue');
				socket.emit('queueRestored');
			}
		},
		addToQueue(queueItem, current = false) {
			if (Array.isArray(queueItem)) {
				if (queueItem.length > 1) {
					queueItem.forEach((item, i) => {
						item.silent = true;
						this.addToQueue(item);
					});
					toast(this.$t('toasts.addedMoreToQueue', { n: queueItem.length }), 'playlist_add_check');
					return
				} else {
					queueItem = queueItem[0];
				}
			}

			// * Here we have only queueItem objects
			this.$set(queueItem, 'current', current);
			this.$set(this.queueList, queueItem.uuid, queueItem);

			// * Used when opening the app in another tab
			const itemIsAlreadyDownloaded = queueItem.downloaded + queueItem.failed == queueItem.size;

			if (itemIsAlreadyDownloaded) {
				const itemIsNotInCompletedQueue = this.queueComplete.indexOf(queueItem.uuid) == -1;

				this.$set(this.queueList[queueItem.uuid], 'status', 'download finished');

				if (itemIsNotInCompletedQueue) {
					// * Add it
					this.queueComplete.push(queueItem.uuid);
				}
			} else {
				const itemIsNotInQueue = this.queue.indexOf(queueItem.uuid) == -1;

				if (itemIsNotInQueue) {
					this.queue.push(queueItem.uuid);
				}
			}

			const needToStartDownload = (queueItem.progress > 0 && queueItem.progress < 100) || current;

			if (needToStartDownload) {
				this.startDownload(queueItem.uuid);
			}

			if (!queueItem.silent) {
				toast(this.$t('toasts.addedToQueue', { item: queueItem.title }), 'playlist_add_check');
			}
		},
		updateQueue(update) {
			// downloaded and failed default to false?
			const { uuid, downloaded, failed, progress, conversion, error, data, errid } = update;

			if (uuid && this.queue.indexOf(uuid) > -1) {
				if (downloaded) {
					this.queueList[uuid].downloaded++;
				}

				if (failed) {
					this.queueList[uuid].failed++;
					this.queueList[uuid].errors.push({ message: error, data: data, errid: errid });
				}

				if (progress) {
					this.queueList[uuid].progress = progress;
				}

				if (conversion) {
					this.queueList[uuid].conversion = conversion;
				}
			}
		},
		removeFromQueue(uuid) {
			let index = this.queue.indexOf(uuid);

			if (index > -1) {
				this.$delete(this.queue, index);
				this.$delete(this.queueList, uuid);
			}
		},
		removeAllDownloads(currentItem) {
			this.queueComplete = [];

			if (!currentItem) {
				this.queue = [];
				this.queueList = {};
			} else {
				this.queue = [currentItem];

				let tempQueueItem = this.queueList[currentItem];

				this.queueList = {};
				this.queueList[currentItem] = tempQueueItem;
			}
		},
		removedFinishedDownloads() {
			this.queueComplete.forEach(uuid => {
				this.$delete(this.queueList, uuid);
			});

			this.queueComplete = [];
		},
		toggleDownloadTab() {
			this.setTabWidth();

			this.$refs.container.style.transition = 'all 250ms ease-in-out';

			// Toggle returns a Boolean based on the action it performed
			let isHidden = this.$refs.container.classList.toggle('tab_hidden');
			this.isExpanded = !isHidden;

			if (this.isExpanded) {
				this.setTabWidth(this.cachedTabWidth);
			}

			localStorage.setItem('downloadTabOpen', this.isExpanded);
		},
		cleanQueue() {
			socket.emit('removeFinishedDownloads');
		},
		cancelQueue() {
			socket.emit('cancelAllDownloads');
		},
		openDownloadsFolder() {
			// if (this.clientMode) {
			socket.emit('openDownloadsFolder');
			// }
		},
		handleDrag(event) {
			let newWidth = window.innerWidth - event.pageX + 2;

			if (newWidth < tabMinWidth) {
				newWidth = tabMinWidth;
			} else if (newWidth > tabMaxWidth) {
				newWidth = tabMaxWidth;
			}

			this.cachedTabWidth = newWidth;
			this.setTabWidth(newWidth);
		},
		startDrag() {
			document.addEventListener('mousemove', this.handleDrag);
		},
		startDownload(uuid) {
			this.$set(this.queueList[uuid], 'status', 'downloading');
		},
		finishDownload(uuid) {
			let isInQueue = this.queue.indexOf(uuid) > -1;

			if (!isInQueue) return

			this.$set(this.queueList[uuid], 'status', 'download finished');
			toast(this.$t('toasts.finishDownload', { item: this.queueList[uuid].title }), 'done');

			let index = this.queue.indexOf(uuid);

			if (index > -1) {
				this.queue.splice(index, 1);
				this.queueComplete.push(uuid);
			}

			if (this.queue.length <= 0) {
				toast(this.$t('toasts.allDownloaded'), 'done_all');
			}
		},
		startConversion(uuid) {
			this.$set(this.queueList[uuid], 'status', 'converting');
			this.$set(this.queueList[uuid], 'conversion', 0);
		},
		async showErrorsTab(item) {
			await this.setErrors(item);

			this.$router.push({ name: 'Errors' });
		}
	}
};

/* script */
const __vue_script__$1 = script$1;

/* template */
var __vue_render__$1 = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c(
    "div",
    {
      ref: "container",
      staticClass: "block tab_hidden bg-panels-bg text-foreground",
      attrs: {
        id: "download_tab_container",
        "data-label": _vm.$t("downloads"),
        "aria-label": "downloads"
      },
      on: {
        transitionend: function($event) {
          _vm.$refs.container.style.transition = "";
        }
      }
    },
    [
      _c("div", {
        directives: [
          {
            name: "show",
            rawName: "v-show",
            value: _vm.isExpanded,
            expression: "isExpanded"
          }
        ],
        staticClass: "absolute w-4 h-full bg-grayscale-200",
        staticStyle: { cursor: "ew-resize" },
        on: {
          mousedown: function($event) {
            $event.preventDefault();
            return _vm.startDrag($event)
          }
        }
      }),
      _vm._v(" "),
      _c("i", {
        ref: "toggler",
        staticClass: "m-1 text-2xl cursor-pointer material-icons",
        attrs: {
          id: "toggle_download_tab",
          title: _vm.$t("globals.toggle_download_tab_hint")
        },
        on: {
          click: function($event) {
            $event.preventDefault();
            return _vm.toggleDownloadTab($event)
          }
        }
      }),
      _vm._v(" "),
      _c("div", { attrs: { id: "queue_buttons" } }, [
        _vm.clientMode
          ? _c(
              "i",
              {
                staticClass: "m-1 text-2xl cursor-pointer material-icons",
                attrs: { title: _vm.$t("globals.open_downloads_folder") },
                on: { click: _vm.openDownloadsFolder }
              },
              [_vm._v("\n\t\t\tfolder_open\n\t\t")]
            )
          : _vm._e(),
        _vm._v(" "),
        _c(
          "i",
          {
            staticClass: "m-1 text-2xl cursor-pointer material-icons",
            attrs: { title: _vm.$t("globals.clean_queue_hint") },
            on: { click: _vm.cleanQueue }
          },
          [_vm._v("\n\t\t\tclear_all\n\t\t")]
        ),
        _vm._v(" "),
        _c(
          "i",
          {
            staticClass: "m-1 text-2xl cursor-pointer material-icons",
            attrs: { title: _vm.$t("globals.cancel_queue_hint") },
            on: { click: _vm.cancelQueue }
          },
          [_vm._v("\n\t\t\tdelete_sweep\n\t\t")]
        )
      ]),
      _vm._v(" "),
      _c(
        "div",
        {
          directives: [
            {
              name: "show",
              rawName: "v-show",
              value: _vm.isExpanded,
              expression: "isExpanded"
            }
          ],
          ref: "list",
          staticClass: "w-full pr-2",
          attrs: { id: "download_list" }
        },
        _vm._l(_vm.queueList, function(item) {
          return _c("QueueItem", {
            key: item.uuid,
            attrs: { "queue-item": item },
            on: {
              "show-errors": _vm.showErrorsTab,
              "remove-item": _vm.onRemoveItem
            }
          })
        }),
        1
      )
    ]
  )
};
var __vue_staticRenderFns__$1 = [];
__vue_render__$1._withStripped = true;

  /* style */
  const __vue_inject_styles__$1 = function (inject) {
    if (!inject) return
    inject("data-v-9384a8cc_0", { source: "#download_tab_container[data-v-9384a8cc] {\n  height: 100vh;\n}\n#download_list[data-v-9384a8cc] {\n  height: calc(100% - 32px);\n  padding-left: 28px;\n  overflow-y: scroll;\n}\n#download_list[data-v-9384a8cc]::-webkit-scrollbar {\n    width: 10px;\n}\n#download_list[data-v-9384a8cc]::-webkit-scrollbar-track {\n    background: var(--panels-background);\n}\n#download_list[data-v-9384a8cc]::-webkit-scrollbar-thumb {\n    background: var(--panels-scroll);\n    border-radius: 4px;\n    width: 6px;\n    padding: 0px 2px;\n}\n\n/*# sourceMappingURL=TheDownloadBar.vue.map */", map: {"version":3,"sources":["C:\\Users\\Roberto\\Dev\\repos\\deemix-pyweb\\webui\\src\\components\\downloads\\TheDownloadBar.vue","TheDownloadBar.vue"],"names":[],"mappings":"AA0DA;EACA,aAAA;AAAA;AAGA;EACA,yBAAA;EACA,kBAAA;EACA,kBAAA;AAAA;AAHA;IAMA,WAAA;AAAA;AANA;IAUA,oCAAA;AAAA;AAVA;IAcA,gCAAA;IACA,kBAAA;IACA,UAAA;IACA,gBAAA;AAAA;;AC9DA,6CAA6C","file":"TheDownloadBar.vue","sourcesContent":["<template>\r\n\t<div\r\n\t\tid=\"download_tab_container\"\r\n\t\tclass=\"block tab_hidden bg-panels-bg text-foreground\"\r\n\t\t@transitionend=\"$refs.container.style.transition = ''\"\r\n\t\tref=\"container\"\r\n\t\t:data-label=\"$t('downloads')\"\r\n\t\taria-label=\"downloads\"\r\n\t>\r\n\t\t<!-- Drag Handler -->\r\n\t\t<div\r\n\t\t\tv-show=\"isExpanded\"\r\n\t\t\tclass=\"absolute w-4 h-full bg-grayscale-200\"\r\n\t\t\t@mousedown.prevent=\"startDrag\"\r\n\t\t\tstyle=\"cursor: ew-resize\"\r\n\t\t></div>\r\n\r\n\t\t<i\r\n\t\t\tid=\"toggle_download_tab\"\r\n\t\t\tclass=\"m-1 text-2xl cursor-pointer material-icons\"\r\n\t\t\t@click.prevent=\"toggleDownloadTab\"\r\n\t\t\tref=\"toggler\"\r\n\t\t\t:title=\"$t('globals.toggle_download_tab_hint')\"\r\n\t\t></i>\r\n\t\t<div id=\"queue_buttons\">\r\n\t\t\t<i\r\n\t\t\t\tv-if=\"clientMode\"\r\n\t\t\t\tclass=\"m-1 text-2xl cursor-pointer material-icons\"\r\n\t\t\t\t:title=\"$t('globals.open_downloads_folder')\"\r\n\t\t\t\t@click=\"openDownloadsFolder\"\r\n\t\t\t>\r\n\t\t\t\tfolder_open\r\n\t\t\t</i>\r\n\t\t\t<i class=\"m-1 text-2xl cursor-pointer material-icons\" @click=\"cleanQueue\" :title=\"$t('globals.clean_queue_hint')\">\r\n\t\t\t\tclear_all\r\n\t\t\t</i>\r\n\t\t\t<i\r\n\t\t\t\tclass=\"m-1 text-2xl cursor-pointer material-icons\"\r\n\t\t\t\t@click=\"cancelQueue\"\r\n\t\t\t\t:title=\"$t('globals.cancel_queue_hint')\"\r\n\t\t\t>\r\n\t\t\t\tdelete_sweep\r\n\t\t\t</i>\r\n\t\t</div>\r\n\r\n\t\t<div v-show=\"isExpanded\" id=\"download_list\" class=\"w-full pr-2\" ref=\"list\">\r\n\t\t\t<QueueItem\r\n\t\t\t\tv-for=\"item in queueList\"\r\n\t\t\t\t:queue-item=\"item\"\r\n\t\t\t\t:key=\"item.uuid\"\r\n\t\t\t\t@show-errors=\"showErrorsTab\"\r\n\t\t\t\t@remove-item=\"onRemoveItem\"\r\n\t\t\t/>\r\n\t\t</div>\r\n\t</div>\r\n</template>\r\n\r\n<style lang=\"scss\" scoped>\r\n#download_tab_container {\r\n\theight: 100vh;\r\n}\r\n\r\n#download_list {\r\n\theight: calc(100% - 32px);\r\n\tpadding-left: 28px;\r\n\toverflow-y: scroll;\r\n\r\n\t&::-webkit-scrollbar {\r\n\t\twidth: 10px;\r\n\t}\r\n\r\n\t&::-webkit-scrollbar-track {\r\n\t\tbackground: var(--panels-background);\r\n\t}\r\n\r\n\t&::-webkit-scrollbar-thumb {\r\n\t\tbackground: var(--panels-scroll);\r\n\t\tborder-radius: 4px;\r\n\t\twidth: 6px;\r\n\t\tpadding: 0px 2px;\r\n\t}\r\n}\r\n</style>\r\n\r\n<script>\r\nimport { mapActions, mapGetters } from 'vuex'\r\nimport QueueItem from '@components/downloads/QueueItem.vue'\r\n\r\nimport { socket } from '@/utils/socket'\r\nimport { toast } from '@/utils/toasts'\r\n\r\nconst tabMinWidth = 250\r\nconst tabMaxWidth = 500\r\n\r\nexport default {\r\n\tcomponents: {\r\n\t\tQueueItem\r\n\t},\r\n\tdata() {\r\n\t\treturn {\r\n\t\t\tcachedTabWidth: parseInt(localStorage.getItem('downloadTabWidth')) || 300,\r\n\t\t\tqueue: [],\r\n\t\t\tqueueList: {},\r\n\t\t\tqueueComplete: [],\r\n\t\t\tisExpanded: localStorage.getItem('downloadTabOpen') === 'true'\r\n\t\t}\r\n\t},\r\n\tcomputed: {\r\n\t\t...mapGetters({\r\n\t\t\tclientMode: 'getClientMode'\r\n\t\t})\r\n\t},\r\n\tcreated() {\r\n\t\tconst checkIfToggleBar = keyEvent => {\r\n\t\t\tif (!(keyEvent.ctrlKey && keyEvent.key === 'b')) return\r\n\r\n\t\t\tthis.toggleDownloadTab()\r\n\t\t}\r\n\r\n\t\tdocument.addEventListener('keyup', checkIfToggleBar)\r\n\r\n\t\tthis.$on('hook:destroyed', () => {\r\n\t\t\tdocument.removeEventListener('keyup', checkIfToggleBar)\r\n\t\t})\r\n\t},\r\n\tmounted() {\r\n\t\tsocket.on('startDownload', this.startDownload)\r\n\t\tsocket.on('startConversion', this.startConversion)\r\n\t\tsocket.on('init_downloadQueue', this.initQueue)\r\n\t\tsocket.on('addedToQueue', this.addToQueue)\r\n\t\tsocket.on('updateQueue', this.updateQueue)\r\n\t\tsocket.on('removedFromQueue', this.removeFromQueue)\r\n\t\tsocket.on('finishDownload', this.finishDownload)\r\n\t\tsocket.on('removedAllDownloads', this.removeAllDownloads)\r\n\t\tsocket.on('removedFinishedDownloads', this.removedFinishedDownloads)\r\n\r\n\t\t// Check if download tab has slim entries\r\n\t\tif ('true' === localStorage.getItem('slimDownloads')) {\r\n\t\t\tthis.$refs.list.classList.add('slim')\r\n\t\t}\r\n\r\n\t\tif ('true' === localStorage.getItem('downloadTabOpen')) {\r\n\t\t\tthis.$refs.container.classList.remove('tab_hidden')\r\n\r\n\t\t\tthis.setTabWidth(this.cachedTabWidth)\r\n\t\t}\r\n\r\n\t\tdocument.addEventListener('mouseup', () => {\r\n\t\t\tdocument.removeEventListener('mousemove', this.handleDrag)\r\n\t\t})\r\n\r\n\t\twindow.addEventListener('beforeunload', () => {\r\n\t\t\tlocalStorage.setItem('downloadTabWidth', this.cachedTabWidth)\r\n\t\t})\r\n\t},\r\n\tmethods: {\r\n\t\t...mapActions(['setErrors']),\r\n\t\tonRemoveItem(uuid) {\r\n\t\t\tsocket.emit('removeFromQueue', uuid)\r\n\t\t},\r\n\t\tsetTabWidth(newWidth) {\r\n\t\t\tif (undefined === newWidth) {\r\n\t\t\t\tthis.$refs.container.style.width = ''\r\n\t\t\t\tthis.$refs.list.style.width = ''\r\n\t\t\t} else {\r\n\t\t\t\tthis.$refs.container.style.width = newWidth + 'px'\r\n\t\t\t\tthis.$refs.list.style.width = newWidth + 'px'\r\n\t\t\t}\r\n\t\t},\r\n\t\tinitQueue(data) {\r\n\t\t\tconst {\r\n\t\t\t\tqueue: initQueue,\r\n\t\t\t\tqueueComplete: initQueueComplete,\r\n\t\t\t\tcurrentItem,\r\n\t\t\t\tqueueList: initQueueList,\r\n\t\t\t\trestored\r\n\t\t\t} = data\r\n\r\n\t\t\tif (initQueueComplete.length) {\r\n\t\t\t\tinitQueueComplete.forEach(item => {\r\n\t\t\t\t\tinitQueueList[item].silent = true\r\n\t\t\t\t\tthis.addToQueue(initQueueList[item])\r\n\t\t\t\t})\r\n\t\t\t}\r\n\r\n\t\t\tif (currentItem) {\r\n\t\t\t\tinitQueueList[currentItem].silent = true\r\n\t\t\t\tthis.addToQueue(initQueueList[currentItem], true)\r\n\t\t\t}\r\n\r\n\t\t\tinitQueue.forEach(item => {\r\n\t\t\t\tinitQueueList[item].silent = true\r\n\t\t\t\tthis.addToQueue(initQueueList[item])\r\n\t\t\t})\r\n\r\n\t\t\tif (restored) {\r\n\t\t\t\ttoast(this.$t('toasts.queueRestored'), 'done', true, 'restoring_queue')\r\n\t\t\t\tsocket.emit('queueRestored')\r\n\t\t\t}\r\n\t\t},\r\n\t\taddToQueue(queueItem, current = false) {\r\n\t\t\tif (Array.isArray(queueItem)) {\r\n\t\t\t\tif (queueItem.length > 1) {\r\n\t\t\t\t\tqueueItem.forEach((item, i) => {\r\n\t\t\t\t\t\titem.silent = true\r\n\t\t\t\t\t\tthis.addToQueue(item)\r\n\t\t\t\t\t})\r\n\t\t\t\t\ttoast(this.$t('toasts.addedMoreToQueue', { n: queueItem.length }), 'playlist_add_check')\r\n\t\t\t\t\treturn\r\n\t\t\t\t} else {\r\n\t\t\t\t\tqueueItem = queueItem[0]\r\n\t\t\t\t}\r\n\t\t\t}\r\n\r\n\t\t\t// * Here we have only queueItem objects\r\n\t\t\tthis.$set(queueItem, 'current', current)\r\n\t\t\tthis.$set(this.queueList, queueItem.uuid, queueItem)\r\n\r\n\t\t\t// * Used when opening the app in another tab\r\n\t\t\tconst itemIsAlreadyDownloaded = queueItem.downloaded + queueItem.failed == queueItem.size\r\n\r\n\t\t\tif (itemIsAlreadyDownloaded) {\r\n\t\t\t\tconst itemIsNotInCompletedQueue = this.queueComplete.indexOf(queueItem.uuid) == -1\r\n\r\n\t\t\t\tthis.$set(this.queueList[queueItem.uuid], 'status', 'download finished')\r\n\r\n\t\t\t\tif (itemIsNotInCompletedQueue) {\r\n\t\t\t\t\t// * Add it\r\n\t\t\t\t\tthis.queueComplete.push(queueItem.uuid)\r\n\t\t\t\t}\r\n\t\t\t} else {\r\n\t\t\t\tconst itemIsNotInQueue = this.queue.indexOf(queueItem.uuid) == -1\r\n\r\n\t\t\t\tif (itemIsNotInQueue) {\r\n\t\t\t\t\tthis.queue.push(queueItem.uuid)\r\n\t\t\t\t}\r\n\t\t\t}\r\n\r\n\t\t\tconst needToStartDownload = (queueItem.progress > 0 && queueItem.progress < 100) || current\r\n\r\n\t\t\tif (needToStartDownload) {\r\n\t\t\t\tthis.startDownload(queueItem.uuid)\r\n\t\t\t}\r\n\r\n\t\t\tif (!queueItem.silent) {\r\n\t\t\t\ttoast(this.$t('toasts.addedToQueue', { item: queueItem.title }), 'playlist_add_check')\r\n\t\t\t}\r\n\t\t},\r\n\t\tupdateQueue(update) {\r\n\t\t\t// downloaded and failed default to false?\r\n\t\t\tconst { uuid, downloaded, failed, progress, conversion, error, data, errid } = update\r\n\r\n\t\t\tif (uuid && this.queue.indexOf(uuid) > -1) {\r\n\t\t\t\tif (downloaded) {\r\n\t\t\t\t\tthis.queueList[uuid].downloaded++\r\n\t\t\t\t}\r\n\r\n\t\t\t\tif (failed) {\r\n\t\t\t\t\tthis.queueList[uuid].failed++\r\n\t\t\t\t\tthis.queueList[uuid].errors.push({ message: error, data: data, errid: errid })\r\n\t\t\t\t}\r\n\r\n\t\t\t\tif (progress) {\r\n\t\t\t\t\tthis.queueList[uuid].progress = progress\r\n\t\t\t\t}\r\n\r\n\t\t\t\tif (conversion) {\r\n\t\t\t\t\tthis.queueList[uuid].conversion = conversion\r\n\t\t\t\t}\r\n\t\t\t}\r\n\t\t},\r\n\t\tremoveFromQueue(uuid) {\r\n\t\t\tlet index = this.queue.indexOf(uuid)\r\n\r\n\t\t\tif (index > -1) {\r\n\t\t\t\tthis.$delete(this.queue, index)\r\n\t\t\t\tthis.$delete(this.queueList, uuid)\r\n\t\t\t}\r\n\t\t},\r\n\t\tremoveAllDownloads(currentItem) {\r\n\t\t\tthis.queueComplete = []\r\n\r\n\t\t\tif (!currentItem) {\r\n\t\t\t\tthis.queue = []\r\n\t\t\t\tthis.queueList = {}\r\n\t\t\t} else {\r\n\t\t\t\tthis.queue = [currentItem]\r\n\r\n\t\t\t\tlet tempQueueItem = this.queueList[currentItem]\r\n\r\n\t\t\t\tthis.queueList = {}\r\n\t\t\t\tthis.queueList[currentItem] = tempQueueItem\r\n\t\t\t}\r\n\t\t},\r\n\t\tremovedFinishedDownloads() {\r\n\t\t\tthis.queueComplete.forEach(uuid => {\r\n\t\t\t\tthis.$delete(this.queueList, uuid)\r\n\t\t\t})\r\n\r\n\t\t\tthis.queueComplete = []\r\n\t\t},\r\n\t\ttoggleDownloadTab() {\r\n\t\t\tthis.setTabWidth()\r\n\r\n\t\t\tthis.$refs.container.style.transition = 'all 250ms ease-in-out'\r\n\r\n\t\t\t// Toggle returns a Boolean based on the action it performed\r\n\t\t\tlet isHidden = this.$refs.container.classList.toggle('tab_hidden')\r\n\t\t\tthis.isExpanded = !isHidden\r\n\r\n\t\t\tif (this.isExpanded) {\r\n\t\t\t\tthis.setTabWidth(this.cachedTabWidth)\r\n\t\t\t}\r\n\r\n\t\t\tlocalStorage.setItem('downloadTabOpen', this.isExpanded)\r\n\t\t},\r\n\t\tcleanQueue() {\r\n\t\t\tsocket.emit('removeFinishedDownloads')\r\n\t\t},\r\n\t\tcancelQueue() {\r\n\t\t\tsocket.emit('cancelAllDownloads')\r\n\t\t},\r\n\t\topenDownloadsFolder() {\r\n\t\t\t// if (this.clientMode) {\r\n\t\t\tsocket.emit('openDownloadsFolder')\r\n\t\t\t// }\r\n\t\t},\r\n\t\thandleDrag(event) {\r\n\t\t\tlet newWidth = window.innerWidth - event.pageX + 2\r\n\r\n\t\t\tif (newWidth < tabMinWidth) {\r\n\t\t\t\tnewWidth = tabMinWidth\r\n\t\t\t} else if (newWidth > tabMaxWidth) {\r\n\t\t\t\tnewWidth = tabMaxWidth\r\n\t\t\t}\r\n\r\n\t\t\tthis.cachedTabWidth = newWidth\r\n\t\t\tthis.setTabWidth(newWidth)\r\n\t\t},\r\n\t\tstartDrag() {\r\n\t\t\tdocument.addEventListener('mousemove', this.handleDrag)\r\n\t\t},\r\n\t\tstartDownload(uuid) {\r\n\t\t\tthis.$set(this.queueList[uuid], 'status', 'downloading')\r\n\t\t},\r\n\t\tfinishDownload(uuid) {\r\n\t\t\tlet isInQueue = this.queue.indexOf(uuid) > -1\r\n\r\n\t\t\tif (!isInQueue) return\r\n\r\n\t\t\tthis.$set(this.queueList[uuid], 'status', 'download finished')\r\n\t\t\ttoast(this.$t('toasts.finishDownload', { item: this.queueList[uuid].title }), 'done')\r\n\r\n\t\t\tlet index = this.queue.indexOf(uuid)\r\n\r\n\t\t\tif (index > -1) {\r\n\t\t\t\tthis.queue.splice(index, 1)\r\n\t\t\t\tthis.queueComplete.push(uuid)\r\n\t\t\t}\r\n\r\n\t\t\tif (this.queue.length <= 0) {\r\n\t\t\t\ttoast(this.$t('toasts.allDownloaded'), 'done_all')\r\n\t\t\t}\r\n\t\t},\r\n\t\tstartConversion(uuid) {\r\n\t\t\tthis.$set(this.queueList[uuid], 'status', 'converting')\r\n\t\t\tthis.$set(this.queueList[uuid], 'conversion', 0)\r\n\t\t},\r\n\t\tasync showErrorsTab(item) {\r\n\t\t\tawait this.setErrors(item)\r\n\r\n\t\t\tthis.$router.push({ name: 'Errors' })\r\n\t\t}\r\n\t}\r\n}\r\n</script>\r\n","#download_tab_container {\n  height: 100vh; }\n\n#download_list {\n  height: calc(100% - 32px);\n  padding-left: 28px;\n  overflow-y: scroll; }\n  #download_list::-webkit-scrollbar {\n    width: 10px; }\n  #download_list::-webkit-scrollbar-track {\n    background: var(--panels-background); }\n  #download_list::-webkit-scrollbar-thumb {\n    background: var(--panels-scroll);\n    border-radius: 4px;\n    width: 6px;\n    padding: 0px 2px; }\n\n/*# sourceMappingURL=TheDownloadBar.vue.map */"]}, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$1 = "data-v-9384a8cc";
  /* module identifier */
  const __vue_module_identifier__$1 = undefined;
  /* functional template */
  const __vue_is_functional_template__$1 = false;
  /* style inject SSR */
  

  
  var TheDownloadBar = normalizeComponent_1(
    { render: __vue_render__$1, staticRenderFns: __vue_staticRenderFns__$1 },
    __vue_inject_styles__$1,
    __vue_script__$1,
    __vue_scope_id__$1,
    __vue_is_functional_template__$1,
    __vue_module_identifier__$1,
    browser,
    undefined
  );

//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//

var script$2 = {
	props: {
		text: {
			type: String,
			required: false,
			default: 'Loading...'
		},
		id: {
			type: String,
			required: false
		},
		hidden: {
			type: Boolean,
			required: false,
			default: false
		}
	}
};

/* script */
const __vue_script__$2 = script$2;

/* template */
var __vue_render__$2 = function(_h, _vm) {
  var _c = _vm._c;
  return _c(
    "div",
    {
      staticClass: "loading_placeholder",
      class: { "loading_placeholder--hidden": _vm.props.hidden },
      attrs: { id: _vm.props.id }
    },
    [
      _c("span", { staticClass: "loading_placeholder__text" }, [
        _vm._v(_vm._s(_vm.props.text))
      ]),
      _vm._v(" "),
      _vm._m(0)
    ]
  )
};
var __vue_staticRenderFns__$2 = [
  function(_h, _vm) {
    var _c = _vm._c;
    return _c("div", { staticClass: "lds-ring" }, [
      _c("div"),
      _vm._v(" "),
      _c("div"),
      _vm._v(" "),
      _c("div"),
      _vm._v(" "),
      _c("div")
    ])
  }
];
__vue_render__$2._withStripped = true;

  /* style */
  const __vue_inject_styles__$2 = function (inject) {
    if (!inject) return
    inject("data-v-25fce705_0", { source: ".lds-ring[data-v-25fce705] {\n  display: inline-block;\n  position: relative;\n  width: 80px;\n  height: 80px;\n}\n.lds-ring div[data-v-25fce705] {\n    box-sizing: border-box;\n    display: block;\n    position: absolute;\n    width: 64px;\n    height: 64px;\n    margin: 8px;\n    border: 8px solid #fff;\n    border-radius: 50%;\n    animation: lds-ring-data-v-25fce705 1.2s cubic-bezier(0.5, 0, 0.5, 1) infinite;\n    border-color: #fff transparent transparent transparent;\n}\n.lds-ring div[data-v-25fce705]:nth-child(1) {\n      animation-delay: -0.45s;\n}\n.lds-ring div[data-v-25fce705]:nth-child(2) {\n      animation-delay: -0.3s;\n}\n.lds-ring div[data-v-25fce705]:nth-child(3) {\n      animation-delay: -0.15s;\n}\n@keyframes lds-ring-data-v-25fce705 {\n0% {\n    transform: rotate(0deg);\n}\n100% {\n    transform: rotate(360deg);\n}\n}\n\n/*# sourceMappingURL=BaseLoadingPlaceholder.vue.map */", map: {"version":3,"sources":["C:\\Users\\Roberto\\Dev\\repos\\deemix-pyweb\\webui\\src\\components\\globals\\BaseLoadingPlaceholder.vue","BaseLoadingPlaceholder.vue"],"names":[],"mappings":"AAcA;EACA,qBAAA;EACA,kBAAA;EACA,WAAA;EACA,YAAA;AAAA;AAJA;IAOA,sBAAA;IACA,cAAA;IACA,kBAAA;IACA,WAAA;IACA,YAAA;IACA,WAAA;IACA,sBAAA;IACA,kBAAA;IACA,8EAAA;IACA,sDAAA;AAAA;AAhBA;MAmBA,uBAAA;AAAA;AAnBA;MAuBA,sBAAA;AAAA;AAvBA;MA2BA,uBAAA;AAAA;AAKA;AACA;IACA,uBAAA;AAAA;AAEA;IACA,yBAAA;AAAA;AAAA;;ACtBA,qDAAqD","file":"BaseLoadingPlaceholder.vue","sourcesContent":["<template functional>\r\n\t<div :id=\"props.id\" class=\"loading_placeholder\" :class=\"{ 'loading_placeholder--hidden': props.hidden }\">\r\n\t\t<span class=\"loading_placeholder__text\">{{ props.text }}</span>\r\n\t\t<div class=\"lds-ring\">\r\n\t\t\t<div></div>\r\n\t\t\t<div></div>\r\n\t\t\t<div></div>\r\n\t\t\t<div></div>\r\n\t\t</div>\r\n\t</div>\r\n</template>\r\n\r\n<style lang=\"scss\" scoped>\r\n// Source: https://loading.io/css/\r\n.lds-ring {\r\n\tdisplay: inline-block;\r\n\tposition: relative;\r\n\twidth: 80px;\r\n\theight: 80px;\r\n\r\n\tdiv {\r\n\t\tbox-sizing: border-box;\r\n\t\tdisplay: block;\r\n\t\tposition: absolute;\r\n\t\twidth: 64px;\r\n\t\theight: 64px;\r\n\t\tmargin: 8px;\r\n\t\tborder: 8px solid #fff;\r\n\t\tborder-radius: 50%;\r\n\t\tanimation: lds-ring 1.2s cubic-bezier(0.5, 0, 0.5, 1) infinite;\r\n\t\tborder-color: #fff transparent transparent transparent;\r\n\r\n\t\t&:nth-child(1) {\r\n\t\t\tanimation-delay: -0.45s;\r\n\t\t}\r\n\r\n\t\t&:nth-child(2) {\r\n\t\t\tanimation-delay: -0.3s;\r\n\t\t}\r\n\r\n\t\t&:nth-child(3) {\r\n\t\t\tanimation-delay: -0.15s;\r\n\t\t}\r\n\t}\r\n}\r\n\r\n@keyframes lds-ring {\r\n\t0% {\r\n\t\ttransform: rotate(0deg);\r\n\t}\r\n\t100% {\r\n\t\ttransform: rotate(360deg);\r\n\t}\r\n}\r\n</style>\r\n\r\n<script>\r\nexport default {\r\n\tprops: {\r\n\t\ttext: {\r\n\t\t\ttype: String,\r\n\t\t\trequired: false,\r\n\t\t\tdefault: 'Loading...'\r\n\t\t},\r\n\t\tid: {\r\n\t\t\ttype: String,\r\n\t\t\trequired: false\r\n\t\t},\r\n\t\thidden: {\r\n\t\t\ttype: Boolean,\r\n\t\t\trequired: false,\r\n\t\t\tdefault: false\r\n\t\t}\r\n\t}\r\n}\r\n</script>\r\n",".lds-ring {\n  display: inline-block;\n  position: relative;\n  width: 80px;\n  height: 80px; }\n  .lds-ring div {\n    box-sizing: border-box;\n    display: block;\n    position: absolute;\n    width: 64px;\n    height: 64px;\n    margin: 8px;\n    border: 8px solid #fff;\n    border-radius: 50%;\n    animation: lds-ring 1.2s cubic-bezier(0.5, 0, 0.5, 1) infinite;\n    border-color: #fff transparent transparent transparent; }\n    .lds-ring div:nth-child(1) {\n      animation-delay: -0.45s; }\n    .lds-ring div:nth-child(2) {\n      animation-delay: -0.3s; }\n    .lds-ring div:nth-child(3) {\n      animation-delay: -0.15s; }\n\n@keyframes lds-ring {\n  0% {\n    transform: rotate(0deg); }\n  100% {\n    transform: rotate(360deg); } }\n\n/*# sourceMappingURL=BaseLoadingPlaceholder.vue.map */"]}, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$2 = "data-v-25fce705";
  /* module identifier */
  const __vue_module_identifier__$2 = undefined;
  /* functional template */
  const __vue_is_functional_template__$2 = true;
  /* style inject SSR */
  

  
  var BaseLoadingPlaceholder = normalizeComponent_1(
    { render: __vue_render__$2, staticRenderFns: __vue_staticRenderFns__$2 },
    __vue_inject_styles__$2,
    __vue_script__$2,
    __vue_scope_id__$2,
    __vue_is_functional_template__$2,
    __vue_module_identifier__$2,
    browser,
    undefined
  );

function sendAddToQueue(url, bitrate = null) {
	if (!url) throw new Error('No URL given to sendAddToQueue function!')

	socket.emit('addToQueue', { url, bitrate }, () => {});
}

function aggregateDownloadLinks(releases) {
	let links = [];

	releases.forEach(release => {
		links.push(release.link);
	});

	return links.join(';')
}

var Downloads = {
	sendAddToQueue
};

/**
 * Climbs the DOM until the root is reached, storing every node passed.
 * @param 	{HTMLElement} el
 * @return	{Array}				Contains all the nodes between el and the root
 */
function generatePath(el) {
	if (!el) {
		throw new Error('No element passed to the generatePath function!')
	}

	let path = [el];

	while ((el = el.parentNode) && el !== document) {
		path.push(el);
	}

	return path
}

function isValidURL(text) {
	let lowerCaseText = text.toLowerCase();

	if (lowerCaseText.startsWith('http')) {
		if (
			lowerCaseText.indexOf('deezer.com') >= 0 ||
			lowerCaseText.indexOf('deezer.page.link') >= 0 ||
			lowerCaseText.indexOf('open.spotify.com') >= 0
		) {
			return true
		}
	} else if (lowerCaseText.startsWith('spotify:')) {
		return true
	}
	return false
}

function convertDuration(duration) {
	// Convert from seconds only to mm:ss format
	let mm, ss;
	mm = Math.floor(duration / 60);
	ss = duration - mm * 60;
	// Add leading zero if ss < 0
	if (ss < 10) {
		ss = '0' + ss;
	}
	return mm + ':' + ss
}

function convertDurationSeparated(duration) {
	let hh, mm, ss;
	mm = Math.floor(duration / 60);
	hh = Math.floor(mm / 60);
	ss = duration - mm * 60;
	mm -= hh * 60;
	return [hh, mm, ss]
}

function numberWithDots(x) {
	return x.toString().replace(/\B(?=(\d{3})+(?!\d))/g, '.')
}

// On scroll event, returns currentTarget = null
// Probably on other events too
function debounce(func, wait, immediate) {
	var timeout;
	return function() {
		var context = this;
		var args = arguments;
		var later = function() {
			timeout = null;
			if (!immediate) func.apply(context, args);
		};
		var callNow = immediate && !timeout;
		clearTimeout(timeout);
		timeout = setTimeout(later, wait);
		if (callNow) func.apply(context, args);
	}
}

/**
 * Workaround to copy to the clipboard cross-OS by generating a
 * ghost input and copying the passed String
 *
 * @param {string}	text Text to copy
 */
function copyToClipboard(text) {
	const ghostInput = document.createElement('input');

	document.body.appendChild(ghostInput);
	ghostInput.setAttribute('type', 'text');
	ghostInput.setAttribute('value', text);
	ghostInput.select();
	ghostInput.setSelectionRange(0, 99999);
	document.execCommand('copy');
	ghostInput.remove();
}

var Utils = {
	isValidURL,
	convertDuration,
	convertDurationSeparated,
	numberWithDots,
	debounce
};

const downloadQualities = [
	{
		objName: 'flac',
		label: 'FLAC',
		value: 9
	},
	{
		objName: '320kbps',
		label: 'MP3 320kbps',
		value: 3
	},
	{
		objName: '128kbps',
		label: 'MP3 128kbps',
		value: 1
	},
	{
		objName: 'realityAudioHQ',
		label: '360 Reality Audio [HQ]',
		value: 15
	},
	{
		objName: 'realityAudioMQ',
		label: '360 Reality Audio [MQ]',
		value: 14
	},
	{
		objName: 'realityAudioLQ',
		label: '360 Reality Audio [LQ]',
		value: 13
	}
];

//

var script$3 = {
	data() {
		return {
			menuOpen: false,
			xPos: 0,
			yPos: 0,
			deezerHref: '',
			generalHref: '',
			imgSrc: ''
		}
	},
	computed: {
		options() {
			// In the action property:
			// Use arrow functions to keep the Vue instance in 'this'
			// Use normal functions to keep the object instance in 'this'
			const options = {
				cut: {
					label: this.$t('globals.cut'),
					show: false,
					position: 1,
					action: () => {
						document.execCommand('Cut');
					}
				},
				copy: {
					label: this.$t('globals.copy'),
					show: false,
					position: 2,
					action: () => {
						document.execCommand('Copy');
					}
				},
				copyLink: {
					label: this.$t('globals.copyLink'),
					show: false,
					position: 3,
					action: () => {
						copyToClipboard(this.generalHref);
					}
				},
				copyImageLink: {
					label: this.$t('globals.copyImageLink'),
					show: false,
					position: 4,
					action: () => {
						copyToClipboard(this.imgSrc);
					}
				},
				copyDeezerLink: {
					label: this.$t('globals.copyDeezerLink'),
					show: false,
					position: 5,
					action: () => {
						copyToClipboard(this.deezerHref);
					}
				},
				paste: {
					label: this.$t('globals.paste'),
					show: false,
					position: 6,
					action: () => {
						// Paste does not always work
						if (clipboard in navigator) {
							navigator.clipboard.readText().then(text => {
								document.execCommand('insertText', undefined, text);
							});
						} else {
							document.execCommand('paste');
						}
					}
				}
			};

			let nextValuePosition = Object.values(options).length + 1;

			downloadQualities.forEach((quality, index) => {
				options[quality.objName] = {
					label: `${this.$t('globals.download', { thing: quality.label })}`,
					show: false,
					position: nextValuePosition + index,
					action: sendAddToQueue.bind(null, this.deezerHref, quality.value)
				};
			});

			return options
		},
		/**
		 * This computed property is used for rendering the options in the wanted order
		 * while keeping the options computed property an Object to make the properties
		 * accessible via property name (es this.options.copyLink)
		 *
		 * @return	{object[]}	Options in order according to position property
		 */
		sortedOptions() {
			return Object.values(this.options).sort((first, second) => {
				return first.position < second.position ? -1 : 1
			})
		}
	},
	mounted() {
		document.body.addEventListener('contextmenu', this.showMenu);
		document.body.addEventListener('click', this.hideMenu);
	},
	methods: {
		showMenu(contextMenuEvent) {
			const { pageX, pageY, target: elementClicked } = contextMenuEvent;
			const path = generatePath(elementClicked);
			let deezerLink = null;

			// Searching for the first element with a data-link attribute
			// let deezerLink = this.searchForDataLink(...)
			for (let i = 0; i < path.length; i++) {
				if (path[i] == document) break

				if (path[i].matches('[data-link]')) {
					deezerLink = path[i].dataset.link;
					break
				}
			}

			const isLink = elementClicked.matches('a');
			const isImage = elementClicked.matches('img');
			const hasDeezerLink = !!deezerLink;

			if (!isLink && !isImage && !hasDeezerLink) return

			contextMenuEvent.preventDefault();
			this.menuOpen = true;
			this.positionMenu(pageX, pageY);

			if (isLink) {
				// Show 'Copy Link' option
				this.generalHref = elementClicked.href;
				this.options.copyLink.show = true;
			}

			if (isImage) {
				// Show 'Copy Image Link' option
				this.imgSrc = elementClicked.src;
				this.options.copyImageLink.show = true;
			}

			if (deezerLink) {
				// Show 'Copy Deezer Link' option
				this.deezerHref = deezerLink;
				this.showDeezerOptions();
			}
		},
		hideMenu() {
			if (!this.menuOpen) return

			// Finish all operations before closing (may be not necessary)
			this.$nextTick()
				.then(() => {
					this.menuOpen = false;

					this.options.copyLink.show = false;
					this.options.copyDeezerLink.show = false;
					this.options.copyImageLink.show = false;

					downloadQualities.forEach(quality => {
						this.options[quality.objName].show = false;
					});
				})
				.catch(err => {
					console.error(err);
				});
		},
		positionMenu(newX, newY) {
			this.xPos = `${newX}px`;
			this.yPos = `${newY}px`;

			this.$nextTick().then(() => {
				const { innerHeight, innerWidth } = window;
				const menuXOffest = newX + this.$refs.contextMenu.getBoundingClientRect().width;
				const menuYOffest = newY + this.$refs.contextMenu.getBoundingClientRect().height;

				if (menuXOffest > innerWidth) {
					const difference = menuXOffest - innerWidth + 15;
					this.xPos = `${newX - difference}px`;
				}

				if (menuYOffest > innerHeight) {
					const difference = menuYOffest - innerHeight + 15;
					this.yPos = `${newY - difference}px`;
				}
			});
		},
		showDeezerOptions() {
			this.options.copyDeezerLink.show = true;

			downloadQualities.forEach(quality => {
				this.options[quality.objName].show = true;
			});
		}
	}
};

/* script */
const __vue_script__$3 = script$3;

/* template */
var __vue_render__$3 = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c(
    "div",
    {
      directives: [
        {
          name: "show",
          rawName: "v-show",
          value: _vm.menuOpen,
          expression: "menuOpen"
        }
      ],
      ref: "contextMenu",
      staticClass: "context-menu",
      style: { top: _vm.yPos, left: _vm.xPos }
    },
    _vm._l(_vm.sortedOptions, function(option) {
      return _c(
        "button",
        {
          directives: [
            {
              name: "show",
              rawName: "v-show",
              value: option.show,
              expression: "option.show"
            }
          ],
          key: option.label,
          staticClass: "btn menu-option",
          on: {
            click: function($event) {
              $event.preventDefault();
              return option.action($event)
            }
          }
        },
        [
          _c("span", { staticClass: "menu-option__text" }, [
            _vm._v(_vm._s(option.label))
          ])
        ]
      )
    }),
    0
  )
};
var __vue_staticRenderFns__$3 = [];
__vue_render__$3._withStripped = true;

  /* style */
  const __vue_inject_styles__$3 = function (inject) {
    if (!inject) return
    inject("data-v-333a56d8_0", { source: ".context-menu[data-v-333a56d8] {\n  position: absolute;\n  top: 0;\n  left: 0;\n  min-width: 100px;\n  border-radius: 7px;\n  background: var(--secondary-background);\n  box-shadow: 4px 10px 18px 0px rgba(0, 0, 0, 0.15);\n  overflow: hidden;\n  z-index: 10000;\n}\n.menu-option[data-v-333a56d8] {\n  display: flex;\n  align-items: center;\n  width: 100%;\n  height: 40px;\n  padding-left: 10px;\n  padding-right: 10px;\n  color: var(--foreground);\n  cursor: pointer;\n}\n.menu-option[data-v-333a56d8]:hover {\n    background: var(--table-highlight);\n    filter: brightness(150%);\n}\n.menu-option__text[data-v-333a56d8] {\n    text-transform: capitalize;\n}\nbutton[data-v-333a56d8] {\n  color: var(--primary-text);\n  color: unset;\n  background-color: var(--primary-color);\n  background-color: unset;\n  min-width: unset;\n  position: unset;\n  border: unset;\n  border-radius: unset;\n  font-family: unset;\n  font-weight: unset;\n  font-size: unset;\n  padding: unset;\n  margin-right: unset;\n  height: unset;\n  text-transform: unset;\n  cursor: unset;\n  transition: unset;\n}\nbutton[data-v-333a56d8]:focus {\n    outline: none;\n}\nbutton[data-v-333a56d8]:active {\n    background-color: unset;\n    transform: unset;\n}\nbutton[data-v-333a56d8]:hover {\n    background: unset;\n    border: unset;\n}\n\n/*# sourceMappingURL=TheContextMenu.vue.map */", map: {"version":3,"sources":["C:\\Users\\Roberto\\Dev\\repos\\deemix-pyweb\\webui\\src\\components\\globals\\TheContextMenu.vue","TheContextMenu.vue"],"names":[],"mappings":"AA4NA;EACA,kBAAA;EACA,MAAA;EACA,OAAA;EACA,gBAAA;EACA,kBAAA;EACA,uCAAA;EACA,iDAAA;EACA,gBAAA;EACA,cAAA;AAAA;AAGA;EACA,aAAA;EACA,mBAAA;EACA,WAAA;EACA,YAAA;EACA,kBAAA;EACA,mBAAA;EACA,wBAAA;EACA,eAAA;AAAA;AARA;IAWA,kCAAA;IACA,wBAAA;AAAA;AAGA;IACA,0BAAA;AAAA;AAKA;EACA,0BAAA;EACA,YAAA;EACA,sCAAA;EACA,uBAAA;EACA,gBAAA;EACA,eAAA;EACA,aAAA;EACA,oBAAA;EACA,kBAAA;EACA,kBAAA;EACA,gBAAA;EACA,cAAA;EACA,mBAAA;EACA,aAAA;EACA,qBAAA;EACA,aAAA;EACA,iBAAA;AAAA;AAjBA;IAoBA,aAAA;AAAA;AApBA;IAwBA,uBAAA;IACA,gBAAA;AAAA;AAzBA;IA6BA,iBAAA;IACA,aAAA;AAAA;;ACtOA,6CAA6C","file":"TheContextMenu.vue","sourcesContent":["<template>\r\n\t<div class=\"context-menu\" v-show=\"menuOpen\" ref=\"contextMenu\" :style=\"{ top: yPos, left: xPos }\">\r\n\t\t<button\r\n\t\t\tclass=\"btn menu-option\"\r\n\t\t\tv-for=\"option of sortedOptions\"\r\n\t\t\t:key=\"option.label\"\r\n\t\t\tv-show=\"option.show\"\r\n\t\t\t@click.prevent=\"option.action\"\r\n\t\t>\r\n\t\t\t<span class=\"menu-option__text\">{{ option.label }}</span>\r\n\t\t</button>\r\n\t</div>\r\n</template>\r\n\r\n<script>\r\nimport { sendAddToQueue } from '@/utils/downloads'\r\nimport { generatePath, copyToClipboard } from '@/utils/utils'\r\nimport { downloadQualities } from '@/data/qualities'\r\n\r\nexport default {\r\n\tdata() {\r\n\t\treturn {\r\n\t\t\tmenuOpen: false,\r\n\t\t\txPos: 0,\r\n\t\t\tyPos: 0,\r\n\t\t\tdeezerHref: '',\r\n\t\t\tgeneralHref: '',\r\n\t\t\timgSrc: ''\r\n\t\t}\r\n\t},\r\n\tcomputed: {\r\n\t\toptions() {\r\n\t\t\t// In the action property:\r\n\t\t\t// Use arrow functions to keep the Vue instance in 'this'\r\n\t\t\t// Use normal functions to keep the object instance in 'this'\r\n\t\t\tconst options = {\r\n\t\t\t\tcut: {\r\n\t\t\t\t\tlabel: this.$t('globals.cut'),\r\n\t\t\t\t\tshow: false,\r\n\t\t\t\t\tposition: 1,\r\n\t\t\t\t\taction: () => {\r\n\t\t\t\t\t\tdocument.execCommand('Cut')\r\n\t\t\t\t\t}\r\n\t\t\t\t},\r\n\t\t\t\tcopy: {\r\n\t\t\t\t\tlabel: this.$t('globals.copy'),\r\n\t\t\t\t\tshow: false,\r\n\t\t\t\t\tposition: 2,\r\n\t\t\t\t\taction: () => {\r\n\t\t\t\t\t\tdocument.execCommand('Copy')\r\n\t\t\t\t\t}\r\n\t\t\t\t},\r\n\t\t\t\tcopyLink: {\r\n\t\t\t\t\tlabel: this.$t('globals.copyLink'),\r\n\t\t\t\t\tshow: false,\r\n\t\t\t\t\tposition: 3,\r\n\t\t\t\t\taction: () => {\r\n\t\t\t\t\t\tcopyToClipboard(this.generalHref)\r\n\t\t\t\t\t}\r\n\t\t\t\t},\r\n\t\t\t\tcopyImageLink: {\r\n\t\t\t\t\tlabel: this.$t('globals.copyImageLink'),\r\n\t\t\t\t\tshow: false,\r\n\t\t\t\t\tposition: 4,\r\n\t\t\t\t\taction: () => {\r\n\t\t\t\t\t\tcopyToClipboard(this.imgSrc)\r\n\t\t\t\t\t}\r\n\t\t\t\t},\r\n\t\t\t\tcopyDeezerLink: {\r\n\t\t\t\t\tlabel: this.$t('globals.copyDeezerLink'),\r\n\t\t\t\t\tshow: false,\r\n\t\t\t\t\tposition: 5,\r\n\t\t\t\t\taction: () => {\r\n\t\t\t\t\t\tcopyToClipboard(this.deezerHref)\r\n\t\t\t\t\t}\r\n\t\t\t\t},\r\n\t\t\t\tpaste: {\r\n\t\t\t\t\tlabel: this.$t('globals.paste'),\r\n\t\t\t\t\tshow: false,\r\n\t\t\t\t\tposition: 6,\r\n\t\t\t\t\taction: () => {\r\n\t\t\t\t\t\t// Paste does not always work\r\n\t\t\t\t\t\tif (clipboard in navigator) {\r\n\t\t\t\t\t\t\tnavigator.clipboard.readText().then(text => {\r\n\t\t\t\t\t\t\t\tdocument.execCommand('insertText', undefined, text)\r\n\t\t\t\t\t\t\t})\r\n\t\t\t\t\t\t} else {\r\n\t\t\t\t\t\t\tdocument.execCommand('paste')\r\n\t\t\t\t\t\t}\r\n\t\t\t\t\t}\r\n\t\t\t\t}\r\n\t\t\t}\r\n\r\n\t\t\tlet nextValuePosition = Object.values(options).length + 1\r\n\r\n\t\t\tdownloadQualities.forEach((quality, index) => {\r\n\t\t\t\toptions[quality.objName] = {\r\n\t\t\t\t\tlabel: `${this.$t('globals.download', { thing: quality.label })}`,\r\n\t\t\t\t\tshow: false,\r\n\t\t\t\t\tposition: nextValuePosition + index,\r\n\t\t\t\t\taction: sendAddToQueue.bind(null, this.deezerHref, quality.value)\r\n\t\t\t\t}\r\n\t\t\t})\r\n\r\n\t\t\treturn options\r\n\t\t},\r\n\t\t/**\r\n\t\t * This computed property is used for rendering the options in the wanted order\r\n\t\t * while keeping the options computed property an Object to make the properties\r\n\t\t * accessible via property name (es this.options.copyLink)\r\n\t\t *\r\n\t\t * @return\t{object[]}\tOptions in order according to position property\r\n\t\t */\r\n\t\tsortedOptions() {\r\n\t\t\treturn Object.values(this.options).sort((first, second) => {\r\n\t\t\t\treturn first.position < second.position ? -1 : 1\r\n\t\t\t})\r\n\t\t}\r\n\t},\r\n\tmounted() {\r\n\t\tdocument.body.addEventListener('contextmenu', this.showMenu)\r\n\t\tdocument.body.addEventListener('click', this.hideMenu)\r\n\t},\r\n\tmethods: {\r\n\t\tshowMenu(contextMenuEvent) {\r\n\t\t\tconst { pageX, pageY, target: elementClicked } = contextMenuEvent\r\n\t\t\tconst path = generatePath(elementClicked)\r\n\t\t\tlet deezerLink = null\r\n\r\n\t\t\t// Searching for the first element with a data-link attribute\r\n\t\t\t// let deezerLink = this.searchForDataLink(...)\r\n\t\t\tfor (let i = 0; i < path.length; i++) {\r\n\t\t\t\tif (path[i] == document) break\r\n\r\n\t\t\t\tif (path[i].matches('[data-link]')) {\r\n\t\t\t\t\tdeezerLink = path[i].dataset.link\r\n\t\t\t\t\tbreak\r\n\t\t\t\t}\r\n\t\t\t}\r\n\r\n\t\t\tconst isLink = elementClicked.matches('a')\r\n\t\t\tconst isImage = elementClicked.matches('img')\r\n\t\t\tconst hasDeezerLink = !!deezerLink\r\n\r\n\t\t\tif (!isLink && !isImage && !hasDeezerLink) return\r\n\r\n\t\t\tcontextMenuEvent.preventDefault()\r\n\t\t\tthis.menuOpen = true\r\n\t\t\tthis.positionMenu(pageX, pageY)\r\n\r\n\t\t\tif (isLink) {\r\n\t\t\t\t// Show 'Copy Link' option\r\n\t\t\t\tthis.generalHref = elementClicked.href\r\n\t\t\t\tthis.options.copyLink.show = true\r\n\t\t\t}\r\n\r\n\t\t\tif (isImage) {\r\n\t\t\t\t// Show 'Copy Image Link' option\r\n\t\t\t\tthis.imgSrc = elementClicked.src\r\n\t\t\t\tthis.options.copyImageLink.show = true\r\n\t\t\t}\r\n\r\n\t\t\tif (deezerLink) {\r\n\t\t\t\t// Show 'Copy Deezer Link' option\r\n\t\t\t\tthis.deezerHref = deezerLink\r\n\t\t\t\tthis.showDeezerOptions()\r\n\t\t\t}\r\n\t\t},\r\n\t\thideMenu() {\r\n\t\t\tif (!this.menuOpen) return\r\n\r\n\t\t\t// Finish all operations before closing (may be not necessary)\r\n\t\t\tthis.$nextTick()\r\n\t\t\t\t.then(() => {\r\n\t\t\t\t\tthis.menuOpen = false\r\n\r\n\t\t\t\t\tthis.options.copyLink.show = false\r\n\t\t\t\t\tthis.options.copyDeezerLink.show = false\r\n\t\t\t\t\tthis.options.copyImageLink.show = false\r\n\r\n\t\t\t\t\tdownloadQualities.forEach(quality => {\r\n\t\t\t\t\t\tthis.options[quality.objName].show = false\r\n\t\t\t\t\t})\r\n\t\t\t\t})\r\n\t\t\t\t.catch(err => {\r\n\t\t\t\t\tconsole.error(err)\r\n\t\t\t\t})\r\n\t\t},\r\n\t\tpositionMenu(newX, newY) {\r\n\t\t\tthis.xPos = `${newX}px`\r\n\t\t\tthis.yPos = `${newY}px`\r\n\r\n\t\t\tthis.$nextTick().then(() => {\r\n\t\t\t\tconst { innerHeight, innerWidth } = window\r\n\t\t\t\tconst menuXOffest = newX + this.$refs.contextMenu.getBoundingClientRect().width\r\n\t\t\t\tconst menuYOffest = newY + this.$refs.contextMenu.getBoundingClientRect().height\r\n\r\n\t\t\t\tif (menuXOffest > innerWidth) {\r\n\t\t\t\t\tconst difference = menuXOffest - innerWidth + 15\r\n\t\t\t\t\tthis.xPos = `${newX - difference}px`\r\n\t\t\t\t}\r\n\r\n\t\t\t\tif (menuYOffest > innerHeight) {\r\n\t\t\t\t\tconst difference = menuYOffest - innerHeight + 15\r\n\t\t\t\t\tthis.yPos = `${newY - difference}px`\r\n\t\t\t\t}\r\n\t\t\t})\r\n\t\t},\r\n\t\tshowDeezerOptions() {\r\n\t\t\tthis.options.copyDeezerLink.show = true\r\n\r\n\t\t\tdownloadQualities.forEach(quality => {\r\n\t\t\t\tthis.options[quality.objName].show = true\r\n\t\t\t})\r\n\t\t}\r\n\t}\r\n}\r\n</script>\r\n\r\n<style lang=\"scss\" scoped>\r\n.context-menu {\r\n\tposition: absolute;\r\n\ttop: 0;\r\n\tleft: 0;\r\n\tmin-width: 100px;\r\n\tborder-radius: 7px;\r\n\tbackground: var(--secondary-background);\r\n\tbox-shadow: 4px 10px 18px 0px hsla(0, 0%, 0%, 0.15);\r\n\toverflow: hidden;\r\n\tz-index: 10000;\r\n}\r\n\r\n.menu-option {\r\n\tdisplay: flex;\r\n\talign-items: center;\r\n\twidth: 100%;\r\n\theight: 40px;\r\n\tpadding-left: 10px;\r\n\tpadding-right: 10px;\r\n\tcolor: var(--foreground);\r\n\tcursor: pointer;\r\n\r\n\t&:hover {\r\n\t\tbackground: var(--table-highlight);\r\n\t\tfilter: brightness(150%);\r\n\t}\r\n\r\n\t&__text {\r\n\t\ttext-transform: capitalize;\r\n\t}\r\n}\r\n\r\n// Resetting buttons only for this component (because the style is scoped)\r\nbutton {\r\n\tcolor: var(--primary-text);\r\n\tcolor: unset;\r\n\tbackground-color: var(--primary-color);\r\n\tbackground-color: unset;\r\n\tmin-width: unset;\r\n\tposition: unset;\r\n\tborder: unset;\r\n\tborder-radius: unset;\r\n\tfont-family: unset;\r\n\tfont-weight: unset;\r\n\tfont-size: unset;\r\n\tpadding: unset;\r\n\tmargin-right: unset;\r\n\theight: unset;\r\n\ttext-transform: unset;\r\n\tcursor: unset;\r\n\ttransition: unset;\r\n\r\n\t&:focus {\r\n\t\toutline: none;\r\n\t}\r\n\r\n\t&:active {\r\n\t\tbackground-color: unset;\r\n\t\ttransform: unset;\r\n\t}\r\n\r\n\t&:hover {\r\n\t\tbackground: unset;\r\n\t\tborder: unset;\r\n\t}\r\n}\r\n</style>\r\n",".context-menu {\n  position: absolute;\n  top: 0;\n  left: 0;\n  min-width: 100px;\n  border-radius: 7px;\n  background: var(--secondary-background);\n  box-shadow: 4px 10px 18px 0px rgba(0, 0, 0, 0.15);\n  overflow: hidden;\n  z-index: 10000; }\n\n.menu-option {\n  display: flex;\n  align-items: center;\n  width: 100%;\n  height: 40px;\n  padding-left: 10px;\n  padding-right: 10px;\n  color: var(--foreground);\n  cursor: pointer; }\n  .menu-option:hover {\n    background: var(--table-highlight);\n    filter: brightness(150%); }\n  .menu-option__text {\n    text-transform: capitalize; }\n\nbutton {\n  color: var(--primary-text);\n  color: unset;\n  background-color: var(--primary-color);\n  background-color: unset;\n  min-width: unset;\n  position: unset;\n  border: unset;\n  border-radius: unset;\n  font-family: unset;\n  font-weight: unset;\n  font-size: unset;\n  padding: unset;\n  margin-right: unset;\n  height: unset;\n  text-transform: unset;\n  cursor: unset;\n  transition: unset; }\n  button:focus {\n    outline: none; }\n  button:active {\n    background-color: unset;\n    transform: unset; }\n  button:hover {\n    background: unset;\n    border: unset; }\n\n/*# sourceMappingURL=TheContextMenu.vue.map */"]}, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$3 = "data-v-333a56d8";
  /* module identifier */
  const __vue_module_identifier__$3 = undefined;
  /* functional template */
  const __vue_is_functional_template__$3 = false;
  /* style inject SSR */
  

  
  var TheContextMenu = normalizeComponent_1(
    { render: __vue_render__$3, staticRenderFns: __vue_staticRenderFns__$3 },
    __vue_inject_styles__$3,
    __vue_script__$3,
    __vue_scope_id__$3,
    __vue_is_functional_template__$3,
    __vue_module_identifier__$3,
    browser,
    undefined
  );

// https://alligator.io/vuejs/global-event-bus/

var EventBus = new Vue();

// https://stackoverflow.com/questions/7451508/html5-audio-playback-with-fade-in-and-fade-out#answer-13149848
async function adjustVolume(element, newVolume, { duration = 1000, easing = swing, interval = 13 } = {}) {
	const originalVolume = element.volume;
	const delta = newVolume - originalVolume;

	if (!delta || !duration || !easing || !interval) {
		element.volume = newVolume;
		return Promise.resolve()
	}

	const ticks = Math.floor(duration / interval);
	let tick = 1;

	return new Promise(resolve => {
		const timer = setInterval(() => {
			element.volume = originalVolume + easing(tick / ticks) * delta;
			if (++tick === ticks) {
				clearInterval(timer);
				resolve();
			}
		}, interval);
	})
}

function swing(p) {
	return 0.5 - Math.cos(p * Math.PI) / 2
}

//

var script$4 = {
	data: () => ({
		previewStopped: false
	}),
	mounted() {
		this.$refs.preview.volume = 1;

		this.$router.beforeEach((to, from, next) => {
			this.stopStackedTabsPreview();
			next();
		});

		EventBus.$on('trackPreview:playPausePreview', this.playPausePreview);
		EventBus.$on('trackPreview:previewMouseEnter', this.previewMouseEnter);
		EventBus.$on('trackPreview:previewMouseLeave', this.previewMouseLeave);
	},
	methods: {
		async onCanPlay() {
			await this.$refs.preview.play();

			this.previewStopped = false;

			await adjustVolume(this.$refs.preview, window.vol.preview_max_volume / 100, { duration: 500 });
		},
		async onTimeUpdate() {
			// Prevents first time entering in this function
			if (isNaN(this.$refs.preview.duration)) return

			let duration = this.$refs.preview.duration;

			if (!isFinite(duration)) {
				duration = 30;
			}

			if (duration - this.$refs.preview.currentTime >= 1) return
			if (this.previewStopped) return

			await adjustVolume(this.$refs.preview, 0, { duration: 800 });

			this.previewStopped = true;

			document.querySelectorAll('a[playing] > .preview_controls').forEach(control => {
				control.style.opacity = 0;
			});

			document.querySelectorAll('*').forEach(el => {
				el.removeAttribute('playing');
			});

			document.querySelectorAll('.preview_controls, .preview_playlist_controls').forEach(el => {
				el.textContent = 'play_arrow';
			});
		},
		async playPausePreview(e) {
			e.preventDefault();
			e.stopPropagation();

			const { currentTarget: obj } = e;

			var icon = obj.tagName == 'I' ? obj : obj.querySelector('i');

			if (obj.hasAttribute('playing')) {
				if (this.$refs.preview.paused) {
					this.$refs.preview.play();
					this.previewStopped = false;

					icon.innerText = 'pause';

					await adjustVolume(this.$refs.preview, window.vol.preview_max_volume / 100, { duration: 500 });
				} else {
					this.previewStopped = true;

					icon.innerText = 'play_arrow';

					await adjustVolume(this.$refs.preview, 0, { duration: 250 });

					this.$refs.preview.pause();
				}
			} else {
				document.querySelectorAll('*').forEach(el => {
					el.removeAttribute('playing');
				});
				obj.setAttribute('playing', true);

				document.querySelectorAll('.preview_controls, .preview_playlist_controls').forEach(el => {
					el.textContent = 'play_arrow';
				});

				document.querySelectorAll('.preview_controls').forEach(el => {
					el.style.opacity = 0;
				});

				icon.innerText = 'pause';
				icon.style.opacity = 1;

				this.previewStopped = false;

				await adjustVolume(this.$refs.preview, 0, { duration: 250 });
				this.$refs.preview.pause();

				document.getElementById('preview-track_source').src = obj.getAttribute('data-preview');

				this.$refs.preview.load();
			}
		},
		async stopStackedTabsPreview() {
			let controls = Array.prototype.slice.call(document.querySelectorAll('.preview_playlist_controls[playing]'));

			if (controls.length === 0) return

			await adjustVolume(this.$refs.preview, 0, { duration: 250 });
			this.$refs.preview.pause();

			this.previewStopped = true;

			controls.forEach(control => {
				control.removeAttribute('playing');
				control.innerText = 'play_arrow';
			});
		},
		previewMouseEnter(e) {
			e.currentTarget.style.opacity = 1;
		},
		previewMouseLeave(event) {
			const { currentTarget: obj } = event;
			const parentIsPlaying = obj.parentElement.hasAttribute('playing');

			if ((parentIsPlaying && this.previewStopped) || !parentIsPlaying) {
				obj.style.opacity = 0;
			}
		}
	}
};

/* script */
const __vue_script__$4 = script$4;

/* template */
var __vue_render__$4 = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c(
    "audio",
    {
      ref: "preview",
      attrs: { id: "preview-track" },
      on: { canplay: _vm.onCanPlay, timeupdate: _vm.onTimeUpdate }
    },
    [
      _c("source", {
        attrs: { id: "preview-track_source", src: "", type: "audio/mpeg" }
      })
    ]
  )
};
var __vue_staticRenderFns__$4 = [];
__vue_render__$4._withStripped = true;

  /* style */
  const __vue_inject_styles__$4 = function (inject) {
    if (!inject) return
    inject("data-v-88481186_0", { source: "\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n", map: {"version":3,"sources":[],"names":[],"mappings":"","file":"TheTrackPreview.vue"}, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$4 = undefined;
  /* module identifier */
  const __vue_module_identifier__$4 = undefined;
  /* functional template */
  const __vue_is_functional_template__$4 = false;
  /* style inject SSR */
  

  
  var TheTrackPreview = normalizeComponent_1(
    { render: __vue_render__$4, staticRenderFns: __vue_staticRenderFns__$4 },
    __vue_inject_styles__$4,
    __vue_script__$4,
    __vue_scope_id__$4,
    __vue_is_functional_template__$4,
    __vue_module_identifier__$4,
    browser,
    undefined
  );

//

var script$5 = {
	data: () => ({
		open: false,
		url: ''
	}),
	mounted() {
		this.$root.$on('QualityModal:open', this.openModal);
		this.$refs.modal.addEventListener('webkitAnimationEnd', this.handleAnimationEnd);
	},
	methods: {
		tryToDownloadTrack(event) {
			const { target } = event;

			this.$refs.modal.classList.add('animated', 'fadeOut');

			// If true, the click did not happen on a button but outside
			if (!target.matches('.quality-button')) return

			Downloads.sendAddToQueue(this.url, target.dataset.qualityValue);
		},
		openModal(link) {
			this.url = link;
			this.open = true;
			this.$refs.modal.classList.add('animated', 'fadeIn');
		},
		handleAnimationEnd(event) {
			const { animationName } = event;

			this.$refs.modal.classList.remove('animated', animationName);

			if (animationName === 'fadeIn') return

			this.open = false;
		}
	}
};

/* script */
const __vue_script__$5 = script$5;

/* template */
var __vue_render__$5 = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c(
    "div",
    {
      directives: [
        { name: "show", rawName: "v-show", value: _vm.open, expression: "open" }
      ],
      ref: "modal",
      staticClass: "smallmodal",
      attrs: { id: "modal_quality" },
      on: {
        click: function($event) {
          return _vm.tryToDownloadTrack($event)
        }
      }
    },
    [
      _c("div", { staticClass: "smallmodal-content" }, [
        _c(
          "button",
          {
            staticClass: "btn btn-primary quality-button",
            attrs: { "data-quality-value": "9" }
          },
          [
            _vm._v(
              "\n\t\t\t" +
                _vm._s(_vm.$t("globals.download", { thing: "FLAC" })) +
                "\n\t\t"
            )
          ]
        ),
        _vm._v(" "),
        _c(
          "button",
          {
            staticClass: "btn btn-primary quality-button",
            attrs: { "data-quality-value": "3" }
          },
          [
            _vm._v(
              "\n\t\t\t" +
                _vm._s(_vm.$t("globals.download", { thing: "MP3 320kbps" })) +
                "\n\t\t"
            )
          ]
        ),
        _vm._v(" "),
        _c(
          "button",
          {
            staticClass: "btn btn-primary quality-button",
            attrs: { "data-quality-value": "1" }
          },
          [
            _vm._v(
              "\n\t\t\t" +
                _vm._s(_vm.$t("globals.download", { thing: "MP3 128kbps" })) +
                "\n\t\t"
            )
          ]
        ),
        _vm._v(" "),
        _c(
          "button",
          {
            staticClass: "btn btn-primary quality-button",
            attrs: { "data-quality-value": "15" }
          },
          [
            _vm._v(
              "\n\t\t\t" +
                _vm._s(
                  _vm.$t("globals.download", {
                    thing: "360 Reality Audio [HQ]"
                  })
                ) +
                "\n\t\t"
            )
          ]
        ),
        _vm._v(" "),
        _c(
          "button",
          {
            staticClass: "btn btn-primary quality-button",
            attrs: { "data-quality-value": "14" }
          },
          [
            _vm._v(
              "\n\t\t\t" +
                _vm._s(
                  _vm.$t("globals.download", {
                    thing: "360 Reality Audio [MQ]"
                  })
                ) +
                "\n\t\t"
            )
          ]
        ),
        _vm._v(" "),
        _c(
          "button",
          {
            staticClass: "btn btn-primary quality-button",
            attrs: { "data-quality-value": "13" }
          },
          [
            _vm._v(
              "\n\t\t\t" +
                _vm._s(
                  _vm.$t("globals.download", {
                    thing: "360 Reality Audio [LQ]"
                  })
                ) +
                "\n\t\t"
            )
          ]
        )
      ])
    ]
  )
};
var __vue_staticRenderFns__$5 = [];
__vue_render__$5._withStripped = true;

  /* style */
  const __vue_inject_styles__$5 = function (inject) {
    if (!inject) return
    inject("data-v-a10d0122_0", { source: "\n.smallmodal {\r\n\tposition: fixed;\r\n\tz-index: 1250;\r\n\tleft: 0;\r\n\ttop: 0;\r\n\twidth: 100%;\r\n\theight: 100%;\r\n\toverflow: auto;\r\n\tbackground-color: hsla(0, 0%, 0%, 0.4);\r\n\tanimation-duration: 0.3s;\n}\n.smallmodal-content {\r\n\tbackground-color: transparent;\r\n\tmargin: auto;\r\n\twidth: var(--modal-content-width);\r\n\tposition: relative;\r\n\ttop: 50%;\r\n\ttransform: translateY(-50%);\n}\n.smallmodal-content button {\r\n\twidth: 100%;\r\n\tmargin-bottom: 8px;\n}\r\n", map: {"version":3,"sources":["C:\\Users\\Roberto\\Dev\\repos\\deemix-pyweb\\webui\\src\\components\\globals\\TheQualityModal.vue"],"names":[],"mappings":";AAyBA;CACA,eAAA;CACA,aAAA;CACA,OAAA;CACA,MAAA;CACA,WAAA;CACA,YAAA;CACA,cAAA;CACA,sCAAA;CACA,wBAAA;AACA;AAEA;CACA,6BAAA;CACA,YAAA;CACA,iCAAA;CACA,kBAAA;CACA,QAAA;CACA,2BAAA;AACA;AAEA;CACA,WAAA;CACA,kBAAA;AACA","file":"TheQualityModal.vue","sourcesContent":["<template>\r\n\t<div id=\"modal_quality\" class=\"smallmodal\" v-show=\"open\" @click=\"tryToDownloadTrack($event)\" ref=\"modal\">\r\n\t\t<div class=\"smallmodal-content\">\r\n\t\t\t<button class=\"btn btn-primary quality-button\" data-quality-value=\"9\">\r\n\t\t\t\t{{ $t('globals.download', { thing: 'FLAC' }) }}\r\n\t\t\t</button>\r\n\t\t\t<button class=\"btn btn-primary quality-button\" data-quality-value=\"3\">\r\n\t\t\t\t{{ $t('globals.download', { thing: 'MP3 320kbps' }) }}\r\n\t\t\t</button>\r\n\t\t\t<button class=\"btn btn-primary quality-button\" data-quality-value=\"1\">\r\n\t\t\t\t{{ $t('globals.download', { thing: 'MP3 128kbps' }) }}\r\n\t\t\t</button>\r\n\t\t\t<button class=\"btn btn-primary quality-button\" data-quality-value=\"15\">\r\n\t\t\t\t{{ $t('globals.download', { thing: '360 Reality Audio [HQ]' }) }}\r\n\t\t\t</button>\r\n\t\t\t<button class=\"btn btn-primary quality-button\" data-quality-value=\"14\">\r\n\t\t\t\t{{ $t('globals.download', { thing: '360 Reality Audio [MQ]' }) }}\r\n\t\t\t</button>\r\n\t\t\t<button class=\"btn btn-primary quality-button\" data-quality-value=\"13\">\r\n\t\t\t\t{{ $t('globals.download', { thing: '360 Reality Audio [LQ]' }) }}\r\n\t\t\t</button>\r\n\t\t</div>\r\n\t</div>\r\n</template>\r\n<style>\r\n.smallmodal {\r\n\tposition: fixed;\r\n\tz-index: 1250;\r\n\tleft: 0;\r\n\ttop: 0;\r\n\twidth: 100%;\r\n\theight: 100%;\r\n\toverflow: auto;\r\n\tbackground-color: hsla(0, 0%, 0%, 0.4);\r\n\tanimation-duration: 0.3s;\r\n}\r\n\r\n.smallmodal-content {\r\n\tbackground-color: transparent;\r\n\tmargin: auto;\r\n\twidth: var(--modal-content-width);\r\n\tposition: relative;\r\n\ttop: 50%;\r\n\ttransform: translateY(-50%);\r\n}\r\n\r\n.smallmodal-content button {\r\n\twidth: 100%;\r\n\tmargin-bottom: 8px;\r\n}\r\n</style>\r\n<script>\r\nimport Downloads from '@/utils/downloads'\r\n\r\nexport default {\r\n\tdata: () => ({\r\n\t\topen: false,\r\n\t\turl: ''\r\n\t}),\r\n\tmounted() {\r\n\t\tthis.$root.$on('QualityModal:open', this.openModal)\r\n\t\tthis.$refs.modal.addEventListener('webkitAnimationEnd', this.handleAnimationEnd)\r\n\t},\r\n\tmethods: {\r\n\t\ttryToDownloadTrack(event) {\r\n\t\t\tconst { target } = event\r\n\r\n\t\t\tthis.$refs.modal.classList.add('animated', 'fadeOut')\r\n\r\n\t\t\t// If true, the click did not happen on a button but outside\r\n\t\t\tif (!target.matches('.quality-button')) return\r\n\r\n\t\t\tDownloads.sendAddToQueue(this.url, target.dataset.qualityValue)\r\n\t\t},\r\n\t\topenModal(link) {\r\n\t\t\tthis.url = link\r\n\t\t\tthis.open = true\r\n\t\t\tthis.$refs.modal.classList.add('animated', 'fadeIn')\r\n\t\t},\r\n\t\thandleAnimationEnd(event) {\r\n\t\t\tconst { animationName } = event\r\n\r\n\t\t\tthis.$refs.modal.classList.remove('animated', animationName)\r\n\r\n\t\t\tif (animationName === 'fadeIn') return\r\n\r\n\t\t\tthis.open = false\r\n\t\t}\r\n\t}\r\n}\r\n</script>\r\n"]}, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$5 = undefined;
  /* module identifier */
  const __vue_module_identifier__$5 = undefined;
  /* functional template */
  const __vue_is_functional_template__$5 = false;
  /* style inject SSR */
  

  
  var TheQualityModal = normalizeComponent_1(
    { render: __vue_render__$5, staticRenderFns: __vue_staticRenderFns__$5 },
    __vue_inject_styles__$5,
    __vue_script__$5,
    __vue_scope_id__$5,
    __vue_is_functional_template__$5,
    __vue_module_identifier__$5,
    browser,
    undefined
  );

//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//

var script$6 = {
	data() {
		return {
			titleText: 'Are you sure you want to reset settings to default?'
		}
	},
	mounted() {
		setTimeout(() => {
			// this.$refs.wrapper.classList.add('bounceIn')
			// this.$refs.body.classList.add('bounceIn')
		}, 2000);
	}
};

/* script */
const __vue_script__$6 = script$6;

/* template */
var __vue_render__$6 = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", { ref: "wrapper", staticClass: "wrapper" }, [
    _c(
      "div",
      { ref: "body", staticClass: "body animate__animated animate__bounce" },
      [
        _c("h1", { staticStyle: { flex: "1" } }, [
          _vm._v(_vm._s(_vm.titleText))
        ]),
        _vm._v(" "),
        _vm._m(0)
      ]
    ),
    _vm._v(" "),
    _c("div", { staticClass: "overlay" })
  ])
};
var __vue_staticRenderFns__$6 = [
  function() {
    var _vm = this;
    var _h = _vm.$createElement;
    var _c = _vm._self._c || _h;
    return _c("div", { staticClass: "confirm-area" }, [
      _c("button", { staticClass: "no-hover" }, [_vm._v("Text")]),
      _vm._v(" "),
      _c("button", { staticClass: "no-hover bg-red-600" }, [_vm._v("Text")])
    ])
  }
];
__vue_render__$6._withStripped = true;

  /* style */
  const __vue_inject_styles__$6 = function (inject) {
    if (!inject) return
    inject("data-v-05b44748_0", { source: ".wrapper[data-v-05b44748] {\n  display: grid;\n  place-items: center;\n  position: absolute;\n  top: 0;\n  left: 0;\n  right: 0;\n  bottom: 0;\n  z-index: 1000;\n}\n.body[data-v-05b44748] {\n  position: relative;\n  display: flex;\n  flex-direction: column;\n  width: 50vw;\n  height: 30vh;\n  border-radius: 15px;\n  padding: 2rem;\n  background: var(--secondary-background);\n  z-index: 2;\n  box-shadow: 9px 10px 39px 12px var(--main-background);\n}\n.confirm-area[data-v-05b44748] {\n  position: relative;\n  flex: 1;\n  display: flex;\n  justify-content: flex-end;\n  align-items: flex-end;\n}\n.overlay[data-v-05b44748] {\n  position: absolute;\n  top: 0;\n  left: 0;\n  right: 0;\n  bottom: 0;\n  background: var(--secondary-background);\n  opacity: 0.75;\n  z-index: 1;\n}\n\n/*# sourceMappingURL=ConfirmModal.vue.map */", map: {"version":3,"sources":["C:\\Users\\Roberto\\Dev\\repos\\deemix-pyweb\\webui\\src\\components\\globals\\ConfirmModal.vue","ConfirmModal.vue"],"names":[],"mappings":"AAmBA;EACA,aAAA;EACA,mBAAA;EAEA,kBAAA;EACA,MAAA;EACA,OAAA;EACA,QAAA;EACA,SAAA;EAEA,aAAA;AAAA;AAGA;EACA,kBAAA;EAEA,aAAA;EACA,sBAAA;EAEA,WAAA;EACA,YAAA;EAEA,mBAxBA;EAyBA,aA1BA;EA2BA,uCAAA;EACA,UAAA;EACA,qDAAA;AAAA;AAGA;EACA,kBAAA;EAEA,OAAA;EAEA,aAAA;EACA,yBAAA;EACA,qBAAA;AAAA;AAGA;EACA,kBAAA;EACA,MAAA;EACA,OAAA;EACA,QAAA;EACA,SAAA;EAEA,uCAAA;EACA,aAAA;EACA,UAAA;AAAA;;AC5BA,2CAA2C","file":"ConfirmModal.vue","sourcesContent":["<template>\r\n\t<div class=\"wrapper\" ref=\"wrapper\">\r\n\t\t<div class=\"body animate__animated animate__bounce\" ref=\"body\">\r\n\t\t\t<h1 style=\"flex: 1\">{{ titleText }}</h1>\r\n\r\n\t\t\t<div class=\"confirm-area\">\r\n\t\t\t\t<button class=\"no-hover\">Text</button>\r\n\t\t\t\t<button class=\"no-hover bg-red-600\">Text</button>\r\n\t\t\t</div>\r\n\t\t</div>\r\n\r\n\t\t<div class=\"overlay\"></div>\r\n\t</div>\r\n</template>\r\n\r\n<style lang=\"scss\" scoped>\r\n$body-padding: 2rem;\r\n$body-radius: 15px;\r\n\r\n.wrapper {\r\n\tdisplay: grid;\r\n\tplace-items: center;\r\n\r\n\tposition: absolute;\r\n\ttop: 0;\r\n\tleft: 0;\r\n\tright: 0;\r\n\tbottom: 0;\r\n\r\n\tz-index: 1000; // +1 of the sidebar\r\n}\r\n\r\n.body {\r\n\tposition: relative;\r\n\r\n\tdisplay: flex;\r\n\tflex-direction: column;\r\n\r\n\twidth: 50vw;\r\n\theight: 30vh;\r\n\r\n\tborder-radius: $body-radius;\r\n\tpadding: $body-padding;\r\n\tbackground: var(--secondary-background);\r\n\tz-index: 2;\r\n\tbox-shadow: 9px 10px 39px 12px var(--main-background);\r\n}\r\n\r\n.confirm-area {\r\n\tposition: relative;\r\n\r\n\tflex: 1;\r\n\r\n\tdisplay: flex;\r\n\tjustify-content: flex-end;\r\n\talign-items: flex-end;\r\n}\r\n\r\n.overlay {\r\n\tposition: absolute;\r\n\ttop: 0;\r\n\tleft: 0;\r\n\tright: 0;\r\n\tbottom: 0;\r\n\r\n\tbackground: var(--secondary-background);\r\n\topacity: 0.75;\r\n\tz-index: 1;\r\n}\r\n</style>\r\n\r\n<script>\r\nexport default {\r\n\tdata() {\r\n\t\treturn {\r\n\t\t\ttitleText: 'Are you sure you want to reset settings to default?'\r\n\t\t}\r\n\t},\r\n\tmounted() {\r\n\t\tsetTimeout(() => {\r\n\t\t\t// this.$refs.wrapper.classList.add('bounceIn')\r\n\t\t\t// this.$refs.body.classList.add('bounceIn')\r\n\t\t}, 2000)\r\n\t}\r\n}\r\n</script>\r\n",".wrapper {\n  display: grid;\n  place-items: center;\n  position: absolute;\n  top: 0;\n  left: 0;\n  right: 0;\n  bottom: 0;\n  z-index: 1000; }\n\n.body {\n  position: relative;\n  display: flex;\n  flex-direction: column;\n  width: 50vw;\n  height: 30vh;\n  border-radius: 15px;\n  padding: 2rem;\n  background: var(--secondary-background);\n  z-index: 2;\n  box-shadow: 9px 10px 39px 12px var(--main-background); }\n\n.confirm-area {\n  position: relative;\n  flex: 1;\n  display: flex;\n  justify-content: flex-end;\n  align-items: flex-end; }\n\n.overlay {\n  position: absolute;\n  top: 0;\n  left: 0;\n  right: 0;\n  bottom: 0;\n  background: var(--secondary-background);\n  opacity: 0.75;\n  z-index: 1; }\n\n/*# sourceMappingURL=ConfirmModal.vue.map */"]}, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$6 = "data-v-05b44748";
  /* module identifier */
  const __vue_module_identifier__$6 = undefined;
  /* functional template */
  const __vue_is_functional_template__$6 = false;
  /* style inject SSR */
  

  
  var ConfirmModal = normalizeComponent_1(
    { render: __vue_render__$6, staticRenderFns: __vue_staticRenderFns__$6 },
    __vue_inject_styles__$6,
    __vue_script__$6,
    __vue_scope_id__$6,
    __vue_is_functional_template__$6,
    __vue_module_identifier__$6,
    browser,
    undefined
  );

//

var script$7 = {
	data() {
		return {
			appOnline: null,
			activeTheme: 'light',
			themes: ['purple', 'dark', 'light'],
			activeTablink: 'home',
			updateAvailable: false,
			links: [
				{
					id: 'main_home_tablink',
					name: 'home',
					ariaLabel: 'home',
					routerName: 'Home',
					icon: 'home',
					label: 'sidebar.home'
				},
				{
					id: 'main_search_tablink',
					name: 'search',
					ariaLabel: 'search',
					routerName: 'Search',
					icon: 'search',
					label: 'sidebar.search'
				},
				{
					id: 'main_charts_tablink',
					name: 'charts',
					ariaLabel: 'charts',
					routerName: 'Charts',
					icon: 'show_chart',
					label: 'sidebar.charts'
				},
				{
					id: 'main_favorites_tablink',
					name: 'favorites',
					ariaLabel: 'favorites',
					routerName: 'Favorites',
					icon: 'star',
					label: 'sidebar.favorites'
				},
				{
					id: 'main_analyzer_tablink',
					name: 'analyzer',
					ariaLabel: 'link analyzer',
					routerName: 'Link Analyzer',
					icon: 'link',
					label: 'sidebar.linkAnalyzer'
				},
				{
					id: 'main_settings_tablink',
					name: 'settings',
					ariaLabel: 'settings',
					routerName: 'Settings',
					icon: 'settings',
					label: 'sidebar.settings'
				},
				{
					id: 'main_about_tablink',
					name: 'about',
					ariaLabel: 'info',
					routerName: 'About',
					icon: 'info',
					label: 'sidebar.about'
				}
			]
		}
	},
	mounted() {
		/* === Online status handling === */
		this.appOnline = navigator.onLine;

		window.addEventListener('online', () => {
			this.appOnline = true;
		});

		window.addEventListener('offline', () => {
			this.appOnline = false;
		});

		/* === Current theme handling === */
		this.activeTheme = localStorage.getItem('selectedTheme') || 'dark';

		this.$router.afterEach((to, from) => {
			const linkInSidebar = this.links.find(link => link.routerName === to.name);

			if (!linkInSidebar) return

			this.activeTablink = linkInSidebar.name;
		});

		/* === Add update notification near info === */
		socket.on('updateAvailable', () => {
			this.updateAvailable = true;
		});
	},
	methods: {
		changeTheme(newTheme) {
			if (newTheme === this.activeTheme) return

			this.activeTheme = newTheme;
			document.documentElement.setAttribute('data-theme', newTheme);
			localStorage.setItem('selectedTheme', newTheme);

			// Animating everything to have a smoother theme switch
			const allElements = document.querySelectorAll('*');

			allElements.forEach(el => {
				el.classList.add('changing-theme');
			});

			document.documentElement.addEventListener('transitionend', function transitionHandler() {
				allElements.forEach(el => {
					el.classList.remove('changing-theme');
				});

				document.documentElement.removeEventListener('transitionend', transitionHandler);
			});
		}
	}
};

/* script */
const __vue_script__$7 = script$7;

/* template */
var __vue_render__$7 = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c(
    "aside",
    {
      staticClass:
        "top-0 left-0 flex flex-col w-64 h-screen bg-panels-bg text-foreground",
      attrs: { id: "sidebar", role: "navigation", "aria-label": "sidebar" }
    },
    [
      _vm._l(_vm.links, function(link) {
        return _c(
          "router-link",
          {
            key: link.id,
            staticClass:
              "relative flex items-center h-16 no-underline group main_tablinks hover:bg-background-main text-foreground",
            class: { "bg-background-main": _vm.activeTablink === link.name },
            attrs: {
              tag: "a",
              id: link.id,
              "aria-label": link.ariaLabel,
              to: { name: link.routerName }
            },
            nativeOn: {
              click: function($event) {
                _vm.activeTablink = link.name;
              }
            }
          },
          [
            _c(
              "i",
              {
                staticClass:
                  "p-2 text-3xl material-icons side_icon group-hover:text-primary",
                class: { "text-primary": _vm.activeTablink === link.name }
              },
              [_vm._v("\n\t\t\t" + _vm._s(link.icon) + "\n\t\t")]
            ),
            _vm._v(" "),
            _c(
              "span",
              {
                staticClass:
                  "ml-5 overflow-hidden capitalize whitespace-no-wrap main_tablinks_text",
                staticStyle: { "letter-spacing": "1.3px" }
              },
              [_vm._v("\n\t\t\t" + _vm._s(_vm.$t(link.label)) + "\n\t\t")]
            ),
            _vm._v(" "),
            link.name === "about" && _vm.updateAvailable
              ? _c("span", {
                  staticClass: "w-3 h-3 bg-red-600 rounded-full",
                  attrs: { id: "update-notification" }
                })
              : _vm._e()
          ]
        )
      }),
      _vm._v(" "),
      _c(
        "span",
        {
          staticClass: "flex h-12 mt-5",
          attrs: {
            id: "theme_selector",
            role: "link",
            "aria-label": "theme selector"
          }
        },
        [
          _c(
            "i",
            {
              staticClass:
                "p-2 text-3xl transition-all duration-500 cursor-default material-icons side_icon side_icon--theme"
            },
            [_vm._v("\n\t\t\tbrush\n\t\t")]
          ),
          _vm._v(" "),
          _c(
            "div",
            {
              staticClass: "relative flex items-center w-full justify-evenly",
              attrs: { id: "theme_togglers" }
            },
            _vm._l(_vm.themes, function(theme) {
              return _c("div", {
                key: theme,
                staticClass:
                  "w-6 h-6 border rounded-full cursor-pointer theme_toggler border-grayscale-500",
                class: [
                  { "theme_toggler--active": _vm.activeTheme === theme },
                  "theme_toggler--" + theme
                ],
                on: {
                  click: function($event) {
                    return _vm.changeTheme(theme)
                  }
                }
              })
            }),
            0
          )
        ]
      ),
      _vm._v(" "),
      _c(
        "div",
        {
          class: { online: _vm.appOnline, offline: !_vm.appOnline },
          attrs: { id: "network-status" }
        },
        [
          _vm.appOnline
            ? _c("i", { staticClass: "material-icons" }, [_vm._v("wifi")])
            : _c("i", { staticClass: "material-icons" }, [
                _c(
                  "svg",
                  {
                    attrs: {
                      xmlns: "http://www.w3.org/2000/svg",
                      viewBox: "0 0 24 24"
                    }
                  },
                  [
                    _c("path", {
                      attrs: {
                        d:
                          "M24 .01c0-.01 0-.01 0 0L0 0v24h24V.01zM0 0h24v24H0V0zm0 0h24v24H0V0z",
                        fill: "none"
                      }
                    }),
                    _vm._v(" "),
                    _c("path", {
                      attrs: {
                        d:
                          "M22.99 9C19.15 5.16 13.8 3.76 8.84 4.78l2.52 2.52c3.47-.17 6.99 1.05 9.63 3.7l2-2zm-4 4c-1.29-1.29-2.84-2.13-4.49-2.56l3.53 3.53.96-.97zM2 3.05L5.07 6.1C3.6 6.82 2.22 7.78 1 9l1.99 2c1.24-1.24 2.67-2.16 4.2-2.77l2.24 2.24C7.81 10.89 6.27 11.73 5 13v.01L6.99 15c1.36-1.36 3.14-2.04 4.92-2.06L18.98 20l1.27-1.26L3.29 1.79 2 3.05zM9 17l3 3 3-3c-1.65-1.66-4.34-1.66-6 0z"
                      }
                    })
                  ]
                )
              ])
        ]
      )
    ],
    2
  )
};
var __vue_staticRenderFns__$7 = [];
__vue_render__$7._withStripped = true;

  /* style */
  const __vue_inject_styles__$7 = function (inject) {
    if (!inject) return
    inject("data-v-c7710300_0", { source: "#sidebar.slim[data-v-c7710300] {\n  width: 46px;\n}\n#sidebar.slim .main_tablinks_text[data-v-c7710300] {\n  display: none;\n}\n#sidebar.slim #theme_selector[data-v-c7710300], #sidebar.slim #theme_togglers[data-v-c7710300] {\n  display: inline-grid;\n  grid-gap: 8px;\n}\n#network-status[data-v-c7710300] {\n  display: flex;\n  justify-content: center;\n  align-items: center;\n  position: relative;\n  margin-top: auto;\n  bottom: 0;\n}\n#network-status.online i.material-icons[data-v-c7710300] {\n  color: #159957;\n}\n#network-status.offline i.material-icons svg[data-v-c7710300] {\n  fill: red;\n  width: 1em;\n  height: 1em;\n}\n#update-notification[data-v-c7710300] {\n  position: absolute;\n  left: 30px;\n  top: 12px;\n}\n.theme_toggler[data-v-c7710300] {\n  transition: border 200ms ease-in-out;\n}\n.theme_toggler--active[data-v-c7710300] {\n    border-width: 3px;\n}\n.theme_toggler--light[data-v-c7710300] {\n    background-color: #fff;\n}\n.theme_toggler--dark[data-v-c7710300] {\n    background-color: #141414;\n}\n.theme_toggler--purple[data-v-c7710300] {\n    background: #460eaf;\n}\n\n/*# sourceMappingURL=TheSidebar.vue.map */", map: {"version":3,"sources":["C:\\Users\\Roberto\\Dev\\repos\\deemix-pyweb\\webui\\src\\components\\TheSidebar.vue","TheSidebar.vue"],"names":[],"mappings":"AAgEA;EACA,WAAA;AAAA;AAEA;EACA,aAAA;AAAA;AAEA;EACA,oBAAA;EACA,aAAA;AAAA;AAGA;EACA,aAAA;EACA,uBAAA;EACA,mBAAA;EACA,kBAAA;EACA,gBAAA;EACA,SAAA;AAAA;AAGA;EACA,cAAA;AAAA;AAGA;EACA,SAAA;EACA,UAAA;EACA,WAAA;AAAA;AAGA;EACA,kBAAA;EACA,UAAA;EACA,SAAA;AAAA;AAGA;EACA,oCAAA;AAAA;AAEA;IACA,iBAAA;AAAA;AAGA;IACA,sBAAA;AAAA;AAGA;IACA,yBAAA;AAAA;AAGA;IACA,mBAAA;AAAA;;AC1EA,yCAAyC","file":"TheSidebar.vue","sourcesContent":["<template>\r\n\t<aside\r\n\t\tid=\"sidebar\"\r\n\t\tclass=\"top-0 left-0 flex flex-col w-64 h-screen bg-panels-bg text-foreground\"\r\n\t\trole=\"navigation\"\r\n\t\taria-label=\"sidebar\"\r\n\t>\r\n\t\t<router-link\r\n\t\t\ttag=\"a\"\r\n\t\t\tv-for=\"link in links\"\r\n\t\t\t:key=\"link.id\"\r\n\t\t\tclass=\"relative flex items-center h-16 no-underline group main_tablinks hover:bg-background-main text-foreground\"\r\n\t\t\t:id=\"link.id\"\r\n\t\t\t:class=\"{ 'bg-background-main': activeTablink === link.name }\"\r\n\t\t\t:aria-label=\"link.ariaLabel\"\r\n\t\t\t:to=\"{ name: link.routerName }\"\r\n\t\t\t@click.native=\"activeTablink = link.name\"\r\n\t\t>\r\n\t\t\t<i\r\n\t\t\t\tclass=\"p-2 text-3xl material-icons side_icon group-hover:text-primary\"\r\n\t\t\t\t:class=\"{ 'text-primary': activeTablink === link.name }\"\r\n\t\t\t>\r\n\t\t\t\t{{ link.icon }}\r\n\t\t\t</i>\r\n\t\t\t<span class=\"ml-5 overflow-hidden capitalize whitespace-no-wrap main_tablinks_text\" style=\"letter-spacing: 1.3px\">\r\n\t\t\t\t{{ $t(link.label) }}\r\n\t\t\t</span>\r\n\t\t\t<span\r\n\t\t\t\tv-if=\"link.name === 'about' && updateAvailable\"\r\n\t\t\t\tid=\"update-notification\"\r\n\t\t\t\tclass=\"w-3 h-3 bg-red-600 rounded-full\"\r\n\t\t\t></span>\r\n\t\t</router-link>\r\n\r\n\t\t<span id=\"theme_selector\" class=\"flex h-12 mt-5\" role=\"link\" aria-label=\"theme selector\">\r\n\t\t\t<i class=\"p-2 text-3xl transition-all duration-500 cursor-default material-icons side_icon side_icon--theme\">\r\n\t\t\t\tbrush\r\n\t\t\t</i>\r\n\t\t\t<div id=\"theme_togglers\" class=\"relative flex items-center w-full justify-evenly\">\r\n\t\t\t\t<div\r\n\t\t\t\t\tv-for=\"theme of themes\"\r\n\t\t\t\t\t:key=\"theme\"\r\n\t\t\t\t\tclass=\"w-6 h-6 border rounded-full cursor-pointer theme_toggler border-grayscale-500\"\r\n\t\t\t\t\t:class=\"[{ 'theme_toggler--active': activeTheme === theme }, `theme_toggler--${theme}`]\"\r\n\t\t\t\t\t@click=\"changeTheme(theme)\"\r\n\t\t\t\t></div>\r\n\t\t\t</div>\r\n\t\t</span>\r\n\t\t<div id=\"network-status\" :class=\"{ online: appOnline, offline: !appOnline }\">\r\n\t\t\t<i v-if=\"appOnline\" class=\"material-icons\">wifi</i>\r\n\t\t\t<i v-else class=\"material-icons\">\r\n\t\t\t\t<!-- wifi_off icon not working, maybe need to include it? -->\r\n\t\t\t\t<svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\">\r\n\t\t\t\t\t<path d=\"M24 .01c0-.01 0-.01 0 0L0 0v24h24V.01zM0 0h24v24H0V0zm0 0h24v24H0V0z\" fill=\"none\" />\r\n\t\t\t\t\t<path\r\n\t\t\t\t\t\td=\"M22.99 9C19.15 5.16 13.8 3.76 8.84 4.78l2.52 2.52c3.47-.17 6.99 1.05 9.63 3.7l2-2zm-4 4c-1.29-1.29-2.84-2.13-4.49-2.56l3.53 3.53.96-.97zM2 3.05L5.07 6.1C3.6 6.82 2.22 7.78 1 9l1.99 2c1.24-1.24 2.67-2.16 4.2-2.77l2.24 2.24C7.81 10.89 6.27 11.73 5 13v.01L6.99 15c1.36-1.36 3.14-2.04 4.92-2.06L18.98 20l1.27-1.26L3.29 1.79 2 3.05zM9 17l3 3 3-3c-1.65-1.66-4.34-1.66-6 0z\"\r\n\t\t\t\t\t/>\r\n\t\t\t\t</svg>\r\n\t\t\t</i>\r\n\t\t</div>\r\n\t</aside>\r\n</template>\r\n\r\n<style lang=\"scss\" scoped>\r\n#sidebar.slim{\r\n\twidth: 46px;\r\n}\r\n#sidebar.slim .main_tablinks_text{\r\n\tdisplay: none;\r\n}\r\n#sidebar.slim #theme_selector, #sidebar.slim #theme_togglers{\r\n\tdisplay: inline-grid;\r\n\tgrid-gap: 8px;\r\n}\r\n\r\n#network-status {\r\n\tdisplay: flex;\r\n\tjustify-content: center;\r\n\talign-items: center;\r\n\tposition: relative;\r\n\tmargin-top: auto;\r\n\tbottom: 0;\r\n}\r\n\r\n#network-status.online i.material-icons {\r\n\tcolor: hsl(150, 76%, 34%);\r\n}\r\n\r\n#network-status.offline i.material-icons svg {\r\n\tfill: red;\r\n\twidth: 1em;\r\n\theight: 1em;\r\n}\r\n\r\n#update-notification {\r\n\tposition: absolute;\r\n\tleft: 30px;\r\n\ttop: 12px;\r\n}\r\n\r\n.theme_toggler {\r\n\ttransition: border 200ms ease-in-out;\r\n\r\n\t&--active {\r\n\t\tborder-width: 3px;\r\n\t}\r\n\r\n\t&--light {\r\n\t\tbackground-color: #fff;\r\n\t}\r\n\r\n\t&--dark {\r\n\t\tbackground-color: hsl(0, 0%, 8%);\r\n\t}\r\n\r\n\t&--purple {\r\n\t\tbackground: hsl(261, 85%, 37%);\r\n\t}\r\n}\r\n</style>\r\n\r\n<script>\r\nimport { socket } from '@/utils/socket'\r\n\r\nexport default {\r\n\tdata() {\r\n\t\treturn {\r\n\t\t\tappOnline: null,\r\n\t\t\tactiveTheme: 'light',\r\n\t\t\tthemes: ['purple', 'dark', 'light'],\r\n\t\t\tactiveTablink: 'home',\r\n\t\t\tupdateAvailable: false,\r\n\t\t\tlinks: [\r\n\t\t\t\t{\r\n\t\t\t\t\tid: 'main_home_tablink',\r\n\t\t\t\t\tname: 'home',\r\n\t\t\t\t\tariaLabel: 'home',\r\n\t\t\t\t\trouterName: 'Home',\r\n\t\t\t\t\ticon: 'home',\r\n\t\t\t\t\tlabel: 'sidebar.home'\r\n\t\t\t\t},\r\n\t\t\t\t{\r\n\t\t\t\t\tid: 'main_search_tablink',\r\n\t\t\t\t\tname: 'search',\r\n\t\t\t\t\tariaLabel: 'search',\r\n\t\t\t\t\trouterName: 'Search',\r\n\t\t\t\t\ticon: 'search',\r\n\t\t\t\t\tlabel: 'sidebar.search'\r\n\t\t\t\t},\r\n\t\t\t\t{\r\n\t\t\t\t\tid: 'main_charts_tablink',\r\n\t\t\t\t\tname: 'charts',\r\n\t\t\t\t\tariaLabel: 'charts',\r\n\t\t\t\t\trouterName: 'Charts',\r\n\t\t\t\t\ticon: 'show_chart',\r\n\t\t\t\t\tlabel: 'sidebar.charts'\r\n\t\t\t\t},\r\n\t\t\t\t{\r\n\t\t\t\t\tid: 'main_favorites_tablink',\r\n\t\t\t\t\tname: 'favorites',\r\n\t\t\t\t\tariaLabel: 'favorites',\r\n\t\t\t\t\trouterName: 'Favorites',\r\n\t\t\t\t\ticon: 'star',\r\n\t\t\t\t\tlabel: 'sidebar.favorites'\r\n\t\t\t\t},\r\n\t\t\t\t{\r\n\t\t\t\t\tid: 'main_analyzer_tablink',\r\n\t\t\t\t\tname: 'analyzer',\r\n\t\t\t\t\tariaLabel: 'link analyzer',\r\n\t\t\t\t\trouterName: 'Link Analyzer',\r\n\t\t\t\t\ticon: 'link',\r\n\t\t\t\t\tlabel: 'sidebar.linkAnalyzer'\r\n\t\t\t\t},\r\n\t\t\t\t{\r\n\t\t\t\t\tid: 'main_settings_tablink',\r\n\t\t\t\t\tname: 'settings',\r\n\t\t\t\t\tariaLabel: 'settings',\r\n\t\t\t\t\trouterName: 'Settings',\r\n\t\t\t\t\ticon: 'settings',\r\n\t\t\t\t\tlabel: 'sidebar.settings'\r\n\t\t\t\t},\r\n\t\t\t\t{\r\n\t\t\t\t\tid: 'main_about_tablink',\r\n\t\t\t\t\tname: 'about',\r\n\t\t\t\t\tariaLabel: 'info',\r\n\t\t\t\t\trouterName: 'About',\r\n\t\t\t\t\ticon: 'info',\r\n\t\t\t\t\tlabel: 'sidebar.about'\r\n\t\t\t\t}\r\n\t\t\t]\r\n\t\t}\r\n\t},\r\n\tmounted() {\r\n\t\t/* === Online status handling === */\r\n\t\tthis.appOnline = navigator.onLine\r\n\r\n\t\twindow.addEventListener('online', () => {\r\n\t\t\tthis.appOnline = true\r\n\t\t})\r\n\r\n\t\twindow.addEventListener('offline', () => {\r\n\t\t\tthis.appOnline = false\r\n\t\t})\r\n\r\n\t\t/* === Current theme handling === */\r\n\t\tthis.activeTheme = localStorage.getItem('selectedTheme') || 'dark'\r\n\r\n\t\tthis.$router.afterEach((to, from) => {\r\n\t\t\tconst linkInSidebar = this.links.find(link => link.routerName === to.name)\r\n\r\n\t\t\tif (!linkInSidebar) return\r\n\r\n\t\t\tthis.activeTablink = linkInSidebar.name\r\n\t\t})\r\n\r\n\t\t/* === Add update notification near info === */\r\n\t\tsocket.on('updateAvailable', () => {\r\n\t\t\tthis.updateAvailable = true\r\n\t\t})\r\n\t},\r\n\tmethods: {\r\n\t\tchangeTheme(newTheme) {\r\n\t\t\tif (newTheme === this.activeTheme) return\r\n\r\n\t\t\tthis.activeTheme = newTheme\r\n\t\t\tdocument.documentElement.setAttribute('data-theme', newTheme)\r\n\t\t\tlocalStorage.setItem('selectedTheme', newTheme)\r\n\r\n\t\t\t// Animating everything to have a smoother theme switch\r\n\t\t\tconst allElements = document.querySelectorAll('*')\r\n\r\n\t\t\tallElements.forEach(el => {\r\n\t\t\t\tel.classList.add('changing-theme')\r\n\t\t\t})\r\n\r\n\t\t\tdocument.documentElement.addEventListener('transitionend', function transitionHandler() {\r\n\t\t\t\tallElements.forEach(el => {\r\n\t\t\t\t\tel.classList.remove('changing-theme')\r\n\t\t\t\t})\r\n\r\n\t\t\t\tdocument.documentElement.removeEventListener('transitionend', transitionHandler)\r\n\t\t\t})\r\n\t\t}\r\n\t}\r\n}\r\n</script>\r\n","#sidebar.slim {\n  width: 46px; }\n\n#sidebar.slim .main_tablinks_text {\n  display: none; }\n\n#sidebar.slim #theme_selector, #sidebar.slim #theme_togglers {\n  display: inline-grid;\n  grid-gap: 8px; }\n\n#network-status {\n  display: flex;\n  justify-content: center;\n  align-items: center;\n  position: relative;\n  margin-top: auto;\n  bottom: 0; }\n\n#network-status.online i.material-icons {\n  color: #159957; }\n\n#network-status.offline i.material-icons svg {\n  fill: red;\n  width: 1em;\n  height: 1em; }\n\n#update-notification {\n  position: absolute;\n  left: 30px;\n  top: 12px; }\n\n.theme_toggler {\n  transition: border 200ms ease-in-out; }\n  .theme_toggler--active {\n    border-width: 3px; }\n  .theme_toggler--light {\n    background-color: #fff; }\n  .theme_toggler--dark {\n    background-color: #141414; }\n  .theme_toggler--purple {\n    background: #460eaf; }\n\n/*# sourceMappingURL=TheSidebar.vue.map */"]}, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$7 = "data-v-c7710300";
  /* module identifier */
  const __vue_module_identifier__$7 = undefined;
  /* functional template */
  const __vue_is_functional_template__$7 = false;
  /* style inject SSR */
  

  
  var TheSidebar = normalizeComponent_1(
    { render: __vue_render__$7, staticRenderFns: __vue_staticRenderFns__$7 },
    __vue_inject_styles__$7,
    __vue_script__$7,
    __vue_scope_id__$7,
    __vue_is_functional_template__$7,
    __vue_module_identifier__$7,
    browser,
    undefined
  );

//

var script$8 = {
	data() {
		return {
			lastTextSearch: ''
		}
	},
	created() {
		const focusSearchBar = keyEvent => {
			if (keyEvent.keyCode === 70 && keyEvent.ctrlKey) {
				keyEvent.preventDefault();
				this.$refs.searchbar.focus();
			}
		};

		const deleteSearchBarContent = keyEvent => {
			if (!(keyEvent.key == 'Backspace' && keyEvent.ctrlKey && keyEvent.shiftKey)) return

			this.$refs.searchbar.value = '';
			this.$refs.searchbar.focus();
		};

		document.addEventListener('keydown', focusSearchBar);
		document.addEventListener('keyup', deleteSearchBarContent);

		this.$on('hook:destroyed', () => {
			document.removeEventListener('keydown', focusSearchBar);
			document.removeEventListener('keyup', deleteSearchBarContent);
		});
	},
	methods: {
		test() {
			console.log('test passato');
		},
		async handleSearchBarKeyup(keyEvent) {
			let isEnterPressed = keyEvent.keyCode === 13;

			// If not enter do nothing
			if (!isEnterPressed) return

			let term = this.$refs.searchbar.value;
			let isEmptySearch = term === '';

			// If empty do nothing
			if (isEmptySearch) return

			let isSearchingURL = isValidURL(term);
			let isCtrlPressed = keyEvent.ctrlKey;
			let isShowingAnalyzer = this.$route.name === 'Link Analyzer';
			let isShowingSearch = this.$route.name === 'Search';
			let sameAsLastSearch = term === this.lastTextSearch;

			if (isSearchingURL) {
				if (isCtrlPressed) {
					this.$root.$emit('QualityModal:open', term);
				} else {
					if (isShowingAnalyzer) {
						// EventBus.$emit('linkAnalyzerTab:reset')
						socket.emit('analyzeLink', term);
					} else {
						// ? Open downloads tab ?
						sendAddToQueue(term);
					}
				}
			} else {
				if (isShowingSearch && sameAsLastSearch) {
					this.$root.$emit('mainSearch:updateResults', term);
					return
				}

				if (!isShowingSearch) {
					await this.$router.push({
						name: 'Search'
					});
				}

				if (!sameAsLastSearch) {
					this.$root.$emit('updateSearchLoadingState', true);
					this.lastTextSearch = term;
				}

				this.$root.$emit('mainSearch:showNewResults', term);
			}
		}
	}
};

/* script */
const __vue_script__$8 = script$8;

/* template */
var __vue_render__$8 = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("header", { attrs: { id: "search", "aria-label": "searchbar" } }, [
    _vm._m(0),
    _vm._v(" "),
    _c("input", {
      ref: "searchbar",
      staticClass: "w-full",
      attrs: {
        id: "searchbar",
        autocomplete: "off",
        type: "search",
        name: "searchbar",
        value: "",
        placeholder: _vm.$t("searchbar"),
        autofocus: ""
      },
      on: {
        keyup: function($event) {
          return _vm.handleSearchBarKeyup($event)
        }
      }
    })
  ])
};
var __vue_staticRenderFns__$8 = [
  function() {
    var _vm = this;
    var _h = _vm.$createElement;
    var _c = _vm._self._c || _h;
    return _c("div", { staticClass: "search__icon" }, [
      _c("i", { staticClass: "material-icons" }, [_vm._v("search")])
    ])
  }
];
__vue_render__$8._withStripped = true;

  /* style */
  const __vue_inject_styles__$8 = function (inject) {
    if (!inject) return
    inject("data-v-4a00406e_0", { source: "#search {\n  background-color: var(--secondary-background);\n  padding: 0 1em;\n  display: flex;\n  align-items: center;\n  border: 1px solid transparent;\n  transition: border 200ms ease-in-out;\n  border-radius: 15px;\n  margin: 10px 10px 20px 10px;\n}\n#search:focus-within {\n    border: 1px solid var(--foreground);\n}\n#search .search__icon {\n    width: 2rem;\n    height: 2rem;\n}\n#search .search__icon i {\n      font-size: 2rem;\n      color: var(--foreground);\n}\n#search .search__icon i::selection {\n        background: none;\n}\n#search #searchbar {\n    height: 45px;\n    padding-left: 0.5em;\n    border: 0px;\n    border-radius: 0px;\n    background-color: var(--secondary-background);\n    color: var(--foreground);\n    font-size: 1.2rem;\n    font-family: 'Open Sans';\n    font-weight: 300;\n    margin-bottom: 0;\n}\n#search #searchbar:focus {\n      outline: none;\n}\n#search #searchbar:-webkit-autofill, #search #searchbar:-webkit-autofill:hover, #search #searchbar:-webkit-autofill:focus, #search #searchbar:-webkit-autofill:active {\n      -webkit-box-shadow: 0 0 0 45px var(--secondary-background) inset !important;\n      box-shadow: 0 0 0 45px var(--secondary-background) inset !important;\n}\n\n/*# sourceMappingURL=TheSearchBar.vue.map */", map: {"version":3,"sources":["C:\\Users\\Roberto\\Dev\\repos\\deemix-pyweb\\webui\\src\\components\\TheSearchBar.vue","TheSearchBar.vue"],"names":[],"mappings":"AA2BA;EACA,6CAAA;EACA,cAAA;EACA,aAAA;EACA,mBAAA;EACA,6BAAA;EACA,oCAAA;EACA,mBAAA;EACA,2BAAA;AAAA;AARA;IAWA,mCAAA;AAAA;AAXA;IAeA,WAlBA;IAmBA,YAnBA;AAAA;AAGA;MAmBA,eAtBA;MAuBA,wBAAA;AAAA;AApBA;QAuBA,gBAAA;AAAA;AAvBA;IA6BA,YA/BA;IAgCA,mBAAA;IACA,WAAA;IACA,kBAAA;IACA,6CAAA;IACA,wBAAA;IACA,iBAAA;IACA,wBAAA;IACA,gBAAA;IACA,gBAAA;AAAA;AAtCA;MAyCA,aAAA;AAAA;AAzCA;MAiDA,2EAAA;MACA,mEAAA;AAAA;;ACzCA,2CAA2C","file":"TheSearchBar.vue","sourcesContent":["<template>\r\n\t<header id=\"search\" aria-label=\"searchbar\">\r\n\t\t<div class=\"search__icon\">\r\n\t\t\t<i class=\"material-icons\">search</i>\r\n\t\t</div>\r\n\r\n\t\t<input\r\n\t\t\tid=\"searchbar\"\r\n\t\t\tclass=\"w-full\"\r\n\t\t\tautocomplete=\"off\"\r\n\t\t\ttype=\"search\"\r\n\t\t\tname=\"searchbar\"\r\n\t\t\tvalue=\"\"\r\n\t\t\t:placeholder=\"$t('searchbar')\"\r\n\t\t\tautofocus\r\n\t\t\tref=\"searchbar\"\r\n\t\t\t@keyup=\"handleSearchBarKeyup($event)\"\r\n\t\t/>\r\n\t\t<!-- @keyup.enter.exact=\"onEnter\"\r\n\t\t\t@keyup.ctrl.enter=\"onCTRLEnter\" -->\r\n\t</header>\r\n</template>\r\n\r\n<style lang=\"scss\">\r\n$icon-dimension: 2rem;\r\n$searchbar-height: 45px;\r\n\r\n#search {\r\n\tbackground-color: var(--secondary-background);\r\n\tpadding: 0 1em;\r\n\tdisplay: flex;\r\n\talign-items: center;\r\n\tborder: 1px solid transparent;\r\n\ttransition: border 200ms ease-in-out;\r\n\tborder-radius: 15px;\r\n\tmargin: 10px 10px 20px 10px;\r\n\r\n\t&:focus-within {\r\n\t\tborder: 1px solid var(--foreground);\r\n\t}\r\n\r\n\t.search__icon {\r\n\t\twidth: $icon-dimension;\r\n\t\theight: $icon-dimension;\r\n\r\n\t\ti {\r\n\t\t\tfont-size: $icon-dimension;\r\n\t\t\tcolor: var(--foreground);\r\n\r\n\t\t\t&::selection {\r\n\t\t\t\tbackground: none;\r\n\t\t\t}\r\n\t\t}\r\n\t}\r\n\r\n\t#searchbar {\r\n\t\theight: $searchbar-height;\r\n\t\tpadding-left: 0.5em;\r\n\t\tborder: 0px;\r\n\t\tborder-radius: 0px;\r\n\t\tbackground-color: var(--secondary-background);\r\n\t\tcolor: var(--foreground);\r\n\t\tfont-size: 1.2rem;\r\n\t\tfont-family: 'Open Sans';\r\n\t\tfont-weight: 300;\r\n\t\tmargin-bottom: 0;\r\n\r\n\t\t&:focus {\r\n\t\t\toutline: none;\r\n\t\t}\r\n\r\n\t\t// Removing Chrome autofill color\r\n\t\t&:-webkit-autofill,\r\n\t\t&:-webkit-autofill:hover,\r\n\t\t&:-webkit-autofill:focus,\r\n\t\t&:-webkit-autofill:active {\r\n\t\t\t-webkit-box-shadow: 0 0 0 $searchbar-height var(--secondary-background) inset !important;\r\n\t\t\tbox-shadow: 0 0 0 $searchbar-height var(--secondary-background) inset !important;\r\n\t\t}\r\n\t}\r\n}\r\n</style>\r\n\r\n<script>\r\nimport { isValidURL } from '@/utils/utils'\r\nimport { sendAddToQueue } from '@/utils/downloads'\r\nimport EventBus from '@/utils/EventBus'\r\nimport { socket } from '@/utils/socket'\r\n\r\nexport default {\r\n\tdata() {\r\n\t\treturn {\r\n\t\t\tlastTextSearch: ''\r\n\t\t}\r\n\t},\r\n\tcreated() {\r\n\t\tconst focusSearchBar = keyEvent => {\r\n\t\t\tif (keyEvent.keyCode === 70 && keyEvent.ctrlKey) {\r\n\t\t\t\tkeyEvent.preventDefault()\r\n\t\t\t\tthis.$refs.searchbar.focus()\r\n\t\t\t}\r\n\t\t}\r\n\r\n\t\tconst deleteSearchBarContent = keyEvent => {\r\n\t\t\tif (!(keyEvent.key == 'Backspace' && keyEvent.ctrlKey && keyEvent.shiftKey)) return\r\n\r\n\t\t\tthis.$refs.searchbar.value = ''\r\n\t\t\tthis.$refs.searchbar.focus()\r\n\t\t}\r\n\r\n\t\tdocument.addEventListener('keydown', focusSearchBar)\r\n\t\tdocument.addEventListener('keyup', deleteSearchBarContent)\r\n\r\n\t\tthis.$on('hook:destroyed', () => {\r\n\t\t\tdocument.removeEventListener('keydown', focusSearchBar)\r\n\t\t\tdocument.removeEventListener('keyup', deleteSearchBarContent)\r\n\t\t})\r\n\t},\r\n\tmethods: {\r\n\t\ttest() {\r\n\t\t\tconsole.log('test passato')\r\n\t\t},\r\n\t\tasync handleSearchBarKeyup(keyEvent) {\r\n\t\t\tlet isEnterPressed = keyEvent.keyCode === 13\r\n\r\n\t\t\t// If not enter do nothing\r\n\t\t\tif (!isEnterPressed) return\r\n\r\n\t\t\tlet term = this.$refs.searchbar.value\r\n\t\t\tlet isEmptySearch = term === ''\r\n\r\n\t\t\t// If empty do nothing\r\n\t\t\tif (isEmptySearch) return\r\n\r\n\t\t\tlet isSearchingURL = isValidURL(term)\r\n\t\t\tlet isCtrlPressed = keyEvent.ctrlKey\r\n\t\t\tlet isShowingAnalyzer = this.$route.name === 'Link Analyzer'\r\n\t\t\tlet isShowingSearch = this.$route.name === 'Search'\r\n\t\t\tlet sameAsLastSearch = term === this.lastTextSearch\r\n\r\n\t\t\tif (isSearchingURL) {\r\n\t\t\t\tif (isCtrlPressed) {\r\n\t\t\t\t\tthis.$root.$emit('QualityModal:open', term)\r\n\t\t\t\t} else {\r\n\t\t\t\t\tif (isShowingAnalyzer) {\r\n\t\t\t\t\t\t// EventBus.$emit('linkAnalyzerTab:reset')\r\n\t\t\t\t\t\tsocket.emit('analyzeLink', term)\r\n\t\t\t\t\t} else {\r\n\t\t\t\t\t\t// ? Open downloads tab ?\r\n\t\t\t\t\t\tsendAddToQueue(term)\r\n\t\t\t\t\t}\r\n\t\t\t\t}\r\n\t\t\t} else {\r\n\t\t\t\tif (isShowingSearch && sameAsLastSearch) {\r\n\t\t\t\t\tthis.$root.$emit('mainSearch:updateResults', term)\r\n\t\t\t\t\treturn\r\n\t\t\t\t}\r\n\r\n\t\t\t\tif (!isShowingSearch) {\r\n\t\t\t\t\tawait this.$router.push({\r\n\t\t\t\t\t\tname: 'Search'\r\n\t\t\t\t\t})\r\n\t\t\t\t}\r\n\r\n\t\t\t\tif (!sameAsLastSearch) {\r\n\t\t\t\t\tthis.$root.$emit('updateSearchLoadingState', true)\r\n\t\t\t\t\tthis.lastTextSearch = term\r\n\t\t\t\t}\r\n\r\n\t\t\t\tthis.$root.$emit('mainSearch:showNewResults', term)\r\n\t\t\t}\r\n\t\t}\r\n\t}\r\n}\r\n</script>\r\n\r\n\r\n","#search {\n  background-color: var(--secondary-background);\n  padding: 0 1em;\n  display: flex;\n  align-items: center;\n  border: 1px solid transparent;\n  transition: border 200ms ease-in-out;\n  border-radius: 15px;\n  margin: 10px 10px 20px 10px; }\n  #search:focus-within {\n    border: 1px solid var(--foreground); }\n  #search .search__icon {\n    width: 2rem;\n    height: 2rem; }\n    #search .search__icon i {\n      font-size: 2rem;\n      color: var(--foreground); }\n      #search .search__icon i::selection {\n        background: none; }\n  #search #searchbar {\n    height: 45px;\n    padding-left: 0.5em;\n    border: 0px;\n    border-radius: 0px;\n    background-color: var(--secondary-background);\n    color: var(--foreground);\n    font-size: 1.2rem;\n    font-family: 'Open Sans';\n    font-weight: 300;\n    margin-bottom: 0; }\n    #search #searchbar:focus {\n      outline: none; }\n    #search #searchbar:-webkit-autofill, #search #searchbar:-webkit-autofill:hover, #search #searchbar:-webkit-autofill:focus, #search #searchbar:-webkit-autofill:active {\n      -webkit-box-shadow: 0 0 0 45px var(--secondary-background) inset !important;\n      box-shadow: 0 0 0 45px var(--secondary-background) inset !important; }\n\n/*# sourceMappingURL=TheSearchBar.vue.map */"]}, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$8 = undefined;
  /* module identifier */
  const __vue_module_identifier__$8 = undefined;
  /* functional template */
  const __vue_is_functional_template__$8 = false;
  /* style inject SSR */
  

  
  var TheSearchBar = normalizeComponent_1(
    { render: __vue_render__$8, staticRenderFns: __vue_staticRenderFns__$8 },
    __vue_inject_styles__$8,
    __vue_script__$8,
    __vue_scope_id__$8,
    __vue_is_functional_template__$8,
    __vue_module_identifier__$8,
    browser,
    undefined
  );

/* script */

/* template */
var __vue_render__$9 = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c(
    "button",
    {
      staticClass:
        "btn-primary border-transparent border-solid flex items-center justify-center p-1 m-0 w-16 h-16 rounded-full z-10",
      on: {
        click: function($event) {
          return _vm.$router.back()
        }
      }
    },
    [
      _c("i", { staticClass: "material-icons mirrored text-4xl text-white" }, [
        _vm._v("forward")
      ])
    ]
  )
};
var __vue_staticRenderFns__$9 = [];
__vue_render__$9._withStripped = true;

  /* style */
  const __vue_inject_styles__$9 = function (inject) {
    if (!inject) return
    inject("data-v-765683d0_0", { source: "\nbutton[data-v-765683d0] {\r\n\ttransition: background 200ms ease-in-out;\n}\r\n", map: {"version":3,"sources":["C:\\Users\\Roberto\\Dev\\repos\\deemix-pyweb\\webui\\src\\components\\globals\\BackButton.vue"],"names":[],"mappings":";AAUA;CACA,wCAAA;AACA","file":"BackButton.vue","sourcesContent":["<template>\r\n\t<button\r\n\t\tclass=\"btn-primary border-transparent border-solid flex items-center justify-center p-1 m-0 w-16 h-16 rounded-full z-10\"\r\n\t\t@click=\"$router.back()\"\r\n\t>\r\n\t\t<i class=\"material-icons mirrored text-4xl text-white\">forward</i>\r\n\t</button>\r\n</template>\r\n\r\n<style scoped>\r\nbutton {\r\n\ttransition: background 200ms ease-in-out;\r\n}\r\n</style>"]}, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$9 = "data-v-765683d0";
  /* module identifier */
  const __vue_module_identifier__$9 = undefined;
  /* functional template */
  const __vue_is_functional_template__$9 = false;
  /* style inject SSR */
  

  
  var BackButton = normalizeComponent_1(
    { render: __vue_render__$9, staticRenderFns: __vue_staticRenderFns__$9 },
    __vue_inject_styles__$9,
    {},
    __vue_scope_id__$9,
    __vue_is_functional_template__$9,
    __vue_module_identifier__$9,
    browser,
    undefined
  );

//

var script$9 = {
	components: {
		BaseLoadingPlaceholder,
		BackButton
	},
	data: () => ({
		performScrolledSearch: false,
		loading: false
	}),
	computed: {
		showBackButton() {
			return ['Tracklist', 'Artist', 'Album', 'Playlist', 'Spotify Playlist'].indexOf(this.$route.name) !== -1
		}
	},
	mounted() {
		this.$root.$on('updateSearchLoadingState', loading => {
			this.loading = loading;
		});

		this.$router.beforeEach((to, from, next) => {
			this.$refs.content.scrollTo(0, 0);
			next();
		});
	},
	methods: {
		handleContentScroll: debounce(async function () {
			if (this.$refs.content.scrollTop + this.$refs.content.clientHeight < this.$refs.content.scrollHeight) return
			this.performScrolledSearch = true;

			await this.$nextTick();

			this.performScrolledSearch = false;
		}, 100)
	}
};

/* script */
const __vue_script__$9 = script$9;

/* template */
var __vue_render__$a = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c(
    "main",
    {
      ref: "content",
      attrs: { id: "content", "aria-label": "main content" },
      on: {
        scroll: function($event) {
          _vm.$route.name === "Search" ? _vm.handleContentScroll($event) : null;
        }
      }
    },
    [
      _c(
        "div",
        { attrs: { id: "container" } },
        [
          _c("BaseLoadingPlaceholder", {
            attrs: {
              id: "search_placeholder",
              text: "Searching...",
              hidden: !_vm.loading
            }
          }),
          _vm._v(" "),
          _vm.showBackButton
            ? _c("BackButton", {
                staticClass: "sticky -ml-20",
                staticStyle: { top: "1rem" }
              })
            : _vm._e(),
          _vm._v(" "),
          _c(
            "keep-alive",
            [
              !_vm.$route.meta.notKeepAlive
                ? _c("router-view", {
                    directives: [
                      {
                        name: "show",
                        rawName: "v-show",
                        value: !_vm.loading,
                        expression: "!loading"
                      }
                    ],
                    key: _vm.$route.fullPath,
                    class: { "-mt-16": _vm.showBackButton },
                    attrs: {
                      "perform-scrolled-search": _vm.performScrolledSearch
                    }
                  })
                : _vm._e()
            ],
            1
          ),
          _vm._v(" "),
          _vm.$route.meta.notKeepAlive
            ? _c("router-view", {
                directives: [
                  {
                    name: "show",
                    rawName: "v-show",
                    value: !_vm.loading,
                    expression: "!loading"
                  }
                ],
                key: _vm.$route.fullPath,
                class: { "-mt-16": _vm.showBackButton },
                attrs: { "perform-scrolled-search": _vm.performScrolledSearch }
              })
            : _vm._e()
        ],
        1
      )
    ]
  )
};
var __vue_staticRenderFns__$a = [];
__vue_render__$a._withStripped = true;

  /* style */
  const __vue_inject_styles__$a = function (inject) {
    if (!inject) return
    inject("data-v-0cf84b3e_0", { source: "#container {\n  margin: 0 auto;\n  max-width: 1280px;\n  width: var(--container-width);\n  transform: scale(1);\n}\nmain {\n  background-color: var(--main-background);\n  padding-right: 5px;\n  width: 100%;\n  height: calc(100vh - 93px);\n  overflow-y: scroll;\n  overflow-x: hidden;\n}\nmain::-webkit-scrollbar {\n  width: 10px;\n}\nmain::-webkit-scrollbar-track {\n  background: var(--main-background);\n}\nmain::-webkit-scrollbar-thumb {\n  background: var(--main-scroll);\n  border-radius: 4px;\n  width: 6px;\n  padding: 0px 2px;\n}\n\n/*# sourceMappingURL=TheContent.vue.map */", map: {"version":3,"sources":["C:\\Users\\Roberto\\Dev\\repos\\deemix-pyweb\\webui\\src\\components\\TheContent.vue","TheContent.vue"],"names":[],"mappings":"AAiCA;EACA,cAAA;EACA,iBAAA;EACA,6BAAA;EACA,mBAAA;AAAA;AAGA;EACA,wCAAA;EACA,kBAAA;EACA,WAAA;EACA,0BAAA;EACA,kBAAA;EACA,kBAAA;AAAA;AAGA;EACA,WAAA;AAAA;AAGA;EACA,kCAAA;AAAA;AAGA;EACA,8BAAA;EACA,kBAAA;EACA,UAAA;EACA,gBAAA;AAAA;;ACnCA,yCAAyC","file":"TheContent.vue","sourcesContent":["<template>\r\n\t<main\r\n\t\tid=\"content\"\r\n\t\t@scroll=\"$route.name === 'Search' ? handleContentScroll($event) : null\"\r\n\t\tref=\"content\"\r\n\t\taria-label=\"main content\"\r\n\t>\r\n\t\t<div id=\"container\">\r\n\t\t\t<BaseLoadingPlaceholder id=\"search_placeholder\" text=\"Searching...\" :hidden=\"!loading\" />\r\n\t\t\t<BackButton v-if=\"showBackButton\" class=\"sticky -ml-20\" style=\"top: 1rem\" />\r\n\r\n\t\t\t<keep-alive>\r\n\t\t\t\t<router-view\r\n\t\t\t\t\tv-if=\"!$route.meta.notKeepAlive\"\r\n\t\t\t\t\tv-show=\"!loading\"\r\n\t\t\t\t\t:class=\"{ '-mt-16': showBackButton }\"\r\n\t\t\t\t\t:key=\"$route.fullPath\"\r\n\t\t\t\t\t:perform-scrolled-search=\"performScrolledSearch\"\r\n\t\t\t\t></router-view>\r\n\t\t\t</keep-alive>\r\n\r\n\t\t\t<router-view\r\n\t\t\t\tv-if=\"$route.meta.notKeepAlive\"\r\n\t\t\t\tv-show=\"!loading\"\r\n\t\t\t\t:class=\"{ '-mt-16': showBackButton }\"\r\n\t\t\t\t:key=\"$route.fullPath\"\r\n\t\t\t\t:perform-scrolled-search=\"performScrolledSearch\"\r\n\t\t\t></router-view>\r\n\t\t</div>\r\n\t</main>\r\n</template>\r\n\r\n<style lang=\"scss\">\r\n#container {\r\n\tmargin: 0 auto;\r\n\tmax-width: 1280px;\r\n\twidth: var(--container-width);\r\n\ttransform: scale(1);\r\n}\r\n\r\nmain {\r\n\tbackground-color: var(--main-background);\r\n\tpadding-right: 5px;\r\n\twidth: 100%;\r\n\theight: calc(100vh - 93px);\r\n\toverflow-y: scroll;\r\n\toverflow-x: hidden;\r\n}\r\n\r\nmain::-webkit-scrollbar {\r\n\twidth: 10px;\r\n}\r\n\r\nmain::-webkit-scrollbar-track {\r\n\tbackground: var(--main-background);\r\n}\r\n\r\nmain::-webkit-scrollbar-thumb {\r\n\tbackground: var(--main-scroll);\r\n\tborder-radius: 4px;\r\n\twidth: 6px;\r\n\tpadding: 0px 2px;\r\n}\r\n</style>\r\n\r\n<script>\r\nimport { debounce } from '@/utils/utils'\r\nimport BaseLoadingPlaceholder from '@components/globals/BaseLoadingPlaceholder.vue'\r\nimport BackButton from '@components/globals/BackButton.vue'\r\n\r\nexport default {\r\n\tcomponents: {\r\n\t\tBaseLoadingPlaceholder,\r\n\t\tBackButton\r\n\t},\r\n\tdata: () => ({\r\n\t\tperformScrolledSearch: false,\r\n\t\tloading: false\r\n\t}),\r\n\tcomputed: {\r\n\t\tshowBackButton() {\r\n\t\t\treturn ['Tracklist', 'Artist', 'Album', 'Playlist', 'Spotify Playlist'].indexOf(this.$route.name) !== -1\r\n\t\t}\r\n\t},\r\n\tmounted() {\r\n\t\tthis.$root.$on('updateSearchLoadingState', loading => {\r\n\t\t\tthis.loading = loading\r\n\t\t})\r\n\r\n\t\tthis.$router.beforeEach((to, from, next) => {\r\n\t\t\tthis.$refs.content.scrollTo(0, 0)\r\n\t\t\tnext()\r\n\t\t})\r\n\t},\r\n\tmethods: {\r\n\t\thandleContentScroll: debounce(async function () {\r\n\t\t\tif (this.$refs.content.scrollTop + this.$refs.content.clientHeight < this.$refs.content.scrollHeight) return\r\n\t\t\tthis.performScrolledSearch = true\r\n\r\n\t\t\tawait this.$nextTick()\r\n\r\n\t\t\tthis.performScrolledSearch = false\r\n\t\t}, 100)\r\n\t}\r\n}\r\n</script>\r\n","#container {\n  margin: 0 auto;\n  max-width: 1280px;\n  width: var(--container-width);\n  transform: scale(1); }\n\nmain {\n  background-color: var(--main-background);\n  padding-right: 5px;\n  width: 100%;\n  height: calc(100vh - 93px);\n  overflow-y: scroll;\n  overflow-x: hidden; }\n\nmain::-webkit-scrollbar {\n  width: 10px; }\n\nmain::-webkit-scrollbar-track {\n  background: var(--main-background); }\n\nmain::-webkit-scrollbar-thumb {\n  background: var(--main-scroll);\n  border-radius: 4px;\n  width: 6px;\n  padding: 0px 2px; }\n\n/*# sourceMappingURL=TheContent.vue.map */"]}, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$a = undefined;
  /* module identifier */
  const __vue_module_identifier__$a = undefined;
  /* functional template */
  const __vue_is_functional_template__$a = false;
  /* style inject SSR */
  

  
  var TheContent = normalizeComponent_1(
    { render: __vue_render__$a, staticRenderFns: __vue_staticRenderFns__$a },
    __vue_inject_styles__$a,
    __vue_script__$9,
    __vue_scope_id__$a,
    __vue_is_functional_template__$a,
    __vue_module_identifier__$a,
    browser,
    undefined
  );

//

var script$a = {
	components: {
		TheSidebar,
		TheSearchBar,
		TheDownloadBar,
		TheTrackPreview,
		TheQualityModal,
		BaseLoadingPlaceholder,
		TheContextMenu,
		TheContent,
		ConfirmModal
	}
};

/* script */
const __vue_script__$a = script$a;

/* template */
var __vue_render__$b = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c(
    "div",
    [
      _c(
        "div",
        { staticClass: "app-container" },
        [
          _c("TheSidebar"),
          _vm._v(" "),
          _c(
            "div",
            { staticClass: "content-container" },
            [_c("TheSearchBar"), _vm._v(" "), _c("TheContent")],
            1
          ),
          _vm._v(" "),
          _c("TheDownloadBar")
        ],
        1
      ),
      _vm._v(" "),
      _c("BaseLoadingPlaceholder", {
        attrs: {
          id: "start_app_placeholder",
          text: "Connecting to the server..."
        }
      }),
      _vm._v(" "),
      _c("TheTrackPreview"),
      _vm._v(" "),
      _c("TheQualityModal"),
      _vm._v(" "),
      _c("TheContextMenu")
    ],
    1
  )
};
var __vue_staticRenderFns__$b = [];
__vue_render__$b._withStripped = true;

  /* style */
  const __vue_inject_styles__$b = function (inject) {
    if (!inject) return
    inject("data-v-7e23ef22_0", { source: "\n.app-container {\r\n\tdisplay: flex;\n}\n.content-container {\r\n\twidth: 100%;\r\n\tdisplay: flex;\r\n\tflex-direction: column;\r\n\t/* margin-left: 48px; */\n}\r\n", map: {"version":3,"sources":["C:\\Users\\Roberto\\Dev\\repos\\deemix-pyweb\\webui\\src\\App.vue"],"names":[],"mappings":";AAwBA;CACA,aAAA;AACA;AAEA;CACA,WAAA;CACA,aAAA;CACA,sBAAA;CACA,uBAAA;AACA","file":"App.vue","sourcesContent":["<template>\r\n\t<div>\r\n\t\t<div class=\"app-container\">\r\n\t\t\t<TheSidebar />\r\n\r\n\t\t\t<div class=\"content-container\">\r\n\t\t\t\t<TheSearchBar />\r\n\t\t\t\t<TheContent />\r\n\t\t\t</div>\r\n\r\n\t\t\t<TheDownloadBar />\r\n\t\t</div>\r\n\r\n\t\t<BaseLoadingPlaceholder id=\"start_app_placeholder\" text=\"Connecting to the server...\" />\r\n\r\n\t\t<TheTrackPreview />\r\n\t\t<TheQualityModal />\r\n\t\t<!-- <ConfirmModal /> -->\r\n\r\n\t\t<TheContextMenu />\r\n\t</div>\r\n</template>\r\n\r\n<style>\r\n.app-container {\r\n\tdisplay: flex;\r\n}\r\n\r\n.content-container {\r\n\twidth: 100%;\r\n\tdisplay: flex;\r\n\tflex-direction: column;\r\n\t/* margin-left: 48px; */\r\n}\r\n</style>\r\n\r\n<script>\r\nimport TheDownloadBar from '@components/downloads/TheDownloadBar.vue'\r\n\r\nimport BaseLoadingPlaceholder from '@components/globals/BaseLoadingPlaceholder.vue'\r\nimport TheContextMenu from '@components/globals/TheContextMenu.vue'\r\nimport TheTrackPreview from '@components/globals/TheTrackPreview.vue'\r\nimport TheQualityModal from '@components/globals/TheQualityModal.vue'\r\nimport ConfirmModal from '@components/globals/ConfirmModal.vue'\r\n\r\nimport TheSidebar from '@components/TheSidebar.vue'\r\nimport TheSearchBar from '@components/TheSearchBar.vue'\r\nimport TheContent from '@components/TheContent.vue'\r\n\r\nexport default {\r\n\tcomponents: {\r\n\t\tTheSidebar,\r\n\t\tTheSearchBar,\r\n\t\tTheDownloadBar,\r\n\t\tTheTrackPreview,\r\n\t\tTheQualityModal,\r\n\t\tBaseLoadingPlaceholder,\r\n\t\tTheContextMenu,\r\n\t\tTheContent,\r\n\t\tConfirmModal\r\n\t}\r\n}\r\n</script>\r\n"]}, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$b = undefined;
  /* module identifier */
  const __vue_module_identifier__$b = undefined;
  /* functional template */
  const __vue_is_functional_template__$b = false;
  /* style inject SSR */
  

  
  var App = normalizeComponent_1(
    { render: __vue_render__$b, staticRenderFns: __vue_staticRenderFns__$b },
    __vue_inject_styles__$b,
    __vue_script__$a,
    __vue_scope_id__$b,
    __vue_is_functional_template__$b,
    __vue_module_identifier__$b,
    browser,
    undefined
  );

/*!
 * vue-i18n v8.22.1 
 * (c) 2020 kazuya kawaguchi
 * Released under the MIT License.
 */
/*  */

/**
 * constants
 */

var numberFormatKeys = [
  'style',
  'currency',
  'currencyDisplay',
  'useGrouping',
  'minimumIntegerDigits',
  'minimumFractionDigits',
  'maximumFractionDigits',
  'minimumSignificantDigits',
  'maximumSignificantDigits',
  'localeMatcher',
  'formatMatcher',
  'unit'
];

/**
 * utilities
 */

function warn$3 (msg, err) {
  if (typeof console !== 'undefined') {
    console.warn('[vue-i18n] ' + msg);
    /* istanbul ignore if */
    if (err) {
      console.warn(err.stack);
    }
  }
}

function error (msg, err) {
  if (typeof console !== 'undefined') {
    console.error('[vue-i18n] ' + msg);
    /* istanbul ignore if */
    if (err) {
      console.error(err.stack);
    }
  }
}

var isArray = Array.isArray;

function isObject$2 (obj) {
  return obj !== null && typeof obj === 'object'
}

function isBoolean$1 (val) {
  return typeof val === 'boolean'
}

function isString (val) {
  return typeof val === 'string'
}

var toString$1 = Object.prototype.toString;
var OBJECT_STRING = '[object Object]';
function isPlainObject$1 (obj) {
  return toString$1.call(obj) === OBJECT_STRING
}

function isNull (val) {
  return val === null || val === undefined
}

function isFunction (val) {
  return typeof val === 'function'
}

function parseArgs () {
  var args = [], len = arguments.length;
  while ( len-- ) args[ len ] = arguments[ len ];

  var locale = null;
  var params = null;
  if (args.length === 1) {
    if (isObject$2(args[0]) || isArray(args[0])) {
      params = args[0];
    } else if (typeof args[0] === 'string') {
      locale = args[0];
    }
  } else if (args.length === 2) {
    if (typeof args[0] === 'string') {
      locale = args[0];
    }
    /* istanbul ignore if */
    if (isObject$2(args[1]) || isArray(args[1])) {
      params = args[1];
    }
  }

  return { locale: locale, params: params }
}

function looseClone (obj) {
  return JSON.parse(JSON.stringify(obj))
}

function remove$3 (arr, item) {
  if (arr.length) {
    var index = arr.indexOf(item);
    if (index > -1) {
      return arr.splice(index, 1)
    }
  }
}

function includes (arr, item) {
  return !!~arr.indexOf(item)
}

var hasOwnProperty$1 = Object.prototype.hasOwnProperty;
function hasOwn$1 (obj, key) {
  return hasOwnProperty$1.call(obj, key)
}

function merge (target) {
  var arguments$1 = arguments;

  var output = Object(target);
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments$1[i];
    if (source !== undefined && source !== null) {
      var key = (void 0);
      for (key in source) {
        if (hasOwn$1(source, key)) {
          if (isObject$2(source[key])) {
            output[key] = merge(output[key], source[key]);
          } else {
            output[key] = source[key];
          }
        }
      }
    }
  }
  return output
}

function looseEqual$1 (a, b) {
  if (a === b) { return true }
  var isObjectA = isObject$2(a);
  var isObjectB = isObject$2(b);
  if (isObjectA && isObjectB) {
    try {
      var isArrayA = isArray(a);
      var isArrayB = isArray(b);
      if (isArrayA && isArrayB) {
        return a.length === b.length && a.every(function (e, i) {
          return looseEqual$1(e, b[i])
        })
      } else if (!isArrayA && !isArrayB) {
        var keysA = Object.keys(a);
        var keysB = Object.keys(b);
        return keysA.length === keysB.length && keysA.every(function (key) {
          return looseEqual$1(a[key], b[key])
        })
      } else {
        /* istanbul ignore next */
        return false
      }
    } catch (e) {
      /* istanbul ignore next */
      return false
    }
  } else if (!isObjectA && !isObjectB) {
    return String(a) === String(b)
  } else {
    return false
  }
}

/**
 * Sanitizes html special characters from input strings. For mitigating risk of XSS attacks.
 * @param rawText The raw input from the user that should be escaped.
 */
function escapeHtml(rawText) {
  return rawText
    .replace(/</g, '&lt;')
    .replace(/>/g, '&gt;')
    .replace(/"/g, '&quot;')
    .replace(/'/g, '&apos;')
}

/**
 * Escapes html tags and special symbols from all provided params which were returned from parseArgs().params.
 * This method performs an in-place operation on the params object.
 *
 * @param {any} params Parameters as provided from `parseArgs().params`.
 *                     May be either an array of strings or a string->any map.
 *
 * @returns The manipulated `params` object.
 */
function escapeParams(params) {
  if(params != null) {
    Object.keys(params).forEach(function (key) {
      if(typeof(params[key]) == 'string') {
        params[key] = escapeHtml(params[key]);
      }
    });
  }
  return params
}

/*  */

function extend$1 (Vue) {
  if (!Vue.prototype.hasOwnProperty('$i18n')) {
    // $FlowFixMe
    Object.defineProperty(Vue.prototype, '$i18n', {
      get: function get () { return this._i18n }
    });
  }

  Vue.prototype.$t = function (key) {
    var values = [], len = arguments.length - 1;
    while ( len-- > 0 ) values[ len ] = arguments[ len + 1 ];

    var i18n = this.$i18n;
    return i18n._t.apply(i18n, [ key, i18n.locale, i18n._getMessages(), this ].concat( values ))
  };

  Vue.prototype.$tc = function (key, choice) {
    var values = [], len = arguments.length - 2;
    while ( len-- > 0 ) values[ len ] = arguments[ len + 2 ];

    var i18n = this.$i18n;
    return i18n._tc.apply(i18n, [ key, i18n.locale, i18n._getMessages(), this, choice ].concat( values ))
  };

  Vue.prototype.$te = function (key, locale) {
    var i18n = this.$i18n;
    return i18n._te(key, i18n.locale, i18n._getMessages(), locale)
  };

  Vue.prototype.$d = function (value) {
    var ref;

    var args = [], len = arguments.length - 1;
    while ( len-- > 0 ) args[ len ] = arguments[ len + 1 ];
    return (ref = this.$i18n).d.apply(ref, [ value ].concat( args ))
  };

  Vue.prototype.$n = function (value) {
    var ref;

    var args = [], len = arguments.length - 1;
    while ( len-- > 0 ) args[ len ] = arguments[ len + 1 ];
    return (ref = this.$i18n).n.apply(ref, [ value ].concat( args ))
  };
}

/*  */

var mixin = {
  beforeCreate: function beforeCreate () {
    var options = this.$options;
    options.i18n = options.i18n || (options.__i18n ? {} : null);

    if (options.i18n) {
      if (options.i18n instanceof VueI18n) {
        // init locale messages via custom blocks
        if (options.__i18n) {
          try {
            var localeMessages = options.i18n && options.i18n.messages ? options.i18n.messages : {};
            options.__i18n.forEach(function (resource) {
              localeMessages = merge(localeMessages, JSON.parse(resource));
            });
            Object.keys(localeMessages).forEach(function (locale) {
              options.i18n.mergeLocaleMessage(locale, localeMessages[locale]);
            });
          } catch (e) {
            {
              error("Cannot parse locale messages via custom blocks.", e);
            }
          }
        }
        this._i18n = options.i18n;
        this._i18nWatcher = this._i18n.watchI18nData();
      } else if (isPlainObject$1(options.i18n)) {
        var rootI18n = this.$root && this.$root.$i18n && this.$root.$i18n instanceof VueI18n
          ? this.$root.$i18n
          : null;
        // component local i18n
        if (rootI18n) {
          options.i18n.root = this.$root;
          options.i18n.formatter = rootI18n.formatter;
          options.i18n.fallbackLocale = rootI18n.fallbackLocale;
          options.i18n.formatFallbackMessages = rootI18n.formatFallbackMessages;
          options.i18n.silentTranslationWarn = rootI18n.silentTranslationWarn;
          options.i18n.silentFallbackWarn = rootI18n.silentFallbackWarn;
          options.i18n.pluralizationRules = rootI18n.pluralizationRules;
          options.i18n.preserveDirectiveContent = rootI18n.preserveDirectiveContent;
        }

        // init locale messages via custom blocks
        if (options.__i18n) {
          try {
            var localeMessages$1 = options.i18n && options.i18n.messages ? options.i18n.messages : {};
            options.__i18n.forEach(function (resource) {
              localeMessages$1 = merge(localeMessages$1, JSON.parse(resource));
            });
            options.i18n.messages = localeMessages$1;
          } catch (e) {
            {
              warn$3("Cannot parse locale messages via custom blocks.", e);
            }
          }
        }

        var ref = options.i18n;
        var sharedMessages = ref.sharedMessages;
        if (sharedMessages && isPlainObject$1(sharedMessages)) {
          options.i18n.messages = merge(options.i18n.messages, sharedMessages);
        }

        this._i18n = new VueI18n(options.i18n);
        this._i18nWatcher = this._i18n.watchI18nData();

        if (options.i18n.sync === undefined || !!options.i18n.sync) {
          this._localeWatcher = this.$i18n.watchLocale();
        }

        if (rootI18n) {
          rootI18n.onComponentInstanceCreated(this._i18n);
        }
      } else {
        {
          warn$3("Cannot be interpreted 'i18n' option.");
        }
      }
    } else if (this.$root && this.$root.$i18n && this.$root.$i18n instanceof VueI18n) {
      // root i18n
      this._i18n = this.$root.$i18n;
    } else if (options.parent && options.parent.$i18n && options.parent.$i18n instanceof VueI18n) {
      // parent i18n
      this._i18n = options.parent.$i18n;
    }
  },

  beforeMount: function beforeMount () {
    var options = this.$options;
    options.i18n = options.i18n || (options.__i18n ? {} : null);

    if (options.i18n) {
      if (options.i18n instanceof VueI18n) {
        // init locale messages via custom blocks
        this._i18n.subscribeDataChanging(this);
        this._subscribing = true;
      } else if (isPlainObject$1(options.i18n)) {
        this._i18n.subscribeDataChanging(this);
        this._subscribing = true;
      } else {
        {
          warn$3("Cannot be interpreted 'i18n' option.");
        }
      }
    } else if (this.$root && this.$root.$i18n && this.$root.$i18n instanceof VueI18n) {
      this._i18n.subscribeDataChanging(this);
      this._subscribing = true;
    } else if (options.parent && options.parent.$i18n && options.parent.$i18n instanceof VueI18n) {
      this._i18n.subscribeDataChanging(this);
      this._subscribing = true;
    }
  },

  beforeDestroy: function beforeDestroy () {
    if (!this._i18n) { return }

    var self = this;
    this.$nextTick(function () {
      if (self._subscribing) {
        self._i18n.unsubscribeDataChanging(self);
        delete self._subscribing;
      }

      if (self._i18nWatcher) {
        self._i18nWatcher();
        self._i18n.destroyVM();
        delete self._i18nWatcher;
      }

      if (self._localeWatcher) {
        self._localeWatcher();
        delete self._localeWatcher;
      }
    });
  }
};

/*  */

var interpolationComponent = {
  name: 'i18n',
  functional: true,
  props: {
    tag: {
      type: [String, Boolean, Object],
      default: 'span'
    },
    path: {
      type: String,
      required: true
    },
    locale: {
      type: String
    },
    places: {
      type: [Array, Object]
    }
  },
  render: function render (h, ref) {
    var data = ref.data;
    var parent = ref.parent;
    var props = ref.props;
    var slots = ref.slots;

    var $i18n = parent.$i18n;
    if (!$i18n) {
      {
        warn$3('Cannot find VueI18n instance!');
      }
      return
    }

    var path = props.path;
    var locale = props.locale;
    var places = props.places;
    var params = slots();
    var children = $i18n.i(
      path,
      locale,
      onlyHasDefaultPlace(params) || places
        ? useLegacyPlaces(params.default, places)
        : params
    );

    var tag = (!!props.tag && props.tag !== true) || props.tag === false ? props.tag : 'span';
    return tag ? h(tag, data, children) : children
  }
};

function onlyHasDefaultPlace (params) {
  var prop;
  for (prop in params) {
    if (prop !== 'default') { return false }
  }
  return Boolean(prop)
}

function useLegacyPlaces (children, places) {
  var params = places ? createParamsFromPlaces(places) : {};

  if (!children) { return params }

  // Filter empty text nodes
  children = children.filter(function (child) {
    return child.tag || child.text.trim() !== ''
  });

  var everyPlace = children.every(vnodeHasPlaceAttribute);
  if ( everyPlace) {
    warn$3('`place` attribute is deprecated in next major version. Please switch to Vue slots.');
  }

  return children.reduce(
    everyPlace ? assignChildPlace : assignChildIndex,
    params
  )
}

function createParamsFromPlaces (places) {
  {
    warn$3('`places` prop is deprecated in next major version. Please switch to Vue slots.');
  }

  return Array.isArray(places)
    ? places.reduce(assignChildIndex, {})
    : Object.assign({}, places)
}

function assignChildPlace (params, child) {
  if (child.data && child.data.attrs && child.data.attrs.place) {
    params[child.data.attrs.place] = child;
  }
  return params
}

function assignChildIndex (params, child, index) {
  params[index] = child;
  return params
}

function vnodeHasPlaceAttribute (vnode) {
  return Boolean(vnode.data && vnode.data.attrs && vnode.data.attrs.place)
}

/*  */

var numberComponent = {
  name: 'i18n-n',
  functional: true,
  props: {
    tag: {
      type: [String, Boolean, Object],
      default: 'span'
    },
    value: {
      type: Number,
      required: true
    },
    format: {
      type: [String, Object]
    },
    locale: {
      type: String
    }
  },
  render: function render (h, ref) {
    var props = ref.props;
    var parent = ref.parent;
    var data = ref.data;

    var i18n = parent.$i18n;

    if (!i18n) {
      {
        warn$3('Cannot find VueI18n instance!');
      }
      return null
    }

    var key = null;
    var options = null;

    if (isString(props.format)) {
      key = props.format;
    } else if (isObject$2(props.format)) {
      if (props.format.key) {
        key = props.format.key;
      }

      // Filter out number format options only
      options = Object.keys(props.format).reduce(function (acc, prop) {
        var obj;

        if (includes(numberFormatKeys, prop)) {
          return Object.assign({}, acc, ( obj = {}, obj[prop] = props.format[prop], obj ))
        }
        return acc
      }, null);
    }

    var locale = props.locale || i18n.locale;
    var parts = i18n._ntp(props.value, locale, key, options);

    var values = parts.map(function (part, index) {
      var obj;

      var slot = data.scopedSlots && data.scopedSlots[part.type];
      return slot ? slot(( obj = {}, obj[part.type] = part.value, obj.index = index, obj.parts = parts, obj )) : part.value
    });

    var tag = (!!props.tag && props.tag !== true) || props.tag === false ? props.tag : 'span';
    return tag
      ? h(tag, {
        attrs: data.attrs,
        'class': data['class'],
        staticClass: data.staticClass
      }, values)
      : values
  }
};

/*  */

function bind$2 (el, binding, vnode) {
  if (!assert$1(el, vnode)) { return }

  t(el, binding, vnode);
}

function update$1 (el, binding, vnode, oldVNode) {
  if (!assert$1(el, vnode)) { return }

  var i18n = vnode.context.$i18n;
  if (localeEqual(el, vnode) &&
    (looseEqual$1(binding.value, binding.oldValue) &&
     looseEqual$1(el._localeMessage, i18n.getLocaleMessage(i18n.locale)))) { return }

  t(el, binding, vnode);
}

function unbind (el, binding, vnode, oldVNode) {
  var vm = vnode.context;
  if (!vm) {
    warn$3('Vue instance does not exists in VNode context');
    return
  }

  var i18n = vnode.context.$i18n || {};
  if (!binding.modifiers.preserve && !i18n.preserveDirectiveContent) {
    el.textContent = '';
  }
  el._vt = undefined;
  delete el['_vt'];
  el._locale = undefined;
  delete el['_locale'];
  el._localeMessage = undefined;
  delete el['_localeMessage'];
}

function assert$1 (el, vnode) {
  var vm = vnode.context;
  if (!vm) {
    warn$3('Vue instance does not exists in VNode context');
    return false
  }

  if (!vm.$i18n) {
    warn$3('VueI18n instance does not exists in Vue instance');
    return false
  }

  return true
}

function localeEqual (el, vnode) {
  var vm = vnode.context;
  return el._locale === vm.$i18n.locale
}

function t (el, binding, vnode) {
  var ref$1, ref$2;

  var value = binding.value;

  var ref = parseValue(value);
  var path = ref.path;
  var locale = ref.locale;
  var args = ref.args;
  var choice = ref.choice;
  if (!path && !locale && !args) {
    warn$3('value type not supported');
    return
  }

  if (!path) {
    warn$3('`path` is required in v-t directive');
    return
  }

  var vm = vnode.context;
  if (choice != null) {
    el._vt = el.textContent = (ref$1 = vm.$i18n).tc.apply(ref$1, [ path, choice ].concat( makeParams(locale, args) ));
  } else {
    el._vt = el.textContent = (ref$2 = vm.$i18n).t.apply(ref$2, [ path ].concat( makeParams(locale, args) ));
  }
  el._locale = vm.$i18n.locale;
  el._localeMessage = vm.$i18n.getLocaleMessage(vm.$i18n.locale);
}

function parseValue (value) {
  var path;
  var locale;
  var args;
  var choice;

  if (isString(value)) {
    path = value;
  } else if (isPlainObject$1(value)) {
    path = value.path;
    locale = value.locale;
    args = value.args;
    choice = value.choice;
  }

  return { path: path, locale: locale, args: args, choice: choice }
}

function makeParams (locale, args) {
  var params = [];

  locale && params.push(locale);
  if (args && (Array.isArray(args) || isPlainObject$1(args))) {
    params.push(args);
  }

  return params
}

var Vue$2;

function install$1 (_Vue) {
  /* istanbul ignore if */
  if ( install$1.installed && _Vue === Vue$2) {
    warn$3('already installed.');
    return
  }
  install$1.installed = true;

  Vue$2 = _Vue;

  var version = (Vue$2.version && Number(Vue$2.version.split('.')[0])) || -1;
  /* istanbul ignore if */
  if ( version < 2) {
    warn$3(("vue-i18n (" + (install$1.version) + ") need to use Vue 2.0 or later (Vue: " + (Vue$2.version) + ")."));
    return
  }

  extend$1(Vue$2);
  Vue$2.mixin(mixin);
  Vue$2.directive('t', { bind: bind$2, update: update$1, unbind: unbind });
  Vue$2.component(interpolationComponent.name, interpolationComponent);
  Vue$2.component(numberComponent.name, numberComponent);

  // use simple mergeStrategies to prevent i18n instance lose '__proto__'
  var strats = Vue$2.config.optionMergeStrategies;
  strats.i18n = function (parentVal, childVal) {
    return childVal === undefined
      ? parentVal
      : childVal
  };
}

/*  */

var BaseFormatter = function BaseFormatter () {
  this._caches = Object.create(null);
};

BaseFormatter.prototype.interpolate = function interpolate (message, values) {
  if (!values) {
    return [message]
  }
  var tokens = this._caches[message];
  if (!tokens) {
    tokens = parse$1(message);
    this._caches[message] = tokens;
  }
  return compile(tokens, values)
};



var RE_TOKEN_LIST_VALUE = /^(?:\d)+/;
var RE_TOKEN_NAMED_VALUE = /^(?:\w)+/;

function parse$1 (format) {
  var tokens = [];
  var position = 0;

  var text = '';
  while (position < format.length) {
    var char = format[position++];
    if (char === '{') {
      if (text) {
        tokens.push({ type: 'text', value: text });
      }

      text = '';
      var sub = '';
      char = format[position++];
      while (char !== undefined && char !== '}') {
        sub += char;
        char = format[position++];
      }
      var isClosed = char === '}';

      var type = RE_TOKEN_LIST_VALUE.test(sub)
        ? 'list'
        : isClosed && RE_TOKEN_NAMED_VALUE.test(sub)
          ? 'named'
          : 'unknown';
      tokens.push({ value: sub, type: type });
    } else if (char === '%') {
      // when found rails i18n syntax, skip text capture
      if (format[(position)] !== '{') {
        text += char;
      }
    } else {
      text += char;
    }
  }

  text && tokens.push({ type: 'text', value: text });

  return tokens
}

function compile (tokens, values) {
  var compiled = [];
  var index = 0;

  var mode = Array.isArray(values)
    ? 'list'
    : isObject$2(values)
      ? 'named'
      : 'unknown';
  if (mode === 'unknown') { return compiled }

  while (index < tokens.length) {
    var token = tokens[index];
    switch (token.type) {
      case 'text':
        compiled.push(token.value);
        break
      case 'list':
        compiled.push(values[parseInt(token.value, 10)]);
        break
      case 'named':
        if (mode === 'named') {
          compiled.push((values)[token.value]);
        } else {
          {
            warn$3(("Type of token '" + (token.type) + "' and format of value '" + mode + "' don't match!"));
          }
        }
        break
      case 'unknown':
        {
          warn$3("Detect 'unknown' type of token!");
        }
        break
    }
    index++;
  }

  return compiled
}

/*  */

/**
 *  Path parser
 *  - Inspired:
 *    Vue.js Path parser
 */

// actions
var APPEND = 0;
var PUSH = 1;
var INC_SUB_PATH_DEPTH = 2;
var PUSH_SUB_PATH = 3;

// states
var BEFORE_PATH = 0;
var IN_PATH = 1;
var BEFORE_IDENT = 2;
var IN_IDENT = 3;
var IN_SUB_PATH = 4;
var IN_SINGLE_QUOTE = 5;
var IN_DOUBLE_QUOTE = 6;
var AFTER_PATH = 7;
var ERROR = 8;

var pathStateMachine = [];

pathStateMachine[BEFORE_PATH] = {
  'ws': [BEFORE_PATH],
  'ident': [IN_IDENT, APPEND],
  '[': [IN_SUB_PATH],
  'eof': [AFTER_PATH]
};

pathStateMachine[IN_PATH] = {
  'ws': [IN_PATH],
  '.': [BEFORE_IDENT],
  '[': [IN_SUB_PATH],
  'eof': [AFTER_PATH]
};

pathStateMachine[BEFORE_IDENT] = {
  'ws': [BEFORE_IDENT],
  'ident': [IN_IDENT, APPEND],
  '0': [IN_IDENT, APPEND],
  'number': [IN_IDENT, APPEND]
};

pathStateMachine[IN_IDENT] = {
  'ident': [IN_IDENT, APPEND],
  '0': [IN_IDENT, APPEND],
  'number': [IN_IDENT, APPEND],
  'ws': [IN_PATH, PUSH],
  '.': [BEFORE_IDENT, PUSH],
  '[': [IN_SUB_PATH, PUSH],
  'eof': [AFTER_PATH, PUSH]
};

pathStateMachine[IN_SUB_PATH] = {
  "'": [IN_SINGLE_QUOTE, APPEND],
  '"': [IN_DOUBLE_QUOTE, APPEND],
  '[': [IN_SUB_PATH, INC_SUB_PATH_DEPTH],
  ']': [IN_PATH, PUSH_SUB_PATH],
  'eof': ERROR,
  'else': [IN_SUB_PATH, APPEND]
};

pathStateMachine[IN_SINGLE_QUOTE] = {
  "'": [IN_SUB_PATH, APPEND],
  'eof': ERROR,
  'else': [IN_SINGLE_QUOTE, APPEND]
};

pathStateMachine[IN_DOUBLE_QUOTE] = {
  '"': [IN_SUB_PATH, APPEND],
  'eof': ERROR,
  'else': [IN_DOUBLE_QUOTE, APPEND]
};

/**
 * Check if an expression is a literal value.
 */

var literalValueRE = /^\s?(?:true|false|-?[\d.]+|'[^']*'|"[^"]*")\s?$/;
function isLiteral (exp) {
  return literalValueRE.test(exp)
}

/**
 * Strip quotes from a string
 */

function stripQuotes (str) {
  var a = str.charCodeAt(0);
  var b = str.charCodeAt(str.length - 1);
  return a === b && (a === 0x22 || a === 0x27)
    ? str.slice(1, -1)
    : str
}

/**
 * Determine the type of a character in a keypath.
 */

function getPathCharType (ch) {
  if (ch === undefined || ch === null) { return 'eof' }

  var code = ch.charCodeAt(0);

  switch (code) {
    case 0x5B: // [
    case 0x5D: // ]
    case 0x2E: // .
    case 0x22: // "
    case 0x27: // '
      return ch

    case 0x5F: // _
    case 0x24: // $
    case 0x2D: // -
      return 'ident'

    case 0x09: // Tab
    case 0x0A: // Newline
    case 0x0D: // Return
    case 0xA0:  // No-break space
    case 0xFEFF:  // Byte Order Mark
    case 0x2028:  // Line Separator
    case 0x2029:  // Paragraph Separator
      return 'ws'
  }

  return 'ident'
}

/**
 * Format a subPath, return its plain form if it is
 * a literal string or number. Otherwise prepend the
 * dynamic indicator (*).
 */

function formatSubPath (path) {
  var trimmed = path.trim();
  // invalid leading 0
  if (path.charAt(0) === '0' && isNaN(path)) { return false }

  return isLiteral(trimmed) ? stripQuotes(trimmed) : '*' + trimmed
}

/**
 * Parse a string path into an array of segments
 */

function parse$1$1 (path) {
  var keys = [];
  var index = -1;
  var mode = BEFORE_PATH;
  var subPathDepth = 0;
  var c;
  var key;
  var newChar;
  var type;
  var transition;
  var action;
  var typeMap;
  var actions = [];

  actions[PUSH] = function () {
    if (key !== undefined) {
      keys.push(key);
      key = undefined;
    }
  };

  actions[APPEND] = function () {
    if (key === undefined) {
      key = newChar;
    } else {
      key += newChar;
    }
  };

  actions[INC_SUB_PATH_DEPTH] = function () {
    actions[APPEND]();
    subPathDepth++;
  };

  actions[PUSH_SUB_PATH] = function () {
    if (subPathDepth > 0) {
      subPathDepth--;
      mode = IN_SUB_PATH;
      actions[APPEND]();
    } else {
      subPathDepth = 0;
      if (key === undefined) { return false }
      key = formatSubPath(key);
      if (key === false) {
        return false
      } else {
        actions[PUSH]();
      }
    }
  };

  function maybeUnescapeQuote () {
    var nextChar = path[index + 1];
    if ((mode === IN_SINGLE_QUOTE && nextChar === "'") ||
      (mode === IN_DOUBLE_QUOTE && nextChar === '"')) {
      index++;
      newChar = '\\' + nextChar;
      actions[APPEND]();
      return true
    }
  }

  while (mode !== null) {
    index++;
    c = path[index];

    if (c === '\\' && maybeUnescapeQuote()) {
      continue
    }

    type = getPathCharType(c);
    typeMap = pathStateMachine[mode];
    transition = typeMap[type] || typeMap['else'] || ERROR;

    if (transition === ERROR) {
      return // parse error
    }

    mode = transition[0];
    action = actions[transition[1]];
    if (action) {
      newChar = transition[2];
      newChar = newChar === undefined
        ? c
        : newChar;
      if (action() === false) {
        return
      }
    }

    if (mode === AFTER_PATH) {
      return keys
    }
  }
}





var I18nPath = function I18nPath () {
  this._cache = Object.create(null);
};

/**
 * External parse that check for a cache hit first
 */
I18nPath.prototype.parsePath = function parsePath (path) {
  var hit = this._cache[path];
  if (!hit) {
    hit = parse$1$1(path);
    if (hit) {
      this._cache[path] = hit;
    }
  }
  return hit || []
};

/**
 * Get path value from path string
 */
I18nPath.prototype.getPathValue = function getPathValue (obj, path) {
  if (!isObject$2(obj)) { return null }

  var paths = this.parsePath(path);
  if (paths.length === 0) {
    return null
  } else {
    var length = paths.length;
    var last = obj;
    var i = 0;
    while (i < length) {
      var value = last[paths[i]];
      if (value === undefined) {
        return null
      }
      last = value;
      i++;
    }

    return last
  }
};

/*  */



var htmlTagMatcher = /<\/?[\w\s="/.':;#-\/]+>/;
var linkKeyMatcher = /(?:@(?:\.[a-z]+)?:(?:[\w\-_|.]+|\([\w\-_|.]+\)))/g;
var linkKeyPrefixMatcher = /^@(?:\.([a-z]+))?:/;
var bracketsMatcher = /[()]/g;
var defaultModifiers = {
  'upper': function (str) { return str.toLocaleUpperCase(); },
  'lower': function (str) { return str.toLocaleLowerCase(); },
  'capitalize': function (str) { return ("" + (str.charAt(0).toLocaleUpperCase()) + (str.substr(1))); }
};

var defaultFormatter = new BaseFormatter();

var VueI18n = function VueI18n (options) {
  var this$1 = this;
  if ( options === void 0 ) options = {};

  // Auto install if it is not done yet and `window` has `Vue`.
  // To allow users to avoid auto-installation in some cases,
  // this code should be placed here. See #290
  /* istanbul ignore if */
  if (!Vue$2 && typeof window !== 'undefined' && window.Vue) {
    install$1(window.Vue);
  }

  var locale = options.locale || 'en-US';
  var fallbackLocale = options.fallbackLocale === false
    ? false
    : options.fallbackLocale || 'en-US';
  var messages = options.messages || {};
  var dateTimeFormats = options.dateTimeFormats || {};
  var numberFormats = options.numberFormats || {};

  this._vm = null;
  this._formatter = options.formatter || defaultFormatter;
  this._modifiers = options.modifiers || {};
  this._missing = options.missing || null;
  this._root = options.root || null;
  this._sync = options.sync === undefined ? true : !!options.sync;
  this._fallbackRoot = options.fallbackRoot === undefined
    ? true
    : !!options.fallbackRoot;
  this._formatFallbackMessages = options.formatFallbackMessages === undefined
    ? false
    : !!options.formatFallbackMessages;
  this._silentTranslationWarn = options.silentTranslationWarn === undefined
    ? false
    : options.silentTranslationWarn;
  this._silentFallbackWarn = options.silentFallbackWarn === undefined
    ? false
    : !!options.silentFallbackWarn;
  this._dateTimeFormatters = {};
  this._numberFormatters = {};
  this._path = new I18nPath();
  this._dataListeners = [];
  this._componentInstanceCreatedListener = options.componentInstanceCreatedListener || null;
  this._preserveDirectiveContent = options.preserveDirectiveContent === undefined
    ? false
    : !!options.preserveDirectiveContent;
  this.pluralizationRules = options.pluralizationRules || {};
  this._warnHtmlInMessage = options.warnHtmlInMessage || 'off';
  this._postTranslation = options.postTranslation || null;
  this._escapeParameterHtml = options.escapeParameterHtml || false;

  /**
   * @param choice {number} a choice index given by the input to $tc: `$tc('path.to.rule', choiceIndex)`
   * @param choicesLength {number} an overall amount of available choices
   * @returns a final choice index
  */
  this.getChoiceIndex = function (choice, choicesLength) {
    var thisPrototype = Object.getPrototypeOf(this$1);
    if (thisPrototype && thisPrototype.getChoiceIndex) {
      var prototypeGetChoiceIndex = (thisPrototype.getChoiceIndex);
      return (prototypeGetChoiceIndex).call(this$1, choice, choicesLength)
    }

    // Default (old) getChoiceIndex implementation - english-compatible
    var defaultImpl = function (_choice, _choicesLength) {
      _choice = Math.abs(_choice);

      if (_choicesLength === 2) {
        return _choice
          ? _choice > 1
            ? 1
            : 0
          : 1
      }

      return _choice ? Math.min(_choice, 2) : 0
    };

    if (this$1.locale in this$1.pluralizationRules) {
      return this$1.pluralizationRules[this$1.locale].apply(this$1, [choice, choicesLength])
    } else {
      return defaultImpl(choice, choicesLength)
    }
  };


  this._exist = function (message, key) {
    if (!message || !key) { return false }
    if (!isNull(this$1._path.getPathValue(message, key))) { return true }
    // fallback for flat key
    if (message[key]) { return true }
    return false
  };

  if (this._warnHtmlInMessage === 'warn' || this._warnHtmlInMessage === 'error') {
    Object.keys(messages).forEach(function (locale) {
      this$1._checkLocaleMessage(locale, this$1._warnHtmlInMessage, messages[locale]);
    });
  }

  this._initVM({
    locale: locale,
    fallbackLocale: fallbackLocale,
    messages: messages,
    dateTimeFormats: dateTimeFormats,
    numberFormats: numberFormats
  });
};

var prototypeAccessors$2 = { vm: { configurable: true },messages: { configurable: true },dateTimeFormats: { configurable: true },numberFormats: { configurable: true },availableLocales: { configurable: true },locale: { configurable: true },fallbackLocale: { configurable: true },formatFallbackMessages: { configurable: true },missing: { configurable: true },formatter: { configurable: true },silentTranslationWarn: { configurable: true },silentFallbackWarn: { configurable: true },preserveDirectiveContent: { configurable: true },warnHtmlInMessage: { configurable: true },postTranslation: { configurable: true } };

VueI18n.prototype._checkLocaleMessage = function _checkLocaleMessage (locale, level, message) {
  var paths = [];

  var fn = function (level, locale, message, paths) {
    if (isPlainObject$1(message)) {
      Object.keys(message).forEach(function (key) {
        var val = message[key];
        if (isPlainObject$1(val)) {
          paths.push(key);
          paths.push('.');
          fn(level, locale, val, paths);
          paths.pop();
          paths.pop();
        } else {
          paths.push(key);
          fn(level, locale, val, paths);
          paths.pop();
        }
      });
    } else if (isArray(message)) {
      message.forEach(function (item, index) {
        if (isPlainObject$1(item)) {
          paths.push(("[" + index + "]"));
          paths.push('.');
          fn(level, locale, item, paths);
          paths.pop();
          paths.pop();
        } else {
          paths.push(("[" + index + "]"));
          fn(level, locale, item, paths);
          paths.pop();
        }
      });
    } else if (isString(message)) {
      var ret = htmlTagMatcher.test(message);
      if (ret) {
        var msg = "Detected HTML in message '" + message + "' of keypath '" + (paths.join('')) + "' at '" + locale + "'. Consider component interpolation with '<i18n>' to avoid XSS. See https://bit.ly/2ZqJzkp";
        if (level === 'warn') {
          warn$3(msg);
        } else if (level === 'error') {
          error(msg);
        }
      }
    }
  };

  fn(level, locale, message, paths);
};

VueI18n.prototype._initVM = function _initVM (data) {
  var silent = Vue$2.config.silent;
  Vue$2.config.silent = true;
  this._vm = new Vue$2({ data: data });
  Vue$2.config.silent = silent;
};

VueI18n.prototype.destroyVM = function destroyVM () {
  this._vm.$destroy();
};

VueI18n.prototype.subscribeDataChanging = function subscribeDataChanging (vm) {
  this._dataListeners.push(vm);
};

VueI18n.prototype.unsubscribeDataChanging = function unsubscribeDataChanging (vm) {
  remove$3(this._dataListeners, vm);
};

VueI18n.prototype.watchI18nData = function watchI18nData () {
  var self = this;
  return this._vm.$watch('$data', function () {
    var i = self._dataListeners.length;
    while (i--) {
      Vue$2.nextTick(function () {
        self._dataListeners[i] && self._dataListeners[i].$forceUpdate();
      });
    }
  }, { deep: true })
};

VueI18n.prototype.watchLocale = function watchLocale () {
  /* istanbul ignore if */
  if (!this._sync || !this._root) { return null }
  var target = this._vm;
  return this._root.$i18n.vm.$watch('locale', function (val) {
    target.$set(target, 'locale', val);
    target.$forceUpdate();
  }, { immediate: true })
};

VueI18n.prototype.onComponentInstanceCreated = function onComponentInstanceCreated (newI18n) {
  if (this._componentInstanceCreatedListener) {
    this._componentInstanceCreatedListener(newI18n, this);
  }
};

prototypeAccessors$2.vm.get = function () { return this._vm };

prototypeAccessors$2.messages.get = function () { return looseClone(this._getMessages()) };
prototypeAccessors$2.dateTimeFormats.get = function () { return looseClone(this._getDateTimeFormats()) };
prototypeAccessors$2.numberFormats.get = function () { return looseClone(this._getNumberFormats()) };
prototypeAccessors$2.availableLocales.get = function () { return Object.keys(this.messages).sort() };

prototypeAccessors$2.locale.get = function () { return this._vm.locale };
prototypeAccessors$2.locale.set = function (locale) {
  this._vm.$set(this._vm, 'locale', locale);
};

prototypeAccessors$2.fallbackLocale.get = function () { return this._vm.fallbackLocale };
prototypeAccessors$2.fallbackLocale.set = function (locale) {
  this._localeChainCache = {};
  this._vm.$set(this._vm, 'fallbackLocale', locale);
};

prototypeAccessors$2.formatFallbackMessages.get = function () { return this._formatFallbackMessages };
prototypeAccessors$2.formatFallbackMessages.set = function (fallback) { this._formatFallbackMessages = fallback; };

prototypeAccessors$2.missing.get = function () { return this._missing };
prototypeAccessors$2.missing.set = function (handler) { this._missing = handler; };

prototypeAccessors$2.formatter.get = function () { return this._formatter };
prototypeAccessors$2.formatter.set = function (formatter) { this._formatter = formatter; };

prototypeAccessors$2.silentTranslationWarn.get = function () { return this._silentTranslationWarn };
prototypeAccessors$2.silentTranslationWarn.set = function (silent) { this._silentTranslationWarn = silent; };

prototypeAccessors$2.silentFallbackWarn.get = function () { return this._silentFallbackWarn };
prototypeAccessors$2.silentFallbackWarn.set = function (silent) { this._silentFallbackWarn = silent; };

prototypeAccessors$2.preserveDirectiveContent.get = function () { return this._preserveDirectiveContent };
prototypeAccessors$2.preserveDirectiveContent.set = function (preserve) { this._preserveDirectiveContent = preserve; };

prototypeAccessors$2.warnHtmlInMessage.get = function () { return this._warnHtmlInMessage };
prototypeAccessors$2.warnHtmlInMessage.set = function (level) {
    var this$1 = this;

  var orgLevel = this._warnHtmlInMessage;
  this._warnHtmlInMessage = level;
  if (orgLevel !== level && (level === 'warn' || level === 'error')) {
    var messages = this._getMessages();
    Object.keys(messages).forEach(function (locale) {
      this$1._checkLocaleMessage(locale, this$1._warnHtmlInMessage, messages[locale]);
    });
  }
};

prototypeAccessors$2.postTranslation.get = function () { return this._postTranslation };
prototypeAccessors$2.postTranslation.set = function (handler) { this._postTranslation = handler; };

VueI18n.prototype._getMessages = function _getMessages () { return this._vm.messages };
VueI18n.prototype._getDateTimeFormats = function _getDateTimeFormats () { return this._vm.dateTimeFormats };
VueI18n.prototype._getNumberFormats = function _getNumberFormats () { return this._vm.numberFormats };

VueI18n.prototype._warnDefault = function _warnDefault (locale, key, result, vm, values, interpolateMode) {
  if (!isNull(result)) { return result }
  if (this._missing) {
    var missingRet = this._missing.apply(null, [locale, key, vm, values]);
    if (isString(missingRet)) {
      return missingRet
    }
  } else {
    if ( !this._isSilentTranslationWarn(key)) {
      warn$3(
        "Cannot translate the value of keypath '" + key + "'. " +
        'Use the value of keypath as default.'
      );
    }
  }

  if (this._formatFallbackMessages) {
    var parsedArgs = parseArgs.apply(void 0, values);
    return this._render(key, interpolateMode, parsedArgs.params, key)
  } else {
    return key
  }
};

VueI18n.prototype._isFallbackRoot = function _isFallbackRoot (val) {
  return !val && !isNull(this._root) && this._fallbackRoot
};

VueI18n.prototype._isSilentFallbackWarn = function _isSilentFallbackWarn (key) {
  return this._silentFallbackWarn instanceof RegExp
    ? this._silentFallbackWarn.test(key)
    : this._silentFallbackWarn
};

VueI18n.prototype._isSilentFallback = function _isSilentFallback (locale, key) {
  return this._isSilentFallbackWarn(key) && (this._isFallbackRoot() || locale !== this.fallbackLocale)
};

VueI18n.prototype._isSilentTranslationWarn = function _isSilentTranslationWarn (key) {
  return this._silentTranslationWarn instanceof RegExp
    ? this._silentTranslationWarn.test(key)
    : this._silentTranslationWarn
};

VueI18n.prototype._interpolate = function _interpolate (
  locale,
  message,
  key,
  host,
  interpolateMode,
  values,
  visitedLinkStack
) {
  if (!message) { return null }

  var pathRet = this._path.getPathValue(message, key);
  if (isArray(pathRet) || isPlainObject$1(pathRet)) { return pathRet }

  var ret;
  if (isNull(pathRet)) {
    /* istanbul ignore else */
    if (isPlainObject$1(message)) {
      ret = message[key];
      if (!(isString(ret) || isFunction(ret))) {
        if ( !this._isSilentTranslationWarn(key) && !this._isSilentFallback(locale, key)) {
          warn$3(("Value of key '" + key + "' is not a string or function !"));
        }
        return null
      }
    } else {
      return null
    }
  } else {
    /* istanbul ignore else */
    if (isString(pathRet) || isFunction(pathRet)) {
      ret = pathRet;
    } else {
      if ( !this._isSilentTranslationWarn(key) && !this._isSilentFallback(locale, key)) {
        warn$3(("Value of key '" + key + "' is not a string or function!"));
      }
      return null
    }
  }

  // Check for the existence of links within the translated string
  if (isString(ret) && (ret.indexOf('@:') >= 0 || ret.indexOf('@.') >= 0)) {
    ret = this._link(locale, message, ret, host, 'raw', values, visitedLinkStack);
  }

  return this._render(ret, interpolateMode, values, key)
};

VueI18n.prototype._link = function _link (
  locale,
  message,
  str,
  host,
  interpolateMode,
  values,
  visitedLinkStack
) {
  var ret = str;

  // Match all the links within the local
  // We are going to replace each of
  // them with its translation
  var matches = ret.match(linkKeyMatcher);
  for (var idx in matches) {
    // ie compatible: filter custom array
    // prototype method
    if (!matches.hasOwnProperty(idx)) {
      continue
    }
    var link = matches[idx];
    var linkKeyPrefixMatches = link.match(linkKeyPrefixMatcher);
    var linkPrefix = linkKeyPrefixMatches[0];
      var formatterName = linkKeyPrefixMatches[1];

    // Remove the leading @:, @.case: and the brackets
    var linkPlaceholder = link.replace(linkPrefix, '').replace(bracketsMatcher, '');

    if (includes(visitedLinkStack, linkPlaceholder)) {
      {
        warn$3(("Circular reference found. \"" + link + "\" is already visited in the chain of " + (visitedLinkStack.reverse().join(' <- '))));
      }
      return ret
    }
    visitedLinkStack.push(linkPlaceholder);

    // Translate the link
    var translated = this._interpolate(
      locale, message, linkPlaceholder, host,
      interpolateMode === 'raw' ? 'string' : interpolateMode,
      interpolateMode === 'raw' ? undefined : values,
      visitedLinkStack
    );

    if (this._isFallbackRoot(translated)) {
      if ( !this._isSilentTranslationWarn(linkPlaceholder)) {
        warn$3(("Fall back to translate the link placeholder '" + linkPlaceholder + "' with root locale."));
      }
      /* istanbul ignore if */
      if (!this._root) { throw Error('unexpected error') }
      var root = this._root.$i18n;
      translated = root._translate(
        root._getMessages(), root.locale, root.fallbackLocale,
        linkPlaceholder, host, interpolateMode, values
      );
    }
    translated = this._warnDefault(
      locale, linkPlaceholder, translated, host,
      isArray(values) ? values : [values],
      interpolateMode
    );

    if (this._modifiers.hasOwnProperty(formatterName)) {
      translated = this._modifiers[formatterName](translated);
    } else if (defaultModifiers.hasOwnProperty(formatterName)) {
      translated = defaultModifiers[formatterName](translated);
    }

    visitedLinkStack.pop();

    // Replace the link with the translated
    ret = !translated ? ret : ret.replace(link, translated);
  }

  return ret
};

VueI18n.prototype._createMessageContext = function _createMessageContext (values) {
  var _list = isArray(values) ? values : [];
  var _named = isObject$2(values) ? values : {};
  var list = function (index) { return _list[index]; };
  var named = function (key) { return _named[key]; };
  return {
    list: list,
    named: named
  }
};

VueI18n.prototype._render = function _render (message, interpolateMode, values, path) {
  if (isFunction(message)) {
    return message(this._createMessageContext(values))
  }

  var ret = this._formatter.interpolate(message, values, path);

  // If the custom formatter refuses to work - apply the default one
  if (!ret) {
    ret = defaultFormatter.interpolate(message, values, path);
  }

  // if interpolateMode is **not** 'string' ('row'),
  // return the compiled data (e.g. ['foo', VNode, 'bar']) with formatter
  return interpolateMode === 'string' && !isString(ret) ? ret.join('') : ret
};

VueI18n.prototype._appendItemToChain = function _appendItemToChain (chain, item, blocks) {
  var follow = false;
  if (!includes(chain, item)) {
    follow = true;
    if (item) {
      follow = item[item.length - 1] !== '!';
      item = item.replace(/!/g, '');
      chain.push(item);
      if (blocks && blocks[item]) {
        follow = blocks[item];
      }
    }
  }
  return follow
};

VueI18n.prototype._appendLocaleToChain = function _appendLocaleToChain (chain, locale, blocks) {
  var follow;
  var tokens = locale.split('-');
  do {
    var item = tokens.join('-');
    follow = this._appendItemToChain(chain, item, blocks);
    tokens.splice(-1, 1);
  } while (tokens.length && (follow === true))
  return follow
};

VueI18n.prototype._appendBlockToChain = function _appendBlockToChain (chain, block, blocks) {
  var follow = true;
  for (var i = 0; (i < block.length) && (isBoolean$1(follow)); i++) {
    var locale = block[i];
    if (isString(locale)) {
      follow = this._appendLocaleToChain(chain, locale, blocks);
    }
  }
  return follow
};

VueI18n.prototype._getLocaleChain = function _getLocaleChain (start, fallbackLocale) {
  if (start === '') { return [] }

  if (!this._localeChainCache) {
    this._localeChainCache = {};
  }

  var chain = this._localeChainCache[start];
  if (!chain) {
    if (!fallbackLocale) {
      fallbackLocale = this.fallbackLocale;
    }
    chain = [];

    // first block defined by start
    var block = [start];

    // while any intervening block found
    while (isArray(block)) {
      block = this._appendBlockToChain(
        chain,
        block,
        fallbackLocale
      );
    }

    // last block defined by default
    var defaults;
    if (isArray(fallbackLocale)) {
      defaults = fallbackLocale;
    } else if (isObject$2(fallbackLocale)) {
      /* $FlowFixMe */
      if (fallbackLocale['default']) {
        defaults = fallbackLocale['default'];
      } else {
        defaults = null;
      }
    } else {
      defaults = fallbackLocale;
    }

    // convert defaults to array
    if (isString(defaults)) {
      block = [defaults];
    } else {
      block = defaults;
    }
    if (block) {
      this._appendBlockToChain(
        chain,
        block,
        null
      );
    }
    this._localeChainCache[start] = chain;
  }
  return chain
};

VueI18n.prototype._translate = function _translate (
  messages,
  locale,
  fallback,
  key,
  host,
  interpolateMode,
  args
) {
  var chain = this._getLocaleChain(locale, fallback);
  var res;
  for (var i = 0; i < chain.length; i++) {
    var step = chain[i];
    res =
      this._interpolate(step, messages[step], key, host, interpolateMode, args, [key]);
    if (!isNull(res)) {
      if (step !== locale && "development" !== 'production' && !this._isSilentTranslationWarn(key) && !this._isSilentFallbackWarn(key)) {
        warn$3(("Fall back to translate the keypath '" + key + "' with '" + step + "' locale."));
      }
      return res
    }
  }
  return null
};

VueI18n.prototype._t = function _t (key, _locale, messages, host) {
    var ref;

    var values = [], len = arguments.length - 4;
    while ( len-- > 0 ) values[ len ] = arguments[ len + 4 ];
  if (!key) { return '' }

  var parsedArgs = parseArgs.apply(void 0, values);
  if(this._escapeParameterHtml) {
    parsedArgs.params = escapeParams(parsedArgs.params);
  }

  var locale = parsedArgs.locale || _locale;

  var ret = this._translate(
    messages, locale, this.fallbackLocale, key,
    host, 'string', parsedArgs.params
  );
  if (this._isFallbackRoot(ret)) {
    if ( !this._isSilentTranslationWarn(key) && !this._isSilentFallbackWarn(key)) {
      warn$3(("Fall back to translate the keypath '" + key + "' with root locale."));
    }
    /* istanbul ignore if */
    if (!this._root) { throw Error('unexpected error') }
    return (ref = this._root).$t.apply(ref, [ key ].concat( values ))
  } else {
    ret = this._warnDefault(locale, key, ret, host, values, 'string');
    if (this._postTranslation && ret !== null && ret !== undefined) {
      ret = this._postTranslation(ret, key);
    }
    return ret
  }
};

VueI18n.prototype.t = function t (key) {
    var ref;

    var values = [], len = arguments.length - 1;
    while ( len-- > 0 ) values[ len ] = arguments[ len + 1 ];
  return (ref = this)._t.apply(ref, [ key, this.locale, this._getMessages(), null ].concat( values ))
};

VueI18n.prototype._i = function _i (key, locale, messages, host, values) {
  var ret =
    this._translate(messages, locale, this.fallbackLocale, key, host, 'raw', values);
  if (this._isFallbackRoot(ret)) {
    if ( !this._isSilentTranslationWarn(key)) {
      warn$3(("Fall back to interpolate the keypath '" + key + "' with root locale."));
    }
    if (!this._root) { throw Error('unexpected error') }
    return this._root.$i18n.i(key, locale, values)
  } else {
    return this._warnDefault(locale, key, ret, host, [values], 'raw')
  }
};

VueI18n.prototype.i = function i (key, locale, values) {
  /* istanbul ignore if */
  if (!key) { return '' }

  if (!isString(locale)) {
    locale = this.locale;
  }

  return this._i(key, locale, this._getMessages(), null, values)
};

VueI18n.prototype._tc = function _tc (
  key,
  _locale,
  messages,
  host,
  choice
) {
    var ref;

    var values = [], len = arguments.length - 5;
    while ( len-- > 0 ) values[ len ] = arguments[ len + 5 ];
  if (!key) { return '' }
  if (choice === undefined) {
    choice = 1;
  }

  var predefined = { 'count': choice, 'n': choice };
  var parsedArgs = parseArgs.apply(void 0, values);
  parsedArgs.params = Object.assign(predefined, parsedArgs.params);
  values = parsedArgs.locale === null ? [parsedArgs.params] : [parsedArgs.locale, parsedArgs.params];
  return this.fetchChoice((ref = this)._t.apply(ref, [ key, _locale, messages, host ].concat( values )), choice)
};

VueI18n.prototype.fetchChoice = function fetchChoice (message, choice) {
  /* istanbul ignore if */
  if (!message || !isString(message)) { return null }
  var choices = message.split('|');

  choice = this.getChoiceIndex(choice, choices.length);
  if (!choices[choice]) { return message }
  return choices[choice].trim()
};

VueI18n.prototype.tc = function tc (key, choice) {
    var ref;

    var values = [], len = arguments.length - 2;
    while ( len-- > 0 ) values[ len ] = arguments[ len + 2 ];
  return (ref = this)._tc.apply(ref, [ key, this.locale, this._getMessages(), null, choice ].concat( values ))
};

VueI18n.prototype._te = function _te (key, locale, messages) {
    var args = [], len = arguments.length - 3;
    while ( len-- > 0 ) args[ len ] = arguments[ len + 3 ];

  var _locale = parseArgs.apply(void 0, args).locale || locale;
  return this._exist(messages[_locale], key)
};

VueI18n.prototype.te = function te (key, locale) {
  return this._te(key, this.locale, this._getMessages(), locale)
};

VueI18n.prototype.getLocaleMessage = function getLocaleMessage (locale) {
  return looseClone(this._vm.messages[locale] || {})
};

VueI18n.prototype.setLocaleMessage = function setLocaleMessage (locale, message) {
  if (this._warnHtmlInMessage === 'warn' || this._warnHtmlInMessage === 'error') {
    this._checkLocaleMessage(locale, this._warnHtmlInMessage, message);
  }
  this._vm.$set(this._vm.messages, locale, message);
};

VueI18n.prototype.mergeLocaleMessage = function mergeLocaleMessage (locale, message) {
  if (this._warnHtmlInMessage === 'warn' || this._warnHtmlInMessage === 'error') {
    this._checkLocaleMessage(locale, this._warnHtmlInMessage, message);
  }
  this._vm.$set(this._vm.messages, locale, merge({}, this._vm.messages[locale] || {}, message));
};

VueI18n.prototype.getDateTimeFormat = function getDateTimeFormat (locale) {
  return looseClone(this._vm.dateTimeFormats[locale] || {})
};

VueI18n.prototype.setDateTimeFormat = function setDateTimeFormat (locale, format) {
  this._vm.$set(this._vm.dateTimeFormats, locale, format);
  this._clearDateTimeFormat(locale, format);
};

VueI18n.prototype.mergeDateTimeFormat = function mergeDateTimeFormat (locale, format) {
  this._vm.$set(this._vm.dateTimeFormats, locale, merge(this._vm.dateTimeFormats[locale] || {}, format));
  this._clearDateTimeFormat(locale, format);
};

VueI18n.prototype._clearDateTimeFormat = function _clearDateTimeFormat (locale, format) {
  for (var key in format) {
    var id = locale + "__" + key;

    if (!this._dateTimeFormatters.hasOwnProperty(id)) {
      continue
    }

    delete this._dateTimeFormatters[id];
  }
};

VueI18n.prototype._localizeDateTime = function _localizeDateTime (
  value,
  locale,
  fallback,
  dateTimeFormats,
  key
) {
  var _locale = locale;
  var formats = dateTimeFormats[_locale];

  var chain = this._getLocaleChain(locale, fallback);
  for (var i = 0; i < chain.length; i++) {
    var current = _locale;
    var step = chain[i];
    formats = dateTimeFormats[step];
    _locale = step;
    // fallback locale
    if (isNull(formats) || isNull(formats[key])) {
      if (step !== locale && "development" !== 'production' && !this._isSilentTranslationWarn(key) && !this._isSilentFallbackWarn(key)) {
        warn$3(("Fall back to '" + step + "' datetime formats from '" + current + "' datetime formats."));
      }
    } else {
      break
    }
  }

  if (isNull(formats) || isNull(formats[key])) {
    return null
  } else {
    var format = formats[key];
    var id = _locale + "__" + key;
    var formatter = this._dateTimeFormatters[id];
    if (!formatter) {
      formatter = this._dateTimeFormatters[id] = new Intl.DateTimeFormat(_locale, format);
    }
    return formatter.format(value)
  }
};

VueI18n.prototype._d = function _d (value, locale, key) {
  /* istanbul ignore if */
  if ( !VueI18n.availabilities.dateTimeFormat) {
    warn$3('Cannot format a Date value due to not supported Intl.DateTimeFormat.');
    return ''
  }

  if (!key) {
    return new Intl.DateTimeFormat(locale).format(value)
  }

  var ret =
    this._localizeDateTime(value, locale, this.fallbackLocale, this._getDateTimeFormats(), key);
  if (this._isFallbackRoot(ret)) {
    if ( !this._isSilentTranslationWarn(key) && !this._isSilentFallbackWarn(key)) {
      warn$3(("Fall back to datetime localization of root: key '" + key + "'."));
    }
    /* istanbul ignore if */
    if (!this._root) { throw Error('unexpected error') }
    return this._root.$i18n.d(value, key, locale)
  } else {
    return ret || ''
  }
};

VueI18n.prototype.d = function d (value) {
    var args = [], len = arguments.length - 1;
    while ( len-- > 0 ) args[ len ] = arguments[ len + 1 ];

  var locale = this.locale;
  var key = null;

  if (args.length === 1) {
    if (isString(args[0])) {
      key = args[0];
    } else if (isObject$2(args[0])) {
      if (args[0].locale) {
        locale = args[0].locale;
      }
      if (args[0].key) {
        key = args[0].key;
      }
    }
  } else if (args.length === 2) {
    if (isString(args[0])) {
      key = args[0];
    }
    if (isString(args[1])) {
      locale = args[1];
    }
  }

  return this._d(value, locale, key)
};

VueI18n.prototype.getNumberFormat = function getNumberFormat (locale) {
  return looseClone(this._vm.numberFormats[locale] || {})
};

VueI18n.prototype.setNumberFormat = function setNumberFormat (locale, format) {
  this._vm.$set(this._vm.numberFormats, locale, format);
  this._clearNumberFormat(locale, format);
};

VueI18n.prototype.mergeNumberFormat = function mergeNumberFormat (locale, format) {
  this._vm.$set(this._vm.numberFormats, locale, merge(this._vm.numberFormats[locale] || {}, format));
  this._clearNumberFormat(locale, format);
};

VueI18n.prototype._clearNumberFormat = function _clearNumberFormat (locale, format) {
  for (var key in format) {
    var id = locale + "__" + key;

    if (!this._numberFormatters.hasOwnProperty(id)) {
      continue
    }

    delete this._numberFormatters[id];
  }
};

VueI18n.prototype._getNumberFormatter = function _getNumberFormatter (
  value,
  locale,
  fallback,
  numberFormats,
  key,
  options
) {
  var _locale = locale;
  var formats = numberFormats[_locale];

  var chain = this._getLocaleChain(locale, fallback);
  for (var i = 0; i < chain.length; i++) {
    var current = _locale;
    var step = chain[i];
    formats = numberFormats[step];
    _locale = step;
    // fallback locale
    if (isNull(formats) || isNull(formats[key])) {
      if (step !== locale && "development" !== 'production' && !this._isSilentTranslationWarn(key) && !this._isSilentFallbackWarn(key)) {
        warn$3(("Fall back to '" + step + "' number formats from '" + current + "' number formats."));
      }
    } else {
      break
    }
  }

  if (isNull(formats) || isNull(formats[key])) {
    return null
  } else {
    var format = formats[key];

    var formatter;
    if (options) {
      // If options specified - create one time number formatter
      formatter = new Intl.NumberFormat(_locale, Object.assign({}, format, options));
    } else {
      var id = _locale + "__" + key;
      formatter = this._numberFormatters[id];
      if (!formatter) {
        formatter = this._numberFormatters[id] = new Intl.NumberFormat(_locale, format);
      }
    }
    return formatter
  }
};

VueI18n.prototype._n = function _n (value, locale, key, options) {
  /* istanbul ignore if */
  if (!VueI18n.availabilities.numberFormat) {
    {
      warn$3('Cannot format a Number value due to not supported Intl.NumberFormat.');
    }
    return ''
  }

  if (!key) {
    var nf = !options ? new Intl.NumberFormat(locale) : new Intl.NumberFormat(locale, options);
    return nf.format(value)
  }

  var formatter = this._getNumberFormatter(value, locale, this.fallbackLocale, this._getNumberFormats(), key, options);
  var ret = formatter && formatter.format(value);
  if (this._isFallbackRoot(ret)) {
    if ( !this._isSilentTranslationWarn(key) && !this._isSilentFallbackWarn(key)) {
      warn$3(("Fall back to number localization of root: key '" + key + "'."));
    }
    /* istanbul ignore if */
    if (!this._root) { throw Error('unexpected error') }
    return this._root.$i18n.n(value, Object.assign({}, { key: key, locale: locale }, options))
  } else {
    return ret || ''
  }
};

VueI18n.prototype.n = function n (value) {
    var args = [], len = arguments.length - 1;
    while ( len-- > 0 ) args[ len ] = arguments[ len + 1 ];

  var locale = this.locale;
  var key = null;
  var options = null;

  if (args.length === 1) {
    if (isString(args[0])) {
      key = args[0];
    } else if (isObject$2(args[0])) {
      if (args[0].locale) {
        locale = args[0].locale;
      }
      if (args[0].key) {
        key = args[0].key;
      }

      // Filter out number format options only
      options = Object.keys(args[0]).reduce(function (acc, key) {
          var obj;

        if (includes(numberFormatKeys, key)) {
          return Object.assign({}, acc, ( obj = {}, obj[key] = args[0][key], obj ))
        }
        return acc
      }, null);
    }
  } else if (args.length === 2) {
    if (isString(args[0])) {
      key = args[0];
    }
    if (isString(args[1])) {
      locale = args[1];
    }
  }

  return this._n(value, locale, key, options)
};

VueI18n.prototype._ntp = function _ntp (value, locale, key, options) {
  /* istanbul ignore if */
  if (!VueI18n.availabilities.numberFormat) {
    {
      warn$3('Cannot format to parts a Number value due to not supported Intl.NumberFormat.');
    }
    return []
  }

  if (!key) {
    var nf = !options ? new Intl.NumberFormat(locale) : new Intl.NumberFormat(locale, options);
    return nf.formatToParts(value)
  }

  var formatter = this._getNumberFormatter(value, locale, this.fallbackLocale, this._getNumberFormats(), key, options);
  var ret = formatter && formatter.formatToParts(value);
  if (this._isFallbackRoot(ret)) {
    if ( !this._isSilentTranslationWarn(key)) {
      warn$3(("Fall back to format number to parts of root: key '" + key + "' ."));
    }
    /* istanbul ignore if */
    if (!this._root) { throw Error('unexpected error') }
    return this._root.$i18n._ntp(value, locale, key, options)
  } else {
    return ret || []
  }
};

Object.defineProperties( VueI18n.prototype, prototypeAccessors$2 );

var availabilities;
// $FlowFixMe
Object.defineProperty(VueI18n, 'availabilities', {
  get: function get () {
    if (!availabilities) {
      var intlDefined = typeof Intl !== 'undefined';
      availabilities = {
        dateTimeFormat: intlDefined && typeof Intl.DateTimeFormat !== 'undefined',
        numberFormat: intlDefined && typeof Intl.NumberFormat !== 'undefined'
      };
    }

    return availabilities
  }
});

VueI18n.install = install$1;
VueI18n.version = '8.22.1';

const it = {
	globals: {
		welcome: 'Benvenuto su deemix',
		back: 'indietro',
		loading: 'caricamento',
		download: 'Scarica {thing}',
		downloadAll: 'Scarica ogni {thing}',
		by: 'di {artist}',
		in: 'in {album}',
		download_hint: 'Scarica',
		play_hint: 'Riproduci',
		toggle_download_tab_hint: 'Espandi/Riduci',
		clean_queue_hint: 'Pulisci Lista',
		cancel_queue_hint: 'Cancella tutti i download',
		open_downloads_folder: 'Apri la cartella di download',
		cut: 'taglia',
		copy: 'copia',
		copyLink: 'copia link',
		copyImageLink: 'copia link immagine',
		copyDeezerLink: 'copia link deezer',
		paste: 'incolla',
		listTabs: {
			all: 'tutto',
			top_result: 'miglior risultato',
			album: 'album',
			artist: 'artista | artisti',
			single: 'singolo | singoli',
			title: 'titolo | titoli',
			track: 'brano | brani',
			trackN: '0 brani | {n} brano | {n} brani',
			releaseN: '0 dischi | {n} disco | {n} dischi',
			playlist: 'playlist',
			compile: 'compilation',
			bundle: 'collezione | collezioni',
			ep: 'ep',
			more: 'Altri album',
			featured: 'Compare in',
			spotifyPlaylist: 'playlist spotify',
			releaseDate: 'data di uscita',
			error: 'errore',
			empty: ''
		}
	},
	about: {
		updates: {
			currentVersion: 'Versione corrente',
			versionNotAvailable: 'N/A',
			updateAvailable: `Non stai usando l'ultima versione disponibile: {version}`,
			deemixVersion: 'Versione libreria deemix'
		},
		titles: {
			usefulLinks: 'Link Utili',
			bugReports: 'Segnalazione di bug',
			contributing: 'Contribuire al progetto',
			donations: 'Donazioni',
			license: 'Licenza'
		},
		subtitles: {
			bugReports: "C'è qualcosa di deemix che non funziona? Faccelo sapere!",
			contributing: 'Vuoi contribuire a questo progetto? Puoi farlo in più modi!',
			donations: 'Vuoi dare una mano economicamente? Puoi fare una donazione!'
		},
		usesLibrary:
			'Questa app utilizza la libreria <strong>deemix</strong>, che puoi utilizzare per creare la tua Interfaccia Utente per deemix.',
		thanks: `Un ringraziamento a <strong>rtonno</strong>, <strong>uhwot</strong> e <strong>lollilol</strong> per l'aiuto che mi stanno dando in questo progetto e a <strong>BasCurtiz</strong> e <strong>scarvimane</strong> per aver creato l'icona.`,
		upToDate: `Rimani al passo con gli ultimi aggiornamenti seguendo il <a href="https://t.me/RemixDevNews" target="_blank">canale delle news</a> su Telegram.`,
		officialWebsite: 'Sito Ufficiale',
		officialRepo: 'Repository Ufficiale della Libreria',
		officialWebuiRepo: `Repository Ufficiale dell'Interfaccia Web`,
		officialSubreddit: 'Subreddit Ufficiale',
		newsChannel: 'Canale delle news',
		questions: `Se dovessi avere domande o problemi con l'app, cerca prima una soluzione nel <a href="https://www.reddit.com/r/deemix" target="_blank">subreddit ufficiale</a>. Se non trovi nulla, puoi postare li il tuo problema.`,
		beforeReporting: `Prima di segnalare un problema controlla che quella che stai usando sia l'ultima versione dell'app e che ciò che vuoi segnalare sia effettivamente un problema e non qualcosa che non funziona solamente a te.`,
		beSure: `Assicurati che il problema sia riproducibile su altri PC e <strong>NON</strong> segnalare un problema che è già stato segnalato.`,
		duplicateReports: 'Le segnalazioni doppie verranno chiuse, tienilo presente.',
		dontOpenIssues: `<strong>NON</strong> aprire issues per porre domande, per quello esiste un subreddit.`,
		newUI: `Se te la cavi in python puoi provare a creare una nuova Interfaccia Utente per l'app usando la libreria base, oppure puoi correggere dei problemi nella libreria con una pull request nella <a href="https://codeberg.org/RemixDev/deemix" target="_blank">repo</a>.`,
		acceptFeatures: `Accetto anche funzionalità, ma non cose complesse, dato che possono essere implementate direttamente nell'app invece che nella libreria.`,
		otherLanguages: `Se te la cavi in altri linguaggi di programmazione, puoi provare a scrivere deemix in quei linguaggi!`,
		understandingCode: `Serve aiuto per capire il codice? Scrivi a RemixDev su Telegram o Reddit`,
		contributeWebUI: `Se te la cavi con Vue.js (JavaScript), HTML o CSS, puoi contribuire alla <a href="https://codeberg.org/RemixDev/deemix-webui" target="_blank">WebUI</a>.`,
		itsFree: `Ricordati che <strong>questo è un progetto gratuito</strong> e che <strong>dovresti supportare gli artisti che ami</strong> prima di supportare gli sviluppatori.`,
		notObligated: `Non sentirti obbligato a donare, mi stai simpatico lo stesso!`,
		lincensedUnder: `Questo lavoro è sotto la licenza
			<a rel="license" href="https://www.gnu.org/licenses/gpl-3.0.en.html" target="_blank"
				>GNU General Public License 3.0</a
			>.`
	},
	charts: {
		title: 'Classifiche',
		changeCountry: 'Cambia Paese',
		download: 'Scarica Classifica'
	},
	errors: {
		title: 'Errori riguardanti {name}',
		ids: {
			invalidURL: 'URL non riconosciuto',
			unsupportedURL: 'URL non ancora supportato',
			ISRCnotOnDeezer: 'Questo ISRC non è disponibile su Deezer',
			notYourPrivatePlaylist: 'Non puoi scaricare le playlist private degli altri.',
			spotifyDisabled: 'Spotify Features non è impostato correttamente.',
			trackNotOnDeezer: 'Brano non trovato su Deezer!',
			albumNotOnDeezer: 'Album non trovato su Deezer!',
			notOnDeezer: 'Brano non disponibile su Deezer!',
			notEncoded: 'Brano non ancora codificato!',
			notEncodedNoAlternative: 'Brano non ancora codificato e nessuna alternativa trovata!',
			wrongBitrate: 'Brano non trovato con il bitrate specificato.',
			wrongBitrateNoAlternative: 'Brano non trovato con il bitrate specificato e nessuna alternativa trovata!',
			no360RA: 'Brano non disponibile in Reality Audio 360.',
			notAvailable: 'Brano non presente sui server di Deezer!',
			notAvailableNoAlternative: 'Brano non presente sui server di Deezer e nessuna alternativa trovata!',
			noSpaceLeft: 'Spazio su disco esaurito!',
			albumDoesntExists: 'Il brano non ha nessun album, impossibile ottenere informazioni'
		}
	},
	favorites: {
		title: 'Preferiti',
		noPlaylists: 'Nessuna Playlist preferita trovata',
		noAlbums: 'Nessun Album preferito trovato',
		noArtists: 'Nessun Artista preferito trovato',
		noTracks: 'Nessun Brano preferito trovato'
	},
	home: {
		needTologin: 'Devi accedere al tuo account Deezer, fino a quel momento non potrai scaricare nulla.',
		openSettings: 'Apri le impostazioni',
		sections: {
			popularPlaylists: 'Playlist Popolari',
			popularAlbums: 'Album più riprodotti'
		}
	},
	linkAnalyzer: {
		info:
			'Puoi utilizzare questa sezione per avere più informazioni riguardanti il link che stai cercando di scaricare.',
		useful:
			'Ciò può esserti utile se stai cercando di scaricare brani che non sono disponibili nel tuo Paese e vuoi sapere in quale Paese sono invece disponibili, per esempio.',
		linkNotSupported: 'Questo link non è ancora supportato',
		linkNotSupportedYet: 'Sembra che questo link non sia ancora supportato, prova ad analizzarne un altro.',
		table: {
			id: 'ID',
			isrc: 'ISRC',
			upc: 'UPC',
			duration: 'Durata',
			diskNumber: 'Numero Disco',
			trackNumber: 'Numero Traccia',
			releaseDate: 'Data di uscita',
			bpm: 'BPM',
			label: 'Etichetta',
			recordType: 'Tipologia di registrazione',
			genres: 'Generi',
			tracklist: 'Lista tracce'
		}
	},
	search: {
		startSearching: 'Inizia a cercare!',
		description:
			'Puoi cercare un brano, un intero album, un artista, una playlist.... quello che vuoi! Puoi anche incollare un link di Deezer',
		fans: '{n} fan',
		noResults: 'Nessun risultato',
		noResultsTrack: 'Nessun brano trovato',
		noResultsAlbum: 'Nessun album trovato',
		noResultsArtist: 'Nessun artista trovato',
		noResultsPlaylist: 'Nessuna playlist trovata'
	},
	searchbar: 'Cerca qualsiasi cosa (o incolla semplicemente un link)',
	downloads: 'download',
	toasts: {
		restoringQueue: 'Ripristinando la coda di download...',
		queueRestored: 'Coda di download ripristinata!',
		addedToQueue: '{item} aggiunto alla coda',
		addedMoreToQueue: '{n} oggetti aggiunti alla coda',
		alreadyInQueue: '{item} è già nella coda!',
		finishDownload: '{item} ha finito di scaricarsi.',
		allDownloaded: 'Tutti i download completati!',
		refreshFavs: 'Preferiti ricaricati!',
		loggingIn: 'Effettuando il login...',
		loggedIn: 'Login effettuato',
		alreadyLogged: 'Sei già loggato',
		loginFailed: 'Impossibile loggarsi',
		loggedOut: 'Disconnesso',
		cancellingCurrentItem: 'Cancellando download corrente.',
		currentItemCancelled: 'Download corrente cancellato.',
		startAddingArtist: 'Aggiungendo gli album di {artist} alla coda',
		finishAddingArtist: 'Aggiunto gli album di {artist} alla coda',
		startConvertingSpotifyPlaylist: 'Convertendo i brani da spotify a deezer',
		finishConvertingSpotifyPlaylist: 'Playlist di spotify convertita',
		loginNeededToDownload: 'Devi accedere prima di poter scaricare brani!',
		deezerNotAvailable: 'Deezer non è disponibile nel tuo paese. Dovresti usare una VPN.',
		startGeneratingItems: 'Elaborando {n} oggetti...',
		finishGeneratingItems: '{n} oggetti generati.'
	},
	settings: {
		title: 'Impostazioni',
		languages: 'Lingue',
		login: {
			title: 'Login',
			loggedIn: 'Sei loggato come {username}',
			arl: {
				question: 'Come ottengo il mio ARL?',
				update: 'Aggiorna ARL'
			},
			logout: 'Disconnettiti',
			login: 'Accedi tramite deezer.com'
		},
		appearance: {
			title: 'Aspetto',
			slimDownloadTab: 'Tab dei download slim'
		},
		downloadPath: {
			title: 'Cartella di download'
		},
		templates: {
			title: 'Template',
			tracknameTemplate: 'Template nome brano',
			albumTracknameTemplate: 'Template nome brano negli Album',
			playlistTracknameTemplate: 'Template nome brano nelle Playlist'
		},
		folders: {
			title: 'Cartelle',
			createPlaylistFolder: 'Crea cartelle per le Playlist',
			playlistNameTemplate: 'Template nome della cartella Playlist',
			createArtistFolder: 'Crea cartelle per gli Artisti',
			artistNameTemplate: 'Template nome della cartella Artista',
			createAlbumFolder: 'Crea cartelle per gli Album',
			albumNameTemplate: 'Template nome della cartella Album',
			createCDFolder: 'Crea cartelle per i CD',
			createStructurePlaylist: 'Crea la struttura di cartelle per le Playlist',
			createSingleFolder: 'Crea la struttura di cartelle per i brani singoli'
		},
		trackTitles: {
			title: 'Titoli brani',
			padTracks: 'Aggiungi zeri ai numeri di traccia',
			paddingSize: 'Sovrascrivi il numero di zeri da aggiungere',
			illegalCharacterReplacer: 'Rimpiazza caratteri illegali con'
		},
		downloads: {
			title: 'Download',
			queueConcurrency: 'Download simultanei',
			maxBitrate: {
				title: 'Bitrate preferito',
				9: 'FLAC 1411kbps',
				3: 'MP3 320kbps',
				1: 'MP3 128kbps'
			},
			overwriteFile: {
				title: 'Dovrei sovrascrivere i file già scaricati?',
				y: 'Si, sovrascrivi i file',
				n: 'No, non sovrascrivere i file',
				t: 'Sovrascrivi solo i tag',
				b: 'No, mantieni entrambi i file e aggiungi un numero al duplicato',
				e: 'No, e non tener conto della estensione del file'
			},
			fallbackBitrate: 'Utilizza bitrate più bassi se il bitrate preferito non è disponibile',
			fallbackSearch: 'Cerca il brano se il link originale non è disponibile',
			logErrors: 'Crea file di log per gli errori',
			logSearched: 'Crea file di log per le alternative cercate',
			syncedLyrics: 'Crea i file .lyr (Testi Sincronizzati)',
			createM3U8File: 'Crea i file playlist',
			playlistFilenameTemplate: 'Template nome del file playlist',
			saveDownloadQueue: "Salva la coda di download quando chiudi l'app"
		},
		covers: {
			title: 'Copertine',
			saveArtwork: 'Salva copertina album',
			coverImageTemplate: 'Template nome copertina album',
			saveArtworkArtist: 'Salva copertina artista',
			artistImageTemplate: 'Template nome copertina artista',
			localArtworkSize: 'Dimensioni copertine locali',
			embeddedArtworkSize: 'Dimensioni copertine incorporate',
			localArtworkFormat: {
				title: 'Come vuoi salvare le copertine locali?',
				jpg: 'In jpeg',
				png: 'In png',
				both: 'Sia in jpeg che in png'
			},
			jpegImageQuality: 'Qualità immagine JPEG',
			embeddedArtworkPNG: 'Salva copertina incorporata come PNG',
			embeddedPNGWarning: 'Le immagini PNG non sono usate ufficialmente da Deezer e potrebbero dare problemi',
			imageSizeWarning:
				'Dimensioni maggiori di x1200 non sono usate ufficialmente da Deezer, potresti incontrare problemi',
			coverDescriptionUTF8: 'Salva la descrizione della copertina in UTF8 (iTunes Cover Fix)'
		},
		tags: {
			head: 'Quali tag salvare',
			title: 'Titolo',
			artist: 'Artista',
			album: 'Album',
			cover: 'Copertina',
			trackNumber: 'Numero Traccia',
			trackTotal: 'Tracce Totali',
			discNumber: 'Numero Disco',
			discTotal: 'Dischi Totali',
			albumArtist: "Artista dell'album",
			genre: 'Genere',
			year: 'Anno',
			date: 'Data',
			explicit: 'Testo Esplicito',
			isrc: 'ISRC',
			length: 'Durata Traccia',
			barcode: "Barcode dell'album (UPC)",
			bpm: 'BPM',
			replayGain: 'Replay gain',
			label: 'Casa Discografica',
			lyrics: 'Testo non Sincronizzato',
			syncedLyrics: 'Testo Sincronizzato',
			copyright: 'Copyright',
			composer: 'Compositori',
			involvedPeople: 'Persone Coinvolte'
		},
		other: {
			title: 'Altro',
			savePlaylistAsCompilation: 'Salva le playlist come Compilation',
			useNullSeparator: 'Usa il carattere NULL come separatore',
			saveID3v1: "Salva anche l'ID3v1",
			multiArtistSeparator: {
				title: 'Come vuoi separare gli artisti?',
				nothing: "Salva solo l'artista principale",
				default: 'Usando la specificazione standard',
				andFeat: 'Usando & e feat.',
				using: 'Usando "{separator}"'
			},
			singleAlbumArtist: "Salva solo l'artista dell'album principale",
			albumVariousArtists: 'Lascia "Artisti Vari" negli artisti dell\'album',
			removeAlbumVersion: 'Rimuovi "Album Version" dal titolo del brano',
			removeDuplicateArtists: 'Rimuovi le combinazioni di artisti',
			dateFormat: {
				title: 'Formato della data per i file FLAC',
				year: 'AAAA',
				month: 'MM',
				day: 'GG'
			},
			featuredToTitle: {
				title: 'Cosa dovrei fare con i feat?',
				0: 'Niente',
				1: 'Rimuovili dal titolo',
				3: "Rimuovili dal titolo e dal nome dell'album",
				2: 'Spostali sul titolo'
			},
			titleCasing: 'Formato testo dei titoli',
			artistCasing: 'Formato testo degli artisti',
			casing: {
				nothing: 'Non cambiare',
				upper: 'TUTTO MAIUSCOLO',
				lower: 'tutto minuscolo',
				start: 'Prima Lettera Maiuscola',
				sentence: 'Come una frase'
			},
			previewVolume: 'Volume Anteprime',
			executeCommand: {
				title: 'Comando da eseguire dopo il download',
				description: 'Lascia vuoto per nessuna azione'
			}
		},
		spotify: {
			title: 'Spotify Features',
			clientID: 'Spotify clientID',
			clientSecret: 'Spotify Client Secret',
			username: 'Spotify username',
			question: 'Come attivo le Spotify Features?'
		},
		reset: 'Reimposta Default',
		save: 'Salva',
		toasts: {
			init: 'Impostazioni caricate!',
			update: 'Impostazioni aggiornate!',
			ARLcopied: 'ARL copiato negli appunti'
		}
	},
	sidebar: {
		home: 'home',
		search: 'ricerca',
		charts: 'classifiche',
		favorites: 'preferiti',
		linkAnalyzer: 'analizza link',
		settings: 'impostazioni',
		about: 'info'
	},
	tracklist: {
		downloadSelection: 'Scarica selezionati'
	}
};

const en = {
	globals: {
		welcome: 'Welcome to deemix',
		back: 'back',
		loading: 'loading',
		download: 'Download {thing}',
		downloadAll: 'Download all {thing}',
		by: 'by {artist}',
		in: 'in {album}',
		download_hint: 'Download',
		play_hint: 'Play',
		toggle_download_tab_hint: 'Expand/Collapse',
		clean_queue_hint: 'Clear Finished',
		cancel_queue_hint: 'Cancel All',
		open_downloads_folder: 'Open Downloads Folder',
		cut: 'cut',
		copy: 'copy',
		copyLink: 'copy link',
		copyImageLink: 'copy image link',
		copyDeezerLink: 'copy deezer link',
		paste: 'paste',
		listTabs: {
			empty: '',
			all: 'all',
			top_result: 'top result',
			album: 'album | albums',
			artist: 'artist | artists',
			single: 'single | singles',
			title: 'title | titles',
			track: 'track | tracks',
			trackN: '0 tracks | {n} track | {n} tracks',
			releaseN: '0 releases | {n} release | {n} releases',
			playlist: 'playlist | playlists',
			compile: 'compilation | compilations',
			ep: 'ep | eps',
			bundle: 'bundle | bundles',
			more: 'More albums',
			featured: 'Featured in',
			spotifyPlaylist: 'spotify playlist | spotify playlists',
			releaseDate: 'release date',
			error: 'error'
		}
	},
	about: {
		updates: {
			currentVersion: 'Current Version',
			versionNotAvailable: 'N/A',
			updateAvailable: `You're not running the latest version available: {version}`,
			deemixVersion: 'deemix lib version'
		},
		titles: {
			usefulLinks: 'Useful Links',
			bugReports: 'Bug Reports',
			contributing: 'Contributing',
			donations: 'Donations',
			license: 'License'
		},
		subtitles: {
			bugReports: "Is there something that isn't working in deemix? Tell us!",
			contributing: 'You want to contribute to this project? You can do it in different ways!',
			donations: 'You want to contribute monetarily? You could make a donation!'
		},
		usesLibrary: 'This app uses the <strong>deemix</strong> library, which you can use to make your own UI for deemix.',
		thanks: `Thanks to <strong>rtonno</strong>, <strong>uhwot</strong> and <strong>lollilol</strong> for helping me with this project and to <strong>BasCurtiz</strong> and <strong>scarvimane</strong> for making the icon.`,
		upToDate: `Stay up to date with the updates by following the <a href="https://t.me/RemixDevNews" target="_blank">news channel</a> on Telegram.`,
		officialWebsite: 'Official Website',
		officialRepo: 'Official Library Repository',
		officialWebuiRepo: 'Official WebUI Repository',
		officialSubreddit: 'Official Subreddit',
		newsChannel: 'News Channel',
		questions: `If you have questions or problems with the app, search for a solution on the <a href="https://www.reddit.com/r/deemix" target="_blank">subreddit</a> first. Then, if you don't find anything you can make a post with your issue on the subreddit.`,
		beforeReporting: `Before reporting a bug make sure you're running the latest version of the app and that what you want to report is actually a bug and not something that's wrong only on your end.`,
		beSure: `Make sure the bug is reproducible on other machines and also <strong>DO NOT</strong> report a bug if it's already been reported.`,
		duplicateReports: 'Duplicate bug reports will be closed, so keep an eye out on that.',
		dontOpenIssues: `<strong>DO NOT</strong> open issues for asking questions, there is a subreddit for that.`,
		newUI: `If you're fluent in python you could try to make a new UI for the app using the base library, or fix bugs in the library with a pull request on the <a href="https://codeberg.org/RemixDev/deemix" target="_blank">repo</a>.`,
		acceptFeatures: `I accept features as well, but no complex things, as they can be implementend directly in the app and not the library.`,
		otherLanguages: `If you're fluent in another programming language you could try to port deemix into other programming languages!`,
		understandingCode: `You need help understanding the code? Just hit RemixDev up on Telegram or Reddit.`,
		contributeWebUI: `If you know Vue.js (JavaScript), HTML or CSS you could contribute to the <a href="https://codeberg.org/RemixDev/deemix-webui" target="_blank">WebUI</a>.`,
		itsFree: `You should remember that <strong>this is a free project</strong> and <strong>you should support the artists you love</strong> before supporting the developers.`,
		notObligated: `Don't feel obligated to donate, I appreciate you anyway!`,
		lincensedUnder: `This work is licensed under the
			<a rel="license" href="https://www.gnu.org/licenses/gpl-3.0.en.html" target="_blank">GNU General Public License 3.0</a>.`
	},
	charts: {
		title: 'Charts',
		changeCountry: 'Change Country',
		download: 'Download Chart'
	},
	errors: {
		title: 'Errors for {name}',
		ids: {
			invalidURL: 'URL not recognized',
			unsupportedURL: 'URL not supported yet',
			ISRCnotOnDeezer: 'Track ISRC is not available on Deezer',
			notYourPrivatePlaylist: "You can't download others private playlists.",
			spotifyDisabled: 'Spotify Features is not setted up correctly.',
			trackNotOnDeezer: 'Track not found on Deezer!',
			albumNotOnDeezer: 'Album not found on Deezer!',
			notOnDeezer: 'Track not available on Deezer!',
			notEncoded: 'Track not yet encoded!',
			notEncodedNoAlternative: 'Track not yet encoded and no alternative found!',
			wrongBitrate: 'Track not found at desired bitrate.',
			wrongBitrateNoAlternative: 'Track not found at desired bitrate and no alternative found!',
			no360RA: 'Track is not available in Reality Audio 360.',
			notAvailable: "Track not available on Deezer's servers!",
			notAvailableNoAlternative: "Track not available on Deezer's servers and no alternative found!",
			noSpaceLeft: 'No space left on the device!',
			albumDoesntExists: "Track's album doesn't exist, failed to gather info"
		}
	},
	favorites: {
		title: 'Favorites',
		noPlaylists: 'No Playlists found',
		noAlbums: 'No Favorite Albums found',
		noArtists: 'No Favorite Artists found',
		noTracks: 'No Favorite Tracks found'
	},
	home: {
		needTologin: 'You need to log into your Deezer account before you can start downloading.',
		openSettings: 'Open Settings',
		sections: {
			popularPlaylists: 'Popular playlists',
			popularAlbums: 'Most streamed albums'
		}
	},
	linkAnalyzer: {
		info: 'You can use this section to find more information about the link you are trying to download.',
		useful:
			"This is useful if you're trying to download some tracks that are not available in your country and want to know where they are available, for instance.",
		linkNotSupported: 'This link is not yet supported',
		linkNotSupportedYet: 'Seems like this link is not yet supported, try analyzing another one.',
		table: {
			id: 'ID',
			isrc: 'ISRC',
			upc: 'UPC',
			duration: 'Duration',
			diskNumber: 'Disk Number',
			trackNumber: 'Track Number',
			releaseDate: 'Release Date',
			bpm: 'BPM',
			label: 'Label',
			recordType: 'Record Type',
			genres: 'Genres',
			tracklist: 'Tracklist'
		}
	},
	search: {
		startSearching: 'Start searching!',
		description:
			'You can search a track, a whole album, an artist, a playlist.... everything! You can also paste a Deezer link',
		fans: '{n} fans',
		noResults: 'No results',
		noResultsTrack: 'No Tracks found',
		noResultsAlbum: 'No Albums found',
		noResultsArtist: 'No Artists found',
		noResultsPlaylist: 'No Playlists found'
	},
	searchbar: 'Search anything you want (or just paste a link)',
	downloads: 'downloads',
	toasts: {
		restoringQueue: 'Restoring download queue...',
		queueRestored: 'Download queue restored!',
		addedToQueue: '{item} added to queue',
		addedMoreToQueue: '{n} items added to queue',
		alreadyInQueue: '{item} is already in queue!',
		finishDownload: '{item} finished downloading.',
		allDownloaded: 'All downloads completed!',
		refreshFavs: 'Refresh completed!',
		loggingIn: 'Logging in...',
		loggedIn: 'Logged in',
		alreadyLogged: 'Already logged in',
		loginFailed: "Couldn't log in",
		loggedOut: 'Logged out',
		cancellingCurrentItem: 'Cancelling current item.',
		currentItemCancelled: 'Current item cancelled.',
		startAddingArtist: 'Adding {artist} albums to queue',
		finishAddingArtist: 'Added {artist} albums to queue',
		startConvertingSpotifyPlaylist: 'Converting spotify tracks to Deezer tracks',
		finishConvertingSpotifyPlaylist: 'Spotify playlist converted',
		loginNeededToDownload: 'You need to log in to download tracks!',
		deezerNotAvailable: 'Deezer is not available in your country. You should use a VPN.',
		startGeneratingItems: 'Processing {n} items...',
		finishGeneratingItems: 'Generated {n} items.'
	},
	settings: {
		title: 'Settings',
		languages: 'Languages',
		login: {
			title: 'Login',
			loggedIn: 'You are logged in as {username}',
			arl: {
				question: 'How do I get my own ARL?',
				update: 'Update ARL'
			},
			logout: 'Logout',
			login: 'Login via deezer.com'
		},
		appearance: {
			title: 'Appearance',
			slimDownloadTab: 'Slim download tab'
		},
		downloadPath: {
			title: 'Download Path'
		},
		templates: {
			title: 'Templates',
			tracknameTemplate: 'Trackname template',
			albumTracknameTemplate: 'Album track template',
			playlistTracknameTemplate: 'Playlist track template'
		},
		folders: {
			title: 'Folders',
			createPlaylistFolder: 'Create folder for playlists',
			playlistNameTemplate: 'Playlist folder template',
			createArtistFolder: 'Create folder for artist',
			artistNameTemplate: 'Artist folder template',
			createAlbumFolder: 'Create folder for album',
			albumNameTemplate: 'Album folder template',
			createCDFolder: 'Create folder for CDs',
			createStructurePlaylist: 'Create folder structure for playlists',
			createSingleFolder: 'Create folder structure for singles'
		},
		trackTitles: {
			title: 'Track titles',
			padTracks: 'Pad tracks',
			paddingSize: 'Overwrite padding size',
			illegalCharacterReplacer: 'Illegal Character replacer'
		},
		downloads: {
			title: 'Downloads',
			queueConcurrency: 'Concurrent Downloads',
			maxBitrate: {
				title: 'Preferred Bitrate',
				9: 'FLAC 1411kbps',
				3: 'MP3 320kbps',
				1: 'MP3 128kbps'
			},
			overwriteFile: {
				title: 'Should I overwrite the files?',
				y: 'Yes, overwrite the file',
				n: "No, don't overwrite the file",
				t: 'Overwrite only the tags',
				b: 'No, keep both files and add a number to the duplicate',
				e: "No, and don't look at the extensions"
			},
			fallbackBitrate: 'Bitrate fallback',
			fallbackSearch: 'Search fallback',
			logErrors: 'Create log files for errors',
			logSearched: 'Create log files for searched tracks',
			createM3U8File: 'Create playlist file',
			syncedLyrics: 'Create .lyr files (Sync Lyrics)',
			playlistFilenameTemplate: 'Playlist filename template',
			saveDownloadQueue: 'Save download queue when closing the app'
		},
		covers: {
			title: 'Album covers',
			saveArtwork: 'Save Covers',
			coverImageTemplate: 'Cover name template',
			saveArtworkArtist: 'Save artist image',
			artistImageTemplate: 'Artist image template',
			localArtworkSize: 'Local artwork size',
			embeddedArtworkSize: 'Embedded artwork size',
			localArtworkFormat: {
				title: 'What format do you want the local artwork to be?',
				jpg: 'A jpeg image',
				png: 'A png image',
				both: 'Both a jpeg and a png'
			},
			jpegImageQuality: 'JPEG image quality',
			embeddedArtworkPNG: 'Save embedded artwork as PNG',
			embeddedPNGWarning: 'PNGs are not officialy supported by Deezer and can be buggy',
			imageSizeWarning: 'Anything above x1200 is not officialy used by Deezer, you may encounter issues',
			coverDescriptionUTF8: 'Save cover description using UTF8 (iTunes Cover Fix)'
		},
		tags: {
			head: 'Which tags to save',
			title: 'Title',
			artist: 'Artist',
			album: 'Album',
			cover: 'Cover',
			trackNumber: 'Track Number',
			trackTotal: 'Track Total',
			discNumber: 'Disc Number',
			discTotal: 'Disc Total',
			albumArtist: 'Album Artist',
			genre: 'Genre',
			year: 'Year',
			date: 'Date',
			explicit: 'Explicit Lyrics',
			isrc: 'ISRC',
			length: 'Track Length',
			barcode: 'Album Barcode (UPC)',
			bpm: 'BPM',
			replayGain: 'Replay Gain',
			label: 'Album Label',
			lyrics: 'Unsynchronized Lyrics',
			syncedLyrics: 'Synchronized Lyrics',
			copyright: 'Copyright',
			composer: 'Composer',
			involvedPeople: 'Involved People'
		},
		other: {
			title: 'Other',
			savePlaylistAsCompilation: 'Save playlists as compilation',
			useNullSeparator: 'Use null separator',
			saveID3v1: 'Save ID3v1 as well',
			multiArtistSeparator: {
				title: 'How would you like to separate your artists?',
				nothing: 'Save only the main artist',
				default: 'Using standard specification',
				andFeat: 'Using & and feat.',
				using: 'Using "{separator}"'
			},
			singleAlbumArtist: 'Save only the main album artist',
			albumVariousArtists: 'Keep "Various Artists" in the Album Artists',
			removeAlbumVersion: 'Remove "Album Version" from track title',
			removeDuplicateArtists: 'Remove combinations of artists',
			dateFormat: {
				title: 'Date format for FLAC files',
				year: 'YYYY',
				month: 'MM',
				day: 'DD'
			},
			featuredToTitle: {
				title: 'What should I do with featured artists?',
				0: 'Nothing',
				1: 'Remove it from the title',
				3: 'Remove it from the title and the album title',
				2: 'Move it to the title'
			},
			titleCasing: 'Title casing',
			artistCasing: 'Artist casing',
			casing: {
				nothing: 'Keep unchanged',
				lower: 'lowercase',
				upper: 'UPPERCASE',
				start: 'Start Of Each Word',
				sentence: 'Like a sentence'
			},
			previewVolume: 'Preview Volume',
			executeCommand: {
				title: 'Command to execute after download',
				description: 'Leave blank for no action'
			}
		},
		spotify: {
			title: 'Spotify Features',
			clientID: 'Spotify ClientID',
			clientSecret: 'Spotify Client Secret',
			username: 'Spotify Username',
			question: 'How do I enable Spotify Features?'
		},
		reset: 'Reset to Default',
		save: 'Save',
		toasts: {
			init: 'Settings loaded!',
			update: 'Settings updated!',
			ARLcopied: 'ARL copied to clipboard'
		}
	},
	sidebar: {
		home: 'home',
		search: 'search',
		charts: 'charts',
		favorites: 'favorites',
		linkAnalyzer: 'link analyzer',
		settings: 'settings',
		about: 'about'
	},
	tracklist: {
		downloadSelection: 'Download selection'
	}
};

const es = {
	globals: {
		welcome: 'Bienvenido a deemix',
		back: 'atrás',
		loading: 'cargando',
		download: 'Descarga {thing}',
		by: 'por {artist}',
		in: 'en {album}',
		download_hint: 'Descargar',
		play_hint: 'Reproducir',
		toggle_download_tab_hint: 'Expandir/Colapsar',
		clean_queue_hint: 'Limpieza terminada',
		cancel_queue_hint: 'Cancelar todo',
		open_downloads_folder: 'Abrir la carpeta de descargas',
		cut: 'cortar',
		copy: 'copiar',
		copyLink: 'copiar vinculo',
		copyImageLink: 'copiar el vínculo de la imagen',
		copyDeezerLink: 'copiar el vínculo de Deezer',
		paste: 'pegar',
		listTabs: {
			empty: '',
			all: 'todo',
			top_result: 'mejor resultado',
			album: 'álbum | álbumes',
			artist: 'artista | artistas',
			single: 'single | singles',
			title: 'título | títulos',
			track: 'pista | pistas',
			trackN: '0 pistas | {n} pista | {n} pistas',
			releaseN: '0 entregas | {n} entrega | {n} entregas',
			playlist: 'lista de reproducción | listas de reproducción',
			compile: 'compilación | compilaciones',
			ep: 'ep | eps',
			more: 'Más álbumes',
			featured: 'Aparece en',
			spotifyPlaylist: 'lista de reproducción spotify | listas de reproducción spotify',
			releaseDate: 'fecha de publicación',
			error: 'error'
		}
	},
	about: {
		updates: {
			currentVersion: 'Versión actual',
			versionNotAvailable: 'N/D',
			updateAvailable: `No estás ejecutando la última versión disponible: {versión}`,
			deemixVersion: 'versión de la biblioteca deemix'
		},
		titles: {
			usefulLinks: 'Enlaces útiles',
			bugReports: 'Reportar fallos',
			contributing: 'Contribuye',
			donations: 'Donaciones',
			license: 'Licencia'
		},
		subtitles: {
			bugReports: '¿Hay algo que no funcione en Deemix? ¡Díganoslo!',
			contributing: '¿Quieres contribuir a este proyecto? ¡Puedes hacerlo de diferentes maneras!',
			donations: '¿Quiere contribuir monetariamente? ¡Puedes hacer una donación!'
		},
		usesLibrary: 'Esta aplicación usa la biblioteca <strong>deemix</strong>, que puedes usar para hacer tu propia interfaz de usuario para deemix.',
		thanks: `Gracias a <strong>rtonno</strong>, <strong>uhwot</strong> y <strong>lollilol</strong> por ayudarme con este proyecto, a <strong>BasCurtiz</strong> y <strong>scarvimane</strong> por hacer el icono.`,
		upToDate: `Mantente al día con las actualizaciones siguiendo el <a href="https://t.me/RemixDevNews" target="_blank">canal de noticias</a> en Telegram.`,
		officialWebsite: 'Página web oficial',
		officialRepo: 'Repositorio de la biblioteca oficial',
		officialWebuiRepo: 'Repositorio oficial de WebUI',
		officialSubreddit: 'Subreddit oficial',
		newsChannel: 'Canal de noticias',
		questions: `Si tienes preguntas o problemas con la aplicación, busca una solución en el <a href="https://www.reddit.com/r/deemix" target="_blank">subreddit</a> primero. Luego, si no encuentras nada puedes hacer un post con tu problema en el subreddit.`,
		beforeReporting: 'Antes de informar de un error asegúrese de que está ejecutando la última versión de la aplicación y que lo que quiere informar es en realidad un error y no algo que está mal sólo en su extremo.',
		beSure: 'Asegúrate de que el fallo es reproducible en otras máquinas y también <strong>NO</strong> reporte un fallo si ya ha sido reportado.',
		duplicateReports: 'Los informes de errores duplicados se cerrarán, así que manténgase al tanto de eso.',
		dontOpenIssues: '<strong>NO</strong> abra problemas para hacer preguntas, hay un subreddit para eso.',
		newUI: `Si tienes fluidez en Python podrías intentar hacer una nueva interfaz de usuario para la aplicación usando la biblioteca base, o arreglar los errores de la biblioteca con una petición pull en el <a href="https://codeberg.org/RemixDev/deemix" target="_blank">repo</a>.`,
		acceptFeatures: 'También acepto características, pero no cosas complejas, ya que se pueden implementar directamente en la aplicación y no en la biblioteca.',
		otherLanguages: '¡Si dominas otro lenguaje de programación podrías intentar portar Deemix a otros lenguajes de programación!',
		understandingCode: '¿Necesitas ayuda para entender el código? Sólo tienes que poner RemixDev en Telegram o Reddit.',
		contributeWebUI: `Si conoces Vue.js (JavaScript), HTML o CSS podrías contribuir a la <a href="https://codeberg.org/RemixDev/deemix-webui" target="_blank">WebUI</a>.`,
		itsFree: 'Debes recordar que <strong>este es un proyecto libre</strong> y <strong>debes apoyar a los artistas que amas</strong> antes de apoyar a los desarrolladores.',
		notObligated: 'No te sientas obligado a donar, ¡te aprecio de todas formas!',
		lincensedUnder: `Esta obra está autorizada bajo una <a rel="licencia" href="https://www.gnu.org/licenses/gpl-3.0.en.html" target="_blank">GNU Licencia Pública General 3.0</a>.`
	},
	charts: {
		title: 'Listas',
		changeCountry: 'Cambiar país',
		download: 'Descargar la lista'
	},
	errors: {
		title: 'Errores para {name}',
		ids: {
			invalidURL: 'No se reconoce la URL',
			unsupportedURL: 'La URL aún no está soportada',
			ISRCnotOnDeezer: 'La pista ISRC no está disponible en Deezer',
			notYourPrivatePlaylist: 'No puedes descargar otras listas de reproducción privadas.',
			spotifyDisabled: 'Las funciones de Spotify no está configurado correctamente.',
			trackNotOnDeezer: '¡No se encontró la pista en Deezer!',
			albumNotOnDeezer: '¡El álbum no se encuentra en Deezer!',
			notOnDeezer: '¡Pista no disponible en Deezer!',
			notEncoded: '¡Pista aún no codificada!',
			notEncodedNoAlternative: '¡Pista aún no codificada y no se ha encontrado ninguna alternativa!',
			wrongBitrate: 'La pista no se encuentra a la velocidad de bitrate deseada.',
			wrongBitrateNoAlternative: '¡Pista no encontrada a la tasa de bits deseada y no se ha encontrado ninguna alternativa!',
			no360RA: 'La pista no está disponible en Reality Audio 360.',
			notAvailable: '¡La pista no está disponible en los servidores de Deezer!',
			notAvailableNoAlternative: '¡La pista no está disponible en los servidores de Deezer y no se ha encontrado ninguna alternativa!',
			noSpaceLeft: '¡No queda espacio en el dispositivo!'
		}
	},
	favorites: {
		title: 'Favoritos',
		noPlaylists: 'No se han encontrado listas de reproducción',
		noAlbums: 'No se han encontrado álbumes favoritos',
		noArtists: 'No se han encontrado artistas favoritos',
		noTracks: 'No se han encontrado pistas favoritas'
	},
	home: {
		needTologin: 'Necesitas entrar en tu cuenta de Deezer antes de poder empezar a descargar.',
		openSettings: 'Abrir la configuración',
		sections: {
			popularPlaylists: 'Listas de reproducción populares',
			popularAlbums: 'Los álbumes más stremeados'
		}
	},
	linkAnalyzer: {
		info: 'Puedes usar esta sección para encontrar más información sobre el enlace que estás tratando de descargar.',
		useful: 'Esto es útil si está tratando de descargar algunas pistas que no están disponibles en su país y quiere saber dónde están disponibles, por ejemplo.',
		linkNotSupported: 'Este enlace aún no está soportado',
		linkNotSupportedYet: 'Parece que este enlace aún no está soportado, intenta analizar otro.',
		table: {
			id: 'ID',
			isrc: 'ISRC',
			upc: 'UPC',
			duration: 'Duración',
			diskNumber: 'Número del disco',
			trackNumber: 'Número de la pista',
			releaseDate: 'Fecha de lanzamiento',
			bpm: 'BPM',
			label: 'Etiqueta',
			recordType: 'Tipo de grabación',
			genres: 'Géneros',
			tracklist: 'Lista de pista'
		}
	},
	search: {
		startSearching: '¡Comienza a buscar!',
		description: 'Puedes buscar un tema, un álbum entero, un artista, una lista de reproducción... ¡todo! También puedes pegar un enlace de Deezer',
		fans: '{n} fans',
		noResults: 'Ningun resultado',
		noResultsTrack: 'No se encontraron pistas',
		noResultsAlbum: 'No se encontraron álbumes',
		noResultsArtist: 'No se encontraron artistas',
		noResultsPlaylist: 'No se encontraron listas de reproducción'
	},
	searchbar: 'Busca lo que quieras (o simplemente pega un enlace)',
	downloads: 'descargas',
	toasts: {
		restoringQueue: 'Restaurando la cola de descarga...',
		queueRestored: '¡Cola de descarga restaurada!',
		addedToQueue: '{item} añadidos a la cola',
		addedMoreToQueue: '{n} elementos añadidos a la cola',
		alreadyInQueue: '¡{item} ya está en la cola!',
		finishDownload: '{item} terminado de descargar.',
		allDownloaded: '¡Todas las descargas se han completado!',
		refreshFavs: '¡Actualización completada!',
		loggingIn: 'Conectando...',
		loggedIn: 'Conectado',
		alreadyLogged: 'Ya está conectado',
		loginFailed: 'No se puede conectar',
		loggedOut: 'Desconectado',
		cancellingCurrentItem: 'Cancelando el elemento actual.',
		currentItemCancelled: 'El elemento actual se ha cancelado.',
		startAddingArtist: 'Añadiendo los álbumes de {artist} a la cola',
		finishAddingArtist: 'Se ha añadido los álbumes de {artist} a la cola',
		startConvertingSpotifyPlaylist: 'Convertir las pistas de Spotify en pistas de Deezer',
		finishConvertingSpotifyPlaylist: 'Lista de reproducción de Spotify convertida',
		loginNeededToDownload: '¡Necesitas iniciar sesión para descargar títulos!',
		deezerNotAvailable: 'Deezer no está disponible en su país. Deberías usar una VPN.'
	},
	settings: {
		title: 'Configuración',
		languages: 'Idiomas',
		login: {
			title: 'Iniciar Sesión',
			loggedIn: 'Usted está conectado como {nombre de usuario}',
			arl: {
				question: '¿Cómo consigo mi propio ARL?',
				update: 'Actualiza la ARL'
			},
			logout: 'Cerrar Sesión',
			login: 'Inicia sesión a través de deezer.com'
		},
		appearance: {
			title: 'Apariencia',
			slimDownloadTab: 'Pestaña de descargas fina'
		},
		downloadPath: {
			title: 'Ruta de descarga'
		},
		templates: {
			title: 'Plantillas',
			tracknameTemplate: 'Plantilla de nombres de pista',
			albumTracknameTemplate: 'Plantilla de pista del álbum',
			playlistTracknameTemplate: 'Plantilla de pista de la lista de reproducción'
		},
		folders: {
			title: 'Carpetas',
			createPlaylistFolder: 'Crear una carpeta para las listas de reproducción',
			playlistNameTemplate: 'Plantilla de la carpeta de la lista de reproducción',
			createArtistFolder: 'Crear carpeta para el artista',
			artistNameTemplate: 'Plantilla de la carpeta del artista',
			createAlbumFolder: 'Crear carpeta para el álbum',
			albumNameTemplate: 'Plantilla de la carpeta del álbum',
			createCDFolder: 'Crear una carpeta para los CDs',
			createStructurePlaylist: 'Crear una estructura de carpetas para las listas de reproducción',
			createSingleFolder: 'Crear una estructura de carpetas para individuales'
		},
		trackTitles: {
			title: 'Títulos de las pistas',
			padTracks: 'Pad de pistas',
			paddingSize: 'Sobrescribir el tamaño del pad',
			illegalCharacterReplacer: 'Reemplazo del carácter ilegal'
		},
		downloads: {
			title: 'Descargas',
			queueConcurrency: 'Descargas simultáneas',
			maxBitrate: {
				title: 'Tasa de bits preferida',
				9: 'FLAC 1411kbps',
				3: 'MP3 320kbps',
				1: 'MP3 128kbps'
			},
			overwriteFile: {
				title: '¿Desea que se sobreescriban los archivos?',
				y: 'Sí, sobrescribir el archivo',
				n: 'No, no sobrescribir el archivo',
				t: 'Sobrescribir sólo las etiquetas',
				b: 'No, mantener los dos archivos y agregar un número al archivo duplicado',
				e: 'No, y no mirar las extensiones'
			},
			fallbackBitrate: 'La solución alternativa de bitrate',
			fallbackSearch: 'Búsqueda de la segunda opción',
			logErrors: 'Crear archivos de registro de errores',
			logSearched: 'Crear archivos de registro para las pistas buscadas',
			createM3U8File: 'Crear archivo de la lista de reproducción',
			syncedLyrics: 'Crear archivos .lyr (lyrics sincronizadas)',
			playlistFilenameTemplate: 'Plantilla de nombres de archivos de la lista de reproducción',
			saveDownloadQueue: 'Guardar la cola de descarga al cerrar la aplicación'
		},
		covers: {
			title: 'Portadas de álbumes',
			saveArtwork: 'Guardar las portadas',
			coverImageTemplate: 'Plantilla de nombres de portada',
			saveArtworkArtist: 'Guardar imagen de artista',
			artistImageTemplate: 'Plantilla de imagen de artista',
			localArtworkSize: 'El tamaño de la portada local',
			embeddedArtworkSize: 'El tamaño de la portada incorporada',
			localArtworkFormat: {
				title: '¿Qué formato quieres que tenga la portada local?',
				jpg: 'Una imagen jpeg',
				png: 'Una imagen png',
				both: 'Ambos, jpeg y png'
			},
			jpegImageQuality: 'Calidad de la imagen JPEG',
			embeddedArtworkPNG: 'Guardar las imágenes incrustadas como PNG',
			embeddedPNGWarning: 'Las PNG no están oficialmente soportadas por Deezer y puedes encontrar errores.',
			imageSizeWarning: 'Nada por encima de x1200 no es usado oficialmente por Deezer, puede que encuentres inconvenientes',
			coverDescriptionUTF8: 'Guardar la descripción de la portada usando UTF8 (arregla la portada de iTunes)'
		},
		tags: {
			head: '¿Qué etiquetas guardar?',
			title: 'Título',
			artist: 'Artista',
			album: 'Álbum',
			cover: 'Portada',
			trackNumber: 'Número de pista',
			trackTotal: 'Total de pistas',
			discNumber: 'Número del disco',
			discTotal: 'Total del disco',
			albumArtist: 'Artista del álbum',
			genre: 'Género',
			year: 'Año',
			date: 'Fecha',
			explicit: 'Letras explícitas',
			isrc: 'ISRC',
			length: 'Duración de la pista',
			barcode: 'Código de barras del álbum (UPC)',
			bpm: 'BPM',
			replayGain: 'Ganancia de la reproducción',
			label: 'Etiqueta del álbum',
			lyrics: 'Lyrics no sincronizadas',
			syncedLyrics: 'Lyrics sincronizadas',
			copyright: 'Derechos de autor',
			composer: 'Compositor',
			involvedPeople: 'Personas involucradas'
		},
		other: {
			title: 'Otro',
			savePlaylistAsCompilation: 'Guardar las listas de reproducción como una compilación',
			useNullSeparator: 'Usar separador nulo',
			saveID3v1: 'Guarda la ID3v1 también',
			multiArtistSeparator: {
				title: '¿Cómo le gustaría separar a sus artistas?',
				nothing: 'Guardar sólo el artista principal',
				default: 'Usar la especificación estándar',
				andFeat: 'Usar & y feat.',
				using: 'Usar "{separator}"'
			},
			singleAlbumArtist: 'Guardar sólo el artista principal del álbum',
			albumVariousArtists: 'Mantener "Various Artists" en los artistas del álbum',
			removeAlbumVersion: 'Eliminar "Album Version" del título de la pista',
			removeDuplicateArtists: 'Eliminar las combinaciones de artistas',
			dateFormat: {
				title: 'Formato de fecha para los archivos FLAC',
				year: 'AAAA',
				month: 'MM',
				day: 'DD'
			},
			featuredToTitle: {
				title: '¿Qué debo hacer con los artistas destacados?',
				0: 'Nada',
				1: 'Quitarlo del título',
				3: 'Quitarlo del título y del título del álbum',
				2: 'Moverlo al título'
			},
			titleCasing: 'Capitalizar título',
			artistCasing: 'Capitalizar artista',
			casing: {
				nothing: 'Manténer sin cambios',
				lower: 'minúsculas',
				upper: 'MAYÚSCULAS',
				start: 'Al Principio De Cada Palabra',
				sentence: 'Como una frase'
			},
			previewVolume: 'Volumen de previsualización',
			executeCommand: {
				title: 'Comando a ejecutar después de la descarga',
				description: 'Dejar en blanco para no hacer nada'
			}
		},
		spotify: {
			title: 'Funciones de Spotify',
			clientID: 'ID del cliente de Spotify',
			clientSecret: 'Cliente Secreto Spotify',
			username: 'Nombre de usuario de Spotify'
		},
		reset: 'Restablecer el valor por defecto',
		save: 'Guardar',
		toasts: {
			init: '¡Configuraciones cargadas!',
			update: '¡Ajustes actualizados!',
			ARLcopied: 'ARL copiado al portapapeles'
		}
	},
	sidebar: {
		home: 'inicio',
		search: 'buscar',
		charts: 'charts',
		favorites: 'favoritos',
		linkAnalyzer: 'analizar enlaces',
		settings: 'ajustes',
		about: 'acerca de'
	},
	tracklist: {
		downloadSelection: 'Descargar selección'
	}
};

const de = {
	globals: {
		welcome: 'Willkommen bei deemix',
		back: 'zurück',
		loading: 'lädt',
		download: 'Download {thing}',
		by: 'von {artist}',
		in: 'in {album}',
		download_hint: 'Download',
		play_hint: 'Play',
		toggle_download_tab_hint: 'Erweitern/Minimieren',
		clean_queue_hint: 'Entferne vollständige',
		cancel_queue_hint: 'Alle abbrechen',
		listTabs: {
			empty: '',
			all: 'alle',
			top_result: 'Top Ergebnis',
			album: 'Album | Alben',
			artist: 'Künstler | Künstler',
			single: 'Single | Singles',
			title: 'Titel | Titel',
			track: 'Track | Tracks',
			trackN: '0 Tracks | {n} Track | {n} Tracks',
			releaseN: '0 Releases | {n} Release | {n} Releases',
			playlist: 'Playlist | Playlists',
			compile: 'Sammlung | Sammlungen',
			ep: 'EP | EPs',
			spotifyPlaylist: 'Spotify Playlist | Spotify Playlists',
			releaseDate: 'Veröffentlichungsdatum',
			error: 'Fehler'
		}
	},
	about: {
		titles: {
			usefulLinks: 'Nützliche Links',
			bugReports: 'Fehlermeldung',
			contributing: 'Mitwirkende',
			donations: 'Spenden',
			license: 'Lizenz'
		},
		subtitles: {
			bugReports: 'Funktioniert etwas in Deemix nicht? Sag uns bescheid!',
			contributing: 'Du möchtest bei dem Projekt helfen? Das kannst du auf verschiedene Arten machen!',
			donations: 'Du möchtest deemix finanziell unterstützen? Dann lasse eine kleine Spende da!'
		},
		usesLibrary: 'Dieses Programm nutzt die <strong>deemix</strong> Bibliothek, die du dazu nutzen kannst deine eigene deemix UI zu erstellen.',
		thanks: 'Ein Dankeschön geht an <strong>rtonno</strong>, <strong>uhwot</strong> and <strong>lollilol</strong> für die Hilfe bei diesem Projekt und an <strong>BasCurtiz</strong> and <strong>scarvimane</strong> für die Erstellung des Logos.',
		upToDate: 'Bleib auf dem Laufenden mit den Updates indem du dem <a href="https://t.me/RemixDevNews" target="_blank">News Channel</a> auf Telegram folgst.',
		officialWebsite: 'Offizielle Website',
		officialRepo: 'Offizielle Library Repository',
		officialWebuiRepo: 'Offizielle WebUI Repository',
		officialSubreddit: 'Offizieller Subreddit',
		newsChannel: 'News Channel',
		questions: 'Bei Fragen oder Problemen mit der App, suche als erstes nach einer Lösung im <a href="https://www.reddit.com/r/deemix" target="_blank">Subreddit</a>. Wenn du da nichts findest, kannst du einen Beitrag mit deinen Problem auf dem Subreddit verfassen.',
		beforeReporting: 'Bevor du einen Bug meldest, stelle sicher, dass du die neueste Version der App hast und dass das, was du melden möchtest, tatsächlich ein Bug ist und nicht nur bei dir falsch ist.',
		beSure: 'Stelle sicher, dass der Bug auf anderen Computern auch vorhanden ist <strong>MELDEN NICHT</strong> einen Bug, wenn er schon gemeldet worden ist.',
		duplicateReports: 'Doppelte Fehlerberichte werden geschlossen, achte darauf.',
		dontOpenIssues: '<strong>ERSTELLE KEINE</strong> Fehlermeldungen um Fragen zu stellen, es gibt einen Subreddit dafür.',
		newUI: 'Wenn du Python fließend beherrschst, kannst du versuchen, mit hilfe der base library eine neue Benutzeroberfläche für die App zu erstellen oder Fehler in der Bibliothek mit einem Pull-Request in der <a href="https://codeberg.org/RemixDev/deemix" target="_blank">deemix Repo</a> zu beheben.',
		acceptFeatures: 'Ich akzeptiere auch Funktionen, aber keine komplexen Dinge, da sie direkt in der App und nicht in der Bibliothek implementiert werden können.',
		otherLanguages: 'Wenn du eine andere Programmiersprache fließend beherrschst, kannst du versuchen, deemix in andere Programmiersprachen zu portieren!',
		understandingCode: 'Du benötigst Hilfe beim verstehen des Codes? Frag einfach RemixDev auf Telegram oder Reddit.',
		contributeWebUI: 'Wenn du Vue.js (JavaScript) oder HTML und CSS kennst, könntest du etwas zum <a href="https://codeberg.org/RemixDev/deemix-webui" target="_blank">WebUI</a> beitragen.',
		itsFree: 'Du solltest im Kopf behalten das <strong>dies ein kostenloses Projekt ist</strong> und <strong>Du solltest die Künstler unterstützen, die du magst </strong> bevor du die Entwickler unterstützt.',
		notObligated: 'Fühle dich nicht gezwungen zu spenden, danke, dass du deemix verwendest!',
		lincensedUnder: 'Diese Arbeit ist lizensiert unter der <a rel="license" href="https://www.gnu.org/licenses/gpl-3.0.en.html" target="_blank">GNU General Public License 3.0</a>.'
	},
	charts: {
		title: 'Charts',
		changeCountry: 'Land wechseln',
		download: 'Download Chart'
	},
	errors: {
		title: 'Errors für {name}',
		ids: {
			invalidURL: 'URL nicht erkannt',
			unsupportedURL: 'URL noch nicht unterstützt',
			ISRCnotOnDeezer: 'Track ISRC ist auf deezer nicht verfügbar',
			notYourPrivatePlaylist: "Du kannst keine privaten Playlisten anderer herunterladen.",
			spotifyDisabled: 'Spotify-Funktionen sind nicht richtig eingerichtet',
			trackNotOnDeezer: 'Track ist nicht verfügbar auf Deezer!',
			albumNotOnDeezer: 'Album auf Deezer nicht gefunden!',
			notOnDeezer: 'Track auf Deezer nicht verfügbar!',
			notEncoded: 'Track noch nicht codiert!',
			notEncodedNoAlternative: 'Track noch nicht codiert und keine Alternative gefunden!',
			wrongBitrate: 'Track mit gewünschter Bitrate nicht gefunden.',
			wrongBitrateNoAlternative: 'Track mit gewünschter Bitrate nicht gefunden und keine Alternative gefunden!',
			no360RA: 'Track ist nicht verfügbar in Reality Audio 360.',
			notAvailable: "Track ist noch nicht verfügbar auf den Servern von Deezer!",
			notAvailableNoAlternative: "Track ist noch nicht verfügbar auf den Servern von Deezer und keine Alternativen gefunden!!"
		}
	},
	favorites: {
		title: 'Favoriten',
		noPlaylists: 'Keine Playlist gefunden',
		noAlbums: 'Keine favorisierten Alben gefunden',
		noArtists: 'Keine favorisierten Künstler gefunden',
		noTracks: 'Keine favorisierten Tracks gefunden'
	},
	home: {
		needTologin: 'Du musst dich in deinem Deezer-Account anmelden bevor du mit dem Download starten kannst.',
		openSettings: 'Einstellungen öffnen',
		sections: {
			popularPlaylists: 'Beliebte Playlists',
			popularAlbums: 'Meistgestreamte Alben'
		}
	},
	linkAnalyzer: {
		info: 'Diesen Abschnitt kannst du nutzen, um weitere Informationen über den gewünschten Link zu erhalten, den du herunterladen möchtest.',
		useful: "Dies ist z.B. nützlich, wenn du versuchst einige Titel herunterzuladen, welche in deinem Land nicht verfügbar sind, und du wissen möchtest, wo sie verfügbar sind.",
		linkNotSupported: 'Dieser Link wird noch nicht unterstützt',
		linkNotSupportedYet: 'Es scheint so, als ob dieser Link noch nicht unterstützt wird. Versuche einen anderen Link zu analysieren.',
		table: {
			id: 'ID',
			isrc: 'ISRC',
			upc: 'UPC',
			duration: 'Dauer',
			diskNumber: 'CD Nummer',
			trackNumber: 'Track Nummer',
			releaseDate: 'Veröffentlichungsdatum',
			bpm: 'BPM',
			label: 'Label',
			recordType: 'Art der Aufnahme',
			genres: 'Genres',
			tracklist: 'Trackliste'
		}
	},
	search: {
		startSearching: 'Suche starten!',
		description: 'Du kannst einen Titel, ein ganzes Album, einen Künstler, eine Playlist suchen ... alles! Du kannst auch einen Deezer-Link einfügen',
		fans: '{n} Fans',
		noResults: 'Keine Ergebnisse',
		noResultsTrack: 'Keine Tracks gefunden',
		noResultsAlbum: 'Keine Alben gefunden',
		noResultsArtist: 'Keinen Künstler gefunden',
		noResultsPlaylist: 'Keine Playlist gefunden'
	},
	searchbar: 'Suche nach allem, was dir gefällt (oder füge einfach einen Link ein)',
	downloads: 'Downloads',
	toasts: {
		addedToQueue: '{item} zur Warteschlange hinzugefügt',
		alreadyInQueue: '{item} ist bereits in der Warteschlange!',
		finishDownload: '{item} vollständig heruntergeladen.',
		allDownloaded: 'Alle Downloads abgeschlossen!',
		refreshFavs: 'Abgeschlossene Downloads neu laden!',
		loggingIn: 'Einloggen',
		loggedIn: 'Eingeloggt',
		alreadyLogged: 'Bereits eingeloggt',
		loginFailed: "Login fehlgeschlagen",
		loggedOut: 'Ausgeloggt',
		cancellingCurrentItem: 'Aktuelle Auswahl abbrechen.',
		currentItemCancelled: 'Aktuelle Auswahl wurde abgebrochen',
		startAddingArtist: '{artist} Alben werden hinzugefügt',
		finishAddingArtist: '{artist} Alben wurden hinzugefügt',
		startConvertingSpotifyPlaylist: 'Konvertierern von Spotify-Tracks zu Deezer-Tracks',
		finishConvertingSpotifyPlaylist: 'Spotify Playlist convertiert'
	},
	settings: {
		title: 'Einstellungen',
		languages: 'Sprachen',
		login: {
			title: 'Login',
			loggedIn: 'Du bist eingeloggt als {username}',
			arl: {
				question: 'Wie bekomme ich meine eigene ARL?',
				update: 'Update ARL'
			},
			logout: 'Logout'
		},
		appearance: {
			title: 'Design',
			slimDownloadTab: 'schmaler Download-Tab'
		},
		downloadPath: {
			title: 'Download Pfad'
		},
		templates: {
			title: 'Vorlagen',
			tracknameTemplate: 'Vorlage für den Tracknamen',
			albumTracknameTemplate: 'Vorlage für Tracks in einem Album',
			playlistTracknameTemplate: 'Vorlage für Tracks in einer Playlist'
		},
		folders: {
			title: 'Folders',
			createPlaylistFolder: 'Ordner für Playlist erstellen',
			playlistNameTemplate: 'Vorlage für Playlist-Ordner',
			createArtistFolder: 'Ordner für Künstler erstellen',
			artistNameTemplate: 'Vorlage für Künstler-Ordner',
			createAlbumFolder: 'Ordner für Album erstellen',
			albumNameTemplate: 'Vorlage für Album-Ordner',
			createCDFolder: 'Ordner für CDs erstellen',
			createStructurePlaylist: 'Erstellen von Künstler-, Alben- und CD-Ordnern auch für Playlists',
			createSingleFolder: 'Ordner für einzelne Titel erstellen'
		},
		trackTitles: {
			title: 'Songtitel',
			padTracks: 'Einheitliche Länge der Titelnummern (voranstehende Nullen werden ergänzt)',
			paddingSize: 'Innenabstand überschreiben',
			illegalCharacterReplacer: 'Unzulässige Zeichen ersetzen'
		},
		downloads: {
			title: 'Downloads',
			queueConcurrency: 'Gleichzeitige Downloads',
			maxBitrate: {
				title: 'Bevorzugte Bitrate',
				9: 'FLAC 1411kbps',
				3: 'MP3 320kbps',
				1: 'MP3 128kbps'
			},
			overwriteFile: {
				title: 'Soll ich die Dateien überchreiben?',
				y: 'Ja überschreibe die Dateien',
				n: 'Nein überschreibe die Dateien nicht',
				t: 'Überschreibe nur die Tags',
				b: 'Nein, behalte beide Dateien und füge der Kopie eine Nummer hinzu'

			},
			fallbackBitrate: 'Falls gewünschte Bitrate nicht verfügbar, auf niedrigere Bitrate zurückgreifen',
			fallbackSearch: 'Zur Suche zurückkehren, wenn der Song nicht verfügbar ist',
			logErrors: 'Protokolldatei für Fehler im Download-Ordner erstellen',
			logSearched: 'Protokolldatei für gesuchte Titel erstellen',
			createM3U8File: 'Erstelle Playlist-Datei (M3U8)',
			syncedLyrics: 'Erstelle synchrone Lyrics-Datei (.lyr)',
			playlistFilenameTemplate: 'Vorlage für den Namen der Playlist',
			saveDownloadQueue: 'Download-Warteschlange beim Schließen der App speichern'
		},
		covers: {
			title: 'Album Cover',
			saveArtwork: 'Cover speichern',
			coverImageTemplate: 'Vorlage für den Covernamen',
			saveArtworkArtist: 'Speichere das Künstlerbild',
			artistImageTemplate: 'Vorlage des Künstlerbildes',
			localArtworkSize: 'Lokale Grafikgröße',
			embeddedArtworkSize: 'Eingebettete Grafikgröße',
			localArtworkFormat: {
				title: 'Welches Datei-Format soll das Cover haben?',
				jpg: 'Ein jpg Bild',
				png: 'Ein png Bild',
				both: 'Beides (jpg + png)'
			},
			jpegImageQuality: 'JPEG Qualität'
		},
		tags: {
			head: 'Welche Tags sollen gespeichert werden?',
			title: 'Titel',
			artist: 'Künstler',
			album: 'Album',
			cover: 'Cover',
			trackNumber: 'Titelnummer',
			trackTotal: 'Titelanzahl',
			discNumber: 'CD Nummer',
			discTotal: 'CDs insgesamt',
			albumArtist: 'Album Künstler',
			genre: 'Genre',
			year: 'Jahr',
			date: 'Datum',
			explicit: 'Explizite Lyrics',
			isrc: 'ISRC',
			length: 'Titel Länge',
			barcode: 'Album Barcode (UPC)',
			bpm: 'BPM',
			replayGain: 'Wiedergabe Lautstärke',
			label: 'Album Plattenlabel',
			lyrics: 'Nicht synchronisierte Texte',
			copyright: 'Copyright',
			composer: 'Komponist',
			involvedPeople: 'Mitwirkende Personen'
		},
		other: {
			title: 'Sonsitge',
			savePlaylistAsCompilation: 'Speichere Playlist als Zusammenstellung',
			useNullSeparator: 'Verwende Nulltrennzeichen',
			saveID3v1: 'Speichere ID3v1 ebenfalls',
			multiArtistSeparator: {
				title: 'Wie möchtest du die Künstler trennen?',
				nothing: 'Speichere nur den Hauptkünstler',
				default: 'Verwende Standard Spezifikationen',
				andFeat: 'Verwende & und feat.',
				using: 'Verwende "{separator}"'
			},
			singleAlbumArtist: 'Nur den Hauptkünstler speichern',
			albumVariousArtists: 'Verschiedene Künstler" im Album Künstler Tag behalten',
			removeAlbumVersion: 'Entferne die "Album Version" vom Songtitel',
			removeDuplicateArtists: 'Kombinationen von Künstlern entfernen',
			dateFormat: {
				title: 'Datumsformatierung für FLAC Dateien',
				year: 'JJJJ',
				month: 'MM',
				day: 'TT'
			},
			featuredToTitle: {
				title: 'Was soll ich mit featured Artists machen?',
				0: 'Nichts',
				1: 'Vom Titel entfernen',
				3: 'Vom Titel und Albumtitel entfernen',
				2: 'Zu dem Titel hinzufügen'
			},
			titleCasing: 'Titel-Schreibweise',
			artistCasing: 'Künstler-Schreibweise',
			casing: {
				nothing: 'Unbearbeitet lassen',
				lower: 'klein',
				upper: 'GROSS',
				start: 'Wortanfang Gross',
				sentence: 'Satzanfang gross'
			},
			previewVolume: 'Vorschau der Lautstärke',
			executeCommand: {
				title: 'Befehl, der nach dem Download ausgeführt werden soll',
				description: 'Leer lassen ohne Aktion'
			}
		},
		spotify: {
			title: 'Spotify Features',
			clientID: 'Spotify Client ID',
			clientSecret: 'Spotify Client Secret',
			username: 'Spotify Benutzername'
		},
		reset: 'Auf Standardwerte zurücksetzen',
		save: 'Speichern',
		toasts: {
			init: 'Einstellungen geladen!',
			update: 'Einstellungen aktualisiert!',
			ARLcopied: 'ARL wurde in die Zwischenablage kopiert'
		}
	},
	sidebar: {
		home: 'Home',
		search: 'Suche',
		charts: 'Charts',
		favorites: 'Favoriten',
		linkAnalyzer: 'Link Analyse',
		settings: 'Einstellungen',
		about: 'Info'
	},
	tracklist: {
		downloadSelection: 'Downloads'
	}
};

const fr = {
	globals: {
		welcome: 'Bienvenue dans deemix',
		back: 'retour',
		loading: 'chargement en cours',
		download: 'Télécharger {thing}',
		downloadAll: "Télécharger l'intégralité des {thing}",
		by: 'par {artist}',
		in: 'dans {album}',
		download_hint: 'Télécharger',
		play_hint: 'Lire',
		toggle_download_tab_hint: 'Développer/Réduire',
		clean_queue_hint: 'Retirer Les Tâches Terminées',
		cancel_queue_hint: 'Tout Annuler',
		open_downloads_folder: 'Ouvrir Le Dossier De Téléchargements',
		cut: 'couper',
		copy: 'copier',
		copyLink: 'copier le lien',
		copyImageLink: "copier le lien de l'image",
		copyDeezerLink: 'copier le lien deezer',
		paste: 'coller',
		listTabs: {
			empty: '',
			all: 'tout',
			top_result: 'meilleur résultat',
			album: 'album | albums',
			artist: 'artiste | artistes',
			single: 'single | singles',
			title: 'titre | titres',
			track: 'piste | pistes',
			trackN: '0 piste | {n} piste | {n} pistes',
			releaseN: '0 sortie | {n} sortie | {n} sorties',
			playlist: 'playlist | playlists',
			compile: 'compilation | compilations',
			ep: 'ep | eps',
			bundle: 'bundle | bundles',
			more: "Plus d'albums",
			featured: 'Apparaît dans',
			spotifyPlaylist: 'playlist spotify | playlists spotify',
			releaseDate: 'date de sortie',
			error: 'erreur'
		}
	},
	about: {
		updates: {
			currentVersion: 'Version Actuelle',
			versionNotAvailable: 'N/A',
			updateAvailable: "Vous n'utilisez pas la dernière version disponible : {version}",
			deemixVersion: 'Version de la bibliothèque deemix'
		},
		titles: {
			usefulLinks: 'Liens Utiles',
			bugReports: 'Rapports De Bug',
			contributing: 'Contribution',
			donations: 'Dons',
			license: 'Licence'
		},
		subtitles: {
			bugReports: 'Quelque chose ne fonctionne pas dans deemix ? Contactez-nous !',
			contributing: 'Vous souhaitez contribuer à ce projet ? Vous pouvez le faire de différentes manières !',
			donations: 'Vous souhaitez contribuer financièrement ? Vous pouvez faire un don !'
		},
		usesLibrary: 'Cette application utilise la bibliothèque <strong>deemix</strong>, que vous pouvez exploiter afin de créer votre propre interface utilisateur pour deemix.',
		thanks: "Merci à <strong>rtonno</strong>, <strong>uhwot</strong> et <strong>lollilol</strong> de m'avoir aidé dans ce projet ainsi qu'à <strong>BasCurtiz</strong> et <strong>scarvimane</strong> pour la création de l'icône.",
		upToDate: `Restez informé des mises à jour en suivant le <a href="https://t.me/RemixDevNews" target="_blank">canal d'informations</a> sur Telegram.`,
		officialWebsite: 'Site Officiel',
		officialRepo: 'Répertoire De Dépôt Officiel De La Bibliothèque',
		officialWebuiRepo: 'Répertoire De Dépôt Officiel De La WebUI',
		officialSubreddit: 'Subreddit Officiel',
		newsChannel: "Canal d'Informations",
		questions: `Si vous avez des questions ou des problèmes avec l'application, cherchez d'abord une solution dans le <a href="https://www.reddit.com/r/deemix" target="_blank">subreddit</a>. Ensuite, si la solution ne s'y trouve pas, vous pouvez publier un message dans le subreddit en décrivant votre problème.`,
		beforeReporting: "Avant de signaler un bug, assurez-vous que vous utilisez la version la plus récente de l'application. Vérifiez que vous souhaitez nous rapporter un bug et non quelque chose qui ne fonctionne pas uniquement de votre côté.",
		beSure: "Assurez-vous que le bug soit reproductible sur d'autres appareils mais aussi de <strong>NE PAS</strong> signaler un bug si celui-ci a déjà été recensé.",
		duplicateReports: "Les rapports de bug répétitifs seront supprimés, merci d'en prendre bonne note.",
		dontOpenIssues: "<strong>NE PAS</strong> rapporter de problème s'il ne s'agit que de simples questions. Un subreddit existe pour ces questions.",
		newUI: `Si vous maîtrisez python, vous pouvez essayer de créer une nouvelle interface utilisateur pour l'application à l'aide de la bibliothèque de base, ou corriger des bugs dans la bibliothèque à l'aide d'une demande de fusion de branches (pull request) sur le <a href="https://codeberg.org/RemixDev/deemix" target="_blank">répertoire de dépôt</a>.`,
		acceptFeatures: "J'accepte également les nouvelles fonctionnalités, mais pas de choses complexes, dans la mesure où elles peuvent être implémentées directement dans l'application et non dans la bibliothèque.",
		otherLanguages: "Si vous maîtrisez un autre langage de programmation, vous pouvez essayer de transposer deemix dans ce dernier !",
		understandingCode: "Vous avez besoin d'aide pour comprendre le code ? Il suffit de contacter RemixDev sur Telegram ou Reddit.",
		contributeWebUI: `Si vous vous y connaissez en Vue.js (JavaScript), HTML ou CSS, vous pouvez contribuer à la <a href="https://codeberg.org/RemixDev/deemix-webui" target="_blank">WebUI</a>.`,
		itsFree: "N'oubliez pas que <strong>ce projet est libre</strong> et qu'il est important de <strong>soutenir vos artistes préférés</strong> avant de supporter les développeurs.",
		notObligated: "Ne vous sentez pas obligé de faire un don, vous êtes tout de même apprécié !",
		lincensedUnder: `Ce projet s'inscrit dans le cadre de la
			<a rel="license" href="https://www.gnu.org/licenses/gpl-3.0.en.html" target="_blank">Licence publique générale GNU, version 3</a>.`
	},
	charts: {
		title: 'Classements',
		changeCountry: 'Changer De Pays',
		download: 'Télécharger Le Classement'
	},
	errors: {
		title: 'Erreurs pour {name}',
		ids: {
			invalidURL: "Cette URL n'est pas reconnue",
			unsupportedURL: "Cette URL n'est actuellement pas supportée",
			ISRCnotOnDeezer: "L'ISRC de la piste est indisponible sur Deezer",
			notYourPrivatePlaylist: "Vous n'êtes pas autorisé à télécharger les playlists privées de quelqu'un d'autre.",
			spotifyDisabled: 'Les Fonctionnalités Spotify ne sont pas configurées correctement.',
			trackNotOnDeezer: 'La piste est introuvable sur Deezer !',
			albumNotOnDeezer: "L'album est introuvable sur Deezer !",
			notOnDeezer: 'La piste est indisponible sur Deezer !',
			notEncoded: "La piste n'a pas encore été encodée !",
			notEncodedNoAlternative: "La piste n'a pas encore été encodée et aucune alternative n'a été trouvée !",
			wrongBitrate: 'La piste est introuvable au débit souhaité.',
			wrongBitrateNoAlternative: "La piste est introuvable au débit souhaité et aucune alternative n'a été trouvée !",
			no360RA: 'La piste est indisponible au format Reality Audio 360.',
			notAvailable: 'La piste est indisponible sur les serveurs de Deezer !',
			notAvailableNoAlternative: "La piste est indisponible sur les serveurs de Deezer et aucune alternative n'a été trouvée !",
			noSpaceLeft: "L'espace disponible sur cet appareil est insuffisant !",
			albumDoesntExists: "Aucun album n'existe pour cette piste, impossible de collecter les informations nécessaires"
		}
	},
	favorites: {
		title: 'Favoris',
		noPlaylists: "Aucune Playlist n'a été trouvée",
		noAlbums: "Aucun Album Favori n'a été trouvé",
		noArtists: "Aucun Artiste Favori n'a été trouvé",
		noTracks: "Aucune Piste Favorite n'a été trouvée"
	},
	home: {
		needTologin: 'Vous devez vous connecter à votre compte Deezer avant de pouvoir démarrer un téléchargement.',
		openSettings: 'Ouvrir Les Paramètres',
		sections: {
			popularPlaylists: 'Playlists les plus écoutées',
			popularAlbums: 'Albums les plus écoutés'
		}
	},
	linkAnalyzer: {
		info: "Vous pouvez utiliser cette section pour obtenir davantage d'informations sur le lien que vous essayez de télécharger.",
		useful:
			"C'est utile si vous essayez, par exemple, de télécharger des pistes indisponibles dans votre pays et que vous souhaitez savoir où elles sont disponibles.",
		linkNotSupported: "Ce lien n'est pas encore pris en charge",
		linkNotSupportedYet: "Il semble que ce lien ne soit pas encore pris en charge, essayez d'en analyser un autre.",
		table: {
			id: 'ID',
			isrc: 'ISRC',
			upc: 'UPC',
			duration: 'Durée',
			diskNumber: 'Numéro De Disque',
			trackNumber: 'Numéro De Piste',
			releaseDate: 'Date De Sortie',
			bpm: 'BPM',
			label: 'Label',
			recordType: "Type d'Enregistrement",
			genres: 'Genres',
			tracklist: 'Liste Des Pistes'
		}
	},
	search: {
		startSearching: 'Démarrer une recherche !',
		description:
			'Vous pouvez rechercher une piste, un album entier, un artiste, une playlist... tout ce que vous voulez ! Vous pouvez également coller un lien Deezer.',
		fans: '{n} fans',
		noResults: 'Aucun résultat',
		noResultsTrack: "Aucune piste n'a été trouvée",
		noResultsAlbum: "Aucun album n'a été trouvé",
		noResultsArtist: "Aucun artiste n'a été trouvé",
		noResultsPlaylist: "Aucune playlist n'a été trouvée"
	},
	searchbar: 'Saisissez une requête (ou collez simplement un lien)',
	downloads: 'téléchargements',
	toasts: {
		restoringQueue: "Restauration de la file d'attente de téléchargement...",
		queueRestored: "La file d'attente de téléchargement a été restaurée !",
		addedToQueue: "{item} ajouté à la file d'attente",
		addedMoreToQueue: "{n} éléments ajoutés à la file d'attente",
		alreadyInQueue: "{item} est déjà dans la file d'attente !",
		finishDownload: '{item} a été téléchargé.',
		allDownloaded: 'Tous les téléchargements sont terminés !',
		refreshFavs: 'Actualisation terminée !',
		loggingIn: 'Connexion en cours...',
		loggedIn: 'Connecté',
		alreadyLogged: 'Déjà connecté',
		loginFailed: 'Connexion impossible',
		loggedOut: 'Déconnecté',
		cancellingCurrentItem: "Annulation de l'élément actuel.",
		currentItemCancelled: 'Élément actuel annulé.',
		startAddingArtist: "Ajout des albums de {artist} à la file d'attente",
		finishAddingArtist: "Les albums de {artist} ont été ajoutés à la file d'attente",
		startConvertingSpotifyPlaylist: 'Conversion de pistes Spotify en équivalents Deezer',
		finishConvertingSpotifyPlaylist: 'Playlist Spotify convertie',
		loginNeededToDownload: 'Vous devez vous connecter pour pouvoir télécharger des pistes !',
		deezerNotAvailable: 'Deezer est indisponible dans votre pays. Vous devez utiliser un VPN.',
		startGeneratingItems: 'Traitement de {n} éléments...',
		finishGeneratingItems: '{n} éléments ont été générés.'
	},
	settings: {
		title: 'Paramètres',
		languages: 'Langues',
		login: {
			title: 'Connexion',
			loggedIn: 'Vous êtes connecté en tant que {username}',
			arl: {
				question: 'Comment obtenir mon ARL personnel ?',
				update: "Mettre à jour l'ARL"
			},
			logout: 'Déconnexion',
			login: 'Connexion via deezer.com'
		},
		appearance: {
			title: 'Apparence',
			slimDownloadTab: 'Onglet de téléchargement compact'
		},
		downloadPath: {
			title: 'Emplacement De Téléchargement'
		},
		templates: {
			title: 'Modèles',
			tracknameTemplate: 'Modèle pour le nom de piste',
			albumTracknameTemplate: "Modèle pour le nom de piste de l'album",
			playlistTracknameTemplate: 'Modèle pour le nom de piste de la playlist'
		},
		folders: {
			title: 'Dossiers',
			createPlaylistFolder: 'Générer des dossiers par playlist',
			playlistNameTemplate: 'Modèle pour le nom du dossier de playlist',
			createArtistFolder: 'Générer des dossiers par artiste',
			artistNameTemplate: "Modèle pour le nom du dossier d'artiste",
			createAlbumFolder: 'Générer des dossiers par album',
			albumNameTemplate: "Modèle pour le nom du dossier d'album",
			createCDFolder: 'Générer des dossiers par CD',
			createStructurePlaylist: 'Générer une structure de dossiers pour les playlists',
			createSingleFolder: 'Générer une structure de dossiers pour les singles'
		},
		trackTitles: {
			title: 'Titres des pistes',
			padTracks: "Longueur uniforme des numéros de piste (ajoute automatiquement des zéros devant le numéro initial de la piste)",
			paddingSize: 'Nombre de zéros à ajouter en permanence devant le numéro initial de la piste',
			illegalCharacterReplacer: "Substitut aux caractères non autorisés (dans les noms de fichiers et de dossiers)"
		},
		downloads: {
			title: 'Téléchargements',
			queueConcurrency: 'Téléchargements Simultanés',
			maxBitrate: {
				title: 'Débit Préféré',
				9: 'FLAC 1411kbps',
				3: 'MP3 320kbps',
				1: 'MP3 128kbps'
			},
			overwriteFile: {
				title: 'Les fichiers doivent-ils être écrasés ?',
				y: 'Oui, écraser le fichier',
				n: 'Non, ne pas écraser le fichier',
				t: 'Écraser uniquement les métadonnées',
				b: 'Non, conserver les deux fichiers et ajouter un numéro au doublon',
				e: "Non, et ne pas tenir compte de l'extension du fichier"
			},
			fallbackBitrate: "Recourir à un débit plus faible si le débit préféré n'est pas disponible",
			fallbackSearch: "Rechercher la piste si le lien original n'est pas disponible",
			logErrors: "Créer un fichier journal d'erreurs",
			logSearched: 'Créer un fichier journal des pistes recherchées',
			createM3U8File: 'Créer un fichier de playlist',
			syncedLyrics: 'Créer des fichiers .lyr (Paroles Synchronisées)',
			playlistFilenameTemplate: 'Modèle du nom de fichier de la playlist',
			saveDownloadQueue: "Enregistrer la file d'attente de téléchargement à la fermeture de l'application"
		},
		covers: {
			title: "Pochettes d'albums",
			saveArtwork: 'Enregistrer Les Pochettes',
			coverImageTemplate: 'Modèle pour le nom de la pochette',
			saveArtworkArtist: "Enregistrer l'image de l'artiste",
			artistImageTemplate: "Modèle pour le nom de l'image de l'artiste",
			localArtworkSize: "Taille de l'illustration locale",
			embeddedArtworkSize: "Taille de l'illustration incorporée aux fichiers audio",
			localArtworkFormat: {
				title: "Dans quel format souhaitez-vous l'illustration locale ?",
				jpg: 'Une image jpeg',
				png: 'Une image png',
				both: 'À la fois jpeg et png'
			},
			jpegImageQuality: "Qualité de l'image JPEG",
			embeddedArtworkPNG: "Enregistrer l'illustration incorporée aux fichiers audio en tant que PNG",
			embeddedPNGWarning: 'Les images PNG ne sont pas officiellement utilisées par Deezer et pourraient causer des problèmes.',
			imageSizeWarning: "Toute valeur supérieure à x1200 n'est pas officiellement supportée par Deezer, vous pourriez donc rencontrer des problèmes.",
			coverDescriptionUTF8: 'Enregistrer la description de la pochette au format UTF8 (iTunes Cover Fix)'
		},
		tags: {
			head: 'Métadonnées à sauvegarder',
			title: 'Titre',
			artist: 'Artiste',
			album: 'Album',
			cover: 'Pochette',
			trackNumber: 'Numéro De Piste',
			trackTotal: 'Nombre De Pistes',
			discNumber: 'Numéro Du Disque',
			discTotal: 'Nombre De Disques',
			albumArtist: "Artiste De l'Album",
			genre: 'Genre',
			year: 'Année',
			date: 'Date',
			explicit: 'Paroles Explicites',
			isrc: 'ISRC',
			length: 'Longueur De La Piste',
			barcode: "Code-Barres De l'Album (UPC)",
			bpm: 'BPM',
			replayGain: 'Gain En Relecture (Replay Gain)',
			label: "Label De l'Album",
			lyrics: 'Paroles Non-Synchronisées',
			syncedLyrics: 'Paroles Synchronisées',
			copyright: "Droits d'Auteur (Copyright)",
			composer: 'Compositeur',
			involvedPeople: 'Personnes Impliquées'
		},
		other: {
			title: 'Autre',
			savePlaylistAsCompilation: 'Enregistrer les playlists en tant que compilation',
			useNullSeparator: 'Utiliser le caractère NULL comme séparateur',
			saveID3v1: 'Enregistrer également les métadonnées ID3v1',
			multiArtistSeparator: {
				title: 'Comment aimeriez-vous séparer les artistes ?',
				nothing: "Enregistrer uniquement l'artiste principal",
				default: 'En utilisant la spécification standard',
				andFeat: 'En utilisant & et feat.',
				using: 'En utilisant "{separator}"'
			},
			singleAlbumArtist: "Enregistrer uniquement l'artiste principal de l'album",
			albumVariousArtists: `Conserver "Various Artists" dans les Artistes de l'Album`,
			removeAlbumVersion: `Supprimer "Album Version" du titre de la piste`,
			removeDuplicateArtists: "Supprimer les combinaisons d'artistes",
			dateFormat: {
				title: 'Format de date pour les fichiers FLAC',
				year: 'AAAA',
				month: 'MM',
				day: 'JJ'
			},
			featuredToTitle: {
				title: 'Que faire des artistes participants (featuring) ?',
				0: 'Ne rien faire',
				1: 'Les retirer du titre de la piste',
				3: "Les supprimer du titre de la piste et du titre de l'album",
				2: 'Les déplacer vers le titre de la piste'
			},
			titleCasing: 'Casse pour le titre',
			artistCasing: "Casse pour l'artiste",
			casing: {
				nothing: 'Conserver inchangé',
				lower: 'minuscules',
				upper: 'MAJUSCULES',
				start: 'Majuscule Au Début De Chaque Mot',
				sentence: 'Majuscule seulement au début de la phrase'
			},
			previewVolume: 'Volume sonore des aperçus de pistes',
			executeCommand: {
				title: 'Commande à exécuter après le téléchargement',
				description: "Laisser vide pour qu'aucune action n'ait lieu"
			}
		},
		spotify: {
			title: 'Fonctionnalités Spotify',
			clientID: 'clientID Spotify',
			clientSecret: 'Client Secret Spotify',
			username: "Nom d'utilisateur Spotify",
			question: 'Comment activer les Fonctionnalités Spotify ?'
		},
		reset: 'Rétablir les valeurs par défaut',
		save: 'Sauvegarder',
		toasts: {
			init: 'Paramètres chargés !',
			update: 'Paramètres mis à jour !',
			ARLcopied: 'ARL copié dans le presse-papier'
		}
	},
	sidebar: {
		home: 'accueil',
		search: 'recherche',
		charts: 'classements',
		favorites: 'favoris',
		linkAnalyzer: 'analyseur de lien',
		settings: 'paramètres',
		about: 'à propos'
	},
	tracklist: {
		downloadSelection: 'Télécharger la sélection'
	}
};

const id = {
	globals: {
		welcome: 'Selamat datang di deemix',
		back: 'kembali',
		loading: 'memuat',
		download: 'Mengunduh {thing}',
		by: 'oleh {artist}',
		in: 'di {album}',
		download_hint: 'Unduh',
		play_hint: 'Putar',
		toggle_download_tab_hint: 'Buka/Tutup',
		clean_queue_hint: 'Berhasil Mengosongkan',
		cancel_queue_hint: 'Batalkan Semua',
		listTabs: {
			empty: '',
			all: 'semua',
			top_result: 'hasil teratas',
			album: 'album | album',
			artist: 'artis | artis',
			single: 'singel | singel',
			title: 'judul | judul',
			track: 'lagu | lagu',
			trackN: '0 lagu | {n} lagu | {n} lagu',
			releaseN: '0 rilis | {n} rilis | {n} rilis',
			playlist: 'daftar putar | daftar putar',
			compile: 'kompilasi | kompilasi',
			ep: 'ep | ep',
			spotifyPlaylist: 'daftar putar spotify | daftar putar spotify',
			releaseDate: 'tanggal rilis',
			error: 'galat'
		}
	},
	about: {
		titles: {
			usefulLinks: 'Tautan Berguna',
			bugReports: 'Laporan Kesalahan',
			contributing: 'Kontirbutor',
			donations: 'Donasi',
			license: 'Lisensi'
		},
		subtitles: {
			bugReports: "Ada yang tidak bekerja dengan baik di deemix? Beri tahu kami!",
			contributing: 'Mau kontribusi dalam proyek ini? Kamu bisa lakukan dengan banyak hal!',
			donations: 'Mau kontribusi secara finansial? Kamu bisa beri donasi!'
		},
		usesLibrary: 'Aplikasi ini menggunakan pustaka <strong>deemix</strong>, yang bisa kamu gunakan untuk membuat UI deemix milikmu sendiri.',
		thanks: `Terima kasih kepada <strong>rtonno</strong>, <strong>uhwot</strong> dan <strong>lollilol</strong> yang telah membantuku dalam proyek ini, serta kepada <strong>BasCurtiz</strong> dan <strong>scarvimane</strong> yang telah membuat ikon.`,
		upToDate: `Ikuti <a href="https://t.me/RemixDevNews" target="_blank">kanal berita deemix</a> di Telegram agar tidak ketinggalan berita terbaru.`,
		officialWebsite: 'Situs Web Resmi',
		officialRepo: 'Repositori Pustaka Resmi',
		officialWebuiRepo: 'Repositori WebUI Resmi',
		officialSubreddit: 'Subreddit Resmi',
		newsChannel: 'Kanal Berita',
		questions: `Kalau kamu punya pertanyaan atau masalah dengan aplikasi ini, tolong cari solusinya di <a href="https://www.reddit.com/r/deemix" target="_blank">subreddit</a> kami terlebih dahulu. Kalau memang tidak ada, silakan buat pos baru berisikan persoalan tersebut.`,
		beforeReporting: `Sebelum melaporkan masalah, pastikan kamu sudah memakai versi aplikasi terbaru dan hal yang akan kamu laporkan memang bukan kesalahan dari pihak kamu sendiri.`,
		beSure: `Pastikan masalah tersebut bisa diemulasikan di mesin lain, dan juga <strong>JANGAN</strong> laporkan masalah yang sudah dilaporkan sebelumnya.`,
		duplicateReports: 'Laporan duplikat akan kami tutup, jadi perhatikan baik-baik.',
		dontOpenIssues: `<strong>JANGAN</strong> buka issue baru untuk mengirimkan pertanyaan, silakan lakukan di subreddit.`,
		newUI: `Kalau kamu mahir pada python, kamu bisa coba membuat UI baru untuk aplikasi ini menggunakan pustaka dasar, atau membenarkan masalah di pustaka kami dengan melakukan pull request pada <a href="https://codeberg.org/RemixDev/deemix" target="_blank">repo</a> kami.`,
		acceptFeatures: `Kami juga menerima fitur baru, tapi jangan yang terlalu kompleks, karena hal itu lebih baik diimplementasikan langsung di aplikasi daripada di pustaka.`,
		otherLanguages: `Kalau kamu mahir dengan bahasa pemrograman lain, kamu bisa coba mentransfer deemix ke bahasa tersebut!`,
		understandingCode: `Butuh bantuan untuk memahami kode deemix? Kontak RemixDev di Telegram atau Reddit.`,
		contributeWebUI: `Kalau kamu paham Vue.js (JavaScript), HTML, atau CSS, kamu bisa berkontribusi pada <a href="https://codeberg.org/RemixDev/deemix-webui" target="_blank">WebUI</a>.`,
		itsFree: `Perlu diingat bahwa <strong>ini adalah proyek gratis</strong> dan <strong>dukung artis idolamu terlebih dahulu</strong> sebelum mendukung kami sebagai pengembang aplikasi.`,
		notObligated: `Jangan merasa terpaksa untuk menyumbang, kami tetap menghargai kamu!`,
		lincensedUnder: `Pekerjaan ini ada di bawah lisensi
			<a rel="license" href="https://www.gnu.org/licenses/gpl-3.0.en.html" target="_blank"
				>GNU General Public License 3.0</a
			>.`
	},
	charts: {
		title: 'Tangga Lagu',
		changeCountry: 'Ubah Negara',
		download: 'Unduh Tangga Lagu'
	},
	errors: {
		title: 'Galat untuk {name}',
		ids: {
			invalidURL: 'URL tidak dikenal',
			unsupportedURL: 'URL belum didukung',
			ISRCnotOnDeezer: 'Lagu ISRC tidak tersedia di deezer',
			notYourPrivatePlaylist: "Kamu tidak bisa mengunduh daftar putar privat orang lain.",
			spotifyDisabled: 'Fitur Spotify tidak diatur dengan benar.',
			trackNotOnDeezer: 'Lagu tidak ditemukan di deezer!',
			albumNotOnDeezer: 'Album tidak ditemukan di deezer!',
			notOnDeezer: 'Lagu tidak ada di Deezer!',
			notEncoded: 'Lagu belum di-encode!',
			notEncodedNoAlternative: 'Lagu belum di-encode dan tidak ada alternatif lain!',
			wrongBitrate: 'Lagu tidak tersedia pada bitrate yang diinginkan.',
			wrongBitrateNoAlternative: 'Lagu tidak tersedia pada bitrate yang diinginkan dan tidak ada alternatif lain!',
			no360RA: 'Lagu tidak tersedia pada Reality Audio 360.',
			notAvailable: "Lagu tidak tersedia pada server deezer!",
			notAvailableNoAlternative: "Lagu tidak tersedia pada server deezer dan tidak ada alternatif lain!"
		}
	},
	favorites: {
		title: 'Favorit',
		noPlaylists: 'Daftar Putar kosong',
		noAlbums: 'Album Favorit kosong',
		noArtists: 'Artis Favorit kosong',
		noTracks: 'Lagu Favorit kosong'
	},
	home: {
		needTologin: 'Kamu harus masuk ke akun Deezer kamu sebelum bisa memulai pengunduhan.',
		openSettings: 'Buka Pengaturan',
		sections: {
			popularPlaylists: 'Daftar putar populer',
			popularAlbums: 'Album paling banyak diputar'
		}
	},
	linkAnalyzer: {
		info: 'Di sini, kamu bisa mencari informasi lebih lanjut tentang tautan yang ingin kamu unduh.',
		useful:
			"Contohnya, ini dapat berguna jika kamu ingin mengunduh lagu yang tidak tersedia di negaramu dan ingin tahu di negara mana lagu itu tersedia.",
		linkNotSupported: 'Tautan seperti ini belum didukung',
		linkNotSupportedYet: 'Sepertinya tautan ini belum didukung, silakan coba analisa tautan lain.',
		table: {
			id: 'ID',
			isrc: 'ISRC',
			upc: 'UPC',
			duration: 'Durasi',
			diskNumber: 'Nomor Disk',
			trackNumber: 'Nomor Lagu',
			releaseDate: 'Tanggal Rilis',
			bpm: 'BPM',
			label: 'Label',
			recordType: 'Tipe Rekaman',
			genres: 'Genre',
			tracklist: 'Daftar Lagu'
		}
	},
	search: {
		startSearching: 'Mulai cari!',
		description:
			'Kamu bisa mencari lagu, album, artis, daftar putar.... apa pun! Kamu juga bisa memberikan tautan Deezer',
		fans: '{n} fan',
		noResults: 'Tak ada hasil',
		noResultsTrack: 'Lagu tidak ditemukan',
		noResultsAlbum: 'Album tidak ditemukan',
		noResultsArtist: 'Artis tidak ditemukan',
		noResultsPlaylist: 'Daftar putar tidak ditemukan'
	},
	searchbar: 'Cari apa pun yang kamu mau (atau berikan tautannya saja)',
	downloads: 'unduhan',
	toasts: {
		addedToQueue: '{item} ditambah ke antrian',
		alreadyInQueue: '{item} sudah ada di antrian!',
		finishDownload: '{item} selesai diunduh.',
		allDownloaded: 'Seluruh unduhan selesai!',
		refreshFavs: 'Penyegaran selesai!',
		loggingIn: 'Masuk',
		loggedIn: 'Telah masuk',
		alreadyLogged: 'Telah masuk',
		loginFailed: "Tidak bisa masuk",
		loggedOut: 'Belum masuk',
		cancellingCurrentItem: 'Membatalkan item.',
		currentItemCancelled: 'Item telah dibatalan.',
		startAddingArtist: 'Menambahkan {artist} album ke antrian',
		finishAddingArtist: '{artist} album telah ditambahkan ke antrian',
		startConvertingSpotifyPlaylist: 'Mengonversi lagu spotify ke deezer',
		finishConvertingSpotifyPlaylist: 'Daftar putar Spotify selesai dikonversi'
	},
	settings: {
		title: 'Pengaturan',
		languages: 'Bahasa',
		login: {
			title: 'Masuk',
			loggedIn: 'Kamu telah masuk sebagai {username}',
			arl: {
				question: 'Bagaimana cara mendapat ARL?',
				update: 'Perbarui ARL'
			},
			logout: 'Keluar'
		},
		appearance: {
			title: 'Tampilan',
			slimDownloadTab: 'Tab unduhan ramping'
		},
		downloadPath: {
			title: 'Direktori Unduhan'
		},
		templates: {
			title: 'Templat',
			tracknameTemplate: 'Templat judul lagu',
			albumTracknameTemplate: 'Templat judul album',
			playlistTracknameTemplate: 'Templat judul daftar putar'
		},
		folders: {
			title: 'Folders',
			createPlaylistFolder: 'Buat folder untuk daftar putar',
			playlistNameTemplate: 'Templat folder daftar putar',
			createArtistFolder: 'Buat folder untuk artis',
			artistNameTemplate: 'Templat folder artis',
			createAlbumFolder: 'Buat folder untuk album',
			albumNameTemplate: 'Templat folder album',
			createCDFolder: 'Buat folder untuk CD',
			createStructurePlaylist: 'Buat struktur folder untuk daftar putar',
			createSingleFolder: 'Buat struktur folder untuk singel'
		},
		trackTitles: {
			title: 'Judul lagu',
			padTracks: 'Judul pad',
			paddingSize: 'Timpa ukuran padding',
			illegalCharacterReplacer: 'Pengubah Simbol Tak Terdukung'
		},
		downloads: {
			title: 'Unduhan',
			queueConcurrency: 'Unduhan Bersamaan',
			maxBitrate: {
				title: 'Bitrate Prioritas',
				9: 'FLAC 1411kbps',
				3: 'MP3 320kbps',
				1: 'MP3 128kbps'
			},
			overwriteFile: {
				title: 'Apakah file mau ditimpa?',
				y: 'Ya, silakan',
				n: "Tidak, jangan ditimpa",
				t: 'Timpa tag-nya saja'
			},
			fallbackBitrate: 'Rendahkan bitrate',
			fallbackSearch: 'Cari bitrate lebih rendah',
			logErrors: 'Buat file log untuk galat',
			logSearched: 'Buat file log untuk lagu yang dicari',
			createM3U8File: 'Buat file daftar putar',
			syncedLyrics: 'Buat file .lyr (Sinkronisasikan Lirik)',
			playlistFilenameTemplate: 'Templat nama file untuk daftar putar',
			saveDownloadQueue: 'Simpan antrian pengunduhan saat menutup aplikasi'
		},
		covers: {
			title: 'Sampul album',
			saveArtwork: 'Simpan Sampul',
			coverImageTemplate: 'Templat nama sampul',
			saveArtworkArtist: 'Simpan gambar artis',
			artistImageTemplate: 'Templat gambar artis',
			localArtworkSize: 'Ukuran sampul lokal',
			embeddedArtworkSize: 'Ukuran sampul tertanam',
			localArtworkFormat: {
				title: 'Format gambar apa yang kamu mau untuk sampul lokal?',
				jpg: 'Gambar JPEG',
				png: 'Gambar PNG',
				both: 'Keduanya'
			},
			jpegImageQuality: 'Kualitas gambar JPEG'
		},
		tags: {
			head: 'Tag apa saja yang disimpan?',
			title: 'Judul',
			artist: 'Artis',
			album: 'Album',
			cover: 'Sampul',
			trackNumber: 'Nomor Lagu',
			trackTotal: 'Jumlah Lagu',
			discNumber: 'Nomor Disk',
			discTotal: 'Jumlah Disk',
			albumArtist: 'Artis pada Album',
			genre: 'Genre',
			year: 'Tahun',
			date: 'Tanggal',
			explicit: 'Lirik Eksplisit',
			isrc: 'ISRC',
			length: 'Durasi',
			barcode: 'Barcode Album (UPC)',
			bpm: 'BPM',
			replayGain: 'Replay Gain',
			label: 'Label Album',
			lyrics: 'Lirik Tak Tersinkronisasi',
			copyright: 'Hak Cipta',
			composer: 'Komposer',
			involvedPeople: 'Orang-Orang Terlibat'
		},
		other: {
			title: 'Lainnya',
			savePlaylistAsCompilation: 'Simpan daftar putar sebagai kompilasi',
			useNullSeparator: 'Gunakan separator null',
			saveID3v1: 'Simpan juga ID3v1',
			multiArtistSeparator: {
				title: 'Bagaimana kamu mau memisahkan nama artis?',
				nothing: 'Simpan artis utamanya saja',
				default: 'Gunakan spesifikasi standard',
				andFeat: 'Gunakan & dan feat.',
				using: 'Gunakan "{separator}"'
			},
			singleAlbumArtist: 'Simpan artis utama saja',
			albumVariousArtists: 'Simpan "Various Artists" sebagai artis',
			removeAlbumVersion: 'Hapus "Versi Album" dari judul lagu',
			removeDuplicateArtists: 'Hapus kombinasi artis',
			dateFormat: {
				title: 'Format tanggal untuk file FLAC',
				year: 'YYYY',
				month: 'MM',
				day: 'DD'
			},
			featuredToTitle: {
				title: 'Apa yang harus dilakukan jika ada artis kedua?',
				0: 'Biarkan saja',
				1: 'Hapus dari judul lagu',
				3: 'Hapus dari judul lagu dan judul album',
				2: 'Pindahkan ke judul lagu'
			},
			titleCasing: 'Kapitalisasi judul',
			artistCasing: 'Kapitalisasi album',
			casing: {
				nothing: 'Biarkan seadanya',
				lower: 'huruf kecil',
				upper: 'HURUF KAPITAL',
				start: 'Setiap Awal Kata',
				sentence: 'Huruf pertama saja'
			},
			previewVolume: 'Pratinjau volume',
			executeCommand: {
				title: 'Perintah yang dijalankan setelah pengunduhan',
				description: 'Biarkan kosong jika tidak ada'
			}
		},
		spotify: {
			title: 'Fitur Spotify',
			clientID: 'clientID Spotify ',
			clientSecret: 'Client Secret Spotify ',
			username: 'Username Spotify'
		},
		reset: 'Kembalikan ke Awal',
		save: 'Simpan',
		toasts: {
			init: 'Pengaturan dimuat!',
			update: 'Pengaturan diperbarui!',
			ARLcopied: 'ARL tersalin ke papan klip'
		}
	},
	sidebar: {
		home: 'utama',
		search: 'cari',
		charts: 'tangga lagu',
		favorites: 'favorit',
		linkAnalyzer: 'penganalisa tautan',
		settings: 'pengaturan',
		about: 'tentang'
	},
	tracklist: {
		downloadSelection: 'Seleksi unduhan'
	}
};

const pt = {
    globals: {
        welcome: 'Bem-vindo ao deemix',
        back: 'voltar',
        loading: 'A carregar',
        download: 'Transferir {thing}',
        by: 'por {artist}',
        in: 'em {album}',
        download_hint: 'Transferir',
        play_hint: 'Tocar',
        toggle_download_tab_hint: 'Expandir/Recolher',
        clean_queue_hint: 'Limpar Finalizados',
        cancel_queue_hint: 'Cancelar Tudo',
        listTabs: {
            empty: '',
            all: 'Tudo',
            top_result: 'melhor resultado',
            album: 'álbum | álbums',
            artist: 'artista | artistas',
            single: 'single | singles',
            title: 'título | títulos',
            track: 'faixa | faixas',
            trackN: '0 faixas | {n} faixa | {n} faixas',
            releaseN: '0 lançamentos | {n} lançamento | {n} lançamento',
            playlist: 'lista de reprodução | listas de reprodução',
            compile: 'compilação | compilações',
            ep: 'ep | eps',
            spotifyPlaylist: 'lista de reprodução spotify | listas de reprodução spotify',
            releaseDate: 'data de lançamento',
            error: 'erro'
        }
    },
    about: {
        titles: {
            usefulLinks: 'Links Úteis',
            bugReports: 'Relatório de erros',
            contributing: 'Contribuir',
            donations: 'Doações',
            license: 'Licenças'
        },
        subtitles: {
            bugReports: 'Existe alguma coisa que não funciona no deemix? Informa-nos!',
            contributing: 'Queres contribuir para o projecto? Podes fazê-lo de diferentes formas!',
            donations: 'Desejas contribuir monetariamente? Faz uma doação!'
        },
        usesLibrary: 'Esta aplicação usa a biblioteca <strong>deemix</strong>, que poderás usar para desenvolver o teu proprio UI para o deemix.',
        thanks: `Agradeço a <strong>rtonno</strong>, <strong>uhwot</strong> and <strong>lollilol</strong> por me ajudarem neste projeto e a <strong>BasCurtiz</strong> and <strong>scarvimane</strong> por elaborarem o ícone.`,
        upToDate: `Mantem-te atualizado seguindo o <a href="https://t.me/RemixDevNews" target="_blank">canal de notícias</a> no Telegram.`,
        officialWebsite: 'Site Oficial',
        officialRepo: 'Repositório Oficial da Biblioteca',
        officialWebuiRepo: 'Repositório Oficial WebUI',
        officialSubreddit: 'Subreddit Oficial',
        newsChannel: 'Canal de Notícias',
        questions: `Caso tenhas alguma duvida ou problema com a app, primeiro procura por uma solução no <a href="https://www.reddit.com/r/deemix" target="_blank">subreddit</a>. Caso não encontres nada podes criar um post com a tua questão no subreddit.`,
        beforeReporting: `Antes de reportares um bug certifica-te que estás a correr a versão mais recente e que o que queres reportar é mesmo um bug e não algo que apenas não funciona do teu lado.`,
        beSure: `Certifica-te que o erro é reprodutivel noutros dispositivos e <strong>NÃO</strong> reportes um bug que já tenha sido reportado.`,
        duplicateReports: 'Bug reports duplicados serão fechados, mantém-te atento a isso.',
        dontOpenIssues: `<strong>NÃO</strong> abras issues para colocar questões, existe um subreddit para isso.`,
        newUI: `Caso sejas fluente em python podes tentar criar um novo UI para a aplicação recorrendo à biblioteca base , ou corrigir erros na biblioteca com um pull request no <a href="https://codeberg.org/RemixDev/deemix" target="_blank">repositório</a>.`,
        acceptFeatures: `Também aceito funcionalidades não complexas caso possam ser implementadas directamente na app e não na biblioteca.`,
        otherLanguages: `Caso sejas fluente noutra linguagem de programação podes tentar migrar o deemix para outra linguagem de programação!`,
        understandingCode: `Precisas de ajuda a entender o código? Acede a RemixDev no Telegram ou no Reddit.`,
        contributeWebUI: `Caso saibas Vue.js (JavaScript), HTML ou CSS podes contribuir para o <a href="https://codeberg.org/RemixDev/deemix-webui" target="_blank">WebUI</a>.`,
        itsFree: `Deves ter em conta que <strong>que este projecto é gratuito</strong> e <strong>deverás apoiar os artistas que aprecias</strong> antes de apoiares os programadores.`,
        notObligated: `Não te sintas obrigado a doar, agradeço-te na mesma!`,
        lincensedUnder: `Este trabalho esta licenciado sobre a
            <a rel="license" href="https://www.gnu.org/licenses/gpl-3.0.en.html" target="_blank"
                >GNU Licença publica geral  3.0</a
            >.`
    },
    charts: {
        title: 'Tabelas',
        changeCountry: 'Alterar país',
        download: 'Transferir tabela'
    },
    errors: {
        title: 'Erros para {name}',
        ids: {
            invalidURL: 'URL não reconhecido',
            unsupportedURL: 'URL ainda não suportado',
            ISRCnotOnDeezer: 'Faixa ISRC não disponível no deezer',
            notYourPrivatePlaylist: "Nao podes baixar listas de reprodução privadas de outros.",
            spotifyDisabled: 'Funcionalidades do Spotify não estão definidas corretamente.',
            trackNotOnDeezer: 'Faixa não encontrada no deezer!',
            albumNotOnDeezer: 'Álbum não encontrado no deezer!',
            notOnDeezer: 'Faixa não encontrada no Deezer!',
            notEncoded: 'Faixa ainda não codificada!',
            notEncodedNoAlternative: 'Faixa ainda não codificada e não foi encontrada alternativa!',
            wrongBitrate: 'Faixa não encontrada no bitrate desejado.',
            wrongBitrateNoAlternative: 'Faixa não encontrada no bitrate desejado e não foi encontrada alternativa!',
            no360RA: 'Faixa não disponível em Reality Audio 360.',
            notAvailable: 'Faixa não disponível nos servidores do deezer!',
            notAvailableNoAlternative: 'Faixa não disponível nos servidores do deezer e não foi encontrada alternativa!'
        }
    },
    favorites: {
        title: 'Favoritos',
        noPlaylists: 'Listas de reprodução não encontradas',
        noAlbums: 'Álbuns favoritos não encontrados',
        noArtists: 'Artistas favoritos não encontrados',
        noTracks: 'Faixas favoritas não encontradas'
    },
    home: {
        needTologin: 'Antes de iniciar transferências é necessário efectuar autenticação na conta Deezer.',
        openSettings: 'Abrir Definições',
        sections: {
            popularPlaylists: 'Listas de reprodução populares',
            popularAlbums: 'Álbuns mais ouvidos'
        }
    },
    linkAnalyzer: {
        info: 'Podes usar esta secção para obteres mais informação sobre o link que estás a tentar transferir.',
        useful: 'Isto é útil caso estejas a tentar transferir faixas que não estão disponíveis no teu país e queres saber onde estão disponíveis, por exemplo.',
        linkNotSupported: 'Este link ainda não é suportado',
        linkNotSupportedYet: 'Parece que este link ainda não é suportado, tenta analisar outro.',
        table: {
            id: 'ID',
            isrc: 'ISRC',
            upc: 'UPC',
            duration: 'Duração',
            diskNumber: 'Número do disco',
            trackNumber: 'Número da faixa',
            releaseDate: 'Data de lançamento',
            bpm: 'BPM',
            label: 'Editora',
            recordType: 'Tipo de Disco',
            genres: 'Géneros',
            tracklist: 'Lista de faixas'
        }
    },
    search: {
        startSearching: 'Começa a pesquisar!',
        description: 'Podes perquisar uma música, um álbum inteiro, um artista, uma lista de reprodução... tudo! Também podes colar um link do Deezer',
        fans: '{n} fãs',
        noResults: 'Sem resultados',
        noResultsTrack: 'Faixa não encontrada',
        noResultsAlbum: 'Álbum não encontrado',
        noResultsArtist: 'Artista não encontrado',
        noResultsPlaylist: 'Lista de reprodução não encontrada'
    },
    searchbar: 'Pesquisa o que quiseres (ou cola um link)',
    downloads: 'transferências',
    toasts: {
        addedToQueue: '{item} adicionados à fila',
        alreadyInQueue: '{item} já está na fila!',
        finishDownload: '{item} foi transferido.',
        allDownloaded: 'Todas as transferências terminadas!',
        refreshFavs: 'Actualizar terminados!',
        loggingIn: 'A autenticar',
        loggedIn: 'Autenticado',
        alreadyLogged: 'Já estás autenticado',
        loginFailed: "Nao foi possivel iniciar sessão",
        loggedOut: 'Desconectado',
        cancellingCurrentItem: 'A cancelar item actual.',
        currentItemCancelled: 'Item actual cancelado.',
        startAddingArtist: 'A adicionar {artist} álbuns à fila',
        finishAddingArtist: 'Adicionados {artist} álbuns à fila',
        startConvertingSpotifyPlaylist: 'A converter faixas do spotify em faixas do deezer',
        finishConvertingSpotifyPlaylist: 'Lista de reprodução do Spotify convertida.'
    },
    settings: {
        title: 'Definições',
        languages: 'Idioma',
        login: {
            title: 'Inicio de Sessão',
            loggedIn: 'Estás autenticado como {username}',
            arl: {
                question: 'Como obter o meu ARL?',
                update: 'Actualizar ARL'
            },
            logout: 'Sair'
        },
        appearance: {
            title: 'Aspecto',
            slimDownloadTab: 'Aba de transferências estreita'
        },
        downloadPath: {
            title: 'Caminho das transferências'
        },
        templates: {
            title: 'Formatos',
            tracknameTemplate: 'Formato do nome de faixa',
            albumTracknameTemplate: 'Formato do nome de Álbum',
            playlistTracknameTemplate: 'Formato do nome de lista de reprodução'
        },
        folders: {
            title: 'Pastas',
            createPlaylistFolder: 'Criar pasta para lista de reprodução',
            playlistNameTemplate: 'Formato da pasta de lista de reprodução',
            createArtistFolder: 'Criar pasta para artista',
            artistNameTemplate: 'Formato da pasta de artista',
            createAlbumFolder: 'Criar pasta para álbum',
            albumNameTemplate: 'Formato da pasta de álbum',
            createCDFolder: 'Criar pasta para CDs',
            createStructurePlaylist: 'Criar estrutura de pastas para listas reprodução',
            createSingleFolder: 'Criar estrutura de pastas para singles'
        },
        trackTitles: {
            title: 'Título',
            padTracks: 'Bloco de Faixas',
            paddingSize: 'Substituir tamanho do preenchimento',
            illegalCharacterReplacer: 'Substituir caractere inválido'
        },
        downloads: {
            title: 'Transferências',
            queueConcurrency: 'Transferências concorrentes',
            maxBitrate: {
                title: 'Bitrate preferencial',
                9: 'FLAC 1411kbps',
                3: 'MP3 320kbps',
                1: 'MP3 128kbps'
            },
            overwriteFile: {
                title: 'Ficheiros existentes. Substituir?',
                y: 'Sim, substituir o ficheiro',
                n: 'Não substituir o ficheiro',
                t: 'Subescrever apenas as etiquetas'
            },
            fallbackBitrate: 'Bitrate fallback',
            fallbackSearch: 'Fallback de pesquisa',
            logErrors: 'Criar histórico para erros',
            logSearched: 'Criar histórico para faixas pesquisadas',
            createM3U8File: 'Criar ficheiro de lista de reprodução',
            syncedLyrics: 'Criar ficheiro .lyr (Letra Sincronizada)',
            playlistFilenameTemplate: 'Formato do nome de ficheiro da lista de reprodução',
            saveDownloadQueue: 'Guardar fila de transferências ao fechar a aplicação'
        },
        covers: {
            title: 'Capas do Álbum',
            saveArtwork: 'Guardar capas',
            coverImageTemplate: 'Modelo do nome da capa',
            saveArtworkArtist: 'Salvar imagem do artista',
            artistImageTemplate: 'Modelo de imagem do artista',
            localArtworkSize: 'Tamanho do trabalho artístico local',
            embeddedArtworkSize: 'Tamanho do trabalho artístico incorporado',
            localArtworkFormat: {
                title: 'Em que formato desejas o trabalho artístico local?',
                jpg: 'Em imagem jpeg',
                png: 'Em imagem png',
                both: 'Em jpeg e em png'
            },
            jpegImageQuality: 'Qualidade de imagem JPEG'
        },
        tags: {
            head: 'Etiquetas a guardar',
            title: 'Título',
            artist: 'Artista',
            album: 'Álbum',
            cover: 'Capa',
            trackNumber: 'Número de faixa',
            trackTotal: 'Total de faixas',
            discNumber: 'Número do Disco',
            discTotal: 'Total de Discos',
            albumArtist: 'Artista do Álbum',
            genre: 'Género',
            year: 'Ano',
            date: 'Data',
            explicit: 'Letra Explícita',
            isrc: 'ISRC',
            length: 'Duração da faixa',
            barcode: 'Código de barras do álbum (UPC)',
            bpm: 'BPM',
            replayGain: 'ReplayGain',
            label: 'Editora do álbum',
            lyrics: 'Letra da música não sincronizada',
            copyright: 'Direitos de Autor',
            composer: 'Compositor',
            involvedPeople: 'Pessoas envolvidas'
        },
        other: {
            title: 'Outros',
            savePlaylistAsCompilation: 'Guardar listas de reprodução como compilação',
            useNullSeparator: 'Usar separador nulo',
            saveID3v1: 'Também guardar ID3v1',
            multiArtistSeparator: {
                title: 'Como queres separarar os artistas?',
                nothing: 'Guardar apenas o artista principal',
                default: 'Usar especificação padrão',
                andFeat: 'Usar & e feat.',
                using: 'Usar "{separator}"'
            },
            singleAlbumArtist: 'Guardar apenas o artista principal do álbum',
            albumVariousArtists: 'Manter "Various Artists" nos Artistas do Álbum',
            removeAlbumVersion: 'Remover "Album Version" do título da faixa',
            removeDuplicateArtists: 'Remover combinação de artistas',
            dateFormat: {
                title: 'Formato de data nos ficheiros FLAC',
                year: 'AAAA',
                month: 'MM',
                day: 'DD'
            },
            featuredToTitle: {
                title: 'O que devo fazer com artistas convidados/participações?',
                0: 'Nada',
                1: 'Remover do título',
                3: 'Remover do título e do título do album',
                2: 'Movê-lo para o título'
            },
            titleCasing: 'Caixa do Título',
            artistCasing: 'Caixa do Artista',
            casing: {
                nothing: 'Manter inalterado',
                lower: 'minusculas',
                upper: 'MAIÚSCULAS',
                start: 'Início De Cada Palavra',
                sentence: 'Como uma frase'
            },
            previewVolume: 'Volume de Pré-visualização',
            executeCommand: {
                title: 'Comando a executar após transferir',
                description: 'Deixar em branco para nenhuma acção'
            }
        },
        spotify: {
            title: 'Funcionalidades Spotify',
            clientID: 'Spotify clientID',
            clientSecret: 'Spotify Client Secret',
            username: 'nome de utilizador Spotify'
        },
        reset: 'Repor configurações padrão',
        save: 'Guardar',
        toasts: {
            init: 'Configurações carregadas!',
            update: 'Configurações actualizadas',
            ARLcopied: 'ARL copiado para area de transferencia'
        }
    },
    sidebar: {
        home: 'início',
        search: 'pesquisa',
        charts: 'tabelas',
        favorites: 'favoritos',
        linkAnalyzer: 'analizador de links',
        settings: 'definições',
        about: 'sobre'
    },
    tracklist: {
        downloadSelection: 'Transferir seleccionados'
    }
};

const pt_br = {
	globals: {
		welcome: 'bem vindo ao deemix',
		back: 'voltar',
		loading: 'carregando',
		download: 'Baixar {thing}',
		by: 'por {artist}',
		in: 'em {album}',
		download_hint: 'Baixar',
		play_hint: 'Reproduzir',
		toggle_download_tab_hint: 'Expandir/Diminuir',
		clean_queue_hint: 'Limpar',
		cancel_queue_hint: 'Cancelar Todos',
		listTabs: {
			empty: '',
			all: 'todos',
			top_result: 'resultado principal',
			album: 'álbum | álbuns',
			artist: 'artista | artistas',
			single: 'single | singles',
			title: 'título | títulos',
			track: 'faixa | faixas',
			trackN: '0 faixas | {n} faixa | {n} faixas',
			releaseN: '0 lançamento | {n} lançamento | {n} lançamentos',
			playlist: 'playlist | playlists',
			compile: 'compilação | compilações',
			ep: 'ep | eps',
			spotifyPlaylist: 'playlist do spotify | playlists do spotify',
			releaseDate: 'data de lançamento',
			error: 'erro'
		}
	},
	about: {
		titles: {
			usefulLinks: 'Links Úteis',
			bugReports: 'Relatar Bugs',
			contributing: 'Contribuições',
			donations: 'Doações',
			license: 'Licença'
		},
		subtitles: {
			bugReports: 'Há algo não funcionando no deemix? Nos diga!',
			contributing: 'Você quer contribuir para este projeto? Você pode fazer isso de diferentes maneiras!',
			donations: 'Você quer contribuir monetariamente? Você pode fazer uma doação!'
		},
		usesLibrary:
			'Esse app usa a biblioteca do <strong>deemix</strong>, no qual você pode usar para criar sua própria UI para o deemix',
		thanks: `Agradecimentos para <strong>rtonno</strong>, <strong>uhwot</strong> e <strong>lollilol</strong> por ajudar neste projeto, e para <strong>BasCurtiz</strong> e <strong>scarvimane</strong> por fazerem o ícone`,
		upToDate: `Para mais novidades siga o <a href="https://t.me/RemixDevNews" target="_blank">news channel</a> no Telegram.`,
		officialWebsite: 'Site Oficial',
		officialRepo: 'Repositório da Biblioteca Oficial',
		officialWebuiRepo: 'Repositório da WebUI Oficial',
		officialSubreddit: 'Subreddit Oficial',
		newsChannel: 'Canal de Notícias',
		questions: `Se você tiver dúvidas ou problemas com o app, procure uma solução em <a href="https://www.reddit.com/r/deemix" target="_blank">subreddit</a> primeiro. Caso você não encontre, você pode fazer um post explicando seu problema no subreddit. `,
		beforeReporting: `Antes de reportar um bug, tenha certeza que você está rodando a versão mais recente do app, e o que você quer reportar seja realmente um bug e não algo que esteja acontecendo especialmente com você.`,
		beSure: `Certifique-se que o bug é reproduzivel em outras máquinas e também <strong>NÃO</strong> reporte um bug se ele já foi reportado.`,
		duplicateReports: 'Reportes de bugs duplicados serão fechados, então fique atento a isso.',
		dontOpenIssues: `<strong>NÃO</strong> abra tópicos para fazer perguntas, há o subreddit para isso.`,
		newUI: `Se você é fluente em Phython, você pode tentar fazer uma nova UI para o app usando a biblioteca base, ou consertar bugs da biblioteca com um pull request em <a href="https://codeberg.org/RemixDev/deemix" target="_blank">repo</a>.`,
		acceptFeatures: `Eu aceito funcionalidades extras também, mas nada de coisas complexas, desde que ela possa ser implementada no app, e não na biblioteca.`,
		otherLanguages: `Se você for fluente em outra linguagem de programação, você pode tentar portar o deemix para outra linguagem!`,
		understandingCode: `Você precisa de ajuda para entender o código? Mande mensagem no RemixDex pelo Telegram ou pelo Reddit.`,
		contributeWebUI: `Se você souber Vue.js (JavaScript), HTML ou CSS você pode contribuir para o <a href="https://codeberg.org/RemixDev/deemix-webui" target="_blank">WebUI</a>.`,
		itsFree: `Lembre-se que <strong>este projeto é livre</strong> e <strong>você deve dar suporte aos artistas que você ama</strong> antes de dar suporte aos desenvolvedores.`,
		notObligated: `Não se sinta na obrigação de doar, eu agradeço de qualquer maneira!`,
		lincensedUnder: `Esse é um projeto licenciado através da
			<a rel="license" href="https://www.gnu.org/licenses/gpl-3.0.en.html" target="_blank"
				>GNU General Public License 3.0</a
			>.`
	},
	charts: {
		title: 'Charts',
		changeCountry: 'Mudar País',
		download: 'Download Chart'
	},
	errors: {
		title: 'Erros para {name}',
		ids: {
			invalidURL: 'URL inválida',
			unsupportedURL: 'URL não suportada ainda',
			ISRCnotOnDeezer: 'Faixa ISRC não está disponível ainda no deezer',
			notYourPrivatePlaylist: 'Você não pode baixar playlists privadas.',
			spotifyDisabled: 'Os Recursos do Spotify não foram configurados corretamente.',
			trackNotOnDeezer: 'Faixa não encontrada no deezer!',
			albumNotOnDeezer: 'Album not found on deezer! Álbum não encontrado no deezer!',
			notOnDeezer: 'Faixa indisponível no deezer!',
			notEncoded: 'Faixa ainda não codificada!',
			notEncodedNoAlternative: 'Faixa ainda não codificada e sem alternativas encontradas!',
			wrongBitrate: 'Faixa não encontrada no bitrate desejado.',
			wrongBitrateNoAlternative: 'Faixa não encontrada no bitrate desejado e nenhuma outra alternativa encontrada!',
			no360RA: 'Faixa não disponível na qualidade Reality Audio 360.',
			notAvailable: 'Faixa não disponível nos servidores do deezer!',
			notAvailableNoAlternative: 'Faixa não disponível nos servidores do deezer e nenhuma outra alternativa encontrada!'
		}
	},
	favorites: {
		title: 'Favoritos',
		noPlaylists: 'Nenhuma Playlist encontrada',
		noAlbums: 'Nenhum Álbum Favorito encontrado',
		noArtists: 'Nenhum Artista Favorito encontrado',
		noTracks: 'Nenhuma Faixa Favorita encontrada'
	},
	home: {
		needTologin: 'Você precisa logar na sua conta do deezer antes de começar a baixar músicas.',
		openSettings: 'Abrir Configurações',
		sections: {
			popularPlaylists: 'Playlists Populares',
			popularAlbums: 'Álbuns mais ouvidos'
		}
	},
	linkAnalyzer: {
		info: 'Você pode usar essa seção para encontrar mais informações sobre o link que você quer baixar.',
		useful:
			'Isso é útil se você está tentando baixar algumas faixas que não estão disponíveis no seu país, e quer saber onde elas estão disponíveis, por exemplo.',
		linkNotSupported: 'Esse link não é suportado ainda',
		linkNotSupportedYet: 'Parece que esse link não é suportado ainda, tente analizar outro.',
		table: {
			id: 'ID',
			isrc: 'ISRC',
			upc: 'UPC',
			duration: 'Duração',
			diskNumber: 'Número do Disco',
			trackNumber: 'Número da Faixa',
			releaseDate: 'Data de Lançamento',
			bpm: 'BPM',
			label: 'Gravadora',
			recordType: 'Tipo de Gravação',
			genres: 'Gêneros',
			tracklist: 'Tracklist'
		}
	},
	search: {
		startSearching: 'Comece pesquisando!',
		description:
			'Você pode pesquisar uma música, um álbum, um artista, uma playlist.... tudo! Você também pode colar um link do Deezer',
		fans: '{n} fãs',
		noResults: 'Sem resultados',
		noResultsTrack: 'Nenhuma Faixa encontrada',
		noResultsAlbum: 'Nenhum Álbum encontrado',
		noResultsArtist: 'Nenhum Artista encontrado',
		noResultsPlaylist: 'Nenhuma Playlist encontrada'
	},
	searchbar: 'Pesquise algo (ou apenas cole um link)',
	downloads: 'downloads',
	toasts: {
		addedToQueue: '{item} adicionado à fila',
		alreadyInQueue: '{item} já está na fila!',
		finishDownload: '{item} download terminado.',
		allDownloaded: 'Todos os downloads foram feitos!',
		refreshFavs: 'Atualização completa!',
		loggingIn: 'Logando',
		loggedIn: 'Logado',
		alreadyLogged: 'Você já está logado',
		loginFailed: 'Não foi possivel entrar',
		loggedOut: 'Desconectando',
		cancellingCurrentItem: 'Cancelando item atual.',
		currentItemCancelled: 'Item atual cancelado.',
		startAddingArtist: 'Adicionando {artist} álbuns à fila',
		finishAddingArtist: '{artist} álbuns adicionados a fila',
		startConvertingSpotifyPlaylist: 'Convertendo faixas do spotify para faixas do deezer',
		finishConvertingSpotifyPlaylist: 'Playlists do Spotify convertidas'
	},
	settings: {
		title: 'Configurações',
		languages: 'Idiomas',
		login: {
			title: 'Login',
			loggedIn: 'Você está logado como {username}',
			arl: {
				question: 'Como eu consigo o meu ARL?',
				update: 'Atualizar ARL'
			},
			logout: 'Sair'
		},
		appearance: {
			title: 'Aparência',
			slimDownloadTab: 'Aba de download slim'
		},
		downloadPath: {
			title: 'Diretório de Downloads'
		},
		templates: {
			title: 'Templates',
			tracknameTemplate: 'Template do nome da faixa',
			albumTracknameTemplate: 'Template da faixa do álbum',
			playlistTracknameTemplate: 'Template da faixa da playlist'
		},
		folders: {
			title: 'Pastas',
			createPlaylistFolder: 'Criar pasta para playlists',
			playlistNameTemplate: 'Template da pasta de playlist',
			createArtistFolder: 'Criar pasta para os artistas',
			artistNameTemplate: 'Template da pasta de artistas',
			createAlbumFolder: 'Criar pasta para álbuns',
			albumNameTemplate: 'Template da pasta de álbuns',
			createCDFolder: 'Criar pasta para CDs',
			createStructurePlaylist: 'Criar estrutura de pastas para playlists',
			createSingleFolder: 'Criar estrutura de pastas para singles'
		},
		trackTitles: {
			title: 'Título das faixas',
			padTracks: 'Faixas com pad',
			paddingSize: 'Sobrescrever tamanho do padding',
			illegalCharacterReplacer: 'Substituir caracteres inválidos'
		},
		downloads: {
			title: 'Downloads',
			queueConcurrency: 'Downloads Simultâneos',
			maxBitrate: {
				title: 'Escolher Taxa de Bits',
				9: 'FLAC 1411kbps',
				3: 'MP3 320kbps',
				1: 'MP3 128kbps'
			},
			overwriteFile: {
				title: 'Sobrescrever arquivos?',
				y: 'Sim, sobrescrever arquivos',
				n: 'Não, não sobrescrever arquivos',
				t: 'Sobrescrever apenas as tags'
			},
			fallbackBitrate: 'Taxa de bits reserva',
			fallbackSearch: 'Procurar reserva',
			logErrors: 'Criar arquivos de log para erros',
			logSearched: 'Criar arquivos de log para faixas pesquisadas',
			createM3U8File: 'Criar arquivo de playlist',
			syncedLyrics: 'Criar arquivos .lyr (Letras)',
			playlistFilenameTemplate: 'Template do nome do arquivo da playlist',
			saveDownloadQueue: 'Salvar a fila de downloads quando fechar o app'
		},
		covers: {
			title: 'Capa dos álbuns',
			saveArtwork: 'Salvar capas',
			coverImageTemplate: 'Template do nome da capa',
			saveArtworkArtist: 'Salvar imagem do artista',
			artistImageTemplate: 'Template da imagem do artista',
			localArtworkSize: 'Tamanho da capa local',
			embeddedArtworkSize: 'Tamanho da capa embutida',
			localArtworkFormat: {
				title: 'Qual o formato da imagem que você quer para a capa local?',
				jpg: '.jpeg',
				png: '.png',
				both: 'Ambas, .jpeg e .png'
			},
			jpegImageQuality: 'Qualidade da imagem JPEG'
		},
		tags: {
			head: 'Quais tags salvar',
			title: 'Título',
			artist: 'Artista',
			album: 'Álbum',
			cover: 'Capa',
			trackNumber: 'Número da Faixa',
			trackTotal: 'Total de Faixas',
			discNumber: 'Número de Discos',
			discTotal: 'Total de Discos',
			albumArtist: 'Artista do Álbum',
			genre: 'Gênero',
			year: 'Ano',
			date: 'Data',
			explicit: 'Letras Explícitas',
			isrc: 'ISRC',
			length: 'Tamanho da Faixa',
			barcode: 'Código de Barras do álbum (UPC)',
			bpm: 'BPM',
			replayGain: 'Replay Gain',
			label: 'Gravadora',
			lyrics: 'Letras Dessincronizadas',
			copyright: 'Copyright',
			composer: 'Compositor',
			involvedPeople: 'Pessoas Envolvidas'
		},
		other: {
			title: 'Outros',
			savePlaylistAsCompilation: 'Salvar playlists como uma compilação',
			useNullSeparator: 'Usar separador nulo',
			saveID3v1: 'Salvar ID3v1',
			multiArtistSeparator: {
				title: 'Como você gostaria de separar os artistas?',
				nothing: 'Salvar apenas o artista principal',
				default: 'Usar a especificação padrão',
				andFeat: 'Usar & e feat.',
				using: 'Usar "{separator}"'
			},
			singleAlbumArtist: 'Salvar apenas o artista principal',
			albumVariousArtists: 'Manter "Various Artists" nos Artistas do Álbum',
			removeAlbumVersion: 'Remover "Album Version" do título da faixa',
			removeDuplicateArtists: 'Remover combinação de artistas',
			dateFormat: {
				title: 'Formato da data para arquivos FLAC',
				year: 'AAAA',
				month: 'MM',
				day: 'DD'
			},
			featuredToTitle: {
				title: 'O que devo fazer com artistas participantes?',
				0: 'Nada',
				1: 'Remova do título da faixa',
				3: 'Remova do título da faixa e do álbum',
				2: 'Mover para o título da faixa'
			},
			titleCasing: 'Formatação do título',
			artistCasing: 'Formatação do artista',
			casing: {
				nothing: 'Manter inalterado',
				lower: 'minúsculo',
				upper: 'MAIÚSCULO',
				start: 'Começo De Cada Palavra',
				sentence: 'Como uma frase'
			},
			previewVolume: 'Prévia do Volume',
			executeCommand: {
				title: 'Comando para executar depois de baixar',
				description: 'Deixe em branco para nenhuma ação'
			}
		},
		spotify: {
			title: 'Recursos do Spotify',
			clientID: 'Spotify clientID',
			clientSecret: 'Spotify Client Secret',
			username: 'usuário do Spotify'
		},
		reset: 'Restaurar para o padrão',
		save: 'Salvar',
		toasts: {
			init: 'Configurações carregadas!',
			update: 'Configurações atualizadas!',
			ARLcopied: 'ARL copiada para a área de transferência'
		}
	},
	sidebar: {
		home: 'início',
		search: 'pesquisa',
		charts: 'charts',
		favorites: 'favoritos',
		linkAnalyzer: 'analizador de links',
		settings: 'configurações',
		about: 'sobre'
	},
	tracklist: {
		downloadSelection: 'Baixar seleção'
	}
};

const ru = {
	globals: {
		welcome: 'Добро пожаловать в deemix',
		back: 'назад',
		loading: 'загрузка',
		download: 'Скачать {thing}',
		by: '{artist}',
		in: 'из {album}',
		download_hint: 'Скачать',
		play_hint: 'Прослушать',
		toggle_download_tab_hint: 'Показать/Скрыть',
		clean_queue_hint: 'Очистить завершённые',
		cancel_queue_hint: 'Очистить всё',
		open_downloads_folder: 'Открыть папку с загрузками',
		cut: 'вырезать',
		copy: 'копировать',
		copyLink: 'копировать ссылку',
		copyImageLink: 'копировать URL картинки',
		copyDeezerLink: 'копировать ссылку deezer',
		paste: 'вставить',
		listTabs: {
			empty: '',
			all: 'все',
			top_result: 'лучший результат',
			album: 'альбом | альбомы | альбомы',
			artist: 'исполнитель | исполнители | исполнители',
			single: 'сингл | синглы | синглы',
			title: 'название',
			track: 'трек | треки | треки',
			trackN: '{n} трек | {n} трека | {n} треков',
			releaseN: '{n} релиз | {n} релиза | {n} релизов',
			playlist: 'плейлист | плейлисты | плейлисты',
			compile: 'сплит | сплиты | сплиты',
			ep: 'ep',
			bundle: 'бандл | бандлы | бандлы',
			more: 'Больше альбомов',
			featured: 'Представлено в',
			spotifyPlaylist: 'плейлист spotify | плейлисты spotify | плейлисты spotify',
			releaseDate: 'Дата выхода',
			error: 'ошибка'
		}
	},
	about: {
		updates: {
			currentVersion: 'Текущая версия',
			versionNotAvailable: 'Н/Д',
			updateAvailable: `Вы используете не последнюю доступную версию: {version}`,
			deemixVersion: 'Версия библиотеки deemix'
		},
		titles: {
			usefulLinks: 'Полезные ссылки',
			bugReports: 'Отчёты об ошибках',
			contributing: 'Помощь проекту',
			donations: 'Пожертвования',
			license: 'Лицензия'
		},
		subtitles: {
			bugReports: "Что-то не работает? Сообщите нам!",
			contributing: 'Хотите внести вклад в развитие этого проекта? Это можно сделать разными способами!',
			donations: 'Хотите поддержать материально? Можно сделать пожертвование!'
		},
		usesLibrary: 'Приложение использует библиотеку <strong>deemix</strong>, с помощью которой вы можете разработать собственный UI для deemix.',
		thanks: `Спасибо <strong>rtonno</strong>, <strong>uhwot</strong> и <strong>lollilol</strong> за помощь с этим проектом, а также <strong>BasCurtiz</strong> и <strong>scarvimane</strong> за иконку.`,
		upToDate: `Следите за последними обновлениями на <a href="https://t.me/RemixDevNews" target="_blank">канале</a> в Telegram.`,
		officialWebsite: 'Официальный сайт',
		officialRepo: 'Официальный репозиторий библиотеки',
		officialWebuiRepo: 'Официальный репозиторий WebUI',
		officialSubreddit: 'Официальный сабреддит',
		newsChannel: 'Канал новостей',
		questions: `Если у вас возникли вопросы или проблемы с приложением, поищите решение на <a href="https://www.reddit.com/r/deemix" target="_blank">сабреддите</a>. Если не нашли решение, можете создать новый пост и описать вашу проблему.`,
		beforeReporting: `Перед тем, как сообщать об ошибках, убедитесь, что вы используете последнюю версию приложения и что проблема не на вашей стороне.`,
		beSure: `Убедитесь, что ошибка возникает и на других устройствах. Также <strong>НЕ</strong> сообщайте об ошибке, если про неё уже известно.`,
		duplicateReports: 'Повторные сообщения об ошибках рассматриваться не будут.',
		dontOpenIssues: `<strong>НЕ</strong> используйте репозиторий для вопросов автору, для этого есть сабреддит.`,
		newUI: `Если вы хорошо знаете python, то можете сделать новый UI для приложения с использованием базовой библиотеки или пофиксить в ней баги и сделать pull request в <a href="https://codeberg.org/RemixDev/deemix" target="_blank">репозитории</a>.`,
		acceptFeatures: `Можете предложить новые функции, но не слишком сложные, так как они будут добавлены в приложение, а не в саму библиотеку.`,
		otherLanguages: `Если вы хорошо знаете другой язык программирования, можете портировать на нём deemix!`,
		understandingCode: `Не можете разобраться в коде? Свяжитесь с RemixDev в Telegram или на Reddit.`,
		contributeWebUI: `Если вы знаете Vue.js (JavaScript), HTML или CSS, можете внести вклад в развитие <a href="https://codeberg.org/RemixDev/deemix-webui" target="_blank">WebUI</a>.`,
		itsFree: `Помните, что это <strong>бесплатное приложение</strong> и вам следует <strong>поддерживать понравившихся исполнителей</strong> прежде, чем поддерживать разработчиков.`,
		notObligated: `Вы не обязаны делать пожертвования, я всё равно вас ценю!`,
		lincensedUnder: `Проект распространяется под лицензией
			<a rel="license" href="https://www.gnu.org/licenses/gpl-3.0.en.html" target="_blank">GNU General Public License 3.0</a>.`
	},
	charts: {
		title: 'Чарты',
		changeCountry: 'Сменить страну',
		download: 'Скачать чарт'
	},
	errors: {
		title: 'Ошибки {name}',
		ids: {
			invalidURL: 'URL не распознан',
			unsupportedURL: 'URL не поддерживается',
			ISRCnotOnDeezer: 'ISRC данного трека недоступен на Deezer',
			notYourPrivatePlaylist: "Вы не можете скачивать чужие приватные плейлисты.",
			spotifyDisabled: 'Неправильно настроены параметры Spotify.',
			trackNotOnDeezer: 'Трек не найден на Deezer!',
			albumNotOnDeezer: 'Альбом не найден на Deezer!',
			notOnDeezer: 'Трек недоступен на Deezer!',
			notEncoded: 'Трек ещё не перекодирован!',
			notEncodedNoAlternative: 'Трек не перекодирован, альтернатив не найдено!',
			wrongBitrate: 'Данного трека нет в нужном битрейте.',
			wrongBitrateNoAlternative: 'Данного трека нет в нужном битрейте. Альтернатив не найдено!',
			no360RA: 'Трек недоступен в формате Reality Audio 360.',
			notAvailable: "Трек недоступен на серверах Deezer!",
			notAvailableNoAlternative: "Трек недоступен на серверах Deezer. Альтернатив не найдено!",
			noSpaceLeft: "На устройстве не осталось свободного места!"
		}
	},
	favorites: {
		title: 'Избранное',
		noPlaylists: 'Плейлисты не найдены',
		noAlbums: 'Избранные альбомы не найдены',
		noArtists: 'Избранные исполнители не найдены',
		noTracks: 'Избранные треки не найдены'
	},
	home: {
		needTologin: 'Вам необходимо войти под своей учетной записью Deezer, прежде чем вы сможете скачивать.',
		openSettings: 'Открыть настройки',
		sections: {
			popularPlaylists: 'Популярные плейлисты',
			popularAlbums: 'Самые прослушиваемые альбомы'
		}
	},
	linkAnalyzer: {
		info: 'Используйте этот раздел, чтобы узнать информацию о ссылке, которую требуется скачать.',
		useful: "Этот раздел нужен, если вы хотите загрузить треки, недоступные в вашей стране, а также посмотреть, где они доступны.",
		linkNotSupported: 'Ссылка не поддерживается',
		linkNotSupportedYet: 'Эта ссылка не поддерживается, попробуйте вставить другую.',
		table: {
			id: 'ID',
			isrc: 'ISRC',
			upc: 'UPC',
			duration: 'Продолжительность',
			diskNumber: 'Номер диска',
			trackNumber: 'Номер трека',
			releaseDate: 'Дата выхода',
			bpm: 'BPM',
			label: 'Издатель',
			recordType: 'Тип',
			genres: 'Жанр',
			tracklist: 'Треклист'
		}
	},
	search: {
		startSearching: 'Начните искать!',
		description: 'Здесь можно найти трек, альбом, исполнителя, плейлист... всё! Можно также вставить ссылку Deezer',
		fans: '{n} поклонников',
		noResults: 'Нет результатов',
		noResultsTrack: 'Треков не найдено',
		noResultsAlbum: 'Альбомов не найдено',
		noResultsArtist: 'Исполнителей не найдено',
		noResultsPlaylist: 'Плейлистов не найдено'
	},
	searchbar: 'Ищите, что хотите (или вставьте ссылку)',
	downloads: 'загрузки',
	toasts: {
		restoringQueue: 'Восстановление очереди загрузок...',
		queueRestored: 'Очередь восстановлена!',
		addedToQueue: '{item} добавлено в очередь',
		addedMoreToQueue: '{n} загрузок добавлены в очередь',
		alreadyInQueue: '{item} уже присутствует в очереди!',
		finishDownload: 'Загрузка {item} завершена.',
		allDownloaded: 'Все загрузки завершены!',
		refreshFavs: 'Обновление завершено!',
		loggingIn: 'Вход...',
		loggedIn: 'Вход выполнен',
		alreadyLogged: 'Вход уже выполнен',
		loginFailed: "Вход не выполнен",
		loggedOut: 'Вы вышли из аккаунта',
		cancellingCurrentItem: 'Отмена текущей загрузки.',
		currentItemCancelled: 'Отменено.',
		startAddingArtist: 'Добавление альбомов {artist} в очередь',
		finishAddingArtist: 'Альбомы {artist} добавлены в очередь',
		startConvertingSpotifyPlaylist: 'Добавление плейлиста Spotify в очередь',
		finishConvertingSpotifyPlaylist: 'Spotify плейлист добавлен в очередь',
		loginNeededToDownload: 'Войдите в аккаунт, чтобы скачивать треки!'
	},
	settings: {
		title: 'Настройки',
		languages: 'Язык',
		login: {
			title: 'Вход',
			loggedIn: 'Вы вошли как {username}',
			arl: {
				question: 'Как узнать свой ARL?',
				update: 'Обновить ARL'
			},
			logout: 'Выйти',
			login: 'Войти через deezer.com'
		},
		appearance: {
			title: 'Внешний вид',
			slimDownloadTab: 'Компактная вкладка с загрузками'
		},
		downloadPath: {
			title: 'Путь для сохранения'
		},
		templates: {
			title: 'Шаблоны',
			tracknameTemplate: 'Шаблон названия трека',
			albumTracknameTemplate: 'Шаблон названия трека альбома',
			playlistTracknameTemplate: 'Шаблон названия трека плейлиста'
		},
		folders: {
			title: 'Папки',
			createPlaylistFolder: 'Создавать папки для плейлистов',
			playlistNameTemplate: 'Название папки плейлиста',
			createArtistFolder: 'Создавать папки для исполнителя',
			artistNameTemplate: 'Название папки исполнителя',
			createAlbumFolder: 'Создавать папки для альбома',
			albumNameTemplate: 'Название папки альбома',
			createCDFolder: 'Создавать папки для CD',
			createStructurePlaylist: 'Создавать структуру папок для плейлистов',
			createSingleFolder: 'Создавать структуру папок для синглов'
		},
		trackTitles: {
			title: 'Названия треков',
			padTracks: 'Добавлять ноль к номерам треков (01, 02, ...)',
			paddingSize: 'Кол-во цифр в номере',
			illegalCharacterReplacer: 'Замена для запрещённых в имени символов'
		},
		downloads: {
			title: 'Загрузки',
			queueConcurrency: 'Количество одновременных загрузок',
			maxBitrate: {
				title: 'Предпочитаемый битрейт',
				9: 'FLAC 1411kbps',
				3: 'MP3 320kbps',
				1: 'MP3 128kbps'
			},
			overwriteFile: {
				title: 'Нужно ли перезаписывать файлы?',
				y: 'Да, перезаписать файл',
				n: "Нет, не перезаписывать",
				t: 'Обновить только теги',
				b: 'Нет, оставить оба файла и добавить номер к дубликату',
				e: "Нет, вне зависимости от расширения"
			},
			fallbackBitrate: 'Загружать с битрейтом ниже, если текущий недоступен',
			fallbackSearch: 'Искать похожий трек, если запрашиваемый недоступен',
			logErrors: 'Сохранять логи ошибок',
			logSearched: 'Сохранять лог истории поиска',
			createM3U8File: 'Создавать файлы плейлистов',
			syncedLyrics: 'Создать .lyr файлы (синхронизированная лирика)',
			playlistFilenameTemplate: 'Шаблон названия плейлиста',
			saveDownloadQueue: 'Сохранять текущую очередь загрузок при закрытии приложения'
		},
		covers: {
			title: 'Обложки',
			saveArtwork: 'Сохранять файл обложки',
			coverImageTemplate: 'Шаблон названия обложки',
			saveArtworkArtist: 'Сохранять файл изображения исполнителя',
			artistImageTemplate: 'Шаблон названия изображения',
			localArtworkSize: 'Размер сохраненной обложки',
			embeddedArtworkSize: 'Размер встроенной в теги обложки',
			localArtworkFormat: {
				title: 'В каком формате сохранять обложки?',
				jpg: 'jpeg',
				png: 'png',
				both: 'jpeg и png'
			},
			jpegImageQuality: 'Качество JPEG',
			embeddedArtworkPNG: 'Сохранять вложенную обложку в PNG',
			embeddedPNGWarning: 'PNG официально не поддерживается в Deezer. Могут быть баги',
			imageSizeWarning: 'Обложки с разрешением выше x1200 не поддерживаются в Deezer. Могут быть проблемы'
		},
		tags: {
			head: 'Какие теги сохранять',
			title: 'Название',
			artist: 'Исполнитель',
			album: 'Альбом',
			cover: 'Обложка',
			trackNumber: 'Номер трека',
			trackTotal: 'Кол-во треков',
			discNumber: 'Номер диска',
			discTotal: 'Кол-во дисков',
			albumArtist: 'Исполнитель альбома',
			genre: 'Жанр',
			year: 'Год',
			date: 'Дата',
			explicit: 'Метка о нецензурной лексике',
			isrc: 'Номер записи (ISRC)',
			length: 'Продолжительность',
			barcode: 'Уникальный код альбома (UPC)',
			bpm: 'BPM',
			replayGain: 'Replay Gain',
			label: 'Издатель',
			lyrics: 'Текст песни',
			syncedLyrics: 'Синхрон. текст песни',
			copyright: 'Права (копирайт)',
			composer: 'Композитор',
			involvedPeople: 'Вовлечённые люди'
		},
		other: {
			title: 'Разное',
			savePlaylistAsCompilation: 'Сохранять плейлисты как сборники',
			useNullSeparator: 'Использовать null в качестве разделителя',
			saveID3v1: 'Сохранять ID3v1',
			multiArtistSeparator: {
				title: 'Как разделять несколько исполнителей?',
				nothing: 'Сохранить только основного',
				default: 'Используя стандартную спецификацию',
				andFeat: 'Используя & и feat.',
				using: 'Используя "{separator}"'
			},
			singleAlbumArtist: 'Сохранить только основного исполнителя альбома',
			albumVariousArtists: 'Оставить "Various Artists" в исполнителях альбома',
			removeAlbumVersion: 'Удалить "Album Version" из названия трека',
			removeDuplicateArtists: 'Удалить повторяющихся исполнителей',
			dateFormat: {
				title: 'Формат даты для FLAC файлов',
				year: 'ГГГГ',
				month: 'ММ',
				day: 'ДД'
			},
			featuredToTitle: {
				title: 'Что делать с приглашёнными исполнителями (feat.)?',
				0: 'Ничего',
				1: 'Удалить из названия трека',
				3: 'Удалить из названия трека и альбома',
				2: 'Добавить в название трека'
			},
			titleCasing: 'Регистр названия',
			artistCasing: 'Регистр исполнителя',
			casing: {
				nothing: 'Не менять',
				lower: 'в нижнем регистре',
				upper: 'В ВЕРХНЕМ РЕГИСТРЕ',
				start: 'Каждое Слово С Заглавной Буквы',
				sentence: 'Как в предложении'
			},
			previewVolume: 'Громкость прослушивания',
			executeCommand: {
				title: 'Выполнять команды по окончании загрузок',
				description: 'Оставьте пустым, если ничего не требуется'
			}
		},
		spotify: {
			title: 'Настройки Spotify',
			clientID: 'Spotify clientID',
			clientSecret: 'Spotify Client Secret',
			username: 'Spotify username',
			question: 'Как включить функции Spotify?'
		},
		reset: 'По умолчанию',
		save: 'Сохранить',
		toasts: {
			init: 'Настройки загружены!',
			update: 'Настройки обновлены!',
			ARLcopied: 'ARL скопирован в буфер обмена'
		}
	},
	sidebar: {
		home: 'главная',
		search: 'поиск',
		charts: 'чарты',
		favorites: 'избранное',
		linkAnalyzer: 'анализ ссылок',
		settings: 'настройки',
		about: 'о проекте'
	},
	tracklist: {
		downloadSelection: 'Скачать выбранные'
	}
};

const tr = {
	globals: {
		welcome: `Deemix'e hoş geldin.`,
		back: `geri`,
		loading: `yükleniyor`,
		download: 'İndir {thing}',
		by: '{artist} tarafından',
		in: '{album} içinde',
		download_hint: 'İndir',
		play_hint: 'Oynat',
		toggle_download_tab_hint: 'Genişlet/Daralt',
		clean_queue_hint: 'Tamamlananları Temizle',
		cancel_queue_hint: 'Hepsini ',
		listTabs: {
			empty: '',
			all: 'Tümü',
			top_result: 'top result',
			album: 'albüm | albümler',
			artist: 'sanatçı | sanatçılar',
			single: 'single | singlelar',
			title: 'başlık | başlıklar',
			track: 'Parça | Parçalar',
			trackN: '0 parça | {n} parça | {n} parça',
			releaseN: '0 yayınlanan | {n} yayınlanan | {n} yayınlanan',
			playlist: 'oynatma listesi | oynatma listeleri',
			compile: 'derleme | derlemeler',
			ep: 'kayıt | kayıtlar',
			spotifyPlaylist: 'spotify oynatma listesi | oynatma listeleri',
			releaseDate: 'yayınlanma tarihi',
			error: 'hata'
		}
	},
	about: {
		titles: {
			usefulLinks: 'Yararlı Bağlantılar',
			bugReports: 'Hata Raporları',
			contributing: 'Katkı Sağlayanlar',
			donations: 'Bağışlar',
			license: 'Lisans'
		},
		subtitles: {
			bugReports: "Deemix'te çalışmayan bir şey mi var?, Bize bildirin!",
			contributing: 'Projeye katkı sağlamak mı istiyorsun? Farklı yollardan sağlayabilirsin!',
			donations: 'Bütçe yardımı mı yapmak istiyorsun? Bağış yapabilirsin!'
		},
		usesLibrary:
			'<strong>deemix</strong> kendi kullanıcı arabiriminizi oluşturabileceğiniz, kendine özgü kütüphanesini kullanıyor.',
		thanks: ` <strong>rtonno</strong>, <strong>uhwot</strong> ve <strong>lollilol</strong>'a bu projeye yaptığı katkılardan ve <strong>BasCurtiz</strong> ile <strong>scarvimane</strong>'e ikonlardan dolayı teşekkür ederim.`,
		upToDate: `Telegramdaki haber kanalını takip ederek <a href="https://t.me/RemixDevNews" target="_blank"></a>güncellemelerden haberdar olun.`,
		officialWebsite: 'İlgili İnternet Sitemiz',
		officialRepo: 'İlgili Kütüphanemiz',
		officialWebuiRepo: 'İlgili Web Kullanıcı Arayüzü Kütüphanemiz.',
		officialSubreddit: 'İlgili Subreddit adresimiz',
		newsChannel: 'Haber Kanalı',
		questions: `Eğer uygulama ile ilgili sorularınız veya bir probleminiz varsa,ilk önce <a href="https://www.reddit.com/r/deemix" target="_blank">subreddit adresinden </a> sorununuzu arayın. Eğer bir şey bulamazsanız, sorununuz ile ilgili bir gönderi paylaşabilirsiniz.`,
		beforeReporting: `Bir hatayı bildirmeden önce, uygulamanın son sürümünde olduğunuza veya sorunun sizden kaynaklı olmayıp bir hata olduğuna emin olduktan sonra emin olun.`,
		beSure: `Hatanın başka cihazlarda da olduğunu doğrulayın ve <strong>Bildirilen</strong> bir hatayı tekrar bildirmeyin.`,
		duplicateReports: 'Birbirinin aynısı olan hata bildirileri kapatılacaktır, o yüzden dikkatli olun.',
		dontOpenIssues: `<strong>Soru sormak</strong> için hata bildirisi yollamayın, bunun için bir subreddit adresimiz var.`,
		newUI: `Eğer Phython kullanmakta iyiysen, ana kütüphaneyi kullanan bir kullanıcı arayüzü yapmayı deneyebilir, veya kütüphanedeki hataları düzeltmek için <a href="https://codeberg.org/RemixDev/deemix" target="_blank">deposuna değişiklik isteği yollayabilirsin.</a>.`,
		acceptFeatures: `Yeni özellikleri de kabul ediyorum, fakat karışık şeyleri kütüphaneye değil uygulamaya eklendiği için kabul edemiyorum.`,
		otherLanguages: `Eğer diğer programlama dillerinde kendine güveniyorsan, deemix'i farklı dillere port etmeye çalışabilirsin!`,
		understandingCode: `Kodu anlamak için yardım mı lazım? Reddit üzerinden veya Telegramdan RemixDev'e ulaş.`,
		contributeWebUI: `Eğer Vue.js (JavaScript), HTML veya CSS biliyorsan, <a href="https://codeberg.org/RemixDev/deemix-webui" target="_blank">Web Kullanıcı Arayüzüne katkıda bulanabilirsin</a>.`,
		itsFree: `Bunun <strong>ücretsiz bir proje olduğunu</strong> ve <strong>geliştiricilerden önce</strong> sevdiğiniz sanatçıları desteklemeniz gerektiğini unutmayın.`,
		notObligated: `Kendinizi bağış yapmak zorunda hissetmeyin!, Sizi her halinizle seviyorum!`,
		lincensedUnder: `Bu çalışma lisanslıdır:
			<a rel="license" href="https://www.gnu.org/licenses/gpl-3.0.en.html" target="_blank"
				>GNU General Public License 3.0</a
			>.`
	},
	charts: {
		title: 'Grafikler',
		changeCountry: 'Ülke Değiştir',
		download: 'Grafiği İndir'
	},
	errors: {
		title: '{name} Hatalı bulundu',
		ids: {
			invalidURL: 'URL geçersiz.',
			unsupportedURL: 'URL şimdilik desteklenmiyor',
			ISRCnotOnDeezer: 'ISRC parça deezerda bulunmuyor',
			notYourPrivatePlaylist: 'Başkalarının özel oynatma listelerini indiremezsin.',
			spotifyDisabled: 'Spotify Özellikleri doğru şekilde ayarlanmamış.',
			trackNotOnDeezer: `Parça Deezer'da bulunamadı!`,
			albumNotOnDeezer: `Albüm Deezer'da bulunamadı!`,
			notOnDeezer: `Parça Deezer'da yok!`,
			notEncoded: `Parça henüz dönüştürülmedi!`,
			notEncodedNoAlternative: 'Parça henüz dönüştürülmedi ve alternatifi bulunamadı!',
			wrongBitrate: 'Parça, istenen kalitede bulunamadı!',
			wrongBitrateNoAlternative: 'Parça veya alternatifler istenen kalitede bulunamadı!',
			no360RA: 'Parça 360 Derece gerçekçi ses olarak bulunamadı!',
			notAvailable: 'Parça Deezer sunucularında bulunamadı!',
			notAvailableNoAlternative: 'Parça veya Alternatifleri Deezer sunucularında bulunamadı.!'
		}
	},
	favorites: {
		title: 'Favoriler',
		noPlaylists: 'Oynatma listesi bulunamadı.',
		noAlbums: 'Favori albümler bulunamadı.',
		noArtists: 'Favori sanatçılar bulunamadı.',
		noTracks: 'Favori parçalar bulunamadı.'
	},
	home: {
		needTologin: 'İndirmeden önce Deezer hesabına giriş yapmalısın.',
		openSettings: 'Ayarları Aç',
		sections: {
			popularPlaylists: 'Popüler Oynatma Listeleri',
			popularAlbums: 'En çok dinlenen albümler'
		}
	},
	linkAnalyzer: {
		info: 'İndirmeye çalıştığın link hakkında daha fazla bilgi için burayı kullanabilirsin.',
		useful: 'Mesela, ülkende dinlenebilir olmayan parçaların nerelerde var olduğunu bulmak için kullanabilirsin.',
		linkNotSupported: 'Bu link şimdilik desteklenmemektedir.',
		linkNotSupportedYet: 'Bu link şimdilik desteklenmiyor gibi duruyor, başkasını analiz etmeyi dene.',
		table: {
			id: 'ID',
			isrc: 'ISRC',
			upc: 'UPC',
			duration: 'Süre',
			diskNumber: 'Sıra numarası',
			trackNumber: 'Parça numarası',
			releaseDate: 'Yayınlanma tarihi',
			bpm: 'BPM',
			label: 'Etiketi',
			recordType: 'Kayıt Şekli',
			genres: 'Türü',
			tracklist: 'Parça listesi'
		}
	},
	search: {
		startSearching: 'Aramayı Başlat!',
		description:
			'Bir parçayı, tüm albümü, bir sanatçıyı, bir oynatma listesini... kısaca her şeyi aratabilirsin! Ayrıca Deezer Linki de yapıştırabilirsin!',
		fans: '{n} Hayranlar',
		noResults: 'Sonuç Bulunamadı',
		noResultsTrack: 'Parça bulunamadı',
		noResultsAlbum: 'Albüm bulunamadı',
		noResultsArtist: 'Sanatçı bulunamadı',
		noResultsPlaylist: 'Oynatma Listesi bulunamadı'
	},
	searchbar: 'İstediğin bir şeyi arat (ya da bir link yapıştır.)',
	downloads: 'İndirilenler',
	toasts: {
		addedToQueue: '{item} kuyruğa eklendi',
		alreadyInQueue: '{item} çoktan kuyrukta!',
		finishDownload: '{item} indirmesi tamamlandı.',
		allDownloaded: 'Tüm indirmeler tamamlandı!',
		refreshFavs: 'Yenileme tamamlandı.!',
		loggingIn: 'Giriş yapılıyor',
		loggedIn: 'Giriş yapıldı',
		alreadyLogged: 'Çoktan giriş yapıldı',
		loginFailed: 'Giriş yapılamadı',
		loggedOut: 'Oturum kapatıldı.',
		cancellingCurrentItem: 'Geçerli öğe iptal ediliyor.',
		currentItemCancelled: 'Geçerli öğe iptal edildi.',
		startAddingArtist: '{artist} albüm kuyruğa ekleniyor',
		finishAddingArtist: '{artist} albüm kuyruğa eklendi.',
		startConvertingSpotifyPlaylist: 'Spotify parçaları deezer parçalarına dönüştürülüyor.',
		finishConvertingSpotifyPlaylist: 'Spotify oynatma listesi dönüştürüldü.'
	},
	settings: {
		title: 'Ayarlar',
		languages: 'Diller',
		login: {
			title: 'Giriş',
			loggedIn: '{username} olarak giriş yaptın.',
			arl: {
				question: `Kendi ARL'mi nasıl alırım?`,
				update: 'ARL güncelle.'
			},
			logout: 'Çıkış'
		},
		appearance: {
			title: 'Görünüm',
			slimDownloadTab: 'İnce indirme sekmesi'
		},
		downloadPath: {
			title: 'İndirilen dizin'
		},
		templates: {
			title: 'Şablonlar',
			tracknameTemplate: 'Parça ismi şablonu',
			albumTracknameTemplate: 'Albüm parçası şablonu',
			playlistTracknameTemplate: 'Oynatma listesi parça şablonu'
		},
		folders: {
			title: 'Dosyalar',
			createPlaylistFolder: 'Oynatma listesi için dosya oluştur',
			playlistNameTemplate: 'Oynatma listesi dosyası şablonu',
			createArtistFolder: 'Sanatçı için dosya oluştur',
			artistNameTemplate: 'Sanatçı dosyası şablonu',
			createAlbumFolder: 'Albüm için dosya oluştur',
			albumNameTemplate: 'Albüm dosyası şablonu',
			createCDFolder: 'CDler için dosya oluştur',
			createStructurePlaylist: 'Oynatma  listeleri için dosya kökü oluştur',
			createSingleFolder: 'Singlelar için dosya kökü oluştur'
		},
		trackTitles: {
			title: 'Parça başlıkları',
			padTracks: 'İz Numaraları',
			paddingSize: 'İz Numaralarını değiştir',
			illegalCharacterReplacer: 'Illegal Karakter Düzenleyici'
		},
		downloads: {
			title: 'İndirilenler',
			queueConcurrency: 'Devam eden indirmeler',
			maxBitrate: {
				title: 'Tercih edilmiş Bitrateler (kaliteler)',
				9: 'FLAC 1411kbps',
				3: 'MP3 320kbps',
				1: 'MP3 128kbps'
			},
			overwriteFile: {
				title: 'Dosyaların üstüne yazmalı mıyım?',
				y: 'Evet, üstüne yaz',
				n: 'Hayır, üstüne yazma',
				t: 'Sadece izleri üstüne yaz'
			},
			fallbackBitrate: 'Bitrate düşürme',
			fallbackSearch: 'Düşürme ara',
			logErrors: 'Hatalar için günlük tut',
			logSearched: 'Aranmış parçalar için günlük tut',
			createM3U8File: 'Oynatma sıra listesi oluştur',
			syncedLyrics: '.lyr dosyaları oluştur (Senkronize şarkı sözleri)',
			playlistFilenameTemplate: 'Oynatma listesi şablonu',
			saveDownloadQueue: 'Uygulamayı kapatırken indirme kuyruğunu kaydet'
		},
		covers: {
			title: 'Albüm kapakları',
			saveArtwork: 'Kapakları kaydet',
			coverImageTemplate: 'Kapak ismi şablonu',
			saveArtworkArtist: 'Sanatçı fotoğrafını kaydet',
			artistImageTemplate: 'Şarkıcı fotoğraf şablonu',
			localArtworkSize: 'Yerel fotoğraf boyutu',
			embeddedArtworkSize: 'Gömülü fotoğraf boyutu',
			localArtworkFormat: {
				title: 'Yerel fotoğrafın hangi formatta olmasını istersin?',
				jpg: 'Jpeg dosyası',
				png: 'Png dosyası',
				both: 'Her ikisi'
			},
			jpegImageQuality: 'JPEG görüntü kalitesi'
		},
		tags: {
			head: 'Hangi izler kayıt edilsin?',
			title: 'Başlık',
			artist: 'Sanatçı',
			album: 'Albüm',
			cover: 'Kapak',
			trackNumber: 'Parça Numarası',
			trackTotal: 'Tüm Parça',
			discNumber: 'Plak Sayısı',
			discTotal: 'Tüm Plak',
			albumArtist: 'Sanatçı Albümü',
			genre: 'Tür',
			year: 'Yıl',
			date: 'Tarih',
			explicit: 'Cinsel içerikli şarkı sözleri',
			isrc: 'ISRC',
			length: 'Parça Uzunluğu',
			barcode: 'Albüm Barkodu (UPC)',
			bpm: 'BPM',
			replayGain: 'Ses Yüksekliği Normalleştirici',
			label: 'Albüm Etiketi',
			lyrics: 'Senkronize edilmemiş şarkı sözleri',
			copyright: 'Telif hakkı',
			composer: 'Besteleyen',
			involvedPeople: 'Alakalı Kişiler'
		},
		other: {
			title: 'Diğer',
			savePlaylistAsCompilation: 'Oynatma listelerini derleme olarak kaydet',
			useNullSeparator: 'Boşluk ayırıcı kullan',
			saveID3v1: 'ID3v1 dosyasını da kaydet',
			multiArtistSeparator: {
				title: 'Sanatçılarınızı nasıl ayırmak istersiniz?',
				nothing: 'Sadece ana sanatçıyı kaydet',
				default: 'Genel prosedür uygulansın',
				andFeat: 'Kullanılanlar & ve Feat.',
				using: 'Kullanılan "{separator}"'
			},
			singleAlbumArtist: 'Sadece ana albüm sanatçısını kaydet',
			albumVariousArtists: '"Çeşitli sanatçılar"ı sanatçı albümlerinde tut',
			removeAlbumVersion: '"Albüm Sürümü"nü parça başlığından çıkart',
			removeDuplicateArtists: 'Sanatçı topluluğunu çıkart',
			dateFormat: {
				title: 'FLAC dosyalar için zaman formatı',
				year: 'YYYY',
				month: 'AA',
				day: 'GG'
			},
			featuredToTitle: {
				title: 'Öne çıkan sanatçıları ne yapmalıyım?',
				0: 'Elleme',
				1: 'Başlıktan çıkart',
				3: 'Başlıktan ve albüm başlığından çıkart',
				2: 'Başlığa taşı'
			},
			titleCasing: 'Albüm harfi',
			artistCasing: 'Sanatçı harfi',
			casing: {
				nothing: 'Değiştirmeden bırak',
				lower: 'küçük harf',
				upper: 'BÜYÜK HARF',
				start: 'Kelimenin başı ile başla',
				sentence: 'Cümle gibi yap'
			},
			previewVolume: 'Ses önizlemesi',
			executeCommand: {
				title: 'İndirdikten sonra komut uygula',
				description: 'Bir şey yapmamak için boş bırak'
			}
		},
		spotify: {
			title: 'Spotify Özelliği',
			clientID: 'Spotify clientID',
			clientSecret: 'Spotify Client Secret',
			username: 'Spotify Kullanıcı Adı'
		},
		reset: 'Varsayılana sıfırla',
		save: 'Kaydet',
		toasts: {
			init: 'Ayarlar yüklendi!',
			update: 'Ayarlar güncellendi!',
			ARLcopied: 'ARL panoya kopyalandı!'
		}
	},
	sidebar: {
		home: 'Ana sayfa',
		search: 'Ara',
		charts: 'Grafikler',
		favorites: 'Favoriler',
		linkAnalyzer: 'Link Analizörü',
		settings: 'Ayarlar',
		about: 'Hakkında'
	},
	tracklist: {
		downloadSelection: 'İndirme bölümü'
	}
};

const vn = {
	globals: {
		welcome: 'Chào mừng đến với deemix',
		back: 'trở lại',
		loading: 'đang tải',
		download: 'Tải xuống {thing}',
		by: 'bởi {artist}',
		in: 'trong {album}',
		download_hint: 'Tải xuống',
		play_hint: 'Phát',
		toggle_download_tab_hint: 'Mở rộng/Giấu',
		clean_queue_hint: 'Xóa những file đã tải xong',
		cancel_queue_hint: 'Hủy tất cả',
		listTabs: {
			empty: '',
			all: 'tất cả',
			top_result: 'kết quả hàng đầu',
			album: 'album | album',
			artist: 'Nghệ sĩ | Nghệ sĩ',
			single: 'đơn | đơn',
			title: 'tiêu đề | tiêu đề',
			track: 'Bài hát | Bài hát',
			trackN: '0 Bài hát | {n} Bài hát | {n} Bài hát',
			releaseN: '0 sản phẩm | {n} sản phẩm | {n} sản phẩm',
			playlist: 'playlist | playlist',
			compile: 'tổng hợp | tổng hợp',
			ep: 'ep | ep',
			spotifyPlaylist: 'playlist của spotify | playlist của spotify',
			releaseDate: 'ngày phát hành',
			error: 'lỗi'
		}
	},
	about: {
		titles: {
			usefulLinks: 'Link hữu dụng',
			bugReports: 'Báo lỗi',
			contributing: 'Đóng góp',
			donations: 'Quyên góp',
			license: 'Bằng phép'
		},
		subtitles: {
			bugReports: "Bạn thấy có gì đó không hoạt động trong deemix? Xin hãy báo với chúng tôi!",
			contributing: 'Bạn muốn đóng góp cho dự án này? Bạn có thể làm điều đó với nhiều cách khác nhau!',
			donations: 'Bạn muốn ủng hộ kinh phí? Bạn có thể quyên góp tại đây!'
		},
		usesLibrary: 'Ứng dụng này sử dụng thư viện <strong>deemix</strong>, bạn có thể dùng nó để tạo một UI riêng cho deemix.',
		thanks: `Cảm ơn <strong>rtonno</strong>, <strong>uhwot</strong> và <strong>lollilol</strong> đã giúp tôi với dự án này và <strong>BasCurtiz</strong> và <strong>scarvimane</strong> với việc thiết kế biểu tượng.`,
		upToDate: `Cập nhật app bằng cách theo dõi <a href="https://t.me/RemixDevNews" target="_blank">kênh tin tức</a> trên Telegram.`,
		officialWebsite: 'Website chính thức',
		officialRepo: 'Repo thư viện chính thức',
		officialWebuiRepo: 'Repo WebUI chính thức',
		officialSubreddit: 'Subreddit chính thức',
		newsChannel: 'Kênh tin tức',
		questions: `Nếu bạn có câu hỏi hoặc vấn đề về ứng dụng này, xin hãy tìm giải pháp trên <a href="https://www.reddit.com/r/deemix" target="_blank">subreddit</a> trước. Sau đó, nếu bạn không tìm được gì thì bạn có thể tạo một bài đăng về vấn đề của bạn trên subreddit dó.`,
		beforeReporting: `Trước khi báo lỗi hãy đảm bảo bạn đang sử dụng phiên bản mới nhất của ứng dụng và lỗi bạn đang gặp không phải là do bạn.`,
		beSure: `Hãy đảm bảo là lỗi này vẫn có thể xảy ra trên các thiết bị khác và <strong>XIN ĐỪNG</strong> báo lỗi đã được báo rồi.`,
		duplicateReports: 'Những bản báo lỗi trùng nhau sẽ bị đóng, xin bạn hãy để ý điều này.',
		dontOpenIssues: `<strong>XIN ĐỪNG</strong> mở vấn đề để hỏi, bạn có thể dùng subreddit trên cho việc đó.`,
		newUI: `Nếu bạn thành thạo với python bạn có thể tạo một UI mới bằng cách sử dụng thư viện gốc, hoặc sửa lỗi trong thư viện đó với một pull request trên <a href="https://codeberg.org/RemixDev/deemix" target="_blank">repo này</a>.`,
		acceptFeatures: `Tôi có chấp nhận yêu cầu về tính năng mới nhưng không quá phức tạp bởi vì chúng có thể được triển khai trực tiếp vào ứng dụng thay vì vào thư viện.`,
		otherLanguages: `Nếu bạn thành thạo với một ngôn ngữ khác, bạn có thể port deemix sang ngôn ngữ đó!`,
		understandingCode: `Bạn muốn hiểu code của deemix? Xin hãy liên lạc RemixDev trên Telegram hoặc Reddit.`,
		contributeWebUI: `Nếu bạn biết Vue.js (JavaScript), HTML hoặc CSS, bạn có thể góp phần phát triển <a href="https://codeberg.org/RemixDev/deemix-webui" target="_blank">WebUI</a>.`,
		itsFree: `Bạn nên nhớ rằng <strong>đây là một dự án phi lợi nhuận</strong> và <strong>bạn nên ủng hộ những Nghệ sĩ yêu thích của bạn</strong> trước khi ủng hộ nhà phát triển.`,
		notObligated: `Đừng nghĩ rằng bạn phải đóng góp tiền, tôi vẫn sẽ rất biết ơn bạn!`,
		lincensedUnder: `Dự án này được cấp phép bởi
			<a rel="license" href="https://www.gnu.org/licenses/gpl-3.0.en.html" target="_blank"
				>GNU General Public License 3.0</a
			>.`
	},
	charts: {
		title: 'Bảng xếp hạng',
		changeCountry: 'Thay đổi quốc gia',
		download: 'Tải xuống bảng xếp hạng này'
	},
	errors: {
		title: 'Lỗi {name}',
		ids: {
			invalidURL: 'Không nhận diện được URL',
			unsupportedURL: 'URL này chưa được hỗ trợ',
			ISRCnotOnDeezer: 'ISRC của bài hát này hiện không có trên Deezer',
			notYourPrivatePlaylist: "Bạn không thể tải xuống playlist riêng của người khác.",
			spotifyDisabled: 'Chức năng Spotify chưa được thiết lập đúng cách.',
			trackNotOnDeezer: 'Bài hát không có trên Deezer!',
			albumNotOnDeezer: 'Album không có trên Deezer!',
			notOnDeezer: 'Bài hát chưa có trên Deezer!',
			notEncoded: 'Bài hát chưa được encode!',
			notEncodedNoAlternative: 'Bài hát chưa được encode và không có bản thay thế nào khác!',
			wrongBitrate: 'Bài hát này không có ở bitrate bạn muốn.',
			wrongBitrateNoAlternative: 'Bài hát này không có ở bitrate bạn muốn và không có bản thay thế nào khác!',
			no360RA: 'Bài hát này không có ở dạng Reality Audio 360.',
			notAvailable: "Bài hát này không có trên server của Deezer!",
			notAvailableNoAlternative: "Bài hát này không có trên server của Deezer và không có bản thay thế nào khác!"
		}
	},
	favorites: {
		title: 'Yêu thích',
		noPlaylists: 'Không tìm được Playlist',
		noAlbums: 'Không tìm được Album Yêu thích',
		noArtists: 'Không tìm được Nghệ sĩ Yêu thích',
		noTracks: 'Không tìm được Bài hát Yêu thích'
	},
	home: {
		needTologin: 'Bạn cần phải đăng nhập vào tài khoản Deezer trước khi bắt đầu tải xuống.',
		openSettings: 'Mở Cài đặt',
		sections: {
			popularPlaylists: 'Playlist Nổi tiếng',
			popularAlbums: 'Album được stream nhiều nhất'
		}
	},
	linkAnalyzer: {
		info: 'Bạn có thể sử dụng chức năng này để kiếm thêm thông tin về đường link mà bạn muốn tải xuống.',
		useful:
			"Chức năng này rất hữu dụng nếu bạn muốn tải các bài hát hiện không có sẵn ở quốc gia của bạn và muốn biết các quốc gia được hỗ trợ.",
		linkNotSupported: 'Đường link này chưa được hỗ trợ',
		linkNotSupportedYet: 'Đường link này chưa được hỗ trợ, xin hãy thử lại với một đường link khác.',
		table: {
			id: 'ID',
			isrc: 'ISRC',
			upc: 'UPC',
			duration: 'Thời lượng',
			diskNumber: 'Số đĩa',
			trackNumber: 'Số bài hát',
			releaseDate: 'Ngày phát hành',
			bpm: 'BPM',
			label: 'Hãng',
			recordType: 'Loại Thu âm',
			genres: 'Thể loại',
			tracklist: 'Danh sách các bài hát'
		}
	},
	search: {
		startSearching: 'Bắt đầu tìm kiếm!',
		description:
			'Bạn có thể tìm một bài hát, album, nghệ sĩ, playlist, v.v...! Bạn cũng có thể dùng link của Deezer',
		fans: '{n} người hâm mộ',
		noResults: 'Không có kết quả',
		noResultsTrack: 'Không tìm được bài hát nào',
		noResultsAlbum: 'Không tìm được album nào',
		noResultsArtist: 'Không tìm được nghệ sĩ nào',
		noResultsPlaylist: 'Không tìm được playlist nào'
	},
	searchbar: 'Tìm những gì bạn muốn (bạn cũng có thể sữ dụng một đường link)',
	downloads: 'Tải xuống',
	toasts: {
		addedToQueue: '{item} đã được đưa vào hàng chờ',
		alreadyInQueue: '{item} đã đang trong hàng chờ!',
		finishDownload: '{item} đã tải xong.',
		allDownloaded: 'Tất cả các bài hát đã được tải xuống!',
		refreshFavs: 'Tải lại hoàn tất!',
		loggingIn: 'Đang đăng nhập',
		loggedIn: 'Đăng nhập thành công',
		alreadyLogged: 'Đã đăng nhập',
		loginFailed: "Không thể đăng nhập",
		loggedOut: 'Đăng xuất',
		cancellingCurrentItem: 'Đang hủy file hiện tại.',
		currentItemCancelled: 'File hiện tại đã bị hủy.',
		startAddingArtist: 'Đang đưa {artist} album vào hàng chờ',
		finishAddingArtist: 'Đã đưa {artist} album vào hàng chờ',
		startConvertingSpotifyPlaylist: 'Đang chuyển đổi các bài hát từ Spotify sang Deezer',
		finishConvertingSpotifyPlaylist: 'Playlist của Spotify đã được chuyển đổi',
		loginNeededToDownload: 'Bạn cần phải đang nhập để tải nhạc!'
	},
	settings: {
		title: 'Cài đặt',
		languages: 'Ngôn ngữ',
		login: {
			title: 'Đăng nhập',
			loggedIn: 'Bạn đã đăng nhập với tên {username}',
			arl: {
				question: 'Làm cách nào để có ARL của tôi?',
				update: 'Cập nhật ARL'
			},
			logout: 'Đăng xuất'
		},
		appearance: {
			title: 'Giao diện',
			slimDownloadTab: 'Thanh tải xuống nhỏ'
		},
		downloadPath: {
			title: 'Nơi tải xuống'
		},
		templates: {
			title: 'Bản mẫu',
			tracknameTemplate: 'Bài hát mẫu',
			albumTracknameTemplate: 'Bài hát trong album mẫu',
			playlistTracknameTemplate: 'Bài hát trong playlist mẫu'
		},
		folders: {
			title: 'Thư mục',
			createPlaylistFolder: 'Tạo thư mục cho playlist',
			playlistNameTemplate: 'Thư mục playlist mẫu',
			createArtistFolder: 'Tạo thư mục cho nghệ sĩ',
			artistNameTemplate: 'Thư mục Nghệ sĩ mẫu',
			createAlbumFolder: 'Tạo thư mục cho album',
			albumNameTemplate: 'Thư mục cho album mẫu',
			createCDFolder: 'Tạo thư mục cho đĩa CD',
			createStructurePlaylist: 'Tạo thư mục có kết cấu cho playlist',
			createSingleFolder: 'Tạo thư mục có kết cấu cho đĩa đơn'
		},
		trackTitles: {
			title: 'Tên bài hát',
			padTracks: 'Đệm tên bài hát',
			paddingSize: 'Ghì đè kích cỡ phần đệm',
			illegalCharacterReplacer: 'Thay các kí tự không hợp lệ với'
		},
		downloads: {
			title: 'Tải xuống',
			queueConcurrency: 'Số lượng tải xuống cùng lúc',
			maxBitrate: {
				title: 'Bitrate ưa thích',
				9: 'FLAC 1411kbps',
				3: 'MP3 320kbps',
				1: 'MP3 128kbps'
			},
			overwriteFile: {
				title: 'Tôi có nên ghi đè file này không?',
				y: 'Có, hãy ghi đè file này',
				n: "Không, đừng ghi đè file này",
				t: 'Chỉ ghi đè các tag'
			},
			fallbackBitrate: 'Bitrate dự phòng',
			fallbackSearch: 'Search dự phòng',
			logErrors: 'Tạo file log khi có lỗi',
			logSearched: 'Tạo file log khi bạn tìm Bài hát',
			createM3U8File: 'Tạo file playlist',
			syncedLyrics: 'Tạo file .lyr (Lời Bài hát)',
			playlistFilenameTemplate: 'Tên playlist mẫu',
			saveDownloadQueue: 'Lưu hàng chờ download khi đóng ứng dụng'
		},
		covers: {
			title: 'Bìa album',
			saveArtwork: 'Lưu bìa',
			coverImageTemplate: 'Tên bìa mẫu',
			saveArtworkArtist: 'Lưu hình Nghệ sĩ',
			artistImageTemplate: 'Hình nghệ sĩ mẫu',
			localArtworkSize: 'Kích cỡ file bìa',
			embeddedArtworkSize: 'Kích cỡ bìa trong file bài hát',
			localArtworkFormat: {
				title: 'Bạn muốn file bìa ở định dạng nào?',
				jpg: 'jpg',
				png: 'png',
				both: 'Cả jpg và png'
			},
			jpegImageQuality: 'Chất lượng file JPEG'
		},
		tags: {
			head: 'Những tag sẽ được lưu',
			title: 'Tiêu đề',
			artist: 'Nghệ sĩ',
			album: 'Album',
			cover: 'Bìa',
			trackNumber: 'Số bài hát',
			trackTotal: 'Tổng số bài hát',
			discNumber: 'Số đĩa',
			discTotal: 'Tổng số đĩa',
			albumArtist: 'Nghệ sĩ của album',
			genre: 'Thể loại',
			year: 'Năm',
			date: 'Ngày',
			explicit: 'Lời explicit',
			isrc: 'ISRC',
			length: 'Thời lượng',
			barcode: 'Mã vạch của album (UPC)',
			bpm: 'BPM',
			replayGain: 'ReplayGain',
			label: 'Nhãn hiệu album',
			lyrics: 'Lời',
			copyright: 'Bản quyền',
			composer: 'Nhà soạn nhạc',
			involvedPeople: 'Những người liên quan'
		},
		other: {
			title: 'Khác',
			savePlaylistAsCompilation: 'Lưu playlist dưới dạng tuyển tập',
			useNullSeparator: 'Dùng dải phân cách null',
			saveID3v1: 'Lưu ID3v1',
			multiArtistSeparator: {
				title: 'Bạn muốn phân cách các nghệ sĩ như thế nào?',
				nothing: 'Chỉ lưu nghệ sĩ chính',
				default: 'Dùng quy cách tiêu chuẩn',
				andFeat: 'Dùng & và feat.',
				using: 'Dùng "{separator}"'
			},
			singleAlbumArtist: 'Chỉ lưu Nghệ sĩ Album chính',
			albumVariousArtists: 'Giữ nguyên "Nhiều Nghệ sĩ" trong Nghệ sĩ Album',
			removeAlbumVersion: 'Bỏ "Phiên bản Album" khỏi tên bài hát',
			removeDuplicateArtists: 'Bỏ các tên nghệ sĩ phối hợp',
			dateFormat: {
				title: 'Định dạng ngày cho file FLAC ',
				year: 'YYYY',
				month: 'MM',
				day: 'DD'
			},
			featuredToTitle: {
				title: 'Tôi nên làm gì với các nghệ sĩ đóng góp?',
				0: 'Không làm gì cả',
				1: 'Bỏ chúng khỏi tên bài hát',
				3: 'Bỏ chúng khỏi tên bài hát và tên album',
				2: 'Đưa chúng vào tên bài hát'
			},
			titleCasing: 'Định dạng tên bài hát',
			artistCasing: 'Định dạng tên nghệ sĩ',
			casing: {
				nothing: 'Không đổi',
				lower: 'chữ thường',
				upper: 'CHỮ HOA',
				start: 'Viết Hoa Ở Chữ Cái Đầu Tiên Của Mỗi Từ',
				sentence: 'Như một câu'
			},
			previewVolume: 'Âm lượng nghe thử',
			executeCommand: {
				title: 'Thực hiện những lệnh này khi đã tải xuống xong',
				description: 'Để trống nếu bạn không muốn thực hiện lệnh nào'
			}
		},
		spotify: {
			title: 'Chức năng Spotify',
			clientID: 'ClientID của Spotify',
			clientSecret: 'Client Secret của Spotify',
			username: 'Tên tài khoản của Spotify'
		},
		reset: 'Quay trở lại cài đặt mặc định',
		save: 'Lưu',
		toasts: {
			init: 'Cài đặt đã được thiết lập!',
			update: 'Cài đặt cập nhật thành công!',
			ARLcopied: 'ARL đã được sao chép vào clipboard'
		}
	},
	sidebar: {
		home: 'trang chủ',
		search: 'tìm kiếm',
		charts: 'bảng xếp hạng',
		favorites: 'yêu thích',
		linkAnalyzer: 'phân tích link',
		settings: 'cài đặt',
		about: 'thông tin'
	},
	tracklist: {
		downloadSelection: 'Tải xuống những mục đã chọn'
	}
};

const hr = {
	globals: {
		welcome: 'Dobrodošli u deemix',
		back: 'nazad',
		loading: 'učitavanje',
		download: 'Preuzmi {thing}',
		by: 'by {artist}',
		in: 'u {album}',
		download_hint: 'Preuzmi',
		play_hint: 'Play',
		toggle_download_tab_hint: 'Proširi/Smanji',
		clean_queue_hint: 'Čišćenje završeno',
		cancel_queue_hint: 'Zaustavi sve',
		listTabs: {
			empty: '',
			all: 'sve',
			top_result: 'Najbolji rezultat',
			album: 'album | albumi',
			artist: 'izvođač | izvođači',
			single: 'singl | singlovi',
			title: 'naslov | naslovi',
			track: 'pjesma | pjesme',
			trackN: '0 pjesmi | {n} pjesma | {n} pjesme',
			releaseN: '0 izdanja | {n} izdanje | {n} izdanja',
			playlist: 'playlista | playliste',
			compile: 'kompilacija | kompilacije',
			ep: 'ep | eps',
			spotifyPlaylist: 'spotify playlista | spotify playliste',
			releaseDate: 'datum izdavanja',
			error: 'greška'
		}
	},
	about: {
		titles: {
			usefulLinks: 'Korisne poveznice',
			bugReports: 'Prijave grešaka',
			contributing: 'Doprinosi',
			donations: 'Donacije',
			license: 'Licenca'
		},
		subtitles: {
			bugReports: "Postoji nešto što ne radi u deemixu? Reci nam!",
			contributing: 'Želiš doprinijeti ovom projektu? Možeš i to čak u više načina!',
			donations: 'Želiš doprijeniti odmah? Možeš donirati!'
		},
		usesLibrary: 'Ova aplikacija koristi <strong>deemix</strong> biblioteku, koju možeš koristiti i ti kako bi napravio svoj UI za demix.',
		thanks: `Hvala <strong>rtonno</strong>, <strong>uhwot</strong> i <strong>lollilol</strong> što su mi pomogli s ovim projektom te <strong>BasCurtiz</strong> i <strong>scarvimane</strong> što su napravili ikonu.`,
		upToDate: `Ostani u tijeku s nadogradnjama prateći <a href="https://t.me/RemixDevNews" target="_blank">kanal s novostima</a> na Telegramu.`,
		officialWebsite: 'Službena web stranica',
		officialRepo: 'Službeni repozitorij biblioteke',
		officialWebuiRepo: 'Službeni WebUI repozitorij',
		officialSubreddit: 'Službeni subreddit',
		newsChannel: 'Kanal s novostima',
		questions: `Ukoliko imate pitanja o aplikaciji, prvo potražite riješenje na <a href="https://www.reddit.com/r/deemix" target="_blank">subreddit</a>. Tada, ako ne pronađete ništa, možete objaviti svoj problem na subredditu.`,
		beforeReporting: `Prije prijavljivanja greške provjerite imate li instaliranu zadnju verziju aplikacije i da to što želite prijaviti je ustvari pogreška, a ne nešto što samo vama ne radi.`,
		beSure: `Provjerite može li se pogreška reproducirati i na drugim uređajima i također <strong>NEMOJTE</strong> prijavljivati grešku ako je već prijavljena.`,
		duplicateReports: 'Duplicirane prijave o greški bit će zatvorene, tako da pripazite na to.',
		dontOpenIssues: `<strong>NEMOJTE</strong> otvarati issue za postavljanje pitanja, za to postoji subreddit.`,
		newUI: `Ako ste vješti u pythonu možete probati napraviti novi UI za aplikaciju koristeći osnovnu biblioteku ili ispraviti pogrešku u biblioteci sa pull zahtjevom na <a href="https://codeberg.org/RemixDev/deemix" target="_blank">repozitoriju</a>.`,
		acceptFeatures: `Prihavaćam i značajke, ali bez kompleksnih stvari, jer one mogu biti implementirane direktno u aplikaciji, a ne u biblioteci.`,
		otherLanguages: `Ako ste vješti u drugom programskom jezikumožete probati portati deemix u drugi programski jezik!`,
		understandingCode: `Trebate pomoć s razumijevanjem koda? Samo potraži RemixDev na Telegramu ili Redditu.`,
		contributeWebUI: `Ako znaš Vue.js (JavaScript), HTML ili CSS možete doprinijeti za <a href="https://codeberg.org/RemixDev/deemix-webui" target="_blank">WebUI</a>.`,
		itsFree: `Trebate zapamtiti da je ovo <strong>besplatni projekt</strong> i <strong>trebali biste podržati autore koje volite</strong> prije podržavanja developera.`,
		notObligated: `Nemojte se osjećati obveznim darivati, svejedno vas cijenim!`,
		lincensedUnder: `Ovaj rad licenciran je unutar
			<a rel="license" href="https://www.gnu.org/licenses/gpl-3.0.en.html" target="_blank"
				>GNU General Public License 3.0</a
			>.`
	},
	charts: {
		title: 'Ljestvice',
		changeCountry: 'Promijeni državu',
		download: 'Preuzmi ljestvicu'
	},
	errors: {
		title: 'Greške za {name}',
		ids: {
			invalidURL: 'URL nije prepoznat',
			unsupportedURL: 'URL još nije podržan',
			ISRCnotOnDeezer: 'Zapis ISRC još nije podržan na Deezeru',
			notYourPrivatePlaylist: "Ne možete preuzeti tuđe privatne playliste.",
			spotifyDisabled: 'Spotify značajke nisu podešene ispravno.',
			trackNotOnDeezer: 'Pjesma nije pronađena na Deezeru!',
			albumNotOnDeezer: 'Album nije pronađen na Deezeru!',
			notOnDeezer: 'Pjesma nije dostupna na Deezeru!',
			notEncoded: 'Pjesma još nije enkodirana!',
			notEncodedNoAlternative: 'Pjesma još nije enkodirana i nije pronađena alternativa!',
			wrongBitrate: 'Pjesma nije pronađena u željenom bitrateu.',
			wrongBitrateNoAlternative: 'Pjesma nije pronađena u željenom bitrateu i nije pronađena alternativa!',
			no360RA: 'Pjesma nije dostupna u Reality Audio 360.',
			notAvailable: "Pjesma nije dostupna na Deezerovim serverima!",
			notAvailableNoAlternative: "Pjesma nije dostupna na Deezerovim serverima i alternativa nije pronađena!"
		}
	},
	favorites: {
		title: 'Favoriti',
		noPlaylists: 'Nisu pronađene playliste',
		noAlbums: 'Omiljeni albumi nisu pronađeni',
		noArtists: 'Omiljeni glazbenici nisu pronađeni',
		noTracks: 'Omiljene pjesme nisu pronađene'
	},
	home: {
		needTologin: 'Trebate se prijaviti sa svojim Deezer računom kako biste mogli početi preuzimati pjesme.',
		openSettings: 'Otvori postavke',
		sections: {
			popularPlaylists: 'Popularne playliste',
			popularAlbums: 'Najpreslušaniji album'
		}
	},
	linkAnalyzer: {
		info: 'Ovu sekciju možete koristiti kako biste saznali više informacija o linku koji pokušavate preuzeti.',
		useful:
			"Ovo je korisno ako pokušavate preuzeti pjesme koje još nisu dostupne u vašoj zemlji i želite, na primjer, znati gdje su dostupne.",
		linkNotSupported: 'Ovaj link još nije podržan',
		linkNotSupportedYet: 'Čini se da ovaj link još nije podržan, pokušaj analizirati neki drugi.',
		table: {
			id: 'ID',
			isrc: 'ISRC',
			upc: 'UPC',
			duration: 'Trajanje',
			diskNumber: 'Broj diska',
			trackNumber: 'Broj pjesme',
			releaseDate: 'Datum izadavanja',
			bpm: 'BPM',
			label: 'Izdavačka kuća',
			recordType: 'Vrsta zapisa',
			genres: 'Žanrovi',
			tracklist: 'Popis pjesama'
		}
	},
	search: {
		startSearching: 'Počni pretraživati!',
		description:
			'Možete pretražiti pjesmu, cijeli album, izvođača, playlistu... sve! Također, možete i zalijepiti Deezer link',
		fans: '{n} obožavatelja',
		noResults: 'Nema rezultata',
		noResultsTrack: 'Pjesme nisu pronađene',
		noResultsAlbum: 'Albumi nisu pronađeni',
		noResultsArtist: 'Izvođači nisu pronađeni',
		noResultsPlaylist: 'Playliste nisu pronađene'
	},
	searchbar: 'Pretraži bilo što (ili samo zalijepi link)',
	downloads: 'preuzimanja',
	toasts: {
		addedToQueue: '{item} dodan u red',
		alreadyInQueue: '{item} je već u redu!',
		finishDownload: '{item} završeno preuzimanje.',
		allDownloaded: 'Sva preuzimanja završena!',
		refreshFavs: 'Osvježavanje završeno!',
		loggingIn: 'Prijavljivanje...',
		loggedIn: 'Prijavljeni',
		alreadyLogged: 'Već prijavljeni',
		loginFailed: "Prijava nije bila moguća",
		loggedOut: 'Odjavljeni',
		cancellingCurrentItem: 'Otkazujem trenutnu stavku.',
		currentItemCancelled: 'Trenutna stavka otkazana.',
		startAddingArtist: 'Dodajem {artist} album u red',
		finishAddingArtist: 'Dodan {artist} album u red',
		startConvertingSpotifyPlaylist: 'Pretvaram Spotify pjesme u Deezer pjesme',
		finishConvertingSpotifyPlaylist: 'Spotify playlista pretvorena',
		loginNeededToDownload: 'Trebate se prijaviti kako bi preuzeli pjesme!'
	},
	settings: {
		title: 'Postavke',
		languages: 'Jezici',
		login: {
			title: 'Prijava',
			loggedIn: 'Prijavljeni ste kao {username}',
			arl: {
				question: 'Kako da dobijem svoj ARL?',
				update: 'Ažuriraj ARL'
			},
			logout: 'Odjavi se'
		},
		appearance: {
			title: 'Izgled',
			slimDownloadTab: 'Tanka kartica za preuzimanje'
		},
		downloadPath: {
			title: 'Putanja za preuzimanja'
		},
		templates: {
			title: 'Predlošci',
			tracknameTemplate: 'Naziv pjesme predložak',
			albumTracknameTemplate: 'Pjesma albuma predložak',
			playlistTracknameTemplate: 'Pjesma playliste predložak'
		},
		folders: {
			title: 'Mape',
			createPlaylistFolder: 'Izradi mapu za playliste',
			playlistNameTemplate: 'Mapa za playliste predložak',
			createArtistFolder: 'Izradi mapu za izvođača',
			artistNameTemplate: 'Izvođač mapa predložak',
			createAlbumFolder: 'Izradi mapu za album',
			albumNameTemplate: 'Album mapa predložak',
			createCDFolder: 'Izradi mapu za CD',
			createStructurePlaylist: 'Strkturiraj mape za playliste',
			createSingleFolder: 'Strukturiraj mape za singlove'
		},
		trackTitles: {
			title: 'Naslovi pjesama',
			padTracks: 'Pad tracks',
			paddingSize: 'Prepiši veličinu paddinga',
			illegalCharacterReplacer: 'Zamjena za nedozvoljeni znak'
		},
		downloads: {
			title: 'Preuzimanja',
			queueConcurrency: 'Istovremena preuzimanja',
			maxBitrate: {
				title: 'Željeni bitrate',
				9: 'FLAC 1411kbps',
				3: 'MP3 320kbps',
				1: 'MP3 128kbps'
			},
			overwriteFile: {
				title: 'Trebam li prepisati datoteke?',
				y: 'Da, prepiši datoteke',
				n: "Ne, nemoj prepisati datoteke",
				t: 'Prepiši samo oznake',
				b: 'Ne, zadrži obje datoteke i dodaj broj duplikatu'
			},
			fallbackBitrate: 'Bitrate fallback',
			fallbackSearch: 'Pretraživanje fallback',
			logErrors: 'Izradi zapisnik datoteku za greške',
			logSearched: 'Izradi zapisnik datoteku za pretražene pjesme',
			createM3U8File: 'Izradi playlist datoteku',
			syncedLyrics: 'Izradi .lyr datoteke (sinkronizirani lyrics)',
			playlistFilenameTemplate: 'Naziv playliste predložak',
			saveDownloadQueue: 'Spremi red za preuzimanje prilikom zatvaranja aplikacije'
		},
		covers: {
			title: 'Omoti albuma',
			saveArtwork: 'Spremi omote',
			coverImageTemplate: 'Naziv omota predložak',
			saveArtworkArtist: 'Spremi sliku izvođača',
			artistImageTemplate: 'Slika izvođača predložak',
			localArtworkSize: 'Veličina lokalnog omota',
			embeddedArtworkSize: 'Veličina ugrađenog omota',
			localArtworkFormat: {
				title: 'U kojem formatu želite lokalni omot?',
				jpg: 'Jpeg slika',
				png: 'Png slika',
				both: 'I jpeg i png'
			},
			jpegImageQuality: 'JPEG kvaliteta slike'
		},
		tags: {
			head: 'Koja oznake spremam',
			title: 'Naslovi',
			artist: 'Izvođač',
			album: 'Album',
			cover: 'Omot',
			trackNumber: 'Broj pjesme',
			trackTotal: 'Ukupno pjesama',
			discNumber: 'Broj diska',
			discTotal: 'Ukupno diskova',
			albumArtist: 'Izvođač albuma',
			genre: 'Žanr',
			year: 'Godina',
			date: 'Datum',
			explicit: 'Eksplicitni lyrics',
			isrc: 'ISRC',
			length: 'Dužina pjesme',
			barcode: 'Album barkod (UPC)',
			bpm: 'BPM',
			replayGain: 'Replay Gain',
			label: 'Izdavačka kuća albuma',
			lyrics: 'Nesinkronizirani lyrics',
			copyright: 'Autorska prava',
			composer: 'Skladatelj',
			involvedPeople: 'Uključeni ljudi'
		},
		other: {
			title: 'Ostalo',
			savePlaylistAsCompilation: 'Spremi playliste kao kompilacije',
			useNullSeparator: 'Koristi null razdvojnik',
			saveID3v1: 'Spremi i ID3v1 također',
			multiArtistSeparator: {
				title: 'Kako biste željeli razdvojiti izvođače?',
				nothing: 'Spremi samo glavnog izvođača',
				default: 'Koristeći standardnu specifikaciju',
				andFeat: 'Koristeći & i feat.',
				using: 'Koristeći "{separator}"'
			},
			singleAlbumArtist: 'Spremi samo izvođača glavnog albuma',
			albumVariousArtists: 'Zadrži "Various Artists" u Izvođačima albuma',
			removeAlbumVersion: 'Izbriši "Album Version" iz naziva pjesme',
			removeDuplicateArtists: 'Izbriši kombinacije izvođača',
			dateFormat: {
				title: 'Format datuma za FLAC datoteke',
				year: 'YYYY',
				month: 'MM',
				day: 'DD'
			},
			featuredToTitle: {
				title: 'Što trebam napraviti s istaknutim izvođačima? (feat. i ft.)',
				0: 'Ništa',
				1: 'Izbriši ih iz naziva',
				3: 'Izbriši ih iz naziva i iz naziva albuma',
				2: 'Premjesti ih u naziv'
			},
			titleCasing: 'Veličina slova naslova',
			artistCasing: 'Veličina slova izvođača',
			casing: {
				nothing: 'Zadrži nepromijenjeno',
				lower: 'sve malo',
				upper: 'sve VELIKO',
				start: 'Početak Svake Riječi',
				sentence: 'Kao rečenica'
			},
			previewVolume: 'Volumen pregleda',
			executeCommand: {
				title: 'Naredba za izvršenje nakon preuzimanja',
				description: 'Ostavi prazno za bez akcije'
			}
		},
		spotify: {
			title: 'Spotify značajke',
			clientID: 'Spotify ClientID',
			clientSecret: 'Spotify Client Secret',
			username: 'Spotify korisničko ime'
		},
		reset: 'Resetiraj na zadano',
		save: 'Spremi',
		toasts: {
			init: 'Postavke učitane!',
			update: 'Postavke ažurirane!',
			ARLcopied: 'ARL kopiran u međuspremnik'
		}
	},
	sidebar: {
		home: 'početna',
		search: 'pretraživanje',
		charts: 'ljestvice',
		favorites: 'favoriti',
		linkAnalyzer: 'analizator linka',
		settings: 'postavke',
		about: 'o programu'
	},
	tracklist: {
		downloadSelection: 'Preuzmi selekciju'
	}
};

const ar = {
	globals: {
		welcome: 'مرحبأ بك في ديمكس',
		back: 'رجوع',
		loading: 'جار التحميل',
		download: 'تحميل {thing}',
		by: 'بواسطة {artist}',
		in: 'في {album}',
		download_hint: 'تحميل',
		play_hint: 'تشغيل',
		toggle_download_tab_hint: 'عرض/اخفاء',
		clean_queue_hint: 'تم المسح',
		cancel_queue_hint: 'الغاء الكل',
		listTabs: {
			empty: '',
			all: 'الكل',
			top_result: 'افضل النتائج',
			album: 'البوم | البومات',
			artist: 'فنان | فنانون',
			single: 'اغنية | اغنية',
			title: 'عنوان | عناوين',
			track: 'مقطع | مقاطع',
			trackN: '0 مقاطع | {n} مقطع | {n} مقطع',
			releaseN: '0 اصدار | {n} اصدار | {n} اصدار',
			playlist: 'قائمة تشغيل | قوائم تشغيل',
			compile: 'مجموعة | مجموعات',
			ep: 'ep | eps',
			spotifyPlaylist: 'قائمة تشغيل سبوتفاي | قوائم تشغيل سبوتفاي',
			releaseDate: 'تاريخ الاصدار',
			error: 'خطأ'
		}
	},
	about: {
		titles: {
			usefulLinks: 'روابط مهمة',
			bugReports: 'ابلاغ عن مشكلة',
			contributing: 'مساهمة',
			donations: 'التبرع',
			license: 'الرخصة'
		},
		subtitles: {
			bugReports: "هل هناك شيء لا يعمل في ديمكس؟ أخبرنا",
			contributing: 'تريد المساهمة في هذا المشروع؟ يمكنك القيام بذلك بعدة طرق',
			donations: 'تريد المساهمة مادياً؟ يمكنك التبرع'
		},
		usesLibrary: 'هذا البرنامج يستخدم مكتبة <strong>ديمكس</strong> والتي يمكنك استخدامها لإنشاء واجهة مستخدم خاصة بك لديمكس.',
		thanks: `شكرا لـ <strong>rtonno</strong>, و <strong>uhwot</strong> و <strong>lollilol</strong> لمساعدتي في هذا المشروع و لـ <strong>BasCurtiz</strong> و <strong>scarvimane</strong> لصنع الايقونة.`,
		upToDate: `تابع اخر التحديثات في قناة الاخبار على تلكرام <a href="https://t.me/RemixDevNews" target="_blank"></a>.`,
		officialWebsite: 'الموقع الرسمي',
		officialRepo: 'مستودع المكتبة الرسمي',
		officialWebuiRepo: 'مستودع واجهة الويب الرسمي',
		officialSubreddit: 'السب ريدت الرسمي',
		newsChannel: 'قناة الاخبار',
		questions: `إذا كانت لديك أسئلة أو مشاكل في التطبيق ، فابحث عن حل في السب ريدت اولاً <a href="https://www.reddit.com/r/deemix" target="_blank">subreddit</a> بعد ذلك ، إذا لم تعثر على أي شيء ، يمكنك نشرمشكلتك على السب ريدت .`,
		beforeReporting: `قبل ان تبلغ عن خطأ، تأكد من أنك تشغل أحدث إصدار من التطبيق وأن ما تريد الإبلاغ عنه هو في الواقع خطأ وليس مشكلة من جهتك.`,
		beSure: `تأكد من أن الخطأ يمكن إعادة إنتاجه على أجهزة أخرى و ايضاً <strong>لا</strong> تبلغ علة خطأ تم التبليغ عنه سابقاً.`,
		duplicateReports: 'سيتم إغلاق تقارير الأخطاء المكررة ، لذلك ترقب ذلك.',
		dontOpenIssues: `<strong>DO NOT</strong> open issues for asking questions, there is a subreddit for that.`,
		newUI: `If you're fluent in python you could try to make a new UI for the app using the base library, or fix bugs in the library with a pull request on the <a href="https://codeberg.org/RemixDev/deemix" target="_blank">repo</a>.`,
		acceptFeatures: `أقبل اقتراحات الميزات أيضًا ، ولكن لا أشياء معقدة ، فقط اشياء يمكنني تنفيذها مباشرة في التطبيق وليس في المكتبة.`,
		otherLanguages: `إذا كنت تجيد لغة برمجة أخرى ، يمكنك محاولة تحويل ديمكس إلى لغات برمجة أخرى!`,
		understandingCode: `أنت بحاجة إلى مساعدة في فهم الكود؟ فقط اتصل بـ RemixDev على تيليكرام او ريديت.`,
		contributeWebUI: `If you know Vue.js (JavaScript), HTML or CSS you could contribute to the <a href="https://codeberg.org/RemixDev/deemix-webui" target="_blank">WebUI</a>.`,
		itsFree: `يجب ان تتذكر ان <strong>هذا هو مشروع مجاني</strong> <strong>و عليك دعم الفنانين المفضلين لك قبل ان تدعم مطورين البرنامج</strong>.`,
		notObligated: `لا تشعر بالالتزام بالتبرع ، لكني أقدر ذلك على أي حال!`,
		lincensedUnder: `This work is licensed under the
			<a rel="license" href="https://www.gnu.org/licenses/gpl-3.0.en.html" target="_blank"
				>GNU General Public License 3.0</a
			>.`
	},
	charts: {
		title: 'قائمة الجداول',
		changeCountry: 'تغيير الدولة',
		download: 'تحميل قائمة الجدول'
	},
	errors: {
		title: 'خطأ في {name}',
		ids: {
			invalidURL: 'الرابط غير صحيح',
			unsupportedURL: 'الرابط غير متاح حتى الانً',
			ISRCnotOnDeezer: 'رمز المقطع غير متوفر في ديزر',
			notYourPrivatePlaylist: "لا يمكنك تحميل قوائم التشغيل الخاصة و المخفية.",
			spotifyDisabled: 'لم يتم اعداد ميزات سبوتفاي بالطرقة الصحيحة .',
			trackNotOnDeezer: 'المقطع لا يوجد في ديزر!',
			albumNotOnDeezer: 'الالبوم لا يوجد في ديزر!',
			notOnDeezer: 'المقطع لا يوجد في ديزر!',
			notEncoded: 'لم يتم تشفير المقطع حتى الانً!',
			notEncodedNoAlternative: 'لم يتم تشفير المقطع حتى الآن ولم يتم العثور على بديل!',
			wrongBitrate: 'لم يتم العثور على المقطع في الدقة المطلوبة.',
			wrongBitrateNoAlternative: 'لم يتم العثور على المقطع في الدقة المطلوبة و لا توجد دقة بديلة!',
			no360RA: 'المقطع غير متوفر في Reality Audio 360.',
			notAvailable: "المقطع غير متوفر في سيرفرات ديزر!",
			notAvailableNoAlternative: "المقطع غير متوفر في سيرفرات ديزر و لا يوجد بديل حتى الان!"
		}
	},
	favorites: {
		title: 'المفضلات',
		noPlaylists: 'لا يوجد قوائم تشغيل',
		noAlbums: 'لم لا توجد البومات مفضلة',
		noArtists: 'لا يوجد فنانين مفضلين',
		noTracks: 'لا توجد مقاطع مفضلة'
	},
	home: {
		needTologin: 'يجب عليك التسجيل في حساب ديزر قبل بدء التحميل.',
		openSettings: 'فتح الاعدادات',
		sections: {
			popularPlaylists: 'قوائم تشغيل مشهورة',
			popularAlbums: 'اكثر الالبومات سماعأ'
		}
	},
	linkAnalyzer: {
		info: 'يمكنك استخدام هذا القسم للعثور على مزيد من المعلومات حول الرابط الذي تحاول تنزيله.',
		useful:
			" كمثال هذا مفيد إذا كنت تحاول تنزيل بعض المقاطع الغير المتاحة في بلدك وتريد معرفة مكان توفرها .",
		linkNotSupported: 'هذا الرابط غير معتمد حتى الآن',
		linkNotSupportedYet: 'يبدو أن هذا الرابط غير معتمد حتى الآن ، حاول تحليل رابط آخر.',
		table: {
			id: 'ID',
			isrc: 'ISRC',
			upc: 'UPC',
			duration: 'المدة الزمنية',
			diskNumber: 'رقم القرص',
			trackNumber: 'رقم المقطع',
			releaseDate: 'تاريخ الاصدار',
			bpm: 'BPM',
			label: 'Label',
			recordType: 'نوع التسجيل',
			genres: 'النوع الفني',
			tracklist: 'قائمة المقاطع'
		}
	},
	search: {
		startSearching: 'ابدأ البحث!',
		description:
			'يمكنك البحث عن مقطع ، ألبوم كامل ، فنان ، قائمة تشغيل .... كل شيء! يمكنك أيضًا لصق رابط ديزر',
		fans: '{n} متابعون',
		noResults: 'لا يوجد نتائج',
		noResultsTrack: 'لم يتم العثور على مقاطع',
		noResultsAlbum: 'لم يتم العثور على البومات',
		noResultsArtist: 'لم يتم العثور على فنانين',
		noResultsPlaylist: 'لم يتم العثور على قوائم تشغيل'
	},
	searchbar: 'ابحث عن أي شيء تريده (أو الصق رابط)',
	downloads: 'التحميلات',
	toasts: {
		addedToQueue: '{item} تمت إلأضافة إلى قائمة الانتظار',
		alreadyInQueue: '{item} حالياً  في قائمة الانتظار!',
		finishDownload: '{item} انتهى تحميل.',
		allDownloaded: 'اكتملت جميع التنزيلات!',
		refreshFavs: 'اكتمل التحديث!',
		loggingIn: 'جار تسجيل الدخول...',
		loggedIn: 'تم تسجيل الدخول',
		alreadyLogged: 'تم تسجيل الدخول بالفعل',
		loginFailed: "تعذر تسجيل الدخول",
		loggedOut: 'تم تسجيل الخروج',
		cancellingCurrentItem: 'جار الغاء العنصر الحالي.',
		currentItemCancelled: 'تم الغاء العنصر الحالي.',
		startAddingArtist: 'جار اضافة {artist} البوم الى قائمة الانتضار',
		finishAddingArtist: 'تم اضافة {artist} البوم الى قائمة الانتضار',
		startConvertingSpotifyPlaylist: 'جار تحويل مقاطع سبوتفاي الى مقاطع ديزر',
		finishConvertingSpotifyPlaylist: 'تم تحويل قائمة تشغيل سبوتفاي',
		loginNeededToDownload: 'يجب عليك تسجيل الدخول لتحميل المقاطع!'
	},
	settings: {
		title: 'الاعدادات',
		languages: 'اللغات',
		login: {
			title: 'تسجيل الدخول',
			loggedIn: 'تم تسجيل الدخول كـ {username}',
			arl: {
				question: 'كيفية الحصول علة ARL',
				update: 'ارفع ال ARL'
			},
			logout: 'تسجيل الخروج'
		},
		appearance: {
			title: 'المظهر',
			slimDownloadTab: 'لوحة التحميل الرفيعة'
		},
		downloadPath: {
			title: 'مسار التحميل'
		},
		templates: {
			title: 'القوالب',
			tracknameTemplate: 'قالب اسم المقطع',
			albumTracknameTemplate: 'قالب مقطع الالبوم',
			playlistTracknameTemplate: 'قالب مقطع قائمة التشغيل'
		},
		folders: {
			title: 'الملفات',
			createPlaylistFolder: 'اصنع ملف لقائمة التشغيل',
			playlistNameTemplate: 'قالب ملف قائمة التشغيل',
			createArtistFolder: 'اصنع ملف للفنان',
			artistNameTemplate: 'قالب ملف الفنان',
			createAlbumFolder: 'اصنع ملف للالبوم',
			albumNameTemplate: 'قالب ملف الالبوم',
			createCDFolder: 'اصنع ملف للاقراص',
			createStructurePlaylist: 'اصنع هيكل مجلدات لقوائم التشغيل',
			createSingleFolder: 'اصنع هيكل مجلدات لالبومات ذات الاغنية الواحدة'
		},
		trackTitles: {
			title: 'عنوان المقطع',
			padTracks: 'Pad tracks',
			paddingSize: 'Overwrite padding size',
			illegalCharacterReplacer: 'محول الكتابات الغير مسموح بها'
		},
		downloads: {
			title: 'التحميلات',
			queueConcurrency: 'التنزيلات المتزامنة',
			maxBitrate: {
				title: 'الدقة المفضلة',
				9: 'FLAC 1411kbps',
				3: 'MP3 320kbps',
				1: 'MP3 128kbps'
			},
			overwriteFile: {
				title: 'هل يمكنني استبدال الملفات?',
				y: 'نعم, استبدال الملفات',
				n: "لا, لا تبدل الملفات",
				t: 'استبدل العلامات فقط',
				b: 'لا ، احتفظ بالملفين وأضف رقمًا إلى الملف المكرر'
			},
			fallbackBitrate: 'تراجع الدقة',
			fallbackSearch: 'تراجع البحث',
			logErrors: 'إنشاء ملفات سجل للأخطاء',
			logSearched: 'إنشاء ملفات سجل للمقاطع التي تم البحث عنها',
			createM3U8File: 'انشاء ملف لقوائم التشغيل',
			syncedLyrics: 'انشاء ملف لكلمات الاغنية',
			playlistFilenameTemplate: 'قالب اسم ملف قائمة التشغيل',
			saveDownloadQueue: 'حفظ قائمة انتظار التنزيل عند إغلاق التطبيق'
		},
		covers: {
			title: 'غلاف الالبوم',
			saveArtwork: 'احفظ الغلاف',
			coverImageTemplate: 'تغطية قالب الاسم',
			saveArtworkArtist: 'احفظ صورة الفنان',
			artistImageTemplate: 'قالب صورة الفنان',
			localArtworkSize: 'حجم الصورة',
			embeddedArtworkSize: 'حجم الصورة المدمجة',
			localArtworkFormat: {
				title: 'بأي صيغة تريد حفظ الصورة?',
				jpg: 'jpeg صورة',
				png: 'png صورة',
				both: 'الاثنين png و jpeg'
			},
			jpegImageQuality: 'JPEG دقة صورة'
		},
		tags: {
			head: 'العلامات التي يتم حفظها',
			title: 'العنوان',
			artist: 'الفنان',
			album: 'الالبوم',
			cover: 'الغلاف',
			trackNumber: 'رقم المقطع',
			trackTotal: 'مجموع المقاطع',
			discNumber: 'رقم القرص',
			discTotal: 'مجموع الاقراص',
			albumArtist: 'فنان الالبوم',
			genre: 'Genre',
			year: 'السنة',
			date: 'التاريخ',
			explicit: 'كلمات اغنية صريحة للكبار',
			isrc: 'ISRC',
			length: 'طول المقطع',
			barcode: 'Album Barcode (UPC)',
			bpm: 'BPM',
			replayGain: 'Replay Gain',
			label: 'Album Label',
			lyrics: 'كلمات غير متزامنة',
			copyright: 'حقوق النشر',
			composer: 'ملحن',
			involvedPeople: 'الناس المشتركون'
		},
		other: {
			title: 'غير',
			savePlaylistAsCompilation: 'حفظ قوائم التشغيل كمجموعة',
			useNullSeparator: 'استخدم فاصل فارغ',
			saveID3v1: 'احفظ ملف ID3v1',
			multiArtistSeparator: {
				title: 'كيف تريد فصل الفنانين?',
				nothing: 'احفظ الفنان الرئيسي فقط',
				default: 'استخدام المواصفات القياسية',
				andFeat: 'استخدام& و feat.',
				using: 'استخدام "{separator}"'
			},
			singleAlbumArtist: 'احفظ فقط فنان الألبوم الرئيسي',
			albumVariousArtists: 'احتفظ بـ "فنانين متنوعين" في ألبوم الفنانين',
			removeAlbumVersion: 'إزالة "إصدار الألبوم" من عنوان المسار',
			removeDuplicateArtists: 'إزالة مجموعات الفنانين',
			dateFormat: {
				title: 'صيغة التاريخ لملفات flac',
				year: 'س س س س',
				month: 'ش ش',
				day: 'ي ي'
			},
			featuredToTitle: {
				title: 'ماذا علي أن أفعل مع الفنانين الغير رئيسيين ?',
				0: 'لا شيء',
				1: 'حذفه من العنوان',
				3: 'حذفه من عنوان الاغنية و الالبوم',
				2: 'وضعه في العنوان'
			},
			titleCasing: 'نوع كتابة العناون',
			artistCasing: 'نوع كتابة الفنان',
			casing: {
				nothing: 'بدون تغيير',
				lower: 'احرف صغيرة',
				upper: 'احرف كبيرة',
				start: 'حرف كبير في بداية كل كلمة',
				sentence: 'مثل جملة'
			},
			previewVolume: 'معاينة الحجم',
			executeCommand: {
				title: 'الأمر للتنفيذ بعد التنزيل',
				description: 'اتركه فارغًا بدون إجراء'
			}
		},
		spotify: {
			title: 'مميزات سبوتفاي',
			clientID: 'معرف عميل سبوتفاي',
			clientSecret: 'الكود السري لعميل سبوتفاي',
			username: 'اسم مستخدم سبوتفاي'
		},
		reset: 'إعادة تعيين إلى الافتراضي',
		save: 'حفظ',
		toasts: {
			init: 'تم تحميل الإعدادات!',
			update: 'تم تحديث الاعدادات!',
			ARLcopied: 'تم نسخ ARL إلى الحافظة'
		}
	},
	sidebar: {
		home: 'الرئيسية',
		search: 'بحث',
		charts: 'قائمة الجداول',
		favorites: 'المفضلة',
		linkAnalyzer: 'محلل الروابط',
		settings: 'الاعدادات',
		about: 'حول'
	},
	tracklist: {
		downloadSelection: 'تحميل الاختيار'
	}
};

const ko = {
	globals: {
		welcome: '잘왔다, deemix에',
		back: '뒤로',
		loading: '불러오는 중',
		download: '{thing} 다운로드',
		by: 'by {artist}',
		in: 'in {album}',
		download_hint: '다운로드',
		play_hint: '재생',
		toggle_download_tab_hint: '펼치기/접기',
		clean_queue_hint: '비우기 완료',
		cancel_queue_hint: '모두 취소',
		open_downloads_folder: '다운로드 폴더 열기',
		cut: '잘라내기',
		copy: '복사',
		copyLink: '링크 복사',
		copyImageLink: '이미지 링크 복사',
		copyDeezerLink: 'deezer 링크 복사',
		paste: '붙여넣기',
		listTabs: {
			empty: '',
			all: '전체',
			top_result: '가장 일치하는 결과',
			album: '앨범 | 앨범',
			artist: '아티스트 | 아티스트',
			single: '싱글 | 싱글',
			title: '제목 | 제목',
			track: '트랙 | 트랙',
			trackN: '0 트랙 | {n} 트랙 | {n} 트랙',
			releaseN: '0 발매 | {n} 발매 | {n} 발매',
			playlist: '재생목록 | 재생목록',
			compile: '편찬물 | 편찬물',
			ep: 'ep | eps',
			more: '더 많은 앨범',
			featured: '특집',
			spotifyPlaylist: '스포티파이 재생목록 | 스포티파이 재생목록',
			releaseDate: '발매일자',
			error: '오류'
		}
	},
	about: {
		titles: {
			usefulLinks: '유용한 링크',
			bugReports: '버그 제보',
			contributing: '기여자',
			donations: '후원',
			license: '이용정책'
		},
		subtitles: {
			bugReports: "무언가 안되는 것이 있다고요? 말해주세요!",
			contributing: '이 프로젝트에 기여하고 싶다고요? 어렵지 않아요!',
			donations: '금전적으로 지원하고 싶다고요? 후원하세요!'
		},
		usesLibrary: '이 프로그램은 <strong>deemix</strong> 라이브러리를 사용합니다, 해당 라이브러리로 자신만의 deemix를 만들 수 있습니다.',
		thanks: `이 프로젝트를 도와준 <strong>rtonno</strong>, <strong>uhwot</strong> 그리고 <strong>lollilol</strong>님과 아이콘을 만들어준 <strong>BasCurtiz</strong> 그리고 <strong>scarvimane</strong>님에게 감사를.`,
		upToDate: `새로운 업데이트 소식을 듣고 싶으면 텔레그램 <a href="https://t.me/RemixDevNews" target="_blank">새소식 정보통</a>을 참고하세요.`,
		officialWebsite: '공식 웹사이트',
		officialRepo: '공식 라이브러리 저장소',
		officialWebuiRepo: '공식 WebUI 저장소',
		officialSubreddit: '공식 서브레딧',
		newsChannel: '새 소식 알리미',
		questions: `프로그램에 대한 질문이나 문제에 관한 것은, 먼저 <a href="https://www.reddit.com/r/deemix" target="_blank">서브레딧</a>에서 답변을 검색해보세요. 그리고, 서브레딧에서 답변을 찾기 못한 경우에 다음 순서를 이용해주세요.`,
		beforeReporting: `버그 제보를 하기 전에 먼저 최신 버전의 프로그램을 실행하고 있는지, 제보하고자 하는 것이 버그이지 오로지 당신의 목적을 이루기 위한 요구가 아님을 확인해주세요.`,
		beSure: `해당 버그가 다른 장치에서도 재현이 가능한지 확인하고 이미 제보된 버그의 경우에는 중복해서 <strong>보고하지 마세요</strong>.`,
		duplicateReports: '중복된 버그 제보의 경우는 해당 요청을 닫을 것이니, 두 눈 뜨고 지켜보세요.',
		dontOpenIssues: `질문에 관한 것은 이슈를 <strong>열지 마세요</strong>, 서브레딧이 있습니다.`,
		newUI: `만약 당신이 파이썬에 능통하고 기본적인 라이브러리를 이용하여 새로운 UI를 만들었거나, 라이브러리의 버그를 수정하였다면 <a href="https://codeberg.org/RemixDev/deemix" target="_blank">저장소</a>에 풀 리퀘스트 해주세요.`,
		acceptFeatures: `복잡하지 않은 기능 추가도 받습니다, 라이브러리가 아닌 앱에서 직접 구현할 수 있는 것으로요.`,
		otherLanguages: `당신이 다른 프로그램 언어에 능통하면, 이 deemix 프로그램을 다른 프로그래밍 언어로 포팅할 수도 있습니다!`,
		understandingCode: `코드를 이해하는 데 도움이 필요합니까? 위에 있는 RemixDev, 텔레그램, 서브레딧 링크를 누르세요.`,
		contributeWebUI: `만약 당신이 Vue.js (JavaScript), HTML 또는 CSS 개발자라면 <a href="https://codeberg.org/RemixDev/deemix-webui" target="_blank">WebUI</a>에 도움을 주세요.`,
		itsFree: `사용하기 전에 이 프로그램이 <strong>무료 프로젝트</strong>이고 개발자를 지원하기 전에 <strong>예술가들</strong>을 먼저 지원해야 함을 기억하세요.`,
		notObligated: `기부는 프로젝트를 지속할 수 있는 동력이 됩니다!`,
		lincensedUnder: `이 작업이 요구하고 있는 라이센스는 아래와 같습니다<br>
			<a rel="license" href="https://www.gnu.org/licenses/gpl-3.0.en.html" target="_blank">GNU General Public License 3.0</a>.`
	},
	charts: {
		title: '차트',
		changeCountry: '국가 변경',
		download: '차트 다운로드'
	},
	errors: {
		title: '오류 발생: {name}',
		ids: {
			unsupportedURL: 'URL 지원 누락',
			invalidURL: 'URL 인식 실패',
			ISRCnotOnDeezer: '트랙 코드 식별이 불가능합니다',
			notYourPrivatePlaylist: "다른 사람의 비공개 재생 목록을 다운로드 할 수 없습니다.",
			spotifyDisabled: '스포티파이 기능이 올바르게 설정되지 않았습니다.',
			trackNotOnDeezer: 'Deezer에서 트랙을 찾을 수 없습니다!',
			albumNotOnDeezer: 'Deezer에서 앨범을 찾을 수 없습니다!',
			notOnDeezer: 'Deezer에서 트랙을 찾을 수 없습니다!',
			notEncoded: '트랙이 아직 변환(encode)되지 않았습니다!',
			notEncodedNoAlternative: '트랙이 아직 변환(encode)되지 않았을 뿐더러 대체할 것을 찾지 못했습니다!',
			wrongBitrate: '요구하는 비트레이트의 트랙을 찾을 수 없습니다.',
			wrongBitrateNoAlternative: '요구하는 비트레이트를 찾을 수 없을 뿐더러 대체할 것을 찾지 못했습니다!',
			no360RA: '해당 트랙은 360 리얼리티 오디오에 존재하지 않습니다.',
			notAvailable: "해당 트랙은 Deezer 서버에 존재하지 않습니다!",
			notAvailableNoAlternative: "해당 트랙은 Deezer 서버에 존재하지 않을 뿐더러 대체할 것을 찾지 못했습니다!",
			noSpaceLeft: "장치에 여유 공간이 없습니다!",
			albumDoesntExists: "트랙의 앨범이 존재하지 않습니다, 정보 수집에 실패했습니다."
		}
	},
	favorites: {
		title: '즐겨듣는 음악',
		noPlaylists: '즐겨듣는 재생목록이 없습니다',
		noAlbums: '즐겨듣는 앨범이 없습니다',
		noArtists: '즐겨듣는 아티스트가 없습니다',
		noTracks: '즐겨듣는 트랙이 없습니다'
	},
	home: {
		needTologin: '다운로드를 시작하기 전에 Deezer 계정에 로그인을 해야합니다.',
		openSettings: '설정 열기',
		sections: {
			popularPlaylists: '인기있는 재생목록',
			popularAlbums: '가장 많이 재생된 앨범'
		}
	},
	linkAnalyzer: {
		info: '이 항목에서는 다운로드를 시도할 링크에 대한 더 많은 정보를 찾을 수 있습니다.',
		linkNotSupported: '해당 링크는 아직 지원하지 않습니다',
		useful: "접속한 국가에서는 재생할 수 없는 특정 트랙을 다운로드 하기 위해서 가능한 국가를 찾는데 유용하게 쓰입니다.",
		linkNotSupportedYet: '해당 링크는 아직 지원하지 않습니다, 다른 링크로 시도해보세요.',
		table: {
			id: 'ID',
			isrc: 'ISRC',
			upc: 'UPC',
			duration: '길이',
			diskNumber: '디스크 번호',
			trackNumber: '트랙 번호',
			releaseDate: '발매일자',
			bpm: 'BPM',
			label: '라벨',
			recordType: '녹음 종류',
			genres: '장르',
			tracklist: '트랙목록'
		}
	},
	search: {
		startSearching: '검색을 해보세요!',
		description: '트랙, 아티스트, 재생목록, Deezer 링크 등으로 검색할 수 있습니다!',
		fans: '{n}명의 팬들',
		noResults: '결과 없음',
		noResultsTrack: '발견된 트랙 없음',
		noResultsAlbum: '발견된 앨범 없음',
		noResultsArtist: '발견된 아티스트 없음',
		noResultsPlaylist: '발견된 재생목록 없음'
	},
	searchbar: '원하는 것을 검색하세요 (링크를 붙여넣을 수도 있습니다)',
	downloads: '다운로드들',
	toasts: {
		restoringQueue: '다운로드 대기 열 복원중...',
		queueRestored: '다운로드 대기 열이 복원되었습니다!',
		addedToQueue: '대기열에 {item}(이)가 추가되었습니다',
		addedMoreToQueue: '대기열에 {n} 항목이 추가되었습니다',
		alreadyInQueue: '{item}(이)가 이미 대기열에 존재합니다!',
		finishDownload: '{item} 항목이 다운로드 완료되었습니다.',
		allDownloaded: '모든 다운로드가 완료되었습니다!',
		refreshFavs: '새로고침이 완료되었습니다!',
		loggingIn: '로그인 하는 중...',
		loggedIn: '로그인 되었습니다',
		alreadyLogged: '이미 로그인되어 있습니다',
		loginFailed: "로그인 할 수 없습니다",
		loggedOut: '로그아웃 하였습니다',
		cancellingCurrentItem: '현재 항목을 취소 중입니다.',
		currentItemCancelled: '항목이 취소되었습니다.',
		startAddingArtist: '{artist} 앨범을 대기열에 추가 중입니다',
		finishAddingArtist: '{artist} 앨범이 대기열에 추가되었습니다',
		startConvertingSpotifyPlaylist: '스포티파이 트랙을 Deezer 트랙으로 전환 중입니다',
		finishConvertingSpotifyPlaylist: '스프토파이 재생 목록이 전환되었습니다',
		loginNeededToDownload: '트랙을 다운로드하려면 로그인이 필요합니다!',
		deezerNotAvailable: 'Deezer 사이트는 현재 귀하의 국가에서 사용이 불가능합니다. VPN을 사용하세요.'
	},
	settings: {
		title: '설정',
		languages: '언어',
		login: {
			title: '로그인',
			loggedIn: '{username}(으)로 로그인되었습니다',
			arl: {
				question: 'ARL을 어떻게 확인합니까?',
				update: 'ARL 업데이트'
			},
			logout: '로그아웃',
			question: '스포티파이 기능들을 쓰려면 어떻게 해야합니까?'
		},
		appearance: {
			title: '외관',
			slimDownloadTab: '얇은 다운로드 탭'
		},
		downloadPath: {
			title: '다운로드 경로'
		},
		templates: {
			title: '템플릿',
			tracknameTemplate: '트랙이름 템플릿',
			albumTracknameTemplate: '앨범 트랙 템플릿',
			playlistTracknameTemplate: '재생목록 트랙 템플릿'
		},
		folders: {
			title: '폴더',
			createPlaylistFolder: '재생목록을 위한 폴더 생성',
			playlistNameTemplate: '재생목록 폴더 템플릿',
			createArtistFolder: '아티스트를 위한 폴더 생성',
			artistNameTemplate: '아티스트 폴더 템플릿',
			createAlbumFolder: '앨범을 위한 폴더 생성',
			albumNameTemplate: '앨범 폴더 템플릿',
			createCDFolder: 'CD를 위한 폴더 생성',
			createStructurePlaylist: '재생목록을 위한 폴더 구조 생성',
			createSingleFolder: '싱글 앨범을 위한 폴더 구조 생성'
		},
		trackTitles: {
			title: '트랙 제목',
			padTracks: '트랙 채워넣기',
			paddingSize: '채워넣을 크기',
			illegalCharacterReplacer: '지원하지 않는 글자 대체'
		},
		downloads: {
			title: '다운로드',
			queueConcurrency: '동시 다운로드',
			maxBitrate: {
				title: '선호하는 비트레이트',
				9: 'FLAC 1411kbps',
				3: 'MP3 320kbps',
				1: 'MP3 128kbps'
			},
			overwriteFile: {
				title: '파일을 덮어쓸까요?',
				y: '네, 파일을 덮어쓰세요',
				n: "아뇨, 파일을 덮어쓰지 마세요",
				t: '태그만 덮어쓰세요',
				b: '아뇨, 양쪽 다 놔두고 중복되는 파일에 번호를 추가하세요',
				e: "아뇨, 확장명을 변경하세요"
			},
			fallbackBitrate: '비트레이트 대비책',
			fallbackSearch: '검색 대비책',
			logErrors: '오류 발생시 로그 파일 생성',
			logSearched: '검색한 트랙에 대한 로그 파일 생성',
			createM3U8File: '재생목록 파일 생성',
			syncedLyrics: '.lyr 파일 생성 (가사 동기화)',
			playlistFilenameTemplate: '재생목록 파일이름 템플릿',
			saveDownloadQueue: '프로그램을 닫을 때 다운로드 대기열 저장'
		},
		covers: {
			title: '앨범 커버',
			saveArtwork: '커버 저장',
			coverImageTemplate: '커버 이름 템플릿',
			saveArtworkArtist: '아티스트 이미지 저장',
			artistImageTemplate: '아티스트 이미지 템플릿',
			localArtworkSize: '외부 저장 그림 크기',
			embeddedArtworkSize: '내부 저장 그림 크기',
			localArtworkFormat: {
				title: '별도로 저장할 그림의 형식을 무엇으로 하시겠습니까?',
				jpg: 'jpeg 이미지',
				png: 'png 이미지',
				both: 'jpeg와 png 둘 다'
			},
			jpegImageQuality: 'JPEG 이미지 품질',
			embeddedArtworkPNG: '포함된 그림의 형식을 PNG로 저장합니다',
			embeddedPNGWarning: 'PNG는 Deezer에서 공식적으로 지원하지 않기 때문에 버그가 있을 수 있습니다',
			imageSizeWarning: 'x1200 크기를 초과해서는 Deezer에서 공식적으로 사용되지 않기 때문에 문제가 생길 수 있습니다',
			coverDescriptionUTF8: '커버 설명을 UTF8 포맷을 이용해 저장합니다 (iTunes 커버 오류 해결)'
		},
		tags: {
			head: '저장할 태그를 선택하세요',
			title: '제목',
			artist: '아티스트',
			album: '앨범',
			cover: '커버',
			trackNumber: '트랙 번호',
			trackTotal: '전체 트랙 크기',
			discNumber: '디스크 번호',
			discTotal: '전체 디스크 수',
			albumArtist: '앨범 아티스트',
			genre: '장르',
			year: '연도',
			date: '일자',
			explicit: '노골적 가사',
			isrc: 'ISRC',
			length: '트랙 길이',
			barcode: '앨범 바코드 (UPC)',
			bpm: 'BPM',
			replayGain: '리플레이 게인',
			label: '앨범 라벨',
			lyrics: '비동기 가사',
			copyright: '저작권',
			composer: '작곡가',
			involvedPeople: '관련있는 사람들'
		},
		other: {
			title: '기타',
			savePlaylistAsCompilation: '재생목록을 편찬물로 저장',
			useNullSeparator: 'null 구분자 사용',
			saveID3v1: 'ID3v1 태그 형식으로 저장',
			multiArtistSeparator: {
				title: '아티스트를 어떻게 구분하시겠습니까?',
				nothing: '주요 아티스트만 저장',
				default: '표준 스펙을 사용',
				andFeat: '& 기호와 feat 사용.',
				using: '"{separator}" 사용'
			},
			singleAlbumArtist: '주요 앨범 아티스트만 저장',
			albumVariousArtists: '앨범 아티스트에 "Various Artists"(다양한 아티스트들) 유지',
			removeAlbumVersion: '트랙 제목에 "Album Version"(앨범 버전) 제거',
			removeDuplicateArtists: '아티스트들의 협업 제거',
			dateFormat: {
				title: 'FLAC 파일의 날짜 형식',
				year: 'YYYY',
				month: 'MM',
				day: 'DD'
			},
			featuredToTitle: {
				title: '특집에 참여한 아티스트들에 할 수 있는 것이 무엇이 있나요?',
				0: '아무것도 하지 않음',
				1: '제목에서 제거',
				3: '앨범 제목과 트랙에서 제거',
				2: '제목으로 이동'
			},
			titleCasing: '제목 케이싱',
			artistCasing: '아티스트 케이싱',
			casing: {
				nothing: '변함없이 유지',
				lower: '소문자로',
				upper: '대문자로',
				start: '각 단어 앞 글자를 대문자로',
				sentence: '문장처럼'
			},
			previewVolume: '미리듣기 볼륨',
			executeCommand: {
				title: '다운로드 후 실행할 명령어',
				description: '빈칸으로 두면 아무 일도 없습니다'
			}
		},
		spotify: {
			title: '스포티파이 기능',
			clientID: 'Spotify ClientID',
			clientSecret: 'Spotify Client Secret',
			username: 'Spotify 사용자이름'
		},
		reset: '기본 설정으로 초기화',
		save: '저장',
		toasts: {
			init: '설정을 불러왔습니다!',
			update: '새로운 설정으로 갱신되었습니다!',
			ARLcopied: 'ARL가 클립보드에 복사되었습니다'
		}
	},
	sidebar: {
		home: '홈',
		search: '검색',
		charts: '차트',
		favorites: '즐겨찾기',
		linkAnalyzer: '링크 분석기',
		settings: '설정',
		about: '정보'
	},
	tracklist: {
		downloadSelection: '선택 다운로드'
	}
};

const ph = {
	globals: {
		welcome: 'Welcome sa deemix',
		back: 'bumalik',
		loading: 'kumakarga',
		download: 'I-download {thing}',
		by: 'ayon sa {artist}',
		in: 'sa {album}',
		download_hint: 'I-download',
		play_hint: 'I-play',
		toggle_download_tab_hint: 'Palakihin/Paliitan',
		clean_queue_hint: 'Natapos na ang Pag-alis',
		cancel_queue_hint: 'Ikansel Lahat',
		open_downloads_folder: 'Buksan ang Polder ng Download',
		cut: 'i-cut',
		copy: 'kopyahin',
		copyLink: 'kopyahin ang link',
		copyImageLink: 'kopyahin ang imahe sa link',
		copyDeezerLink: 'kopyahin ang link ng deezer',
		paste: 'idikit',
		listTabs: {
			empty: '',
			all: 'lahat',
			top_result: 'nangungunang resulta',
			album: 'album | mga album',
			artist: 'artist | mga artist',
			single: 'single | mga single',
			title: 'pamagat | mga pamagat',
			track: 'track | mga track',
			trackN: '0 mga track | {n} track | {n} mga track',
			releaseN: '0 mga release | {n} release | {n} mga release',
			playlist: 'playlist | mga playlist',
			compile: 'pinagsama | mga pinagsama',
			ep: 'ep | mga ep',
			bundle: 'bundle | mga bundle',
			more: 'Iba pang mga album',
			featured: 'Ibinida sa',
			spotifyPlaylist: 'playlist sa spotify | mga playlist sa spotify',
			releaseDate: 'petsa ng paglabas',
			error: 'error'
		}
	},
	about: {
		updates: {
			currentVersion: 'Kasalukuyang version',
			versionNotAvailable: 'H/P',
			updateAvailable: `Hindi mo ginagamit ang pinakabagong version: {version}`,
			deemixVersion: 'deemix lib version'
		},
		titles: {
			usefulLinks: 'Nakatutulong na mga Link',
			bugReports: 'Report sa Bug',
			contributing: 'Pagtulong',
			donations: 'Mga donasiyon',
			license: 'Lisensiya'
		},
		subtitles: {
			bugReports: "Meron bang hindi gumagana sa deemix? Ipaalam mo sa amin!",
			contributing: 'Gusto mo bang tumulong sa proyektong ito? Pwede mong gawin iyan sa maraming paraan!',
			donations: 'Gusto mo bang tumulong sa pamamagitan ng pera? Pwede kang magbigay ng donasiyon!'
		},
		usesLibrary: 'Ang app na ito ay gumagamit ng library galing sa <strong>deemix</strong>, na kung saan ay pwede mong gamitin para gumawa ng sarili mong UI ng deemix.',
		thanks: `Salamat kay <strong>rtonno</strong>, <strong>uhwot</strong> at <strong>lollilol</strong> sa pagtulong sa akin para sa proyektong ito at kay <strong>BasCurtiz</strong> at <strong>scarvimane</strong> sa paggawa ng icon.`,
		upToDate: `Huwag magpapahuli sa mga update patungkol dito sa pamamagitan ng pagsali sa <a href="https://t.me/RemixDevNews" target="_blank">news channel</a> sa Telegram.`,
		officialWebsite: 'Opisyal na Website',
		officialRepo: 'Opisyal na Library Repository',
		officialWebuiRepo: 'Opisyal na Repository ng WebUI',
		officialSubreddit: 'Opisyal na Subreddit',
		newsChannel: 'News Channel',
		questions: `Kung may tanong ka o problema sa app, maghanap ka muna ng solusiyon sa <a href="https://www.reddit.com/r/deemix" target="_blank">subreddit</a>. Ngayon, kung wala ka talagang mahanap ay pwede kang mag-post patungkol sa iyong isyu doon sa subreddit.`,
		beforeReporting: `Bago ka magreport ng bug, siguraduhing pinakabagong version ang ginagamit mo at ang ire-report mo ay talagang bug at hindi dahil sa pagkakamali mo lang ng paggamit.`,
		beSure: `Siguraduhing nangyayari rin ang bug sa iba't ibang plataporma at tsaka <strong>HUWAG</strong> mo nang i-report ang bug kung ito ay naipa-alam na ng iba.`,
		duplicateReports: 'Isasara namin ang mga magkaparehong report sa bug, kaya alamin mo muna.',
		dontOpenIssues: `<strong>HUWAG</strong> kayong magbubukas ng isyu kung magtatanong lang kayo, meron tayong subreddit para diyan.`,
		newUI: `Kung ikaw ay maraming alam sa python, subukan mong gumawa ng bagong UI gamit ng base library, o kaya ayusin ang mga bug sa library sa pamamagitan ng pag-pull ng request sa <a href="https://codeberg.org/RemixDev/deemix" target="_blank">repo</a>.`,
		acceptFeatures: `Tumatangggap din ako ng mga feature, basta hindi komplikado, dahil diretso ko itong nilalagay sa app at hindi sa library.`,
		otherLanguages: `Kung ikaw ay maraming alam sa ibang programming language, maaari mo ring subukan i-port ang deemix sa iba't ibang programming language!`,
		understandingCode: `Kailangan mo ba ng tulong para maintindihan ang code? Bisitahin si RemixDev sa Telegram o sa Reddit.`,
		contributeWebUI: `Kung may alam ka sa Vue.js (JavaScript), HTML o kaya CSS, maaari kang sumali at tumulong dito sa <a href="https://codeberg.org/RemixDev/deemix-webui" target="_blank">WebUI</a>.`,
		itsFree: `Lagi mong tandaang <strong>ang proyektong ito ay libre</strong> at <strong>suportuhanmuna ang minamahal ninyong mga artist</strong> bago ang mga developer.`,
		notObligated: `Huwag mong pilitin ang sarili para mag-donate, Naiintindihan ka namin!`,
		lincensedUnder: `Ang aktibidad na ito ay lisensiyado sa
			<a rel="license" href="https://www.gnu.org/licenses/gpl-3.0.en.html" target="_blank">GNU General Public License 3.0</a>.`
	},
	charts: {
		title: 'Mga Chart',
		changeCountry: 'Palitan ang Country',
		download: 'I-download ang Chart'
	},
	errors: {
		title: 'Mga error sa {name}',
		ids: {
			invalidURL: 'Hindi makilala ang URL',
			unsupportedURL: 'Hindi pa suportado ang URL',
			ISRCnotOnDeezer: 'Ang Track ISRC ay hindi pwede sa Deezer',
			notYourPrivatePlaylist: "Hindi pwedeng i-download ang mga pribadong playlist ng iba.",
			spotifyDisabled: 'Hindi mo nai-set nang tama ang Spotify Features.',
			trackNotOnDeezer: 'Hindi mahanap ang track sa Deezer!',
			albumNotOnDeezer: 'Hindi mahanap ang album sa Deezer!',
			notOnDeezer: 'Hindi available ang track sa Deezer!',
			notEncoded: 'Hindi pa nae-encode ang track!',
			notEncodedNoAlternative: 'Hindi pa nae-encode ang track at walang mahanap na iba!',
			wrongBitrate: 'Hindi mahanap ang track sa gusto mong bitrate.',
			wrongBitrateNoAlternative: 'Hindi mahanap ang track sa gusto mong bitrate at walang mahanap na iba!',
			no360RA: 'Hindi pwede ang track para sa Reality Audio 360.',
			notAvailable: "Walang available na track sa server ng Deezer!",
			notAvailableNoAlternative: "Walang available na track sa server ng Deezer at walang mahanap na iba!",
			noSpaceLeft: "Wala nang natitirang space sa iyong device!"
		}
	},
	favorites: {
		title: 'Mga Paborito',
		noPlaylists: 'Walang makitang mga Playlist',
		noAlbums: 'Walang makitang mga Paboritong Album',
		noArtists: 'Walang makitang mga Paboritong Artist',
		noTracks: 'Walang makitang mga Paboritong Track'
	},
	home: {
		needTologin: 'Kailangan mong mag-log in sa iyong Deezer account bago ka makasimulang magdownload.',
		openSettings: 'Buksan ang Mga Setting',
		sections: {
			popularPlaylists: 'Mga sikat na playlist',
			popularAlbums: 'Pinakamaraming pinakikinggang mga album'
		}
	},
	linkAnalyzer: {
		info: 'Pwede gamitin ang section na ito para sa iba pang impormasyon patungkol sa link na gusto mong i-download.',
		useful: "Makatutulong ito kung meron kang gustong i-download na track na hindi available sa bansa mo at gusto mong malaman kung meron bang ganito kapag sa iba.",
		linkNotSupported: 'Hindi pa suportado ang link',
		linkNotSupportedYet: 'Mukhang hindi pa suportado itong link, iba na lang ang ilagay mo.',
		table: {
			id: 'ID',
			isrc: 'ISRC',
			upc: 'UPC',
			duration: 'Haba',
			diskNumber: 'Bilang ng Disk',
			trackNumber: 'Bilang ng Track',
			releaseDate: 'Petsa ng Release',
			bpm: 'BPM',
			label: 'Label',
			recordType: 'Uri ng Rekord',
			genres: 'Mga Genre',
			tracklist: 'Listahan ng Track'
		}
	},
	search: {
		startSearching: 'Simulang Maghanap!',
		description: 'Pwede kang maghanap ng track, buong album, artist, playlist.... kahit ano! Pwede ka ring mag-paste dito ng link na galing sa Deezer',
		fans: '{n} mga fan',
		noResults: 'Walang resulta',
		noResultsTrack: 'Walang mahanap na mga Track',
		noResultsAlbum: 'Walang mahanap na mga Album',
		noResultsArtist: 'Walang mahanap na mga Artist',
		noResultsPlaylist: 'Walang mahanap na mga Playlist'
	},
	searchbar: 'Maghanap ka ng gusto mo (o mag-paste ka ng link)',
	downloads: 'mga download',
	toasts: {
		restoringQueue: 'Binabalik ang download queue...',
		queueRestored: 'Naibalik na ang download queue!',
		addedToQueue: '{item} ay naidagdag sa queue',
		addedMoreToQueue: '{n} naidagdag rin sa queue',
		alreadyInQueue: '{item} ay meron na sa queue!',
		finishDownload: '{item} ay natapos nang i-download.',
		allDownloaded: 'Nadownload na lahat!',
		refreshFavs: 'Narefresh na!',
		loggingIn: 'Nagla-log in...',
		loggedIn: 'Na-login na',
		alreadyLogged: 'Nakalogin ka na',
		loginFailed: "Hindi maka-log in",
		loggedOut: 'Na-logout na',
		cancellingCurrentItem: 'Kinakansel ang item.',
		currentItemCancelled: 'Nakansel na ang item.',
		startAddingArtist: 'Idinadagdag si {artist} sa queue ng mga album',
		finishAddingArtist: 'Naidagdag na si {artist} sa queue ng mga album',
		startConvertingSpotifyPlaylist: 'Kino-convert ang mga track sa spotify papuntang Deezer',
		finishConvertingSpotifyPlaylist: 'Naconvert na ang playlist sa Spotify',
		loginNeededToDownload: 'Kailangan mong mag-login para madownload ang mga track!',
		deezerNotAvailable: 'Hindi available ang Deezer sa iyong bansa. Kailangan mong gumamit ng VPN.'
	},
	settings: {
		title: 'Mga Setting',
		languages: 'Mga Wika',
		login: {
			title: 'Login',
			loggedIn: 'Ikaw ay naka-login sa pangalang {username}',
			arl: {
				question: 'Paano ako makakuha ng sariling ARL?',
				update: 'I-update ang ARL'
			},
			logout: 'Logout',
			login: 'Mag-login gamit ng deezer.com'
		},
		appearance: {
			title: 'Hitsura',
			slimDownloadTab: 'Pinaliit na download tab'
		},
		downloadPath: {
			title: 'Paglalagyan ng Download'
		},
		templates: {
			title: 'Mga Template',
			tracknameTemplate: 'Template sa pangalan ng Track',
			albumTracknameTemplate: 'Template sa track ng Album',
			playlistTracknameTemplate: 'Template sa track ng Playlist'
		},
		folders: {
			title: 'Mga Folder',
			createPlaylistFolder: 'Gumawa ng folder para sa mga playlist',
			playlistNameTemplate: 'Template sa folder ng Playlist',
			createArtistFolder: 'Gumawa ng folder para sa artist',
			artistNameTemplate: 'Template sa folder ng Artist',
			createAlbumFolder: 'Gumawa ng folder para sa album',
			albumNameTemplate: 'Template sa folder ng Album',
			createCDFolder: 'Gumawa ng folder para sa mga CD',
			createStructurePlaylist: 'Gumawa ng istraktura ng folder para sa mga playlist',
			createSingleFolder: 'Gumawa ng istraktura ng folder para sa mga single'
		},
		trackTitles: {
			title: 'Pamagat sa mga track',
			padTracks: 'Mga track ng Pad',
			paddingSize: 'Patungan ang laki ng padding',
			illegalCharacterReplacer: 'Pamalit sa ilegal na Karakter'
		},
		downloads: {
			title: 'Mga Download',
			queueConcurrency: 'Mga Kasabay na Download',
			maxBitrate: {
				title: 'Gustong Bitrate',
				9: 'FLAC 1411kbps',
				3: 'MP3 320kbps',
				1: 'MP3 128kbps'
			},
			overwriteFile: {
				title: 'Papatungan ko ba ang file?',
				y: 'Oo, patungan mo ang file',
				n: "Hindi, huwag mong patungan ang file",
				t: 'Patungan mo lang ang mga tag',
				b: 'Hindi, hayaan mo silang dalawa at lagyan mo lang ng numero sa kapareho niya',
				e: "Hindi, at huwag mong tignan ang mga extension"
			},
			fallbackBitrate: 'Binabaang bitrate',
			fallbackSearch: 'Maghanap para sa binabaan',
			logErrors: 'Gumawa ng log file para sa mga error',
			logSearched: 'Gumawa ng log file para sa mga hinanap na track',
			createM3U8File: 'Gumawa ng file sa playlist',
			syncedLyrics: 'Gumawa ng mga .lyr file (Mga Sync Lyric)',
			playlistFilenameTemplate: 'Template sa pangalan ng Playlist file',
			saveDownloadQueue: 'I-save ang download queue kapag isasara the app'
		},
		covers: {
			title: 'Mga cover ng album',
			saveArtwork: 'I-save ang mga Cover',
			coverImageTemplate: 'Template ng pangalan ng cover',
			saveArtworkArtist: 'I-save ang imahe ng artist',
			artistImageTemplate: 'Template ng imahe ng artist',
			localArtworkSize: 'Laki ng lokal na artwork',
			embeddedArtworkSize: 'Laki ng Nakadikit na artwork',
			localArtworkFormat: {
				title: 'Anong gusto mong format para sa mga lokal na artwork?',
				jpg: 'jpeg na imahe',
				png: 'png na imahe',
				both: 'Parehong jpeg at png'
			},
			jpegImageQuality: 'Kalidad ng JPEG na imahe',
			embeddedArtworkPNG: 'I-save ang nakadikit na artwork bilang PNG',
			embeddedPNGWarning: 'Ang mga PNG ay hindi opisyal na suportado ng Deezer at maaaring magkaroon ng bug',
			imageSizeWarning: 'Lahat ng mas mataas sa x1200 ay hindi opisyal na ginagamit sa Deezer, at posibleng magkaroon ng isyu',
			coverDescriptionUTF8: 'I-save ang deskripsyon ng cover gamit ng UTF8 (iTunes Cover Fix)'
		},
		tags: {
			head: 'Aling tag ang ise-save',
			title: 'Pamagat',
			artist: 'Artist',
			album: 'Album',
			cover: 'Cover',
			trackNumber: 'Bilang ng Track',
			trackTotal: 'Kabuuang Track',
			discNumber: 'Bilang ng Disk',
			discTotal: 'Kabuuang Disk',
			albumArtist: 'Album Artist',
			genre: 'Genre',
			year: 'Taon',
			date: 'Petsa',
			explicit: 'Mga Explicit na Lyric',
			isrc: 'ISRC',
			length: 'Haba ng Track',
			barcode: 'Barcode ng Album (UPC)',
			bpm: 'BPM',
			replayGain: 'Replay Gain',
			label: 'Label ng Album',
			lyrics: 'Unsynchronized na mga Lyric',
			syncedLyrics: 'Synchronized na mga Lyric',
			copyright: 'Karapatang Ari',
			composer: 'Komposer',
			involvedPeople: 'Mga Kasamang Tao'
		},
		other: {
			title: 'Iba pa',
			savePlaylistAsCompilation: 'I-save ang mga playlist bilang compilation',
			useNullSeparator: 'Gumamit ng panghiwalay sa null',
			saveID3v1: 'I-save rin ang ID3v1',
			multiArtistSeparator: {
				title: 'Anong gusto mo para maihanay mga artist?',
				nothing: 'I-save lang ang pangunahing artist',
				default: 'Gamit ng standard na specification',
				andFeat: 'Gamit ng & at feat.',
				using: 'Gamit ng "{separator}"'
			},
			singleAlbumArtist: 'I-save lang ang pangunahing album ng artist',
			albumVariousArtists: 'Isama ang  "Various Artists" sa mga Album Artist',
			removeAlbumVersion: 'Tanggalin ang "Album Version" sa pamagat ng track',
			removeDuplicateArtists: 'Tanggalin ang kombinasyon ng mga artist',
			dateFormat: {
				title: 'Format ng petsa para sa mga FLAC file',
				year: 'YYYY',
				month: 'MM',
				day: 'DD'
			},
			featuredToTitle: {
				title: 'Anong gagawin ko sa mga itinampok na artist',
				0: 'Wala',
				1: 'Tanggalin mo sila sa Pamagat',
				3: 'Tanggalin mo sila sa Pamagat mismo at Pamagat ng Album',
				2: 'Ilipat mo sila sa pamagat'
			},
			titleCasing: 'Pagleletra sa Pamagat',
			artistCasing: 'Pagleletra sa Artist',
			casing: {
				nothing: 'Walang babaguhin',
				lower: 'maliliit',
				upper: 'MALALAKI',
				start: 'Simula Ng Bawata Salita',
				sentence: 'Kagaya ng pangungusap'
			},
			previewVolume: 'Volume ng Preview',
			executeCommand: {
				title: 'Mga gagawin pagkatapos ng download',
				description: 'Hayaan lang na blangko kung wala'
			}
		},
		spotify: {
			title: 'Spotify Features',
			clientID: 'Spotify ClientID',
			clientSecret: 'Spotify Client Secret',
			username: 'Spotify Username',
			question: 'Paano ma-enable ang Spotify Features?'
		},
		reset: 'Ibalik sa Dati',
		save: 'I-save',
		toasts: {
			init: 'Ikinarga ang mga Setting!',
			update: 'In-update ang mga Setting!',
			ARLcopied: 'Kinopya ang ARL sa clipboard'
		}
	},
	sidebar: {
		home: 'tahanan',
		search: 'maghanap',
		charts: 'mga chart',
		favorites: 'mga paborito',
		linkAnalyzer: 'tagasuri ng link',
		settings: 'mga setting',
		about: 'tungkol sa'
	},
	tracklist: {
		downloadSelection: 'Pagpipili ng download'
	}
};

const zh_tw = {
	globals: {
		welcome: '歡迎使用 deemix',
		back: '返回',
		loading: '載入中',
		download: '下載 {thing}',
		by: '{artist}',
		in: '於 {album}',
		download_hint: '下載',
		play_hint: '播放',
		toggle_download_tab_hint: '展開/折疊',
		clean_queue_hint: '清除完成',
		cancel_queue_hint: '取消全部',
		open_downloads_folder: '開啟下載資料夾',
		cut: '剪下',
		copy: '複製',
		copyLink: '複製連結',
		copyImageLink: '複製圖片連結',
		copyDeezerLink: '複製 deezer 連結',
		paste: '貼上',
		listTabs: {
			empty: '',
			all: '所有',
			top_result: '最佳結果',
			album: '專輯|專輯',
			artist: '藝人|藝人',
			single: '單曲',
			title: '標題|標題',
			track: '歌曲|歌曲',
			trackN: '0 首歌曲| {n} 首歌曲| {n} 首歌曲',
			releaseN: '0 發行| {n} 發行| {n} 發行',
			playlist: '播放清單|播放清單',
			compile: '合輯|合輯',
			ep: '迷你專輯 | 迷你專輯',
			bundle: 'bundle | bundles',
			more: '更多專輯',
			featured: '出現於',
			spotifyPlaylist: 'Spotify 播放清單 | Spotify 播放清單',
			releaseDate: '發布日期',
			error: '錯誤'
		}
	},
	about: {
		updates: {
			currentVersion: '目前版本',
			versionNotAvailable: 'N/A',
			updateAvailable: `您尚未更新至最新版本：{version}`,
			deemixVersion: 'deemix 函示庫版本'
		},
		titles: {
			usefulLinks: '實用連結',
			bugReports: '錯誤報告',
			contributing: '貢獻',
			donations: '贊助',
			license: '使用許可'
		},
		subtitles: {
			bugReports: "使用 deemix 時，遇到了什麼問題嗎？歡迎回報錯誤！",
			contributing: '您想替這個專案提出貢獻嗎？您可以透過許多不同的方式來幫忙！',
			donations: '您想要捐款嗎？可以贊助我們！'
		},
		usesLibrary: '本程式基於 <strong>deemix</strong> 函示庫。您可以使用該函示庫來製作自己的前端。',
		thanks: `感謝 <strong>rtonno</strong>、<strong>uhwot</strong> 及 <strong>lollilol</strong> 對於本專案的貢獻，另外也感謝 <strong>BasCurtiz</strong> 及 <strong>scarvimane</strong> 幫忙製作本專案的圖示`,
		upToDate: `您可於 Telegram 上關注<a href="https://t.me/RemixDevNews" target="_blank">最新消息頻道</a>以取得最新動態。`,
		officialWebsite: '官方網站',
		officialRepo: '官方函示版本庫',
		officialWebuiRepo: '官方 WebUI 版本庫',
		officialSubreddit: '官方 Subreddit',
		newsChannel: '最新消息頻道',
		questions: `如果您對本程式有疑問或問題，請先在<a href="https://www.reddit.com/r/deemix" target="_blank"> subreddit </a>上搜尋解決方案。如果找不到任何解決方法，則可以在我們的 subreddit 上發布與您問題相關的文章。`,
		beforeReporting: `在報告錯誤之前，請確保您正在運行最新版本的程式，並且要報告的內容真的是一個錯誤，而不僅是您自己遇到的問題。`,
		beSure: `請確保您所想回報的錯誤可在其他台裝置上再現的，並且<strong>請勿</strong>回報已知錯誤。`,
		duplicateReports: '請注意，重複的錯誤報告將被移除。',
		dontOpenIssues: `<strong>請勿</strong>透過本版本庫的 Issues 問問題，我們開 subreddit 是有原因的。`,
		newUI: `如果您精通 Python，則可以嘗試使用我們的函示庫來建立新的 UI，或者透過<a href ="https://codeberg.org/RemixDev/ deemix" target ="_ blank">我們的版本庫</a>提出錯誤相關的 PR。`,
		acceptFeatures: `我也歡迎你提交新的功能－但前提是這個功能不能過於複雜－過於複雜的功能，應被新增至程式內而非函示庫內。`,
		otherLanguages: `如果您精通其他程式語言，你也可以嘗試將 deemix 移植到其他程式語言中！`,
		understandingCode: `你需要幫助了解本專案的程式碼嗎？只需在 Telegram 或 Reddit 上按一下 RemixDev。`,
		contributeWebUI: `如果你熟悉 Vue.js（JavaScript）、HTML 或 CSS，你也可以參與 <a href="https://codeberg.org/RemixDev/deemix-webui" target="_blank">WebUI</a> 前端的貢獻。`,
		itsFree: `記得，<strong>這是一個免費的專案</strong>，<strong>在支持開發人員之前，應該先支持你喜歡的歌手或藝人</ strong>。`,
		notObligated: `別認為你有義務捐款，無論如何我們都感謝您！`,
		lincensedUnder: `本作品使用 
			<a rel="license" href="https://www.gnu.org/licenses/gpl-3.0.en.html" target="_blank">GNU General Public License 3.0</a> 許可授權。`
	},
	charts: {
		title: '排行榜',
		changeCountry: '改變國家',
		download: '下載排行榜'
	},
	errors: {
		title: '{name} 的錯誤',
		ids: {
			invalidURL: '無法識別網址',
			unsupportedURL: '尚不支持此網址',
			ISRCnotOnDeezer: '無法在 Deezer 上使用單曲 ISRC',
			notYourPrivatePlaylist: "您無法下載他人的私人播放清單。",
			spotifyDisabled: 'Spotify 功能未正確設定。',
			trackNotOnDeezer: '在 Deezer 上找不到此歌曲！',
			albumNotOnDeezer: '在 Deezer 上找不到此專輯！',
			notOnDeezer: '無法在 Deezer 上載入此歌曲！',
			notEncoded: '本歌曲尚未編碼！',
			notEncodedNoAlternative: '本歌曲尚未編碼，且無法找到其他替代歌曲！',
			wrongBitrate: '找不到符合所設位元率的歌曲。',
			wrongBitrateNoAlternative: '找不到符合所設位元率的歌曲，且無法找到其他替代歌曲！',
			no360RA: '本歌曲並不支援 Reality Audio 360。',
			notAvailable: "無法在 Deezer 伺服器載入此歌曲！",
			notAvailableNoAlternative: "無法在 Deezer 伺服器載入此歌曲，且無法找到其他替代歌曲！",
			noSpaceLeft: "本裝置可用空間已用盡！",
			albumDoesntExists: "本歌曲的專輯不存在，無法取得資訊"
		}
	},
	favorites: {
		title: '收藏',
		noPlaylists: '尚未收藏任何播放清單',
		noAlbums: '尚未收藏任何專輯',
		noArtists: '尚未收藏任何藝人',
		noTracks: '尚未收藏任何歌曲'
	},
	home: {
		needTologin: '您需要先登入 Deezer 帳戶，然後才能開始下載。',
		openSettings: '開啟設定',
		sections: {
			popularPlaylists: '熱門播放清單',
			popularAlbums: '熱門專輯'
		}
	},
	linkAnalyzer: {
		info: '您可以透過此工具取得您所想下載的連結的相關資訊。',
		useful: "比如，當您所想下載的歌曲無法在您的國家播放，且您想知道哪些國家可以播放此歌曲時，您可使用此工具。",
		linkNotSupported: '尚未支援此連結',
		linkNotSupportedYet: '我們似乎尚未支援此連結，請改用其他連結。',
		table: {
			id: 'ID',
			isrc: 'ISRC',
			upc: 'UPC',
			duration: '長度',
			diskNumber: '光碟編號',
			trackNumber: '歌曲編號',
			releaseDate: '發布日期',
			bpm: 'BPM',
			label: '標籤',
			recordType: '媒體類型',
			genres: '類型',
			tracklist: '歌曲清單'
		}
	},
	search: {
		startSearching: '開始搜尋！',
		description: '您可以搜索歌曲名稱、專輯、藝人、播放清單...等等。您也可以直接貼上 Deezer 網址。',
		fans: '{n} 個粉絲',
		noResults: '無搜尋結果',
		noResultsTrack: '找不到歌曲',
		noResultsAlbum: '找不到專輯',
		noResultsArtist: '找不到藝人',
		noResultsPlaylist: '找不到播放清單'
	},
	searchbar: '搜尋任何關鍵字（或貼上連結）',
	downloads: '下載',
	toasts: {
		restoringQueue: '正在恢復下載清單...',
		queueRestored: '下載清單已恢復！',
		addedToQueue: '已新增 {item} 到下載清單中',
		addedMoreToQueue: '已新增 {n} 個項目到下載清單中',
		alreadyInQueue: '{item} 已在下載清單中！',
		finishDownload: '{item} 已完成下載。',
		allDownloaded: '全部下載完成！',
		refreshFavs: '刷新完成！',
		loggingIn: '登入中...',
		loggedIn: '登入',
		alreadyLogged: '已登入',
		loginFailed: "無法登入",
		loggedOut: '登出',
		cancellingCurrentItem: '取消當前項目。',
		currentItemCancelled: '當前項目已取消。',
		startAddingArtist: '已新增 {artist} 個專輯到下載清單中',
		finishAddingArtist: '已新增 {artist} 個專輯到下載清單中',
		startConvertingSpotifyPlaylist: '將 Spotify 歌曲轉換為 Deezer 歌曲中',
		finishConvertingSpotifyPlaylist: '已轉換 Spotify 播放清單',
		loginNeededToDownload: '您需要登入才能下載歌曲！',
		deezerNotAvailable: 'Deezer 在您所在的國家/地區無法使用。請您使用 VPN。'
	},
	settings: {
		title: '設定',
		languages: '語言',
		login: {
			title: '登入',
			loggedIn: '目前以 {username} 的身份登入',
			arl: {
				question: '如何取得自己的 ARL？',
				update: '更新 ARL'
			},
			logout: '登出',
			login: '透過 deezer.com 登入'
		},
		appearance: {
			title: '外觀',
			slimDownloadTab: '薄型下載分頁'
		},
		downloadPath: {
			title: '下載目錄'
		},
		templates: {
			title: '檔案名稱格式',
			tracknameTemplate: '單曲名稱格式',
			albumTracknameTemplate: '專輯單曲名稱格式',
			playlistTracknameTemplate: '播放清單單曲名稱格式'
		},
		folders: {
			title: '資料夾',
			createPlaylistFolder: '替播放清單建立資料夾',
			playlistNameTemplate: '播放清單資料夾名稱格式',
			createArtistFolder: '替藝人建立資料夾',
			artistNameTemplate: '藝人資料夾名稱格式',
			createAlbumFolder: '替專輯建立資料夾',
			albumNameTemplate: '專輯資料夾名稱格式',
			createCDFolder: '替 CD 建立資料夾',
			createStructurePlaylist: '建立播放清單資料夾結構',
			createSingleFolder: '建立單曲資料夾結構'
		},
		trackTitles: {
			title: '單曲名稱',
			padTracks: '歌曲數目字串填充',
			paddingSize: '覆蓋數目字串填充長度',
			illegalCharacterReplacer: '替換非法字元'
		},
		downloads: {
			title: '下載',
			queueConcurrency: '並行下載',
			maxBitrate: {
				title: '偏好位元率',
				9: 'FLAC 1411kbps',
				3: 'MP3 320kbps',
				1: 'MP3 128kbps'
			},
			overwriteFile: {
				title: '是否要覆蓋檔案？',
				y: '是，覆蓋檔案',
				n: "否，請勿覆蓋檔案",
				t: '僅覆蓋標籤',
				b: '否，保留兩個檔案並在重複的檔名中加入一個數字',
				e: "否，不顧慮附檔名"
			},
			fallbackBitrate: '當偏好位元率無法下載時，下載其他版本',
			fallbackSearch: '當搜尋結果無法使用時，使用其他搜尋結果',
			logErrors: '記錄錯誤至日誌',
			logSearched: '記錄搜尋歌曲至日誌',
			createM3U8File: '建立播放清單檔案',
			syncedLyrics: '建立 .lyr 檔案（同步歌詞）',
			playlistFilenameTemplate: '播放清單檔名格式',
			saveDownloadQueue: '關閉應用程式時，保存下載清單'
		},
		covers: {
			title: '專輯封面',
			saveArtwork: '保存封面',
			coverImageTemplate: '封面檔名格式',
			saveArtworkArtist: '保存藝人照片',
			artistImageTemplate: '藝人照片檔名格式',
			localArtworkSize: '本地圖片大小',
			embeddedArtworkSize: '嵌入圖片大小',
			localArtworkFormat: {
				title: '您希望本地圖片採用哪種格式？',
				jpg: 'JPEG',
				png: 'PNG',
				both: 'JPEG 及 PNG'
			},
			jpegImageQuality: 'JPEG 影像品質',
			embeddedArtworkPNG: '將嵌入式圖片存為 PNG',
			embeddedPNGWarning: 'Deezer 官方並不支援 PNG，結果可能有誤',
			imageSizeWarning: 'Deezer 官方並不使用高於 x1200 的圖片，您可能會遇到問題',
			coverDescriptionUTF8: '使用 UTF8 保存封面敘述（修正 iTunes 專輯封面)'
		},
		tags: {
			head: '要保存哪些標籤',
			title: '標題',
			artist: '藝人',
			album: '專輯',
			cover: '專輯封面',
			trackNumber: '單曲編號',
			trackTotal: '總計歌曲',
			discNumber: '光碟編號',
			discTotal: '光碟總數',
			albumArtist: '專輯藝人',
			genre: '類型',
			year: '年',
			date: '日期',
			explicit: '不良歌詞',
			isrc: 'ISRC',
			length: '單曲長度',
			barcode: '專輯條碼（UPC）',
			bpm: 'BPM',
			replayGain: '重播增益（Replay Gain）',
			label: '專輯標籤',
			lyrics: '不同步的歌詞',
			syncedLyrics: '同步歌詞',
			copyright: '版權',
			composer: '作曲家',
			involvedPeople: '相關藝人'
		},
		other: {
			title: '其他',
			savePlaylistAsCompilation: '將播放清單儲存為合輯',
			useNullSeparator: '使用空分隔符',
			saveID3v1: '保存 ID3v1 標籤',
			multiArtistSeparator: {
				title: '如何隔開作者名稱？',
				nothing: '僅保留主作者',
				default: '使用標準規格',
				andFeat: '使用 & 及 feat.',
				using: '使用 "{separator}"'
			},
			singleAlbumArtist: '僅儲存專輯主作者名稱',
			albumVariousArtists: '於專輯作者欄位中保留「多位藝人 (Various Artists)」字樣',
			removeAlbumVersion: '於單曲名稱中移除「專輯版本 (Album Version)」字樣',
			removeDuplicateArtists: '移除重複的作者名稱',
			dateFormat: {
				title: 'FLAC 檔案日期格式',
				year: 'YYYY',
				month: 'MM',
				day: 'DD'
			},
			featuredToTitle: {
				title: '如何處理客串藝人名稱 (如 feat. 等字樣) ？',
				0: '什麼都不做',
				1: '從標題中刪除',
				3: '從標題和專輯標題中刪除',
				2: '將其移至標題'
			},
			titleCasing: '歌曲名稱大小寫',
			artistCasing: '藝人名稱大小寫',
			casing: {
				nothing: '保持不變',
				lower: '小寫',
				upper: '大寫',
				start: '字詞開頭大寫',
				sentence: '句子大寫'
			},
			previewVolume: '預覽音量',
			executeCommand: {
				title: '下載後執行指令',
				description: '留空則不執行'
			}
		},
		spotify: {
			title: 'Spotify 功能',
			clientID: 'Spotify 客戶端 ID',
			clientSecret: 'Spotify 客戶端密碼',
			username: 'Spotify 用戶名',
			question: '如何啟用 Spotify 功能？'
		},
		reset: '重設至預設',
		save: '儲存',
		toasts: {
			init: '已載入設定！',
			update: '已更新設定！',
			ARLcopied: '已複製 ARL 到剪貼簿中'
		}
	},
	sidebar: {
		home: '首頁',
		search: '搜尋',
		charts: '排行榜',
		favorites: '收藏',
		linkAnalyzer: '連結分析',
		settings: '設定',
		about: '關於'
	},
	tracklist: {
		downloadSelection: '下載所選'
	}
};

const pl = {
    globals: {
        welcome: 'Witaj w deemix',
        back: 'wróć',
        loading: 'ładowanie',
        download: 'Pobierz {thing}',
        by: 'od {artist}',
        in: 'w {album}',
        download_hint: 'Pobierz',
        play_hint: 'Odtwórz',
        toggle_download_tab_hint: 'Rozszerz/Zwiń',
        clean_queue_hint: 'Wyczyść ukończone',
        cancel_queue_hint: 'Anuluj wszystkie',
        open_downloads_folder: 'Otwórz pobrane',
        cut: 'wytnij',
        copy: 'kopiuj',
        copyLink: 'kopiuj link',
        copyImageLink: 'kopiuj link obrazu',
        copyDeezerLink: 'kopiuj link deezera',
        paste: 'wklej',
        listTabs: {
            empty: '',
            all: 'wszystkie',
            top_result: 'najlepszy wynik',
            album: 'album | albumy',
            artist: 'artysta | artyści',
            single: 'singiel | single',
            title: 'tytuł | tytuły',
            track: 'utwór | utwory',
            trackN: '0 utworów | {n} utwór | {n} utworów',
            releaseN: '0 wydań | {n} wydanie | {n} wydań',
            playlist: 'playlista | playlisty',
            compile: 'kompilacja | kompilacje',
            ep: 'ep | ep',
            bundle: 'zestaw | zestawy',
            more: 'Więcej albumów',
            featured: 'Występuje w',
            spotifyPlaylist: 'playlista spotify | playlisty spotify',
            releaseDate: 'data wydania',
            error: 'błąd'
        }
    },
    about: {
        updates: {
            currentVersion: 'Obecna wersja',
            versionNotAvailable: 'N/A',
            updateAvailable: `Nie masz najnowszej dostępnej wersji: {version}`,
            deemixVersion: 'Wersja biblioteki deemix'
        },
        titles: {
            usefulLinks: 'Przydatne linki',
            bugReports: 'Zgłoszenia błędów',
            contributing: 'Wkład',
            donations: 'Dotacje',
            license: 'Licencja'
        },
        subtitles: {
            bugReports: "Czy deemix działa inaczej niż powinien? Powiedz nam!",
            contributing: 'Chcesz pomóc w tym projekcie? Możesz to zrobić na wiele sposobów!',
            donations: 'Chcesz pomóc finansowo? Możesz nas wesprzeć!'
        },
        usesLibrary: 'Ten program używa biblioteki <strong>deemix</strong>, której możesz użyć do stworzenia własnego interfejsu użytkownika',
        thanks: `Podziękowania dla <strong>rtonno</strong>, <strong>uhwot</strong> i <strong>lollilol</strong> za pomoc w tym projekcie oraz dla <strong>BasCurtiz</strong> i <strong>scarvimane</strong> za stworzenie ikony.`,
        upToDate: `Bądź na bieżąco z aktualizacjami dołączając do <a href="https://t.me/RemixDevNews" target="_blank">kanału wiadomości</a> na Telegramie.`,
        officialWebsite: 'Oficjalna strona',
        officialRepo: 'Oficjalne repozytorium biblioteki',
        officialWebuiRepo: 'Oficjalne repozytorium WebUI',
        officialSubreddit: 'Oficjalny subreddit',
        newsChannel: 'Kanał wiadomości',
        questions: `Jeżeli masz pytania lub problemy związane z aplikacją, szukaj odpowiedzi na <a href="https://www.reddit.com/r/deemix" target="_blank">subreddicie</a>. Jeżeli niczego nie znajdziesz, stwórz post na subreddicie.`,
        beforeReporting: `Przed zgłaszaniem błędu upewnij się, że masz najnowszą wersje aplikacji i to, co chcesz zgłosić jest błędem, a nie usterką z twojej strony.`,
        beSure: `Upewnij się, że błąd można odtworzyć na innych urządzeniach i <strong>NIE ZGŁASZAJ</strong> błędów, które zostały już zgłoszone`,
        duplicateReports: 'Identyczne zgłoszenia błędów będą zamykane, więc zwróć na to uwagę.',
        dontOpenIssues: `<strong>NIE OTWIERAJ</strong> zgłoszeń do zadawania pytań, od tego jest subreddit.`,
        newUI: `Jeżeli dobrze znasz Pythona, możesz spróbować stworzyć nowy interfejs dla aplikacji używając bazowej biblioteki lub naprawiać błędy w bibliotece tworząc pull request w <a href="https://codeberg.org/RemixDev/deemix" target="_blank">repozytorium</a>.`,
        acceptFeatures: `Przyjmuję nowe funkcje, ale nic złożonego, co mogłoby być zaimplementowane w aplikacji, a nie w bibliotece.`,
        otherLanguages: `Jeżeli dobrze znasz inny język programowania, możesz spróbować przeportować deemix do innych języków!`,
        understandingCode: `Potrzebujesz pomocy w zrozumieniu kodu? Zapytaj RemixDev na Telegramie lub Reddicie.`,
        contributeWebUI: `Jeżeli znasz Vue.js (JavaScript), HTML lub CSS, możesz pomóc w <a href="https://codeberg.org/RemixDev/deemix-webui" target="_blank">WebUI</a>.`,
        itsFree: `Pamiętaj, że <strong>ten projekt jest darmowy</strong> i <strong>powinieneś wspierać artystów</strong> przed twórcami aplikacji.`,
        notObligated: `Nie czuj potrzeby płacenia, i tak cię doceniam!`,
        lincensedUnder: `Ten projekt jest chroniony licencją
            <a rel="license" href="https://www.gnu.org/licenses/gpl-3.0.en.html" target="_blank">GNU General Public License 3.0</a>.`
    },
    charts: {
        title: 'Wykresy',
        changeCountry: 'Zmień kraj',
        download: 'Pobierz wykres'
    },
    errors: {
        title: 'Błędy dla {name}',
        ids: {
            invalidURL: 'Nierozpoznany URL',
            unsupportedURL: 'Niewspierany URL',
            ISRCnotOnDeezer: 'ISRC nie jest dostępne na Deezerze',
            notYourPrivatePlaylist: "Nie możesz pobierać czyichś prywatnych playlist.",
            spotifyDisabled: 'Funkcje Spotify nie są poprawnie ustawione',
            trackNotOnDeezer: 'Nie znaleziono utworu na Deezerze!',
            albumNotOnDeezer: 'Nie znaleziono albumu na Deezerze!',
            notOnDeezer: 'Utwór nie jest dostępny na Deezerze!',
            notEncoded: 'Utwór nie jest jeszcze zakodowany!',
            notEncodedNoAlternative: 'Utwór nie jest jeszcze zakodowany i nie można znaleźć alternatywy!',
            wrongBitrate: 'Nie znaleziono utworu w wybranym bitrate.',
            wrongBitrateNoAlternative: 'Nie znaleziono utworu w wybranym bitrate i nie mozna znaleźć alternatywy!',
            no360RA: 'Utwór nie jest dostępny w Reality Audio 360.',
            notAvailable: "Utwór nie jest dostępny na serwerach Deezera!",
            notAvailableNoAlternative: "Utwór nie jest dostępny na serwerach Deezera i nie można znaleźć alternatywy!"
        }
    },
    favorites: {
        title: 'Ulubione',
        noPlaylists: 'Nie znaleziono playlist',
        noAlbums: 'Nie znaleziono ulubionych albumów',
        noArtists: 'Nie znaleziono ulubionych artystów',
        noTracks: 'Nie znaleziono ulubonych utworów'
    },
    home: {
        needTologin: 'Musisz się zalogwać do konta na Deezerze zanim zaczniesz pobierać.',
        openSettings: 'Otwórz ustawienia',
        sections: {
            popularPlaylists: 'Popularne playlisty',
            popularAlbums: 'Najpopularniejsze albumy'
        }
    },
    linkAnalyzer: {
        info: 'Możesz użyć tej sekcji, aby znaleźć więcej informacji o linku, który chcesz pobrać.',
        useful: "Jest to przydatne na przykład gdy chcesz pobrać jakieś utwory, które nie są dostępne w twoim kraju i chcesz wiedzieć gdzie są dostępne.",
        linkNotSupported: 'Ten link nie jest jeszcze wspierany',
        linkNotSupportedYet: 'Wygląda na to, że ten link nie jest jeszcze wspierany. Spróbuj przeanalizować inny.',
        table: {
            id: 'ID',
            isrc: 'ISRC',
            upc: 'UPC',
            duration: 'Czas',
            diskNumber: 'Numer płyty',
            trackNumber: 'Numer utworu',
            releaseDate: 'Data wydania',
            bpm: 'BPM',
            label: 'Wytwórnia',
            recordType: 'Rodzaj wydania',
            genres: 'Gatunki',
            tracklist: 'Lista utworów'
        }
    },
    search: {
        startSearching: 'Zacznij szukać!',
        description: 'Możesz wyszukać utwór, album, artystę, playlistę... wszystko! Możesz też wkleić link do Deezera',
        fans: '{n} fanów',
        noResults: 'Brak wyników',
        noResultsTrack: 'Nie znaleziono utworów',
        noResultsAlbum: 'Nie znaleziono albumów',
        noResultsArtist: 'Nie znaleziono artystów',
        noResultsPlaylist: 'Nie znaleziono playlist'
    },
    searchbar: 'Szukaj czego chcesz (lub wklej link)',
    downloads: 'pobrane',
    toasts: {
        restoringQueue: 'Przywracanie kolejki pobierania...',
        queueRestored: 'Przywrócono kolejkę pobierania!',
        addedToQueue: 'Dodano {item} do kolejki',
        addedMoreToQueue: 'Dodano {n} przedmiotów do kolejki',
        alreadyInQueue: '{item} jest już w kolejce!',
        finishDownload: 'Ukończono pobieranie {item}.',
        allDownloaded: 'Pobrano wszystkie!',
        refreshFavs: 'Ukończono odświeżanie!',
        loggingIn: 'Logowanie...',
        loggedIn: 'Zalogowano',
        alreadyLogged: 'Już zalogowano',
        loginFailed: "Nie można zalogować",
        loggedOut: 'Wylogowano',
        cancellingCurrentItem: 'Anulowanie przedmiotu.',
        currentItemCancelled: 'Anulowano przedmiot.',
        startAddingArtist: 'Dodawanie {artist} albumów do kolejki',
        finishAddingArtist: 'Dodano {artist} albumów do kolejki',
        startConvertingSpotifyPlaylist: 'Konwertowanie utworów Spotify na Deezer',
        finishConvertingSpotifyPlaylist: 'Przekonwertowano playlistę Spotify',
        loginNeededToDownload: 'Musisz się zalogować, aby pobierać utwory!'
    },
    settings: {
        title: 'Ustawienia',
        languages: 'Języki',
        login: {
            title: 'Logowanie',
            loggedIn: 'Zalogowano jako {username}',
            arl: {
                question: 'Jak zdobyć swój własny ARL?',
                    update: 'Zakualizuj ARL'
            },
            logout: 'Wyloguj',
            login: 'Zaloguj przez deezer.com'
        },
        appearance: {
            title: 'Wygląd',
            slimDownloadTab: 'Cienka karta pobranych'
        },
        downloadPath: {
            title: 'Ścieżka pobierania'
        },
        templates: {
            title: 'Szablony',
            tracknameTemplate: 'Szablon utworu',
            albumTracknameTemplate: 'Szablon utworu z albumu',
            playlistTracknameTemplate: 'Szablon utworu z playlisy'
        },
        folders: {
            title: 'Foldery',
            createPlaylistFolder: 'Utwórz foldery dla playlist',
            playlistNameTemplate: 'Szablon folderu playlisty',
            createArtistFolder: 'Utwórz foldery dla artystów',
            artistNameTemplate: 'Szablon folderu artysty',
            createAlbumFolder: 'Utwórz foldery dla albumów',
            albumNameTemplate: 'Szablon folderu albumu',
            createCDFolder: 'Utwórz foldery dla płyt',
            createStructurePlaylist: 'Utwórz strukturę folderów dla playlist',
            createSingleFolder: 'Utwórz strukturę folderów dla singli'
        },
        trackTitles: {
            title: 'Tytuły utworow',
            padTracks: 'Wypchaj utwory',
            paddingSize: 'Rozmiar wypchania',
            illegalCharacterReplacer: 'Zamiennik niedozwolonych znaków'
        },
        downloads: {
            title: 'Pobrane',
            queueConcurrency: 'Równoległe pobieranie',
            maxBitrate: {
                title: 'Bitrate',
                9: 'FLAC 1411kbps',
                3: 'MP3 320kbps',
                1: 'MP3 128kbps'
            },
            overwriteFile: {
                title: 'Nadpisywać pliki?',
                y: 'Tak',
                n: "Nie",
                t: 'Tylko tagi',
                b: 'Nie, dodaj numer do drugiego pliku',
                e: 'Nie, nie patrz na rozszerzenia'
            },
            fallbackBitrate: 'Rezerwowy bitrate',
            fallbackSearch: 'Rezerwowe wyszukiwanie',
            logErrors: 'Utwórz plik dziennika błędów',
            logSearched: 'Utwórz plik dziennika wyszukiwanych utworów',
            createM3U8File: 'Utwórz plik playlisty',
            syncedLyrics: 'Utwórz plik .lyr (synchronizowany tekst)',
            playlistFilenameTemplate: 'Szablon pliku playlisty',
            saveDownloadQueue: 'Zapisz kolejkę pobierania przy zamykaniu aplikacji'
        },
        covers: {
            title: 'Okładki albumów',
            saveArtwork: 'Zapisz okładki',
            coverImageTemplate: 'Szablon nazwy okładki',
            saveArtworkArtist: 'Zapisz zdjęcie artysty',
            artistImageTemplate: 'Szablon zdjęcia artysty',
            localArtworkSize: 'Rozmiar lokalnej okładki',
            embeddedArtworkSize: 'Rozmiar osadzonej okładki',
            localArtworkFormat: {
                title: 'W jakim formacie ma zostać zapisana okładka?',
                jpg: 'Plik JPEG',
                png: 'Plik PNG',
                both: 'Pliki JPEG i PNG'
            },
            jpegImageQuality: 'Jakość JPEG',
            embeddedArtworkPNG: 'Zapisz osadzoną okładkę jako PNG',
            embeddedPNGWarning: 'PNG nie jest oficjalnie wspierane przez Deezer i może powodować błędy',
            imageSizeWarning: 'Wszystko powyżej x1200 nie jest oficjalnie używane przez Deezera, więc mogą wystąpić problemy.'
        },
        tags: {
            head: 'Które tagi zapisać',
            title: 'Tytuł',
            artist: 'Artysta',
            album: 'Album',
            cover: 'Okładka',
            trackNumber: 'Numer utworu',
            trackTotal: 'Liczba utworów',
            discNumber: 'Numer płyty',
            discTotal: 'Liczba płyt',
            albumArtist: 'Album Artist',
            genre: 'Gatunek',
            year: 'Rok',
            date: 'Data',
            explicit: 'Wulgarny tekst',
            isrc: 'ISRC',
            length: 'Długość',
            barcode: 'Kod kreskowy albumu (UPC)',
            bpm: 'BPM',
            replayGain: 'Replay Gain',
            label: 'Wytwórnia',
            lyrics: 'Niezsynchronizowany tekst',
            syncedLyrics: 'Zsynchronizowany tekst',
            copyright: 'Prawa autorskie',
            composer: 'Kompozytor',
            involvedPeople: 'Zaangażowane osoby'
        },
        other: {
            title: 'Inne',
            savePlaylistAsCompilation: 'Zapisz playlisty jako kompilacje',
            useNullSeparator: 'Użyj separatora null',
            saveID3v1: 'Zapisz ID3v1',
            multiArtistSeparator: {
                title: 'Jak oddzielić artystów?',
                nothing: 'Zapisz tylko głównego artystę',
                default: 'Standardowa specyfikacja',
                andFeat: '& i feat.',
                using: 'Używa "{separator}"'
            },
            singleAlbumArtist: 'Zapisz tylko głównego autora albumu',
            albumVariousArtists: 'Zostaw "Various Artists" w autorach albumu',
            removeAlbumVersion: 'Usuń "Album Version" z tytułu utworu',
            removeDuplicateArtists: 'Usuń kombinacje artystów',
            dateFormat: {
                title: 'Format daty dla plików FLAC',
                year: 'YYYY',
                month: 'MM',
                day: 'DD'
            },
            featuredToTitle: {
                title: 'Co zrobić z dodatkowymi artystami?',
                0: 'Nic',
                1: 'Usuń z tytułu',
                3: 'Usuń z tytułu i tytułu albumu',
                2: 'Przenieś do tytułu'
            },
            titleCasing: 'Rozmiar liter tytułu',
            artistCasing: 'Rozmiar liter artysty',
            casing: {
                nothing: 'Zostaw',
                lower: 'małe litery',
                upper: 'DUŻE LITERY',
                start: 'Na Początku Każdego Słowa',
                sentence: 'Jak w zdaniu'
            },
            previewVolume: 'Głośność podglądu',
            executeCommand: {
                title: 'Polecenie do wykonania po pobraniu',
                description: 'Zostaw puste, aby nic nie robić'
            }
        },
        spotify: {
            title: 'Funkcje Spotify',
            clientID: 'Spotify ClientID',
            clientSecret: 'Spotify Client Secret',
            username: 'Nazwa użytkownika',
            question: 'Jak włączyć funkcje Spotify?'
        },
        reset: 'Przywróć domyślne',
        save: 'Zapisz',
        toasts: {
            init: 'Załadowano ustawienia!',
            update: 'Zaktualizowano ustawienia!',
            ARLcopied: 'Skopiowano ARL do schowka'
        }
    },
    sidebar: {
        home: 'strona główna',
        search: 'szukaj',
        charts: 'wykresy',
        favorites: 'ulubione',
        linkAnalyzer: 'analiza linków',
        settings: 'ustawienia',
        about: 'informacje'
    },
    tracklist: {
        downloadSelection: 'Pobierz wybrane'
    }
};

const locales = {
	it,
	en,
	es,
	de,
	fr,
	id,
	pt,
	pt_br,
	ru,
	tr,
	vn,
	hr,
	ar,
	ko,
	ph,
	zh_tw,
	pl
};

Vue.use(VueI18n);

const storedLocale = localStorage.getItem('locale');
const DEFAULT_LANG = storedLocale || 'en';

document.querySelector('html').setAttribute('lang', DEFAULT_LANG);

const i18n = new VueI18n({
	locale: DEFAULT_LANG,
	fallbackLocale: 'en',
	messages: locales,
	pluralizationRules: {
		/**
		 * @param {number}	choice 					A choice index given by the input to $tc: `$tc('path.to.rule', choiceIndex)`
		 * @param {number}	choicesLength		An overall amount of available choices
		 * @returns 				A final choice index to select plural word by
		 */
		ru: function(choice, choicesLength) {
			var n = Math.abs(choice) % 100;
			var n1 = n % 10;

			if (n > 10 && n < 20) {
				return 2
			}

			if (n1 > 1 && n1 < 5) {
				return 1
			}

			if (n1 == 1) {
				return 0
			}

			return 2
		}
	}
});

/*!
  * vue-router v3.4.8
  * (c) 2020 Evan You
  * @license MIT
  */
/*  */

function assert$2 (condition, message) {
  if (!condition) {
    throw new Error(("[vue-router] " + message))
  }
}

function warn$4 (condition, message) {
  if ( !condition) {
    typeof console !== 'undefined' && console.warn(("[vue-router] " + message));
  }
}

function extend$2 (a, b) {
  for (var key in b) {
    a[key] = b[key];
  }
  return a
}

/*  */

var encodeReserveRE = /[!'()*]/g;
var encodeReserveReplacer = function (c) { return '%' + c.charCodeAt(0).toString(16); };
var commaRE = /%2C/g;

// fixed encodeURIComponent which is more conformant to RFC3986:
// - escapes [!'()*]
// - preserve commas
var encode = function (str) { return encodeURIComponent(str)
    .replace(encodeReserveRE, encodeReserveReplacer)
    .replace(commaRE, ','); };

function decode (str) {
  try {
    return decodeURIComponent(str)
  } catch (err) {
    {
      warn$4(false, ("Error decoding \"" + str + "\". Leaving it intact."));
    }
  }
  return str
}

function resolveQuery (
  query,
  extraQuery,
  _parseQuery
) {
  if ( extraQuery === void 0 ) extraQuery = {};

  var parse = _parseQuery || parseQuery;
  var parsedQuery;
  try {
    parsedQuery = parse(query || '');
  } catch (e) {
     warn$4(false, e.message);
    parsedQuery = {};
  }
  for (var key in extraQuery) {
    var value = extraQuery[key];
    parsedQuery[key] = Array.isArray(value)
      ? value.map(castQueryParamValue)
      : castQueryParamValue(value);
  }
  return parsedQuery
}

var castQueryParamValue = function (value) { return (value == null || typeof value === 'object' ? value : String(value)); };

function parseQuery (query) {
  var res = {};

  query = query.trim().replace(/^(\?|#|&)/, '');

  if (!query) {
    return res
  }

  query.split('&').forEach(function (param) {
    var parts = param.replace(/\+/g, ' ').split('=');
    var key = decode(parts.shift());
    var val = parts.length > 0 ? decode(parts.join('=')) : null;

    if (res[key] === undefined) {
      res[key] = val;
    } else if (Array.isArray(res[key])) {
      res[key].push(val);
    } else {
      res[key] = [res[key], val];
    }
  });

  return res
}

function stringifyQuery (obj) {
  var res = obj
    ? Object.keys(obj)
      .map(function (key) {
        var val = obj[key];

        if (val === undefined) {
          return ''
        }

        if (val === null) {
          return encode(key)
        }

        if (Array.isArray(val)) {
          var result = [];
          val.forEach(function (val2) {
            if (val2 === undefined) {
              return
            }
            if (val2 === null) {
              result.push(encode(key));
            } else {
              result.push(encode(key) + '=' + encode(val2));
            }
          });
          return result.join('&')
        }

        return encode(key) + '=' + encode(val)
      })
      .filter(function (x) { return x.length > 0; })
      .join('&')
    : null;
  return res ? ("?" + res) : ''
}

/*  */

var trailingSlashRE = /\/?$/;

function createRoute (
  record,
  location,
  redirectedFrom,
  router
) {
  var stringifyQuery = router && router.options.stringifyQuery;

  var query = location.query || {};
  try {
    query = clone(query);
  } catch (e) {}

  var route = {
    name: location.name || (record && record.name),
    meta: (record && record.meta) || {},
    path: location.path || '/',
    hash: location.hash || '',
    query: query,
    params: location.params || {},
    fullPath: getFullPath(location, stringifyQuery),
    matched: record ? formatMatch(record) : []
  };
  if (redirectedFrom) {
    route.redirectedFrom = getFullPath(redirectedFrom, stringifyQuery);
  }
  return Object.freeze(route)
}

function clone (value) {
  if (Array.isArray(value)) {
    return value.map(clone)
  } else if (value && typeof value === 'object') {
    var res = {};
    for (var key in value) {
      res[key] = clone(value[key]);
    }
    return res
  } else {
    return value
  }
}

// the starting route that represents the initial state
var START = createRoute(null, {
  path: '/'
});

function formatMatch (record) {
  var res = [];
  while (record) {
    res.unshift(record);
    record = record.parent;
  }
  return res
}

function getFullPath (
  ref,
  _stringifyQuery
) {
  var path = ref.path;
  var query = ref.query; if ( query === void 0 ) query = {};
  var hash = ref.hash; if ( hash === void 0 ) hash = '';

  var stringify = _stringifyQuery || stringifyQuery;
  return (path || '/') + stringify(query) + hash
}

function isSameRoute (a, b) {
  if (b === START) {
    return a === b
  } else if (!b) {
    return false
  } else if (a.path && b.path) {
    return (
      a.path.replace(trailingSlashRE, '') === b.path.replace(trailingSlashRE, '') &&
      a.hash === b.hash &&
      isObjectEqual(a.query, b.query)
    )
  } else if (a.name && b.name) {
    return (
      a.name === b.name &&
      a.hash === b.hash &&
      isObjectEqual(a.query, b.query) &&
      isObjectEqual(a.params, b.params)
    )
  } else {
    return false
  }
}

function isObjectEqual (a, b) {
  if ( a === void 0 ) a = {};
  if ( b === void 0 ) b = {};

  // handle null value #1566
  if (!a || !b) { return a === b }
  var aKeys = Object.keys(a).sort();
  var bKeys = Object.keys(b).sort();
  if (aKeys.length !== bKeys.length) {
    return false
  }
  return aKeys.every(function (key, i) {
    var aVal = a[key];
    var bKey = bKeys[i];
    if (bKey !== key) { return false }
    var bVal = b[key];
    // query values can be null and undefined
    if (aVal == null || bVal == null) { return aVal === bVal }
    // check nested equality
    if (typeof aVal === 'object' && typeof bVal === 'object') {
      return isObjectEqual(aVal, bVal)
    }
    return String(aVal) === String(bVal)
  })
}

function isIncludedRoute (current, target) {
  return (
    current.path.replace(trailingSlashRE, '/').indexOf(
      target.path.replace(trailingSlashRE, '/')
    ) === 0 &&
    (!target.hash || current.hash === target.hash) &&
    queryIncludes(current.query, target.query)
  )
}

function queryIncludes (current, target) {
  for (var key in target) {
    if (!(key in current)) {
      return false
    }
  }
  return true
}

function handleRouteEntered (route) {
  for (var i = 0; i < route.matched.length; i++) {
    var record = route.matched[i];
    for (var name in record.instances) {
      var instance = record.instances[name];
      var cbs = record.enteredCbs[name];
      if (!instance || !cbs) { continue }
      delete record.enteredCbs[name];
      for (var i$1 = 0; i$1 < cbs.length; i$1++) {
        if (!instance._isBeingDestroyed) { cbs[i$1](instance); }
      }
    }
  }
}

var View = {
  name: 'RouterView',
  functional: true,
  props: {
    name: {
      type: String,
      default: 'default'
    }
  },
  render: function render (_, ref) {
    var props = ref.props;
    var children = ref.children;
    var parent = ref.parent;
    var data = ref.data;

    // used by devtools to display a router-view badge
    data.routerView = true;

    // directly use parent context's createElement() function
    // so that components rendered by router-view can resolve named slots
    var h = parent.$createElement;
    var name = props.name;
    var route = parent.$route;
    var cache = parent._routerViewCache || (parent._routerViewCache = {});

    // determine current view depth, also check to see if the tree
    // has been toggled inactive but kept-alive.
    var depth = 0;
    var inactive = false;
    while (parent && parent._routerRoot !== parent) {
      var vnodeData = parent.$vnode ? parent.$vnode.data : {};
      if (vnodeData.routerView) {
        depth++;
      }
      if (vnodeData.keepAlive && parent._directInactive && parent._inactive) {
        inactive = true;
      }
      parent = parent.$parent;
    }
    data.routerViewDepth = depth;

    // render previous view if the tree is inactive and kept-alive
    if (inactive) {
      var cachedData = cache[name];
      var cachedComponent = cachedData && cachedData.component;
      if (cachedComponent) {
        // #2301
        // pass props
        if (cachedData.configProps) {
          fillPropsinData(cachedComponent, data, cachedData.route, cachedData.configProps);
        }
        return h(cachedComponent, data, children)
      } else {
        // render previous empty view
        return h()
      }
    }

    var matched = route.matched[depth];
    var component = matched && matched.components[name];

    // render empty node if no matched route or no config component
    if (!matched || !component) {
      cache[name] = null;
      return h()
    }

    // cache component
    cache[name] = { component: component };

    // attach instance registration hook
    // this will be called in the instance's injected lifecycle hooks
    data.registerRouteInstance = function (vm, val) {
      // val could be undefined for unregistration
      var current = matched.instances[name];
      if (
        (val && current !== vm) ||
        (!val && current === vm)
      ) {
        matched.instances[name] = val;
      }
    }

    // also register instance in prepatch hook
    // in case the same component instance is reused across different routes
    ;(data.hook || (data.hook = {})).prepatch = function (_, vnode) {
      matched.instances[name] = vnode.componentInstance;
    };

    // register instance in init hook
    // in case kept-alive component be actived when routes changed
    data.hook.init = function (vnode) {
      if (vnode.data.keepAlive &&
        vnode.componentInstance &&
        vnode.componentInstance !== matched.instances[name]
      ) {
        matched.instances[name] = vnode.componentInstance;
      }

      // if the route transition has already been confirmed then we weren't
      // able to call the cbs during confirmation as the component was not
      // registered yet, so we call it here.
      handleRouteEntered(route);
    };

    var configProps = matched.props && matched.props[name];
    // save route and configProps in cache
    if (configProps) {
      extend$2(cache[name], {
        route: route,
        configProps: configProps
      });
      fillPropsinData(component, data, route, configProps);
    }

    return h(component, data, children)
  }
};

function fillPropsinData (component, data, route, configProps) {
  // resolve props
  var propsToPass = data.props = resolveProps(route, configProps);
  if (propsToPass) {
    // clone to prevent mutation
    propsToPass = data.props = extend$2({}, propsToPass);
    // pass non-declared props as attrs
    var attrs = data.attrs = data.attrs || {};
    for (var key in propsToPass) {
      if (!component.props || !(key in component.props)) {
        attrs[key] = propsToPass[key];
        delete propsToPass[key];
      }
    }
  }
}

function resolveProps (route, config) {
  switch (typeof config) {
    case 'undefined':
      return
    case 'object':
      return config
    case 'function':
      return config(route)
    case 'boolean':
      return config ? route.params : undefined
    default:
      {
        warn$4(
          false,
          "props in \"" + (route.path) + "\" is a " + (typeof config) + ", " +
          "expecting an object, function or boolean."
        );
      }
  }
}

/*  */

function resolvePath (
  relative,
  base,
  append
) {
  var firstChar = relative.charAt(0);
  if (firstChar === '/') {
    return relative
  }

  if (firstChar === '?' || firstChar === '#') {
    return base + relative
  }

  var stack = base.split('/');

  // remove trailing segment if:
  // - not appending
  // - appending to trailing slash (last segment is empty)
  if (!append || !stack[stack.length - 1]) {
    stack.pop();
  }

  // resolve relative path
  var segments = relative.replace(/^\//, '').split('/');
  for (var i = 0; i < segments.length; i++) {
    var segment = segments[i];
    if (segment === '..') {
      stack.pop();
    } else if (segment !== '.') {
      stack.push(segment);
    }
  }

  // ensure leading slash
  if (stack[0] !== '') {
    stack.unshift('');
  }

  return stack.join('/')
}

function parsePath$1 (path) {
  var hash = '';
  var query = '';

  var hashIndex = path.indexOf('#');
  if (hashIndex >= 0) {
    hash = path.slice(hashIndex);
    path = path.slice(0, hashIndex);
  }

  var queryIndex = path.indexOf('?');
  if (queryIndex >= 0) {
    query = path.slice(queryIndex + 1);
    path = path.slice(0, queryIndex);
  }

  return {
    path: path,
    query: query,
    hash: hash
  }
}

function cleanPath (path) {
  return path.replace(/\/\//g, '/')
}

var isarray = Array.isArray || function (arr) {
  return Object.prototype.toString.call(arr) == '[object Array]';
};

/**
 * Expose `pathToRegexp`.
 */
var pathToRegexp_1 = pathToRegexp;
var parse_1 = parse$2;
var compile_1 = compile$1;
var tokensToFunction_1 = tokensToFunction;
var tokensToRegExp_1 = tokensToRegExp;

/**
 * The main path matching regexp utility.
 *
 * @type {RegExp}
 */
var PATH_REGEXP = new RegExp([
  // Match escaped characters that would otherwise appear in future matches.
  // This allows the user to escape special characters that won't transform.
  '(\\\\.)',
  // Match Express-style parameters and un-named parameters with a prefix
  // and optional suffixes. Matches appear as:
  //
  // "/:test(\\d+)?" => ["/", "test", "\d+", undefined, "?", undefined]
  // "/route(\\d+)"  => [undefined, undefined, undefined, "\d+", undefined, undefined]
  // "/*"            => ["/", undefined, undefined, undefined, undefined, "*"]
  '([\\/.])?(?:(?:\\:(\\w+)(?:\\(((?:\\\\.|[^\\\\()])+)\\))?|\\(((?:\\\\.|[^\\\\()])+)\\))([+*?])?|(\\*))'
].join('|'), 'g');

/**
 * Parse a string for the raw tokens.
 *
 * @param  {string}  str
 * @param  {Object=} options
 * @return {!Array}
 */
function parse$2 (str, options) {
  var tokens = [];
  var key = 0;
  var index = 0;
  var path = '';
  var defaultDelimiter = options && options.delimiter || '/';
  var res;

  while ((res = PATH_REGEXP.exec(str)) != null) {
    var m = res[0];
    var escaped = res[1];
    var offset = res.index;
    path += str.slice(index, offset);
    index = offset + m.length;

    // Ignore already escaped sequences.
    if (escaped) {
      path += escaped[1];
      continue
    }

    var next = str[index];
    var prefix = res[2];
    var name = res[3];
    var capture = res[4];
    var group = res[5];
    var modifier = res[6];
    var asterisk = res[7];

    // Push the current path onto the tokens.
    if (path) {
      tokens.push(path);
      path = '';
    }

    var partial = prefix != null && next != null && next !== prefix;
    var repeat = modifier === '+' || modifier === '*';
    var optional = modifier === '?' || modifier === '*';
    var delimiter = res[2] || defaultDelimiter;
    var pattern = capture || group;

    tokens.push({
      name: name || key++,
      prefix: prefix || '',
      delimiter: delimiter,
      optional: optional,
      repeat: repeat,
      partial: partial,
      asterisk: !!asterisk,
      pattern: pattern ? escapeGroup(pattern) : (asterisk ? '.*' : '[^' + escapeString(delimiter) + ']+?')
    });
  }

  // Match any characters still remaining.
  if (index < str.length) {
    path += str.substr(index);
  }

  // If the path exists, push it onto the end.
  if (path) {
    tokens.push(path);
  }

  return tokens
}

/**
 * Compile a string to a template function for the path.
 *
 * @param  {string}             str
 * @param  {Object=}            options
 * @return {!function(Object=, Object=)}
 */
function compile$1 (str, options) {
  return tokensToFunction(parse$2(str, options), options)
}

/**
 * Prettier encoding of URI path segments.
 *
 * @param  {string}
 * @return {string}
 */
function encodeURIComponentPretty (str) {
  return encodeURI(str).replace(/[\/?#]/g, function (c) {
    return '%' + c.charCodeAt(0).toString(16).toUpperCase()
  })
}

/**
 * Encode the asterisk parameter. Similar to `pretty`, but allows slashes.
 *
 * @param  {string}
 * @return {string}
 */
function encodeAsterisk (str) {
  return encodeURI(str).replace(/[?#]/g, function (c) {
    return '%' + c.charCodeAt(0).toString(16).toUpperCase()
  })
}

/**
 * Expose a method for transforming tokens into the path function.
 */
function tokensToFunction (tokens, options) {
  // Compile all the tokens into regexps.
  var matches = new Array(tokens.length);

  // Compile all the patterns before compilation.
  for (var i = 0; i < tokens.length; i++) {
    if (typeof tokens[i] === 'object') {
      matches[i] = new RegExp('^(?:' + tokens[i].pattern + ')$', flags(options));
    }
  }

  return function (obj, opts) {
    var path = '';
    var data = obj || {};
    var options = opts || {};
    var encode = options.pretty ? encodeURIComponentPretty : encodeURIComponent;

    for (var i = 0; i < tokens.length; i++) {
      var token = tokens[i];

      if (typeof token === 'string') {
        path += token;

        continue
      }

      var value = data[token.name];
      var segment;

      if (value == null) {
        if (token.optional) {
          // Prepend partial segment prefixes.
          if (token.partial) {
            path += token.prefix;
          }

          continue
        } else {
          throw new TypeError('Expected "' + token.name + '" to be defined')
        }
      }

      if (isarray(value)) {
        if (!token.repeat) {
          throw new TypeError('Expected "' + token.name + '" to not repeat, but received `' + JSON.stringify(value) + '`')
        }

        if (value.length === 0) {
          if (token.optional) {
            continue
          } else {
            throw new TypeError('Expected "' + token.name + '" to not be empty')
          }
        }

        for (var j = 0; j < value.length; j++) {
          segment = encode(value[j]);

          if (!matches[i].test(segment)) {
            throw new TypeError('Expected all "' + token.name + '" to match "' + token.pattern + '", but received `' + JSON.stringify(segment) + '`')
          }

          path += (j === 0 ? token.prefix : token.delimiter) + segment;
        }

        continue
      }

      segment = token.asterisk ? encodeAsterisk(value) : encode(value);

      if (!matches[i].test(segment)) {
        throw new TypeError('Expected "' + token.name + '" to match "' + token.pattern + '", but received "' + segment + '"')
      }

      path += token.prefix + segment;
    }

    return path
  }
}

/**
 * Escape a regular expression string.
 *
 * @param  {string} str
 * @return {string}
 */
function escapeString (str) {
  return str.replace(/([.+*?=^!:${}()[\]|\/\\])/g, '\\$1')
}

/**
 * Escape the capturing group by escaping special characters and meaning.
 *
 * @param  {string} group
 * @return {string}
 */
function escapeGroup (group) {
  return group.replace(/([=!:$\/()])/g, '\\$1')
}

/**
 * Attach the keys as a property of the regexp.
 *
 * @param  {!RegExp} re
 * @param  {Array}   keys
 * @return {!RegExp}
 */
function attachKeys (re, keys) {
  re.keys = keys;
  return re
}

/**
 * Get the flags for a regexp from the options.
 *
 * @param  {Object} options
 * @return {string}
 */
function flags (options) {
  return options && options.sensitive ? '' : 'i'
}

/**
 * Pull out keys from a regexp.
 *
 * @param  {!RegExp} path
 * @param  {!Array}  keys
 * @return {!RegExp}
 */
function regexpToRegexp (path, keys) {
  // Use a negative lookahead to match only capturing groups.
  var groups = path.source.match(/\((?!\?)/g);

  if (groups) {
    for (var i = 0; i < groups.length; i++) {
      keys.push({
        name: i,
        prefix: null,
        delimiter: null,
        optional: false,
        repeat: false,
        partial: false,
        asterisk: false,
        pattern: null
      });
    }
  }

  return attachKeys(path, keys)
}

/**
 * Transform an array into a regexp.
 *
 * @param  {!Array}  path
 * @param  {Array}   keys
 * @param  {!Object} options
 * @return {!RegExp}
 */
function arrayToRegexp (path, keys, options) {
  var parts = [];

  for (var i = 0; i < path.length; i++) {
    parts.push(pathToRegexp(path[i], keys, options).source);
  }

  var regexp = new RegExp('(?:' + parts.join('|') + ')', flags(options));

  return attachKeys(regexp, keys)
}

/**
 * Create a path regexp from string input.
 *
 * @param  {string}  path
 * @param  {!Array}  keys
 * @param  {!Object} options
 * @return {!RegExp}
 */
function stringToRegexp (path, keys, options) {
  return tokensToRegExp(parse$2(path, options), keys, options)
}

/**
 * Expose a function for taking tokens and returning a RegExp.
 *
 * @param  {!Array}          tokens
 * @param  {(Array|Object)=} keys
 * @param  {Object=}         options
 * @return {!RegExp}
 */
function tokensToRegExp (tokens, keys, options) {
  if (!isarray(keys)) {
    options = /** @type {!Object} */ (keys || options);
    keys = [];
  }

  options = options || {};

  var strict = options.strict;
  var end = options.end !== false;
  var route = '';

  // Iterate over the tokens and create our regexp string.
  for (var i = 0; i < tokens.length; i++) {
    var token = tokens[i];

    if (typeof token === 'string') {
      route += escapeString(token);
    } else {
      var prefix = escapeString(token.prefix);
      var capture = '(?:' + token.pattern + ')';

      keys.push(token);

      if (token.repeat) {
        capture += '(?:' + prefix + capture + ')*';
      }

      if (token.optional) {
        if (!token.partial) {
          capture = '(?:' + prefix + '(' + capture + '))?';
        } else {
          capture = prefix + '(' + capture + ')?';
        }
      } else {
        capture = prefix + '(' + capture + ')';
      }

      route += capture;
    }
  }

  var delimiter = escapeString(options.delimiter || '/');
  var endsWithDelimiter = route.slice(-delimiter.length) === delimiter;

  // In non-strict mode we allow a slash at the end of match. If the path to
  // match already ends with a slash, we remove it for consistency. The slash
  // is valid at the end of a path match, not in the middle. This is important
  // in non-ending mode, where "/test/" shouldn't match "/test//route".
  if (!strict) {
    route = (endsWithDelimiter ? route.slice(0, -delimiter.length) : route) + '(?:' + delimiter + '(?=$))?';
  }

  if (end) {
    route += '$';
  } else {
    // In non-ending mode, we need the capturing groups to match as much as
    // possible by using a positive lookahead to the end or next path segment.
    route += strict && endsWithDelimiter ? '' : '(?=' + delimiter + '|$)';
  }

  return attachKeys(new RegExp('^' + route, flags(options)), keys)
}

/**
 * Normalize the given path string, returning a regular expression.
 *
 * An empty array can be passed in for the keys, which will hold the
 * placeholder key descriptions. For example, using `/user/:id`, `keys` will
 * contain `[{ name: 'id', delimiter: '/', optional: false, repeat: false }]`.
 *
 * @param  {(string|RegExp|Array)} path
 * @param  {(Array|Object)=}       keys
 * @param  {Object=}               options
 * @return {!RegExp}
 */
function pathToRegexp (path, keys, options) {
  if (!isarray(keys)) {
    options = /** @type {!Object} */ (keys || options);
    keys = [];
  }

  options = options || {};

  if (path instanceof RegExp) {
    return regexpToRegexp(path, /** @type {!Array} */ (keys))
  }

  if (isarray(path)) {
    return arrayToRegexp(/** @type {!Array} */ (path), /** @type {!Array} */ (keys), options)
  }

  return stringToRegexp(/** @type {string} */ (path), /** @type {!Array} */ (keys), options)
}
pathToRegexp_1.parse = parse_1;
pathToRegexp_1.compile = compile_1;
pathToRegexp_1.tokensToFunction = tokensToFunction_1;
pathToRegexp_1.tokensToRegExp = tokensToRegExp_1;

/*  */

// $flow-disable-line
var regexpCompileCache = Object.create(null);

function fillParams (
  path,
  params,
  routeMsg
) {
  params = params || {};
  try {
    var filler =
      regexpCompileCache[path] ||
      (regexpCompileCache[path] = pathToRegexp_1.compile(path));

    // Fix #2505 resolving asterisk routes { name: 'not-found', params: { pathMatch: '/not-found' }}
    // and fix #3106 so that you can work with location descriptor object having params.pathMatch equal to empty string
    if (typeof params.pathMatch === 'string') { params[0] = params.pathMatch; }

    return filler(params, { pretty: true })
  } catch (e) {
    {
      // Fix #3072 no warn if `pathMatch` is string
      warn$4(typeof params.pathMatch === 'string', ("missing param for " + routeMsg + ": " + (e.message)));
    }
    return ''
  } finally {
    // delete the 0 if it was added
    delete params[0];
  }
}

/*  */

function normalizeLocation (
  raw,
  current,
  append,
  router
) {
  var next = typeof raw === 'string' ? { path: raw } : raw;
  // named target
  if (next._normalized) {
    return next
  } else if (next.name) {
    next = extend$2({}, raw);
    var params = next.params;
    if (params && typeof params === 'object') {
      next.params = extend$2({}, params);
    }
    return next
  }

  // relative params
  if (!next.path && next.params && current) {
    next = extend$2({}, next);
    next._normalized = true;
    var params$1 = extend$2(extend$2({}, current.params), next.params);
    if (current.name) {
      next.name = current.name;
      next.params = params$1;
    } else if (current.matched.length) {
      var rawPath = current.matched[current.matched.length - 1].path;
      next.path = fillParams(rawPath, params$1, ("path " + (current.path)));
    } else {
      warn$4(false, "relative params navigation requires a current route.");
    }
    return next
  }

  var parsedPath = parsePath$1(next.path || '');
  var basePath = (current && current.path) || '/';
  var path = parsedPath.path
    ? resolvePath(parsedPath.path, basePath, append || next.append)
    : basePath;

  var query = resolveQuery(
    parsedPath.query,
    next.query,
    router && router.options.parseQuery
  );

  var hash = next.hash || parsedPath.hash;
  if (hash && hash.charAt(0) !== '#') {
    hash = "#" + hash;
  }

  return {
    _normalized: true,
    path: path,
    query: query,
    hash: hash
  }
}

/*  */

// work around weird flow bug
var toTypes = [String, Object];
var eventTypes = [String, Array];

var noop$1 = function () {};

var Link = {
  name: 'RouterLink',
  props: {
    to: {
      type: toTypes,
      required: true
    },
    tag: {
      type: String,
      default: 'a'
    },
    exact: Boolean,
    append: Boolean,
    replace: Boolean,
    activeClass: String,
    exactActiveClass: String,
    ariaCurrentValue: {
      type: String,
      default: 'page'
    },
    event: {
      type: eventTypes,
      default: 'click'
    }
  },
  render: function render (h) {
    var this$1 = this;

    var router = this.$router;
    var current = this.$route;
    var ref = router.resolve(
      this.to,
      current,
      this.append
    );
    var location = ref.location;
    var route = ref.route;
    var href = ref.href;

    var classes = {};
    var globalActiveClass = router.options.linkActiveClass;
    var globalExactActiveClass = router.options.linkExactActiveClass;
    // Support global empty active class
    var activeClassFallback =
      globalActiveClass == null ? 'router-link-active' : globalActiveClass;
    var exactActiveClassFallback =
      globalExactActiveClass == null
        ? 'router-link-exact-active'
        : globalExactActiveClass;
    var activeClass =
      this.activeClass == null ? activeClassFallback : this.activeClass;
    var exactActiveClass =
      this.exactActiveClass == null
        ? exactActiveClassFallback
        : this.exactActiveClass;

    var compareTarget = route.redirectedFrom
      ? createRoute(null, normalizeLocation(route.redirectedFrom), null, router)
      : route;

    classes[exactActiveClass] = isSameRoute(current, compareTarget);
    classes[activeClass] = this.exact
      ? classes[exactActiveClass]
      : isIncludedRoute(current, compareTarget);

    var ariaCurrentValue = classes[exactActiveClass] ? this.ariaCurrentValue : null;

    var handler = function (e) {
      if (guardEvent(e)) {
        if (this$1.replace) {
          router.replace(location, noop$1);
        } else {
          router.push(location, noop$1);
        }
      }
    };

    var on = { click: guardEvent };
    if (Array.isArray(this.event)) {
      this.event.forEach(function (e) {
        on[e] = handler;
      });
    } else {
      on[this.event] = handler;
    }

    var data = { class: classes };

    var scopedSlot =
      !this.$scopedSlots.$hasNormal &&
      this.$scopedSlots.default &&
      this.$scopedSlots.default({
        href: href,
        route: route,
        navigate: handler,
        isActive: classes[activeClass],
        isExactActive: classes[exactActiveClass]
      });

    if (scopedSlot) {
      if (scopedSlot.length === 1) {
        return scopedSlot[0]
      } else if (scopedSlot.length > 1 || !scopedSlot.length) {
        {
          warn$4(
            false,
            ("RouterLink with to=\"" + (this.to) + "\" is trying to use a scoped slot but it didn't provide exactly one child. Wrapping the content with a span element.")
          );
        }
        return scopedSlot.length === 0 ? h() : h('span', {}, scopedSlot)
      }
    }

    if (this.tag === 'a') {
      data.on = on;
      data.attrs = { href: href, 'aria-current': ariaCurrentValue };
    } else {
      // find the first <a> child and apply listener and href
      var a = findAnchor(this.$slots.default);
      if (a) {
        // in case the <a> is a static node
        a.isStatic = false;
        var aData = (a.data = extend$2({}, a.data));
        aData.on = aData.on || {};
        // transform existing events in both objects into arrays so we can push later
        for (var event in aData.on) {
          var handler$1 = aData.on[event];
          if (event in on) {
            aData.on[event] = Array.isArray(handler$1) ? handler$1 : [handler$1];
          }
        }
        // append new listeners for router-link
        for (var event$1 in on) {
          if (event$1 in aData.on) {
            // on[event] is always a function
            aData.on[event$1].push(on[event$1]);
          } else {
            aData.on[event$1] = handler;
          }
        }

        var aAttrs = (a.data.attrs = extend$2({}, a.data.attrs));
        aAttrs.href = href;
        aAttrs['aria-current'] = ariaCurrentValue;
      } else {
        // doesn't have <a> child, apply listener to self
        data.on = on;
      }
    }

    return h(this.tag, data, this.$slots.default)
  }
};

function guardEvent (e) {
  // don't redirect with control keys
  if (e.metaKey || e.altKey || e.ctrlKey || e.shiftKey) { return }
  // don't redirect when preventDefault called
  if (e.defaultPrevented) { return }
  // don't redirect on right click
  if (e.button !== undefined && e.button !== 0) { return }
  // don't redirect if `target="_blank"`
  if (e.currentTarget && e.currentTarget.getAttribute) {
    var target = e.currentTarget.getAttribute('target');
    if (/\b_blank\b/i.test(target)) { return }
  }
  // this may be a Weex event which doesn't have this method
  if (e.preventDefault) {
    e.preventDefault();
  }
  return true
}

function findAnchor (children) {
  if (children) {
    var child;
    for (var i = 0; i < children.length; i++) {
      child = children[i];
      if (child.tag === 'a') {
        return child
      }
      if (child.children && (child = findAnchor(child.children))) {
        return child
      }
    }
  }
}

var _Vue;

function install$2 (Vue) {
  if (install$2.installed && _Vue === Vue) { return }
  install$2.installed = true;

  _Vue = Vue;

  var isDef = function (v) { return v !== undefined; };

  var registerInstance = function (vm, callVal) {
    var i = vm.$options._parentVnode;
    if (isDef(i) && isDef(i = i.data) && isDef(i = i.registerRouteInstance)) {
      i(vm, callVal);
    }
  };

  Vue.mixin({
    beforeCreate: function beforeCreate () {
      if (isDef(this.$options.router)) {
        this._routerRoot = this;
        this._router = this.$options.router;
        this._router.init(this);
        Vue.util.defineReactive(this, '_route', this._router.history.current);
      } else {
        this._routerRoot = (this.$parent && this.$parent._routerRoot) || this;
      }
      registerInstance(this, this);
    },
    destroyed: function destroyed () {
      registerInstance(this);
    }
  });

  Object.defineProperty(Vue.prototype, '$router', {
    get: function get () { return this._routerRoot._router }
  });

  Object.defineProperty(Vue.prototype, '$route', {
    get: function get () { return this._routerRoot._route }
  });

  Vue.component('RouterView', View);
  Vue.component('RouterLink', Link);

  var strats = Vue.config.optionMergeStrategies;
  // use the same hook merging strategy for route hooks
  strats.beforeRouteEnter = strats.beforeRouteLeave = strats.beforeRouteUpdate = strats.created;
}

/*  */

var inBrowser$1 = typeof window !== 'undefined';

/*  */

function createRouteMap (
  routes,
  oldPathList,
  oldPathMap,
  oldNameMap
) {
  // the path list is used to control path matching priority
  var pathList = oldPathList || [];
  // $flow-disable-line
  var pathMap = oldPathMap || Object.create(null);
  // $flow-disable-line
  var nameMap = oldNameMap || Object.create(null);

  routes.forEach(function (route) {
    addRouteRecord(pathList, pathMap, nameMap, route);
  });

  // ensure wildcard routes are always at the end
  for (var i = 0, l = pathList.length; i < l; i++) {
    if (pathList[i] === '*') {
      pathList.push(pathList.splice(i, 1)[0]);
      l--;
      i--;
    }
  }

  {
    // warn if routes do not include leading slashes
    var found = pathList
    // check for missing leading slash
      .filter(function (path) { return path && path.charAt(0) !== '*' && path.charAt(0) !== '/'; });

    if (found.length > 0) {
      var pathNames = found.map(function (path) { return ("- " + path); }).join('\n');
      warn$4(false, ("Non-nested routes must include a leading slash character. Fix the following routes: \n" + pathNames));
    }
  }

  return {
    pathList: pathList,
    pathMap: pathMap,
    nameMap: nameMap
  }
}

function addRouteRecord (
  pathList,
  pathMap,
  nameMap,
  route,
  parent,
  matchAs
) {
  var path = route.path;
  var name = route.name;
  {
    assert$2(path != null, "\"path\" is required in a route configuration.");
    assert$2(
      typeof route.component !== 'string',
      "route config \"component\" for path: " + (String(
        path || name
      )) + " cannot be a " + "string id. Use an actual component instead."
    );
  }

  var pathToRegexpOptions =
    route.pathToRegexpOptions || {};
  var normalizedPath = normalizePath(path, parent, pathToRegexpOptions.strict);

  if (typeof route.caseSensitive === 'boolean') {
    pathToRegexpOptions.sensitive = route.caseSensitive;
  }

  var record = {
    path: normalizedPath,
    regex: compileRouteRegex(normalizedPath, pathToRegexpOptions),
    components: route.components || { default: route.component },
    instances: {},
    enteredCbs: {},
    name: name,
    parent: parent,
    matchAs: matchAs,
    redirect: route.redirect,
    beforeEnter: route.beforeEnter,
    meta: route.meta || {},
    props:
      route.props == null
        ? {}
        : route.components
          ? route.props
          : { default: route.props }
  };

  if (route.children) {
    // Warn if route is named, does not redirect and has a default child route.
    // If users navigate to this route by name, the default child will
    // not be rendered (GH Issue #629)
    {
      if (
        route.name &&
        !route.redirect &&
        route.children.some(function (child) { return /^\/?$/.test(child.path); })
      ) {
        warn$4(
          false,
          "Named Route '" + (route.name) + "' has a default child route. " +
            "When navigating to this named route (:to=\"{name: '" + (route.name) + "'\"), " +
            "the default child route will not be rendered. Remove the name from " +
            "this route and use the name of the default child route for named " +
            "links instead."
        );
      }
    }
    route.children.forEach(function (child) {
      var childMatchAs = matchAs
        ? cleanPath((matchAs + "/" + (child.path)))
        : undefined;
      addRouteRecord(pathList, pathMap, nameMap, child, record, childMatchAs);
    });
  }

  if (!pathMap[record.path]) {
    pathList.push(record.path);
    pathMap[record.path] = record;
  }

  if (route.alias !== undefined) {
    var aliases = Array.isArray(route.alias) ? route.alias : [route.alias];
    for (var i = 0; i < aliases.length; ++i) {
      var alias = aliases[i];
      if ( alias === path) {
        warn$4(
          false,
          ("Found an alias with the same value as the path: \"" + path + "\". You have to remove that alias. It will be ignored in development.")
        );
        // skip in dev to make it work
        continue
      }

      var aliasRoute = {
        path: alias,
        children: route.children
      };
      addRouteRecord(
        pathList,
        pathMap,
        nameMap,
        aliasRoute,
        parent,
        record.path || '/' // matchAs
      );
    }
  }

  if (name) {
    if (!nameMap[name]) {
      nameMap[name] = record;
    } else if ( !matchAs) {
      warn$4(
        false,
        "Duplicate named routes definition: " +
          "{ name: \"" + name + "\", path: \"" + (record.path) + "\" }"
      );
    }
  }
}

function compileRouteRegex (
  path,
  pathToRegexpOptions
) {
  var regex = pathToRegexp_1(path, [], pathToRegexpOptions);
  {
    var keys = Object.create(null);
    regex.keys.forEach(function (key) {
      warn$4(
        !keys[key.name],
        ("Duplicate param keys in route with path: \"" + path + "\"")
      );
      keys[key.name] = true;
    });
  }
  return regex
}

function normalizePath (
  path,
  parent,
  strict
) {
  if (!strict) { path = path.replace(/\/$/, ''); }
  if (path[0] === '/') { return path }
  if (parent == null) { return path }
  return cleanPath(((parent.path) + "/" + path))
}

/*  */



function createMatcher (
  routes,
  router
) {
  var ref = createRouteMap(routes);
  var pathList = ref.pathList;
  var pathMap = ref.pathMap;
  var nameMap = ref.nameMap;

  function addRoutes (routes) {
    createRouteMap(routes, pathList, pathMap, nameMap);
  }

  function match (
    raw,
    currentRoute,
    redirectedFrom
  ) {
    var location = normalizeLocation(raw, currentRoute, false, router);
    var name = location.name;

    if (name) {
      var record = nameMap[name];
      {
        warn$4(record, ("Route with name '" + name + "' does not exist"));
      }
      if (!record) { return _createRoute(null, location) }
      var paramNames = record.regex.keys
        .filter(function (key) { return !key.optional; })
        .map(function (key) { return key.name; });

      if (typeof location.params !== 'object') {
        location.params = {};
      }

      if (currentRoute && typeof currentRoute.params === 'object') {
        for (var key in currentRoute.params) {
          if (!(key in location.params) && paramNames.indexOf(key) > -1) {
            location.params[key] = currentRoute.params[key];
          }
        }
      }

      location.path = fillParams(record.path, location.params, ("named route \"" + name + "\""));
      return _createRoute(record, location, redirectedFrom)
    } else if (location.path) {
      location.params = {};
      for (var i = 0; i < pathList.length; i++) {
        var path = pathList[i];
        var record$1 = pathMap[path];
        if (matchRoute(record$1.regex, location.path, location.params)) {
          return _createRoute(record$1, location, redirectedFrom)
        }
      }
    }
    // no match
    return _createRoute(null, location)
  }

  function redirect (
    record,
    location
  ) {
    var originalRedirect = record.redirect;
    var redirect = typeof originalRedirect === 'function'
      ? originalRedirect(createRoute(record, location, null, router))
      : originalRedirect;

    if (typeof redirect === 'string') {
      redirect = { path: redirect };
    }

    if (!redirect || typeof redirect !== 'object') {
      {
        warn$4(
          false, ("invalid redirect option: " + (JSON.stringify(redirect)))
        );
      }
      return _createRoute(null, location)
    }

    var re = redirect;
    var name = re.name;
    var path = re.path;
    var query = location.query;
    var hash = location.hash;
    var params = location.params;
    query = re.hasOwnProperty('query') ? re.query : query;
    hash = re.hasOwnProperty('hash') ? re.hash : hash;
    params = re.hasOwnProperty('params') ? re.params : params;

    if (name) {
      // resolved named direct
      var targetRecord = nameMap[name];
      {
        assert$2(targetRecord, ("redirect failed: named route \"" + name + "\" not found."));
      }
      return match({
        _normalized: true,
        name: name,
        query: query,
        hash: hash,
        params: params
      }, undefined, location)
    } else if (path) {
      // 1. resolve relative redirect
      var rawPath = resolveRecordPath(path, record);
      // 2. resolve params
      var resolvedPath = fillParams(rawPath, params, ("redirect route with path \"" + rawPath + "\""));
      // 3. rematch with existing query and hash
      return match({
        _normalized: true,
        path: resolvedPath,
        query: query,
        hash: hash
      }, undefined, location)
    } else {
      {
        warn$4(false, ("invalid redirect option: " + (JSON.stringify(redirect))));
      }
      return _createRoute(null, location)
    }
  }

  function alias (
    record,
    location,
    matchAs
  ) {
    var aliasedPath = fillParams(matchAs, location.params, ("aliased route with path \"" + matchAs + "\""));
    var aliasedMatch = match({
      _normalized: true,
      path: aliasedPath
    });
    if (aliasedMatch) {
      var matched = aliasedMatch.matched;
      var aliasedRecord = matched[matched.length - 1];
      location.params = aliasedMatch.params;
      return _createRoute(aliasedRecord, location)
    }
    return _createRoute(null, location)
  }

  function _createRoute (
    record,
    location,
    redirectedFrom
  ) {
    if (record && record.redirect) {
      return redirect(record, redirectedFrom || location)
    }
    if (record && record.matchAs) {
      return alias(record, location, record.matchAs)
    }
    return createRoute(record, location, redirectedFrom, router)
  }

  return {
    match: match,
    addRoutes: addRoutes
  }
}

function matchRoute (
  regex,
  path,
  params
) {
  try {
    path = decodeURI(path);
  } catch (err) {
    {
      warn$4(false, ("Error decoding \"" + path + "\". Leaving it intact."));
    }
  }

  var m = path.match(regex);

  if (!m) {
    return false
  } else if (!params) {
    return true
  }

  for (var i = 1, len = m.length; i < len; ++i) {
    var key = regex.keys[i - 1];
    if (key) {
      // Fix #1994: using * with props: true generates a param named 0
      params[key.name || 'pathMatch'] = m[i];
    }
  }

  return true
}

function resolveRecordPath (path, record) {
  return resolvePath(path, record.parent ? record.parent.path : '/', true)
}

/*  */

// use User Timing api (if present) for more accurate key precision
var Time =
  inBrowser$1 && window.performance && window.performance.now
    ? window.performance
    : Date;

function genStateKey () {
  return Time.now().toFixed(3)
}

var _key = genStateKey();

function getStateKey () {
  return _key
}

function setStateKey (key) {
  return (_key = key)
}

/*  */

var positionStore = Object.create(null);

function setupScroll () {
  // Prevent browser scroll behavior on History popstate
  if ('scrollRestoration' in window.history) {
    window.history.scrollRestoration = 'manual';
  }
  // Fix for #1585 for Firefox
  // Fix for #2195 Add optional third attribute to workaround a bug in safari https://bugs.webkit.org/show_bug.cgi?id=182678
  // Fix for #2774 Support for apps loaded from Windows file shares not mapped to network drives: replaced location.origin with
  // window.location.protocol + '//' + window.location.host
  // location.host contains the port and location.hostname doesn't
  var protocolAndPath = window.location.protocol + '//' + window.location.host;
  var absolutePath = window.location.href.replace(protocolAndPath, '');
  // preserve existing history state as it could be overriden by the user
  var stateCopy = extend$2({}, window.history.state);
  stateCopy.key = getStateKey();
  window.history.replaceState(stateCopy, '', absolutePath);
  window.addEventListener('popstate', handlePopState);
  return function () {
    window.removeEventListener('popstate', handlePopState);
  }
}

function handleScroll (
  router,
  to,
  from,
  isPop
) {
  if (!router.app) {
    return
  }

  var behavior = router.options.scrollBehavior;
  if (!behavior) {
    return
  }

  {
    assert$2(typeof behavior === 'function', "scrollBehavior must be a function");
  }

  // wait until re-render finishes before scrolling
  router.app.$nextTick(function () {
    var position = getScrollPosition();
    var shouldScroll = behavior.call(
      router,
      to,
      from,
      isPop ? position : null
    );

    if (!shouldScroll) {
      return
    }

    if (typeof shouldScroll.then === 'function') {
      shouldScroll
        .then(function (shouldScroll) {
          scrollToPosition((shouldScroll), position);
        })
        .catch(function (err) {
          {
            assert$2(false, err.toString());
          }
        });
    } else {
      scrollToPosition(shouldScroll, position);
    }
  });
}

function saveScrollPosition () {
  var key = getStateKey();
  if (key) {
    positionStore[key] = {
      x: window.pageXOffset,
      y: window.pageYOffset
    };
  }
}

function handlePopState (e) {
  saveScrollPosition();
  if (e.state && e.state.key) {
    setStateKey(e.state.key);
  }
}

function getScrollPosition () {
  var key = getStateKey();
  if (key) {
    return positionStore[key]
  }
}

function getElementPosition (el, offset) {
  var docEl = document.documentElement;
  var docRect = docEl.getBoundingClientRect();
  var elRect = el.getBoundingClientRect();
  return {
    x: elRect.left - docRect.left - offset.x,
    y: elRect.top - docRect.top - offset.y
  }
}

function isValidPosition (obj) {
  return isNumber(obj.x) || isNumber(obj.y)
}

function normalizePosition (obj) {
  return {
    x: isNumber(obj.x) ? obj.x : window.pageXOffset,
    y: isNumber(obj.y) ? obj.y : window.pageYOffset
  }
}

function normalizeOffset (obj) {
  return {
    x: isNumber(obj.x) ? obj.x : 0,
    y: isNumber(obj.y) ? obj.y : 0
  }
}

function isNumber (v) {
  return typeof v === 'number'
}

var hashStartsWithNumberRE = /^#\d/;

function scrollToPosition (shouldScroll, position) {
  var isObject = typeof shouldScroll === 'object';
  if (isObject && typeof shouldScroll.selector === 'string') {
    // getElementById would still fail if the selector contains a more complicated query like #main[data-attr]
    // but at the same time, it doesn't make much sense to select an element with an id and an extra selector
    var el = hashStartsWithNumberRE.test(shouldScroll.selector) // $flow-disable-line
      ? document.getElementById(shouldScroll.selector.slice(1)) // $flow-disable-line
      : document.querySelector(shouldScroll.selector);

    if (el) {
      var offset =
        shouldScroll.offset && typeof shouldScroll.offset === 'object'
          ? shouldScroll.offset
          : {};
      offset = normalizeOffset(offset);
      position = getElementPosition(el, offset);
    } else if (isValidPosition(shouldScroll)) {
      position = normalizePosition(shouldScroll);
    }
  } else if (isObject && isValidPosition(shouldScroll)) {
    position = normalizePosition(shouldScroll);
  }

  if (position) {
    // $flow-disable-line
    if ('scrollBehavior' in document.documentElement.style) {
      window.scrollTo({
        left: position.x,
        top: position.y,
        // $flow-disable-line
        behavior: shouldScroll.behavior
      });
    } else {
      window.scrollTo(position.x, position.y);
    }
  }
}

/*  */

var supportsPushState =
  inBrowser$1 &&
  (function () {
    var ua = window.navigator.userAgent;

    if (
      (ua.indexOf('Android 2.') !== -1 || ua.indexOf('Android 4.0') !== -1) &&
      ua.indexOf('Mobile Safari') !== -1 &&
      ua.indexOf('Chrome') === -1 &&
      ua.indexOf('Windows Phone') === -1
    ) {
      return false
    }

    return window.history && typeof window.history.pushState === 'function'
  })();

function pushState (url, replace) {
  saveScrollPosition();
  // try...catch the pushState call to get around Safari
  // DOM Exception 18 where it limits to 100 pushState calls
  var history = window.history;
  try {
    if (replace) {
      // preserve existing history state as it could be overriden by the user
      var stateCopy = extend$2({}, history.state);
      stateCopy.key = getStateKey();
      history.replaceState(stateCopy, '', url);
    } else {
      history.pushState({ key: setStateKey(genStateKey()) }, '', url);
    }
  } catch (e) {
    window.location[replace ? 'replace' : 'assign'](url);
  }
}

function replaceState (url) {
  pushState(url, true);
}

/*  */

function runQueue (queue, fn, cb) {
  var step = function (index) {
    if (index >= queue.length) {
      cb();
    } else {
      if (queue[index]) {
        fn(queue[index], function () {
          step(index + 1);
        });
      } else {
        step(index + 1);
      }
    }
  };
  step(0);
}

// When changing thing, also edit router.d.ts
var NavigationFailureType = {
  redirected: 2,
  aborted: 4,
  cancelled: 8,
  duplicated: 16
};

function createNavigationRedirectedError (from, to) {
  return createRouterError(
    from,
    to,
    NavigationFailureType.redirected,
    ("Redirected when going from \"" + (from.fullPath) + "\" to \"" + (stringifyRoute(
      to
    )) + "\" via a navigation guard.")
  )
}

function createNavigationDuplicatedError (from, to) {
  var error = createRouterError(
    from,
    to,
    NavigationFailureType.duplicated,
    ("Avoided redundant navigation to current location: \"" + (from.fullPath) + "\".")
  );
  // backwards compatible with the first introduction of Errors
  error.name = 'NavigationDuplicated';
  return error
}

function createNavigationCancelledError (from, to) {
  return createRouterError(
    from,
    to,
    NavigationFailureType.cancelled,
    ("Navigation cancelled from \"" + (from.fullPath) + "\" to \"" + (to.fullPath) + "\" with a new navigation.")
  )
}

function createNavigationAbortedError (from, to) {
  return createRouterError(
    from,
    to,
    NavigationFailureType.aborted,
    ("Navigation aborted from \"" + (from.fullPath) + "\" to \"" + (to.fullPath) + "\" via a navigation guard.")
  )
}

function createRouterError (from, to, type, message) {
  var error = new Error(message);
  error._isRouter = true;
  error.from = from;
  error.to = to;
  error.type = type;

  return error
}

var propertiesToLog = ['params', 'query', 'hash'];

function stringifyRoute (to) {
  if (typeof to === 'string') { return to }
  if ('path' in to) { return to.path }
  var location = {};
  propertiesToLog.forEach(function (key) {
    if (key in to) { location[key] = to[key]; }
  });
  return JSON.stringify(location, null, 2)
}

function isError (err) {
  return Object.prototype.toString.call(err).indexOf('Error') > -1
}

function isNavigationFailure (err, errorType) {
  return (
    isError(err) &&
    err._isRouter &&
    (errorType == null || err.type === errorType)
  )
}

/*  */

function resolveAsyncComponents (matched) {
  return function (to, from, next) {
    var hasAsync = false;
    var pending = 0;
    var error = null;

    flatMapComponents(matched, function (def, _, match, key) {
      // if it's a function and doesn't have cid attached,
      // assume it's an async component resolve function.
      // we are not using Vue's default async resolving mechanism because
      // we want to halt the navigation until the incoming component has been
      // resolved.
      if (typeof def === 'function' && def.cid === undefined) {
        hasAsync = true;
        pending++;

        var resolve = once$1(function (resolvedDef) {
          if (isESModule(resolvedDef)) {
            resolvedDef = resolvedDef.default;
          }
          // save resolved on async factory in case it's used elsewhere
          def.resolved = typeof resolvedDef === 'function'
            ? resolvedDef
            : _Vue.extend(resolvedDef);
          match.components[key] = resolvedDef;
          pending--;
          if (pending <= 0) {
            next();
          }
        });

        var reject = once$1(function (reason) {
          var msg = "Failed to resolve async component " + key + ": " + reason;
           warn$4(false, msg);
          if (!error) {
            error = isError(reason)
              ? reason
              : new Error(msg);
            next(error);
          }
        });

        var res;
        try {
          res = def(resolve, reject);
        } catch (e) {
          reject(e);
        }
        if (res) {
          if (typeof res.then === 'function') {
            res.then(resolve, reject);
          } else {
            // new syntax in Vue 2.3
            var comp = res.component;
            if (comp && typeof comp.then === 'function') {
              comp.then(resolve, reject);
            }
          }
        }
      }
    });

    if (!hasAsync) { next(); }
  }
}

function flatMapComponents (
  matched,
  fn
) {
  return flatten(matched.map(function (m) {
    return Object.keys(m.components).map(function (key) { return fn(
      m.components[key],
      m.instances[key],
      m, key
    ); })
  }))
}

function flatten (arr) {
  return Array.prototype.concat.apply([], arr)
}

var hasSymbol$1 =
  typeof Symbol === 'function' &&
  typeof Symbol.toStringTag === 'symbol';

function isESModule (obj) {
  return obj.__esModule || (hasSymbol$1 && obj[Symbol.toStringTag] === 'Module')
}

// in Webpack 2, require.ensure now also returns a Promise
// so the resolve/reject functions may get called an extra time
// if the user uses an arrow function shorthand that happens to
// return that Promise.
function once$1 (fn) {
  var called = false;
  return function () {
    var args = [], len = arguments.length;
    while ( len-- ) args[ len ] = arguments[ len ];

    if (called) { return }
    called = true;
    return fn.apply(this, args)
  }
}

/*  */

var History = function History (router, base) {
  this.router = router;
  this.base = normalizeBase(base);
  // start with a route object that stands for "nowhere"
  this.current = START;
  this.pending = null;
  this.ready = false;
  this.readyCbs = [];
  this.readyErrorCbs = [];
  this.errorCbs = [];
  this.listeners = [];
};

History.prototype.listen = function listen (cb) {
  this.cb = cb;
};

History.prototype.onReady = function onReady (cb, errorCb) {
  if (this.ready) {
    cb();
  } else {
    this.readyCbs.push(cb);
    if (errorCb) {
      this.readyErrorCbs.push(errorCb);
    }
  }
};

History.prototype.onError = function onError (errorCb) {
  this.errorCbs.push(errorCb);
};

History.prototype.transitionTo = function transitionTo (
  location,
  onComplete,
  onAbort
) {
    var this$1 = this;

  var route;
  // catch redirect option https://github.com/vuejs/vue-router/issues/3201
  try {
    route = this.router.match(location, this.current);
  } catch (e) {
    this.errorCbs.forEach(function (cb) {
      cb(e);
    });
    // Exception should still be thrown
    throw e
  }
  var prev = this.current;
  this.confirmTransition(
    route,
    function () {
      this$1.updateRoute(route);
      onComplete && onComplete(route);
      this$1.ensureURL();
      this$1.router.afterHooks.forEach(function (hook) {
        hook && hook(route, prev);
      });

      // fire ready cbs once
      if (!this$1.ready) {
        this$1.ready = true;
        this$1.readyCbs.forEach(function (cb) {
          cb(route);
        });
      }
    },
    function (err) {
      if (onAbort) {
        onAbort(err);
      }
      if (err && !this$1.ready) {
        // Initial redirection should not mark the history as ready yet
        // because it's triggered by the redirection instead
        // https://github.com/vuejs/vue-router/issues/3225
        // https://github.com/vuejs/vue-router/issues/3331
        if (!isNavigationFailure(err, NavigationFailureType.redirected) || prev !== START) {
          this$1.ready = true;
          this$1.readyErrorCbs.forEach(function (cb) {
            cb(err);
          });
        }
      }
    }
  );
};

History.prototype.confirmTransition = function confirmTransition (route, onComplete, onAbort) {
    var this$1 = this;

  var current = this.current;
  this.pending = route;
  var abort = function (err) {
    // changed after adding errors with
    // https://github.com/vuejs/vue-router/pull/3047 before that change,
    // redirect and aborted navigation would produce an err == null
    if (!isNavigationFailure(err) && isError(err)) {
      if (this$1.errorCbs.length) {
        this$1.errorCbs.forEach(function (cb) {
          cb(err);
        });
      } else {
        warn$4(false, 'uncaught error during route navigation:');
        console.error(err);
      }
    }
    onAbort && onAbort(err);
  };
  var lastRouteIndex = route.matched.length - 1;
  var lastCurrentIndex = current.matched.length - 1;
  if (
    isSameRoute(route, current) &&
    // in the case the route map has been dynamically appended to
    lastRouteIndex === lastCurrentIndex &&
    route.matched[lastRouteIndex] === current.matched[lastCurrentIndex]
  ) {
    this.ensureURL();
    return abort(createNavigationDuplicatedError(current, route))
  }

  var ref = resolveQueue(
    this.current.matched,
    route.matched
  );
    var updated = ref.updated;
    var deactivated = ref.deactivated;
    var activated = ref.activated;

  var queue = [].concat(
    // in-component leave guards
    extractLeaveGuards(deactivated),
    // global before hooks
    this.router.beforeHooks,
    // in-component update hooks
    extractUpdateHooks(updated),
    // in-config enter guards
    activated.map(function (m) { return m.beforeEnter; }),
    // async components
    resolveAsyncComponents(activated)
  );

  var iterator = function (hook, next) {
    if (this$1.pending !== route) {
      return abort(createNavigationCancelledError(current, route))
    }
    try {
      hook(route, current, function (to) {
        if (to === false) {
          // next(false) -> abort navigation, ensure current URL
          this$1.ensureURL(true);
          abort(createNavigationAbortedError(current, route));
        } else if (isError(to)) {
          this$1.ensureURL(true);
          abort(to);
        } else if (
          typeof to === 'string' ||
          (typeof to === 'object' &&
            (typeof to.path === 'string' || typeof to.name === 'string'))
        ) {
          // next('/') or next({ path: '/' }) -> redirect
          abort(createNavigationRedirectedError(current, route));
          if (typeof to === 'object' && to.replace) {
            this$1.replace(to);
          } else {
            this$1.push(to);
          }
        } else {
          // confirm transition and pass on the value
          next(to);
        }
      });
    } catch (e) {
      abort(e);
    }
  };

  runQueue(queue, iterator, function () {
    // wait until async components are resolved before
    // extracting in-component enter guards
    var enterGuards = extractEnterGuards(activated);
    var queue = enterGuards.concat(this$1.router.resolveHooks);
    runQueue(queue, iterator, function () {
      if (this$1.pending !== route) {
        return abort(createNavigationCancelledError(current, route))
      }
      this$1.pending = null;
      onComplete(route);
      if (this$1.router.app) {
        this$1.router.app.$nextTick(function () {
          handleRouteEntered(route);
        });
      }
    });
  });
};

History.prototype.updateRoute = function updateRoute (route) {
  this.current = route;
  this.cb && this.cb(route);
};

History.prototype.setupListeners = function setupListeners () {
  // Default implementation is empty
};

History.prototype.teardown = function teardown () {
  // clean up event listeners
  // https://github.com/vuejs/vue-router/issues/2341
  this.listeners.forEach(function (cleanupListener) {
    cleanupListener();
  });
  this.listeners = [];

  // reset current history route
  // https://github.com/vuejs/vue-router/issues/3294
  this.current = START;
  this.pending = null;
};

function normalizeBase (base) {
  if (!base) {
    if (inBrowser$1) {
      // respect <base> tag
      var baseEl = document.querySelector('base');
      base = (baseEl && baseEl.getAttribute('href')) || '/';
      // strip full URL origin
      base = base.replace(/^https?:\/\/[^\/]+/, '');
    } else {
      base = '/';
    }
  }
  // make sure there's the starting slash
  if (base.charAt(0) !== '/') {
    base = '/' + base;
  }
  // remove trailing slash
  return base.replace(/\/$/, '')
}

function resolveQueue (
  current,
  next
) {
  var i;
  var max = Math.max(current.length, next.length);
  for (i = 0; i < max; i++) {
    if (current[i] !== next[i]) {
      break
    }
  }
  return {
    updated: next.slice(0, i),
    activated: next.slice(i),
    deactivated: current.slice(i)
  }
}

function extractGuards (
  records,
  name,
  bind,
  reverse
) {
  var guards = flatMapComponents(records, function (def, instance, match, key) {
    var guard = extractGuard(def, name);
    if (guard) {
      return Array.isArray(guard)
        ? guard.map(function (guard) { return bind(guard, instance, match, key); })
        : bind(guard, instance, match, key)
    }
  });
  return flatten(reverse ? guards.reverse() : guards)
}

function extractGuard (
  def,
  key
) {
  if (typeof def !== 'function') {
    // extend now so that global mixins are applied.
    def = _Vue.extend(def);
  }
  return def.options[key]
}

function extractLeaveGuards (deactivated) {
  return extractGuards(deactivated, 'beforeRouteLeave', bindGuard, true)
}

function extractUpdateHooks (updated) {
  return extractGuards(updated, 'beforeRouteUpdate', bindGuard)
}

function bindGuard (guard, instance) {
  if (instance) {
    return function boundRouteGuard () {
      return guard.apply(instance, arguments)
    }
  }
}

function extractEnterGuards (
  activated
) {
  return extractGuards(
    activated,
    'beforeRouteEnter',
    function (guard, _, match, key) {
      return bindEnterGuard(guard, match, key)
    }
  )
}

function bindEnterGuard (
  guard,
  match,
  key
) {
  return function routeEnterGuard (to, from, next) {
    return guard(to, from, function (cb) {
      if (typeof cb === 'function') {
        if (!match.enteredCbs[key]) {
          match.enteredCbs[key] = [];
        }
        match.enteredCbs[key].push(cb);
      }
      next(cb);
    })
  }
}

/*  */

var HTML5History = /*@__PURE__*/(function (History) {
  function HTML5History (router, base) {
    History.call(this, router, base);

    this._startLocation = getLocation(this.base);
  }

  if ( History ) HTML5History.__proto__ = History;
  HTML5History.prototype = Object.create( History && History.prototype );
  HTML5History.prototype.constructor = HTML5History;

  HTML5History.prototype.setupListeners = function setupListeners () {
    var this$1 = this;

    if (this.listeners.length > 0) {
      return
    }

    var router = this.router;
    var expectScroll = router.options.scrollBehavior;
    var supportsScroll = supportsPushState && expectScroll;

    if (supportsScroll) {
      this.listeners.push(setupScroll());
    }

    var handleRoutingEvent = function () {
      var current = this$1.current;

      // Avoiding first `popstate` event dispatched in some browsers but first
      // history route not updated since async guard at the same time.
      var location = getLocation(this$1.base);
      if (this$1.current === START && location === this$1._startLocation) {
        return
      }

      this$1.transitionTo(location, function (route) {
        if (supportsScroll) {
          handleScroll(router, route, current, true);
        }
      });
    };
    window.addEventListener('popstate', handleRoutingEvent);
    this.listeners.push(function () {
      window.removeEventListener('popstate', handleRoutingEvent);
    });
  };

  HTML5History.prototype.go = function go (n) {
    window.history.go(n);
  };

  HTML5History.prototype.push = function push (location, onComplete, onAbort) {
    var this$1 = this;

    var ref = this;
    var fromRoute = ref.current;
    this.transitionTo(location, function (route) {
      pushState(cleanPath(this$1.base + route.fullPath));
      handleScroll(this$1.router, route, fromRoute, false);
      onComplete && onComplete(route);
    }, onAbort);
  };

  HTML5History.prototype.replace = function replace (location, onComplete, onAbort) {
    var this$1 = this;

    var ref = this;
    var fromRoute = ref.current;
    this.transitionTo(location, function (route) {
      replaceState(cleanPath(this$1.base + route.fullPath));
      handleScroll(this$1.router, route, fromRoute, false);
      onComplete && onComplete(route);
    }, onAbort);
  };

  HTML5History.prototype.ensureURL = function ensureURL (push) {
    if (getLocation(this.base) !== this.current.fullPath) {
      var current = cleanPath(this.base + this.current.fullPath);
      push ? pushState(current) : replaceState(current);
    }
  };

  HTML5History.prototype.getCurrentLocation = function getCurrentLocation () {
    return getLocation(this.base)
  };

  return HTML5History;
}(History));

function getLocation (base) {
  var path = window.location.pathname;
  if (base && path.toLowerCase().indexOf(base.toLowerCase()) === 0) {
    path = path.slice(base.length);
  }
  return (path || '/') + window.location.search + window.location.hash
}

/*  */

var HashHistory = /*@__PURE__*/(function (History) {
  function HashHistory (router, base, fallback) {
    History.call(this, router, base);
    // check history fallback deeplinking
    if (fallback && checkFallback(this.base)) {
      return
    }
    ensureSlash();
  }

  if ( History ) HashHistory.__proto__ = History;
  HashHistory.prototype = Object.create( History && History.prototype );
  HashHistory.prototype.constructor = HashHistory;

  // this is delayed until the app mounts
  // to avoid the hashchange listener being fired too early
  HashHistory.prototype.setupListeners = function setupListeners () {
    var this$1 = this;

    if (this.listeners.length > 0) {
      return
    }

    var router = this.router;
    var expectScroll = router.options.scrollBehavior;
    var supportsScroll = supportsPushState && expectScroll;

    if (supportsScroll) {
      this.listeners.push(setupScroll());
    }

    var handleRoutingEvent = function () {
      var current = this$1.current;
      if (!ensureSlash()) {
        return
      }
      this$1.transitionTo(getHash(), function (route) {
        if (supportsScroll) {
          handleScroll(this$1.router, route, current, true);
        }
        if (!supportsPushState) {
          replaceHash(route.fullPath);
        }
      });
    };
    var eventType = supportsPushState ? 'popstate' : 'hashchange';
    window.addEventListener(
      eventType,
      handleRoutingEvent
    );
    this.listeners.push(function () {
      window.removeEventListener(eventType, handleRoutingEvent);
    });
  };

  HashHistory.prototype.push = function push (location, onComplete, onAbort) {
    var this$1 = this;

    var ref = this;
    var fromRoute = ref.current;
    this.transitionTo(
      location,
      function (route) {
        pushHash(route.fullPath);
        handleScroll(this$1.router, route, fromRoute, false);
        onComplete && onComplete(route);
      },
      onAbort
    );
  };

  HashHistory.prototype.replace = function replace (location, onComplete, onAbort) {
    var this$1 = this;

    var ref = this;
    var fromRoute = ref.current;
    this.transitionTo(
      location,
      function (route) {
        replaceHash(route.fullPath);
        handleScroll(this$1.router, route, fromRoute, false);
        onComplete && onComplete(route);
      },
      onAbort
    );
  };

  HashHistory.prototype.go = function go (n) {
    window.history.go(n);
  };

  HashHistory.prototype.ensureURL = function ensureURL (push) {
    var current = this.current.fullPath;
    if (getHash() !== current) {
      push ? pushHash(current) : replaceHash(current);
    }
  };

  HashHistory.prototype.getCurrentLocation = function getCurrentLocation () {
    return getHash()
  };

  return HashHistory;
}(History));

function checkFallback (base) {
  var location = getLocation(base);
  if (!/^\/#/.test(location)) {
    window.location.replace(cleanPath(base + '/#' + location));
    return true
  }
}

function ensureSlash () {
  var path = getHash();
  if (path.charAt(0) === '/') {
    return true
  }
  replaceHash('/' + path);
  return false
}

function getHash () {
  // We can't use window.location.hash here because it's not
  // consistent across browsers - Firefox will pre-decode it!
  var href = window.location.href;
  var index = href.indexOf('#');
  // empty path
  if (index < 0) { return '' }

  href = href.slice(index + 1);

  return href
}

function getUrl (path) {
  var href = window.location.href;
  var i = href.indexOf('#');
  var base = i >= 0 ? href.slice(0, i) : href;
  return (base + "#" + path)
}

function pushHash (path) {
  if (supportsPushState) {
    pushState(getUrl(path));
  } else {
    window.location.hash = path;
  }
}

function replaceHash (path) {
  if (supportsPushState) {
    replaceState(getUrl(path));
  } else {
    window.location.replace(getUrl(path));
  }
}

/*  */

var AbstractHistory = /*@__PURE__*/(function (History) {
  function AbstractHistory (router, base) {
    History.call(this, router, base);
    this.stack = [];
    this.index = -1;
  }

  if ( History ) AbstractHistory.__proto__ = History;
  AbstractHistory.prototype = Object.create( History && History.prototype );
  AbstractHistory.prototype.constructor = AbstractHistory;

  AbstractHistory.prototype.push = function push (location, onComplete, onAbort) {
    var this$1 = this;

    this.transitionTo(
      location,
      function (route) {
        this$1.stack = this$1.stack.slice(0, this$1.index + 1).concat(route);
        this$1.index++;
        onComplete && onComplete(route);
      },
      onAbort
    );
  };

  AbstractHistory.prototype.replace = function replace (location, onComplete, onAbort) {
    var this$1 = this;

    this.transitionTo(
      location,
      function (route) {
        this$1.stack = this$1.stack.slice(0, this$1.index).concat(route);
        onComplete && onComplete(route);
      },
      onAbort
    );
  };

  AbstractHistory.prototype.go = function go (n) {
    var this$1 = this;

    var targetIndex = this.index + n;
    if (targetIndex < 0 || targetIndex >= this.stack.length) {
      return
    }
    var route = this.stack[targetIndex];
    this.confirmTransition(
      route,
      function () {
        var prev = this$1.current;
        this$1.index = targetIndex;
        this$1.updateRoute(route);
        this$1.router.afterHooks.forEach(function (hook) {
          hook && hook(route, prev);
        });
      },
      function (err) {
        if (isNavigationFailure(err, NavigationFailureType.duplicated)) {
          this$1.index = targetIndex;
        }
      }
    );
  };

  AbstractHistory.prototype.getCurrentLocation = function getCurrentLocation () {
    var current = this.stack[this.stack.length - 1];
    return current ? current.fullPath : '/'
  };

  AbstractHistory.prototype.ensureURL = function ensureURL () {
    // noop
  };

  return AbstractHistory;
}(History));

/*  */

var VueRouter = function VueRouter (options) {
  if ( options === void 0 ) options = {};

  this.app = null;
  this.apps = [];
  this.options = options;
  this.beforeHooks = [];
  this.resolveHooks = [];
  this.afterHooks = [];
  this.matcher = createMatcher(options.routes || [], this);

  var mode = options.mode || 'hash';
  this.fallback =
    mode === 'history' && !supportsPushState && options.fallback !== false;
  if (this.fallback) {
    mode = 'hash';
  }
  if (!inBrowser$1) {
    mode = 'abstract';
  }
  this.mode = mode;

  switch (mode) {
    case 'history':
      this.history = new HTML5History(this, options.base);
      break
    case 'hash':
      this.history = new HashHistory(this, options.base, this.fallback);
      break
    case 'abstract':
      this.history = new AbstractHistory(this, options.base);
      break
    default:
      {
        assert$2(false, ("invalid mode: " + mode));
      }
  }
};

var prototypeAccessors$3 = { currentRoute: { configurable: true } };

VueRouter.prototype.match = function match (raw, current, redirectedFrom) {
  return this.matcher.match(raw, current, redirectedFrom)
};

prototypeAccessors$3.currentRoute.get = function () {
  return this.history && this.history.current
};

VueRouter.prototype.init = function init (app /* Vue component instance */) {
    var this$1 = this;

  
    assert$2(
      install$2.installed,
      "not installed. Make sure to call `Vue.use(VueRouter)` " +
        "before creating root instance."
    );

  this.apps.push(app);

  // set up app destroyed handler
  // https://github.com/vuejs/vue-router/issues/2639
  app.$once('hook:destroyed', function () {
    // clean out app from this.apps array once destroyed
    var index = this$1.apps.indexOf(app);
    if (index > -1) { this$1.apps.splice(index, 1); }
    // ensure we still have a main app or null if no apps
    // we do not release the router so it can be reused
    if (this$1.app === app) { this$1.app = this$1.apps[0] || null; }

    if (!this$1.app) { this$1.history.teardown(); }
  });

  // main app previously initialized
  // return as we don't need to set up new history listener
  if (this.app) {
    return
  }

  this.app = app;

  var history = this.history;

  if (history instanceof HTML5History || history instanceof HashHistory) {
    var handleInitialScroll = function (routeOrError) {
      var from = history.current;
      var expectScroll = this$1.options.scrollBehavior;
      var supportsScroll = supportsPushState && expectScroll;

      if (supportsScroll && 'fullPath' in routeOrError) {
        handleScroll(this$1, routeOrError, from, false);
      }
    };
    var setupListeners = function (routeOrError) {
      history.setupListeners();
      handleInitialScroll(routeOrError);
    };
    history.transitionTo(
      history.getCurrentLocation(),
      setupListeners,
      setupListeners
    );
  }

  history.listen(function (route) {
    this$1.apps.forEach(function (app) {
      app._route = route;
    });
  });
};

VueRouter.prototype.beforeEach = function beforeEach (fn) {
  return registerHook(this.beforeHooks, fn)
};

VueRouter.prototype.beforeResolve = function beforeResolve (fn) {
  return registerHook(this.resolveHooks, fn)
};

VueRouter.prototype.afterEach = function afterEach (fn) {
  return registerHook(this.afterHooks, fn)
};

VueRouter.prototype.onReady = function onReady (cb, errorCb) {
  this.history.onReady(cb, errorCb);
};

VueRouter.prototype.onError = function onError (errorCb) {
  this.history.onError(errorCb);
};

VueRouter.prototype.push = function push (location, onComplete, onAbort) {
    var this$1 = this;

  // $flow-disable-line
  if (!onComplete && !onAbort && typeof Promise !== 'undefined') {
    return new Promise(function (resolve, reject) {
      this$1.history.push(location, resolve, reject);
    })
  } else {
    this.history.push(location, onComplete, onAbort);
  }
};

VueRouter.prototype.replace = function replace (location, onComplete, onAbort) {
    var this$1 = this;

  // $flow-disable-line
  if (!onComplete && !onAbort && typeof Promise !== 'undefined') {
    return new Promise(function (resolve, reject) {
      this$1.history.replace(location, resolve, reject);
    })
  } else {
    this.history.replace(location, onComplete, onAbort);
  }
};

VueRouter.prototype.go = function go (n) {
  this.history.go(n);
};

VueRouter.prototype.back = function back () {
  this.go(-1);
};

VueRouter.prototype.forward = function forward () {
  this.go(1);
};

VueRouter.prototype.getMatchedComponents = function getMatchedComponents (to) {
  var route = to
    ? to.matched
      ? to
      : this.resolve(to).route
    : this.currentRoute;
  if (!route) {
    return []
  }
  return [].concat.apply(
    [],
    route.matched.map(function (m) {
      return Object.keys(m.components).map(function (key) {
        return m.components[key]
      })
    })
  )
};

VueRouter.prototype.resolve = function resolve (
  to,
  current,
  append
) {
  current = current || this.history.current;
  var location = normalizeLocation(to, current, append, this);
  var route = this.match(location, current);
  var fullPath = route.redirectedFrom || route.fullPath;
  var base = this.history.base;
  var href = createHref(base, fullPath, this.mode);
  return {
    location: location,
    route: route,
    href: href,
    // for backwards compat
    normalizedTo: location,
    resolved: route
  }
};

VueRouter.prototype.addRoutes = function addRoutes (routes) {
  this.matcher.addRoutes(routes);
  if (this.history.current !== START) {
    this.history.transitionTo(this.history.getCurrentLocation());
  }
};

Object.defineProperties( VueRouter.prototype, prototypeAccessors$3 );

function registerHook (list, fn) {
  list.push(fn);
  return function () {
    var i = list.indexOf(fn);
    if (i > -1) { list.splice(i, 1); }
  }
}

function createHref (base, fullPath, mode) {
  var path = mode === 'hash' ? '#' + fullPath : fullPath;
  return base ? cleanPath(base + '/' + path) : path
}

VueRouter.install = install$2;
VueRouter.version = '3.4.8';
VueRouter.isNavigationFailure = isNavigationFailure;
VueRouter.NavigationFailureType = NavigationFailureType;

if (inBrowser$1 && window.Vue) {
  window.Vue.use(VueRouter);
}

var paypal = "<?xml version=\"1.0\" encoding=\"iso-8859-1\"?>\r\n<!-- Generator: Adobe Illustrator 19.0.0, SVG Export Plug-In . SVG Version: 6.00 Build 0)  -->\r\n<svg version=\"1.1\" id=\"Capa_1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\"\r\n\t viewBox=\"0 0 512.001 512.001\" style=\"enable-background:new 0 0 512.001 512.001;\" xml:space=\"preserve\">\r\n<path style=\"fill:#03A9F4;\" d=\"M425.457,117.739c-3.121-1.838-6.961-1.966-10.197-0.341c-3.231,1.629-5.416,4.786-5.803,8.384\r\n\tc-0.384,3.499-0.981,6.997-1.728,10.667c-20.885,94.784-62.827,140.885-128.256,140.885h-96c-5.062,0.009-9.42,3.574-10.432,8.533\r\n\tl-32,149.995l-5.717,38.187c-3.287,17.365,8.125,34.107,25.489,37.394c1.915,0.362,3.858,0.549,5.807,0.558h64.213\r\n\tc14.718,0.045,27.55-10,31.04-24.299l25.941-103.701h55.659c65.685,0,111.083-52.373,127.829-147.477l0,0\r\n\tC482.356,191.238,464.068,143.856,425.457,117.739z\"/>\r\n<path style=\"fill:#283593;\" d=\"M405.339,38.017c-21.078-23.909-51.327-37.731-83.2-38.016h-176.64\r\n\tC119.064-0.141,96.558,19.2,92.721,45.355L37.873,411.243c-2.627,17.477,9.41,33.774,26.887,36.402\r\n\tc1.586,0.239,3.189,0.357,4.793,0.356h81.92c5.062-0.009,9.42-3.574,10.432-8.533l30.187-140.8h87.467\r\n\tc75.904,0,126.059-53.056,149.099-157.867c0.926-4.178,1.638-8.4,2.133-12.651C436.139,95.815,426.81,62.778,405.339,38.017z\"/>\r\n<g>\r\n</g>\r\n<g>\r\n</g>\r\n<g>\r\n</g>\r\n<g>\r\n</g>\r\n<g>\r\n</g>\r\n<g>\r\n</g>\r\n<g>\r\n</g>\r\n<g>\r\n</g>\r\n<g>\r\n</g>\r\n<g>\r\n</g>\r\n<g>\r\n</g>\r\n<g>\r\n</g>\r\n<g>\r\n</g>\r\n<g>\r\n</g>\r\n<g>\r\n</g>\r\n</svg>";

var ethereum = "<svg viewBox=\"-116 0 512 512\" xmlns=\"http://www.w3.org/2000/svg\"><path d=\"m140.28125 333.582031-140.28125-66.734375 140.28125 245.152344 140.285156-245.152344zm0 0\"/><path d=\"m265.289062 217.117188-125.007812-217.117188-125.148438 217.367188 125.148438-59.367188zm0 0\"/><path d=\"m25.980469 245.535156 114.300781 54.140625 114.492188-54.230469-114.492188-54.136718zm0 0\"/></svg>";

//

var script$b = {
	data() {
		return {
			paypal,
			ethereum,
			current: null,
			latest: null,
			updateAvailable: false,
			deemixVersion: null
		}
	},
	computed: {
		...mapGetters(['getAboutInfo'])
	},
	methods: {
		initUpdate(data) {
			const { currentCommit, latestCommit, updateAvailable, deemixVersion } = data;

			this.current = currentCommit;
			this.latest = latestCommit;
			this.updateAvailable = updateAvailable;
			this.deemixVersion = deemixVersion;
		}
	},
	mounted() {
		this.initUpdate(this.getAboutInfo);
	}
};

/* script */
const __vue_script__$b = script$b;

/* template */
var __vue_render__$c = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", { ref: "root", attrs: { id: "about_tab" } }, [
    _c("h1", { staticClass: "mb-8 text-5xl capitalize" }, [
      _vm._v(_vm._s(_vm.$t("sidebar.about")))
    ]),
    _vm._v(" "),
    _c("ul", [
      _c("li", [
        _vm._v(
          "\n\t\t\t" +
            _vm._s(_vm.$t("about.updates.currentVersion")) +
            ":\n\t\t\t"
        ),
        _c("span", [
          _vm._v(
            _vm._s(_vm.current || _vm.$t("about.updates.versionNotAvailable"))
          )
        ])
      ]),
      _vm._v(" "),
      _c("li", [
        _vm._v(
          _vm._s(_vm.$t("about.updates.deemixVersion")) +
            ": " +
            _vm._s(_vm.deemixVersion)
        )
      ]),
      _vm._v(" "),
      _vm.updateAvailable && _vm.latest
        ? _c("li", [
            _vm._v(
              _vm._s(
                _vm.$t("about.updates.updateAvailable", { version: _vm.latest })
              )
            )
          ])
        : _vm._e()
    ]),
    _vm._v(" "),
    _c("ul", [
      _c("li", {
        domProps: { innerHTML: _vm._s(_vm.$t("about.usesLibrary")) }
      }),
      _vm._v(" "),
      _c("li", { domProps: { innerHTML: _vm._s(_vm.$t("about.thanks")) } }),
      _vm._v(" "),
      _c("li", { domProps: { innerHTML: _vm._s(_vm.$t("about.upToDate")) } })
    ]),
    _vm._v(" "),
    _c("h2", [_vm._v(_vm._s(_vm.$t("about.titles.usefulLinks")))]),
    _vm._v(" "),
    _c("ul", { staticClass: "no-dots" }, [
      _c("li", [
        _c("a", { attrs: { href: "https://deemix.app", target: "_blank" } }, [
          _vm._v("🌍 " + _vm._s(_vm.$t("about.officialWebsite")))
        ])
      ]),
      _vm._v(" "),
      _c("li", [
        _c(
          "a",
          {
            attrs: {
              href: "https://codeberg.org/RemixDev/deemix",
              target: "_blank"
            }
          },
          [_vm._v("🚀 " + _vm._s(_vm.$t("about.officialRepo")))]
        )
      ]),
      _vm._v(" "),
      _c("li", [
        _c(
          "a",
          {
            attrs: {
              href: "https://codeberg.org/RemixDev/deemix-webui",
              target: "_blank"
            }
          },
          [_vm._v("💻 " + _vm._s(_vm.$t("about.officialWebuiRepo")))]
        )
      ]),
      _vm._v(" "),
      _c("li", [
        _c(
          "a",
          {
            attrs: { href: "https://www.reddit.com/r/deemix", target: "_blank" }
          },
          [_vm._v("🤖 " + _vm._s(_vm.$t("about.officialSubreddit")))]
        )
      ]),
      _vm._v(" "),
      _c("li", [
        _c(
          "a",
          { attrs: { href: "https://t.me/RemixDevNews", target: "_blank" } },
          [_vm._v("📰 " + _vm._s(_vm.$t("about.newsChannel")))]
        )
      ])
    ]),
    _vm._v(" "),
    _c("h2", [
      _vm._v("\n\t\t" + _vm._s(_vm.$t("about.titles.bugReports")) + "\n\t\t"),
      _c("span", { staticClass: "subheading" }, [
        _vm._v(
          "\n\t\t\t" + _vm._s(_vm.$t("about.subtitles.bugReports")) + "\n\t\t"
        )
      ])
    ]),
    _vm._v(" "),
    _c("ul", [
      _c("li", { domProps: { innerHTML: _vm._s(_vm.$t("about.questions")) } }),
      _vm._v(" "),
      _c("li", [
        _vm._v("\n\t\t\t" + _vm._s(_vm.$t("about.beforeReporting")) + "\n\t\t")
      ]),
      _vm._v(" "),
      _c("li", { domProps: { innerHTML: _vm._s(_vm.$t("about.beSure")) } }),
      _vm._v(" "),
      _c("li", [
        _vm._v("\n\t\t\t" + _vm._s(_vm.$t("about.duplicateReports")) + "\n\t\t")
      ]),
      _vm._v(" "),
      _c("li", {
        domProps: { innerHTML: _vm._s(_vm.$t("about.dontOpenIssues")) }
      })
    ]),
    _vm._v(" "),
    _c("h2", [
      _vm._v("\n\t\t" + _vm._s(_vm.$t("about.titles.contributing")) + "\n\t\t"),
      _c("span", { staticClass: "subheading" }, [
        _vm._v(
          "\n\t\t\t" + _vm._s(_vm.$t("about.subtitles.contributing")) + "\n\t\t"
        )
      ])
    ]),
    _vm._v(" "),
    _c("ul", [
      _c("li", { domProps: { innerHTML: _vm._s(_vm.$t("about.newUI")) } }),
      _vm._v(" "),
      _c("li", [
        _vm._v("\n\t\t\t" + _vm._s(_vm.$t("about.acceptFeatures")) + "\n\t\t")
      ]),
      _vm._v(" "),
      _c("li", {
        domProps: { innerHTML: _vm._s(_vm.$t("about.contributeWebUI")) }
      }),
      _vm._v(" "),
      _c("li", [
        _vm._v("\n\t\t\t" + _vm._s(_vm.$t("about.otherLanguages")) + "\n\t\t")
      ]),
      _vm._v(" "),
      _c("li", [
        _vm._v(
          "\n\t\t\t" + _vm._s(_vm.$t("about.understandingCode")) + "\n\t\t"
        )
      ])
    ]),
    _vm._v(" "),
    _c("h2", [
      _vm._v("\n\t\t" + _vm._s(_vm.$t("about.titles.donations")) + "\n\t\t"),
      _c("span", { staticClass: "subheading" }, [
        _vm._v(
          "\n\t\t\t" + _vm._s(_vm.$t("about.subtitles.donations")) + "\n\t\t"
        )
      ])
    ]),
    _vm._v(" "),
    _c("ul", [
      _c("li", { domProps: { innerHTML: _vm._s(_vm.$t("about.itsFree")) } }),
      _vm._v(" "),
      _c("li", [
        _vm._v("\n\t\t\t" + _vm._s(_vm.$t("about.notObligated")) + "\n\t\t")
      ])
    ]),
    _vm._v(" "),
    _c("ul", [
      _c("li", [
        _c("i", { domProps: { innerHTML: _vm._s(_vm.paypal) } }),
        _vm._v(" "),
        _c("strong", [_vm._v("PayPal:")]),
        _vm._v(" "),
        _c(
          "a",
          { attrs: { href: "https://paypal.me/RemixDev", target: "_blank" } },
          [_vm._v("PayPal.me/RemixDev")]
        )
      ]),
      _vm._v(" "),
      _c("li", [
        _c("i", {
          staticClass: "ethereum",
          domProps: { innerHTML: _vm._s(_vm.ethereum) }
        }),
        _vm._v(" "),
        _c("strong", [_vm._v("Ethereum:")]),
        _vm._v(" 0x1d2aa67e671485CD4062289772B662e0A6Ff976c\n\t\t")
      ])
    ]),
    _vm._v(" "),
    _c("h2", [_vm._v(_vm._s(_vm.$t("about.titles.license")))]),
    _vm._v(" "),
    _vm._m(0),
    _vm._v(" "),
    _c("p", { domProps: { innerHTML: _vm._s(_vm.$t("about.lincensedUnder")) } })
  ])
};
var __vue_staticRenderFns__$c = [
  function() {
    var _vm = this;
    var _h = _vm.$createElement;
    var _c = _vm._self._c || _h;
    return _c("p", [
      _c(
        "a",
        {
          attrs: {
            rel: "license",
            href: "https://www.gnu.org/licenses/gpl-3.0.en.html",
            target: "_blank"
          }
        },
        [
          _c("img", {
            staticStyle: { "border-width": "0" },
            attrs: {
              alt: "GNU General Public License",
              src: "https://www.gnu.org/graphics/gplv3-127x51.png"
            }
          })
        ]
      )
    ])
  }
];
__vue_render__$c._withStripped = true;

  /* style */
  const __vue_inject_styles__$c = function (inject) {
    if (!inject) return
    inject("data-v-3a0e3ecc_0", { source: "@charset \"UTF-8\";\nli[data-v-3a0e3ecc],\np[data-v-3a0e3ecc],\na[data-v-3a0e3ecc] {\n  letter-spacing: 0.4px;\n  font-size: 20px;\n  line-height: 1.2;\n}\ni[data-v-3a0e3ecc] {\n  vertical-align: middle;\n}\ni[data-v-3a0e3ecc] svg {\n  fill: white;\n  width: 20px;\n}\n.ethereum[data-v-3a0e3ecc] svg {\n  fill: var(--foreground);\n}\n[data-v-3a0e3ecc]:link {\n  text-decoration: none;\n}\n#about_tab[data-v-3a0e3ecc] {\n  margin-bottom: 40px;\n}\nh2[data-v-3a0e3ecc] {\n  text-transform: capitalize;\n}\nh2[data-v-3a0e3ecc]:not(.page_heading) {\n    font-size: 2rem;\n    border-bottom: 1px solid rgba(51, 51, 51, 0.25);\n    padding-top: 2rem;\n    padding-bottom: 1rem;\n}\nh2 .subheading[data-v-3a0e3ecc] {\n    display: block;\n    font-size: 0.5em;\n    margin-top: 0.5em;\n    font-weight: normal;\n    opacity: 0.8;\n    text-transform: none;\n}\np[data-v-3a0e3ecc] {\n  margin: 0 !important;\n}\nul li[data-v-3a0e3ecc] {\n  margin-bottom: 7px;\n}\nh2 + ul[data-v-3a0e3ecc] {\n  margin-top: 1rem;\n}\nul + ul[data-v-3a0e3ecc] {\n  margin-top: 1.25rem;\n}\nul.no-dots[data-v-3a0e3ecc] {\n  list-style-type: none;\n}\nul[data-v-3a0e3ecc]:not(.no-dots) {\n  list-style-type: none;\n}\nul:not(.no-dots) li[data-v-3a0e3ecc] {\n    position: relative;\n}\nul:not(.no-dots) li[data-v-3a0e3ecc]::before {\n      content: '—';\n      position: absolute;\n      left: -30px;\n      opacity: 0.25;\n}\n\n/*# sourceMappingURL=About.vue.map */", map: {"version":3,"sources":["About.vue","C:\\Users\\Roberto\\Dev\\repos\\deemix-pyweb\\webui\\src\\components\\pages\\About.vue"],"names":[],"mappings":"AAAA,gBAAgB;ACmHhB;;;EAGA,qBAAA;EACA,eAAA;EACA,gBAAA;AAAA;AAGA;EACA,sBAAA;AAAA;AAGA;EACA,WAAA;EACA,WAAA;AAAA;AAGA;EACA,uBAAA;AAAA;AAGA;EACA,qBAAA;AAAA;AAGA;EACA,mBAAA;AAAA;AAGA;EACA,0BAAA;AAAA;AADA;IAIA,eAAA;IACA,+CAAA;IAEA,iBAAA;IACA,oBAAA;AAAA;AARA;IAaA,cAAA;IACA,gBAAA;IACA,iBAAA;IACA,mBAAA;IACA,YAAA;IACA,oBAAA;AAAA;AAIA;EACA,oBAAA;AAAA;AAGA;EAEA,kBAAA;AAAA;AAGA;EACA,gBAAA;AAAA;AAGA;EACA,mBAAA;AAAA;AAVA;EAcA,qBAAA;AAAA;AAdA;EAkBA,qBAAA;AAAA;AAlBA;IAqBA,kBAAA;AAAA;AArBA;MAwBA,YAAA;MACA,kBAAA;MACA,WAAA;MACA,aAAA;AAAA;;ADrIA,oCAAoC","file":"About.vue","sourcesContent":["@charset \"UTF-8\";\nli,\np,\na {\n  letter-spacing: 0.4px;\n  font-size: 20px;\n  line-height: 1.2; }\n\ni {\n  vertical-align: middle; }\n\ni /deep/ svg {\n  fill: white;\n  width: 20px; }\n\n.ethereum /deep/ svg {\n  fill: var(--foreground); }\n\n:link {\n  text-decoration: none; }\n\n#about_tab {\n  margin-bottom: 40px; }\n\nh2 {\n  text-transform: capitalize; }\n  h2:not(.page_heading) {\n    font-size: 2rem;\n    border-bottom: 1px solid rgba(51, 51, 51, 0.25);\n    padding-top: 2rem;\n    padding-bottom: 1rem; }\n  h2 .subheading {\n    display: block;\n    font-size: 0.5em;\n    margin-top: 0.5em;\n    font-weight: normal;\n    opacity: 0.8;\n    text-transform: none; }\n\np {\n  margin: 0 !important; }\n\nul li {\n  margin-bottom: 7px; }\n\nh2 + ul {\n  margin-top: 1rem; }\n\nul + ul {\n  margin-top: 1.25rem; }\n\nul.no-dots {\n  list-style-type: none; }\n\nul:not(.no-dots) {\n  list-style-type: none; }\n  ul:not(.no-dots) li {\n    position: relative; }\n    ul:not(.no-dots) li::before {\n      content: '—';\n      position: absolute;\n      left: -30px;\n      opacity: 0.25; }\n\n/*# sourceMappingURL=About.vue.map */","<template>\r\n\t<div id=\"about_tab\" ref=\"root\">\r\n\t\t<h1 class=\"mb-8 text-5xl capitalize\">{{ $t('sidebar.about') }}</h1>\r\n\r\n\t\t<ul>\r\n\t\t\t<li>\r\n\t\t\t\t{{ $t('about.updates.currentVersion') }}:\r\n\t\t\t\t<span>{{ current || $t('about.updates.versionNotAvailable') }}</span>\r\n\t\t\t</li>\r\n\t\t\t<li>{{ $t('about.updates.deemixVersion') }}: {{ deemixVersion }}</li>\r\n\t\t\t<li v-if=\"updateAvailable && latest\">{{ $t('about.updates.updateAvailable', { version: latest }) }}</li>\r\n\t\t</ul>\r\n\r\n\t\t<ul>\r\n\t\t\t<li v-html=\"$t('about.usesLibrary')\"></li>\r\n\t\t\t<li v-html=\"$t('about.thanks')\"></li>\r\n\t\t\t<li v-html=\"$t('about.upToDate')\"></li>\r\n\t\t</ul>\r\n\r\n\t\t<h2>{{ $t('about.titles.usefulLinks') }}</h2>\r\n\t\t<ul class=\"no-dots\">\r\n\t\t\t<li>\r\n\t\t\t\t<a href=\"https://deemix.app\" target=\"_blank\">🌍 {{ $t('about.officialWebsite') }}</a>\r\n\t\t\t</li>\r\n\t\t\t<li>\r\n\t\t\t\t<a href=\"https://codeberg.org/RemixDev/deemix\" target=\"_blank\">🚀 {{ $t('about.officialRepo') }}</a>\r\n\t\t\t</li>\r\n\t\t\t<li>\r\n\t\t\t\t<a href=\"https://codeberg.org/RemixDev/deemix-webui\" target=\"_blank\">💻 {{ $t('about.officialWebuiRepo') }}</a>\r\n\t\t\t</li>\r\n\t\t\t<li>\r\n\t\t\t\t<a href=\"https://www.reddit.com/r/deemix\" target=\"_blank\">🤖 {{ $t('about.officialSubreddit') }}</a>\r\n\t\t\t</li>\r\n\t\t\t<li>\r\n\t\t\t\t<a href=\"https://t.me/RemixDevNews\" target=\"_blank\">📰 {{ $t('about.newsChannel') }}</a>\r\n\t\t\t</li>\r\n\t\t</ul>\r\n\r\n\t\t<h2>\r\n\t\t\t{{ $t('about.titles.bugReports') }}\r\n\t\t\t<span class=\"subheading\">\r\n\t\t\t\t{{ $t('about.subtitles.bugReports') }}\r\n\t\t\t</span>\r\n\t\t</h2>\r\n\t\t<ul>\r\n\t\t\t<li v-html=\"$t('about.questions')\"></li>\r\n\t\t\t<li>\r\n\t\t\t\t{{ $t('about.beforeReporting') }}\r\n\t\t\t</li>\r\n\t\t\t<li v-html=\"$t('about.beSure')\"></li>\r\n\t\t\t<li>\r\n\t\t\t\t{{ $t('about.duplicateReports') }}\r\n\t\t\t</li>\r\n\t\t\t<li v-html=\"$t('about.dontOpenIssues')\"></li>\r\n\t\t</ul>\r\n\r\n\t\t<h2>\r\n\t\t\t{{ $t('about.titles.contributing') }}\r\n\t\t\t<span class=\"subheading\">\r\n\t\t\t\t{{ $t('about.subtitles.contributing') }}\r\n\t\t\t</span>\r\n\t\t</h2>\r\n\t\t<ul>\r\n\t\t\t<li v-html=\"$t('about.newUI')\"></li>\r\n\t\t\t<li>\r\n\t\t\t\t{{ $t('about.acceptFeatures') }}\r\n\t\t\t</li>\r\n\t\t\t<li v-html=\"$t('about.contributeWebUI')\"></li>\r\n\t\t\t<li>\r\n\t\t\t\t{{ $t('about.otherLanguages') }}\r\n\t\t\t</li>\r\n\t\t\t<li>\r\n\t\t\t\t{{ $t('about.understandingCode') }}\r\n\t\t\t</li>\r\n\t\t</ul>\r\n\r\n\t\t<h2>\r\n\t\t\t{{ $t('about.titles.donations') }}\r\n\t\t\t<span class=\"subheading\">\r\n\t\t\t\t{{ $t('about.subtitles.donations') }}\r\n\t\t\t</span>\r\n\t\t</h2>\r\n\t\t<ul>\r\n\t\t\t<li v-html=\"$t('about.itsFree')\"></li>\r\n\t\t\t<li>\r\n\t\t\t\t{{ $t('about.notObligated') }}\r\n\t\t\t</li>\r\n\t\t</ul>\r\n\t\t<ul>\r\n\t\t\t<li>\r\n\t\t\t\t<i v-html=\"paypal\" />\r\n\t\t\t\t<strong>PayPal:</strong>\r\n\t\t\t\t<a href=\"https://paypal.me/RemixDev\" target=\"_blank\">PayPal.me/RemixDev</a>\r\n\t\t\t</li>\r\n\t\t\t<li>\r\n\t\t\t\t<i class=\"ethereum\" v-html=\"ethereum\" />\r\n\t\t\t\t<strong>Ethereum:</strong> 0x1d2aa67e671485CD4062289772B662e0A6Ff976c\r\n\t\t\t</li>\r\n\t\t</ul>\r\n\r\n\t\t<h2>{{ $t('about.titles.license') }}</h2>\r\n\t\t<p>\r\n\t\t\t<a rel=\"license\" href=\"https://www.gnu.org/licenses/gpl-3.0.en.html\" target=\"_blank\">\r\n\t\t\t\t<img\r\n\t\t\t\t\talt=\"GNU General Public License\"\r\n\t\t\t\t\tstyle=\"border-width: 0\"\r\n\t\t\t\t\tsrc=\"https://www.gnu.org/graphics/gplv3-127x51.png\"\r\n\t\t\t\t/>\r\n\t\t\t</a>\r\n\t\t</p>\r\n\t\t<p v-html=\"$t('about.lincensedUnder')\"></p>\r\n\t</div>\r\n</template>\r\n\r\n<style lang=\"scss\" scoped>\r\nli,\r\np,\r\na {\r\n\tletter-spacing: 0.4px;\r\n\tfont-size: 20px;\r\n\tline-height: 1.2;\r\n}\r\n\r\ni {\r\n\tvertical-align: middle;\r\n}\r\n\r\ni /deep/ svg {\r\n\tfill: white;\r\n\twidth: 20px;\r\n}\r\n\r\n.ethereum /deep/ svg {\r\n\tfill: var(--foreground);\r\n}\r\n\r\n:link {\r\n\ttext-decoration: none;\r\n}\r\n\r\n#about_tab {\r\n\tmargin-bottom: 40px;\r\n}\r\n\r\nh2 {\r\n\ttext-transform: capitalize;\r\n\r\n\t&:not(.page_heading) {\r\n\t\tfont-size: 2rem;\r\n\t\tborder-bottom: 1px solid hsla(0, 0%, 20%, 0.25);\r\n\t\tpadding: {\r\n\t\t\ttop: 2rem;\r\n\t\t\tbottom: 1rem;\r\n\t\t}\r\n\t}\r\n\r\n\t.subheading {\r\n\t\tdisplay: block;\r\n\t\tfont-size: 0.5em;\r\n\t\tmargin-top: 0.5em;\r\n\t\tfont-weight: normal;\r\n\t\topacity: 0.8;\r\n\t\ttext-transform: none;\r\n\t}\r\n}\r\n\r\np {\r\n\tmargin: 0 !important;\r\n}\r\n\r\nul {\r\n\tli {\r\n\t\tmargin-bottom: 7px;\r\n\t}\r\n\r\n\th2 + & {\r\n\t\tmargin-top: 1rem;\r\n\t}\r\n\r\n\tul + & {\r\n\t\tmargin-top: 1.25rem;\r\n\t}\r\n\r\n\t&.no-dots {\r\n\t\tlist-style-type: none;\r\n\t}\r\n\r\n\t&:not(.no-dots) {\r\n\t\tlist-style-type: none;\r\n\r\n\t\tli {\r\n\t\t\tposition: relative;\r\n\r\n\t\t\t&::before {\r\n\t\t\t\tcontent: '—';\r\n\t\t\t\tposition: absolute;\r\n\t\t\t\tleft: -30px;\r\n\t\t\t\topacity: 0.25;\r\n\t\t\t}\r\n\t\t}\r\n\t}\r\n}\r\n</style>\r\n\r\n<script>\r\nimport { socket } from '@/utils/socket'\r\nimport paypal from '@/assets/paypal.svg'\r\nimport ethereum from '@/assets/ethereum.svg'\r\nimport { mapGetters } from 'vuex'\r\n\r\nexport default {\r\n\tdata() {\r\n\t\treturn {\r\n\t\t\tpaypal,\r\n\t\t\tethereum,\r\n\t\t\tcurrent: null,\r\n\t\t\tlatest: null,\r\n\t\t\tupdateAvailable: false,\r\n\t\t\tdeemixVersion: null\r\n\t\t}\r\n\t},\r\n\tcomputed: {\r\n\t\t...mapGetters(['getAboutInfo'])\r\n\t},\r\n\tmethods: {\r\n\t\tinitUpdate(data) {\r\n\t\t\tconst { currentCommit, latestCommit, updateAvailable, deemixVersion } = data\r\n\r\n\t\t\tthis.current = currentCommit\r\n\t\t\tthis.latest = latestCommit\r\n\t\t\tthis.updateAvailable = updateAvailable\r\n\t\t\tthis.deemixVersion = deemixVersion\r\n\t\t}\r\n\t},\r\n\tmounted() {\r\n\t\tthis.initUpdate(this.getAboutInfo)\r\n\t}\r\n}\r\n</script>\r\n"]}, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$c = "data-v-3a0e3ecc";
  /* module identifier */
  const __vue_module_identifier__$c = undefined;
  /* functional template */
  const __vue_is_functional_template__$c = false;
  /* style inject SSR */
  

  
  var About = normalizeComponent_1(
    { render: __vue_render__$c, staticRenderFns: __vue_staticRenderFns__$c },
    __vue_inject_styles__$c,
    __vue_script__$b,
    __vue_scope_id__$c,
    __vue_is_functional_template__$c,
    __vue_module_identifier__$c,
    browser,
    undefined
  );

/** Detect free variable `global` from Node.js. */
var freeGlobal = typeof global == 'object' && global && global.Object === Object && global;

/** Detect free variable `self`. */
var freeSelf = typeof self == 'object' && self && self.Object === Object && self;

/** Used as a reference to the global object. */
var root = freeGlobal || freeSelf || Function('return this')();

/** Built-in value references. */
var Symbol$1 = root.Symbol;

/** Used for built-in method references. */
var objectProto = Object.prototype;

/** Used to check objects for own properties. */
var hasOwnProperty$2 = objectProto.hasOwnProperty;

/**
 * Used to resolve the
 * [`toStringTag`](http://ecma-international.org/ecma-262/7.0/#sec-object.prototype.tostring)
 * of values.
 */
var nativeObjectToString = objectProto.toString;

/** Built-in value references. */
var symToStringTag = Symbol$1 ? Symbol$1.toStringTag : undefined;

/**
 * A specialized version of `baseGetTag` which ignores `Symbol.toStringTag` values.
 *
 * @private
 * @param {*} value The value to query.
 * @returns {string} Returns the raw `toStringTag`.
 */
function getRawTag(value) {
  var isOwn = hasOwnProperty$2.call(value, symToStringTag),
      tag = value[symToStringTag];

  try {
    value[symToStringTag] = undefined;
    var unmasked = true;
  } catch (e) {}

  var result = nativeObjectToString.call(value);
  if (unmasked) {
    if (isOwn) {
      value[symToStringTag] = tag;
    } else {
      delete value[symToStringTag];
    }
  }
  return result;
}

/** Used for built-in method references. */
var objectProto$1 = Object.prototype;

/**
 * Used to resolve the
 * [`toStringTag`](http://ecma-international.org/ecma-262/7.0/#sec-object.prototype.tostring)
 * of values.
 */
var nativeObjectToString$1 = objectProto$1.toString;

/**
 * Converts `value` to a string using `Object.prototype.toString`.
 *
 * @private
 * @param {*} value The value to convert.
 * @returns {string} Returns the converted string.
 */
function objectToString(value) {
  return nativeObjectToString$1.call(value);
}

/** `Object#toString` result references. */
var nullTag = '[object Null]',
    undefinedTag = '[object Undefined]';

/** Built-in value references. */
var symToStringTag$1 = Symbol$1 ? Symbol$1.toStringTag : undefined;

/**
 * The base implementation of `getTag` without fallbacks for buggy environments.
 *
 * @private
 * @param {*} value The value to query.
 * @returns {string} Returns the `toStringTag`.
 */
function baseGetTag(value) {
  if (value == null) {
    return value === undefined ? undefinedTag : nullTag;
  }
  return (symToStringTag$1 && symToStringTag$1 in Object(value))
    ? getRawTag(value)
    : objectToString(value);
}

/**
 * Checks if `value` is object-like. A value is object-like if it's not `null`
 * and has a `typeof` result of "object".
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is object-like, else `false`.
 * @example
 *
 * _.isObjectLike({});
 * // => true
 *
 * _.isObjectLike([1, 2, 3]);
 * // => true
 *
 * _.isObjectLike(_.noop);
 * // => false
 *
 * _.isObjectLike(null);
 * // => false
 */
function isObjectLike(value) {
  return value != null && typeof value == 'object';
}

/** `Object#toString` result references. */
var symbolTag = '[object Symbol]';

/**
 * Checks if `value` is classified as a `Symbol` primitive or object.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a symbol, else `false`.
 * @example
 *
 * _.isSymbol(Symbol.iterator);
 * // => true
 *
 * _.isSymbol('abc');
 * // => false
 */
function isSymbol(value) {
  return typeof value == 'symbol' ||
    (isObjectLike(value) && baseGetTag(value) == symbolTag);
}

/**
 * A specialized version of `_.map` for arrays without support for iteratee
 * shorthands.
 *
 * @private
 * @param {Array} [array] The array to iterate over.
 * @param {Function} iteratee The function invoked per iteration.
 * @returns {Array} Returns the new mapped array.
 */
function arrayMap(array, iteratee) {
  var index = -1,
      length = array == null ? 0 : array.length,
      result = Array(length);

  while (++index < length) {
    result[index] = iteratee(array[index], index, array);
  }
  return result;
}

/**
 * Checks if `value` is classified as an `Array` object.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an array, else `false`.
 * @example
 *
 * _.isArray([1, 2, 3]);
 * // => true
 *
 * _.isArray(document.body.children);
 * // => false
 *
 * _.isArray('abc');
 * // => false
 *
 * _.isArray(_.noop);
 * // => false
 */
var isArray$1 = Array.isArray;

/** Used as references for various `Number` constants. */
var INFINITY = 1 / 0;

/** Used to convert symbols to primitives and strings. */
var symbolProto = Symbol$1 ? Symbol$1.prototype : undefined,
    symbolToString = symbolProto ? symbolProto.toString : undefined;

/**
 * The base implementation of `_.toString` which doesn't convert nullish
 * values to empty strings.
 *
 * @private
 * @param {*} value The value to process.
 * @returns {string} Returns the string.
 */
function baseToString(value) {
  // Exit early for strings to avoid a performance hit in some environments.
  if (typeof value == 'string') {
    return value;
  }
  if (isArray$1(value)) {
    // Recursively convert values (susceptible to call stack limits).
    return arrayMap(value, baseToString) + '';
  }
  if (isSymbol(value)) {
    return symbolToString ? symbolToString.call(value) : '';
  }
  var result = (value + '');
  return (result == '0' && (1 / value) == -INFINITY) ? '-0' : result;
}

/**
 * Checks if `value` is the
 * [language type](http://www.ecma-international.org/ecma-262/7.0/#sec-ecmascript-language-types)
 * of `Object`. (e.g. arrays, functions, objects, regexes, `new Number(0)`, and `new String('')`)
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an object, else `false`.
 * @example
 *
 * _.isObject({});
 * // => true
 *
 * _.isObject([1, 2, 3]);
 * // => true
 *
 * _.isObject(_.noop);
 * // => true
 *
 * _.isObject(null);
 * // => false
 */
function isObject$3(value) {
  var type = typeof value;
  return value != null && (type == 'object' || type == 'function');
}

/**
 * This method returns the first argument it receives.
 *
 * @static
 * @since 0.1.0
 * @memberOf _
 * @category Util
 * @param {*} value Any value.
 * @returns {*} Returns `value`.
 * @example
 *
 * var object = { 'a': 1 };
 *
 * console.log(_.identity(object) === object);
 * // => true
 */
function identity$1(value) {
  return value;
}

/** `Object#toString` result references. */
var asyncTag = '[object AsyncFunction]',
    funcTag = '[object Function]',
    genTag = '[object GeneratorFunction]',
    proxyTag = '[object Proxy]';

/**
 * Checks if `value` is classified as a `Function` object.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a function, else `false`.
 * @example
 *
 * _.isFunction(_);
 * // => true
 *
 * _.isFunction(/abc/);
 * // => false
 */
function isFunction$1(value) {
  if (!isObject$3(value)) {
    return false;
  }
  // The use of `Object#toString` avoids issues with the `typeof` operator
  // in Safari 9 which returns 'object' for typed arrays and other constructors.
  var tag = baseGetTag(value);
  return tag == funcTag || tag == genTag || tag == asyncTag || tag == proxyTag;
}

/** Used to detect overreaching core-js shims. */
var coreJsData = root['__core-js_shared__'];

/** Used to detect methods masquerading as native. */
var maskSrcKey = (function() {
  var uid = /[^.]+$/.exec(coreJsData && coreJsData.keys && coreJsData.keys.IE_PROTO || '');
  return uid ? ('Symbol(src)_1.' + uid) : '';
}());

/**
 * Checks if `func` has its source masked.
 *
 * @private
 * @param {Function} func The function to check.
 * @returns {boolean} Returns `true` if `func` is masked, else `false`.
 */
function isMasked(func) {
  return !!maskSrcKey && (maskSrcKey in func);
}

/** Used for built-in method references. */
var funcProto = Function.prototype;

/** Used to resolve the decompiled source of functions. */
var funcToString = funcProto.toString;

/**
 * Converts `func` to its source code.
 *
 * @private
 * @param {Function} func The function to convert.
 * @returns {string} Returns the source code.
 */
function toSource(func) {
  if (func != null) {
    try {
      return funcToString.call(func);
    } catch (e) {}
    try {
      return (func + '');
    } catch (e) {}
  }
  return '';
}

/**
 * Used to match `RegExp`
 * [syntax characters](http://ecma-international.org/ecma-262/7.0/#sec-patterns).
 */
var reRegExpChar = /[\\^$.*+?()[\]{}|]/g;

/** Used to detect host constructors (Safari). */
var reIsHostCtor = /^\[object .+?Constructor\]$/;

/** Used for built-in method references. */
var funcProto$1 = Function.prototype,
    objectProto$2 = Object.prototype;

/** Used to resolve the decompiled source of functions. */
var funcToString$1 = funcProto$1.toString;

/** Used to check objects for own properties. */
var hasOwnProperty$3 = objectProto$2.hasOwnProperty;

/** Used to detect if a method is native. */
var reIsNative = RegExp('^' +
  funcToString$1.call(hasOwnProperty$3).replace(reRegExpChar, '\\$&')
  .replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g, '$1.*?') + '$'
);

/**
 * The base implementation of `_.isNative` without bad shim checks.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a native function,
 *  else `false`.
 */
function baseIsNative(value) {
  if (!isObject$3(value) || isMasked(value)) {
    return false;
  }
  var pattern = isFunction$1(value) ? reIsNative : reIsHostCtor;
  return pattern.test(toSource(value));
}

/**
 * Gets the value at `key` of `object`.
 *
 * @private
 * @param {Object} [object] The object to query.
 * @param {string} key The key of the property to get.
 * @returns {*} Returns the property value.
 */
function getValue$1(object, key) {
  return object == null ? undefined : object[key];
}

/**
 * Gets the native function at `key` of `object`.
 *
 * @private
 * @param {Object} object The object to query.
 * @param {string} key The key of the method to get.
 * @returns {*} Returns the function if it's native, else `undefined`.
 */
function getNative(object, key) {
  var value = getValue$1(object, key);
  return baseIsNative(value) ? value : undefined;
}

/* Built-in method references that are verified to be native. */
var WeakMap = getNative(root, 'WeakMap');

/** Used as references for various `Number` constants. */
var MAX_SAFE_INTEGER = 9007199254740991;

/** Used to detect unsigned integer values. */
var reIsUint = /^(?:0|[1-9]\d*)$/;

/**
 * Checks if `value` is a valid array-like index.
 *
 * @private
 * @param {*} value The value to check.
 * @param {number} [length=MAX_SAFE_INTEGER] The upper bounds of a valid index.
 * @returns {boolean} Returns `true` if `value` is a valid index, else `false`.
 */
function isIndex(value, length) {
  var type = typeof value;
  length = length == null ? MAX_SAFE_INTEGER : length;

  return !!length &&
    (type == 'number' ||
      (type != 'symbol' && reIsUint.test(value))) &&
        (value > -1 && value % 1 == 0 && value < length);
}

/**
 * Performs a
 * [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
 * comparison between two values to determine if they are equivalent.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to compare.
 * @param {*} other The other value to compare.
 * @returns {boolean} Returns `true` if the values are equivalent, else `false`.
 * @example
 *
 * var object = { 'a': 1 };
 * var other = { 'a': 1 };
 *
 * _.eq(object, object);
 * // => true
 *
 * _.eq(object, other);
 * // => false
 *
 * _.eq('a', 'a');
 * // => true
 *
 * _.eq('a', Object('a'));
 * // => false
 *
 * _.eq(NaN, NaN);
 * // => true
 */
function eq(value, other) {
  return value === other || (value !== value && other !== other);
}

/** Used as references for various `Number` constants. */
var MAX_SAFE_INTEGER$1 = 9007199254740991;

/**
 * Checks if `value` is a valid array-like length.
 *
 * **Note:** This method is loosely based on
 * [`ToLength`](http://ecma-international.org/ecma-262/7.0/#sec-tolength).
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a valid length, else `false`.
 * @example
 *
 * _.isLength(3);
 * // => true
 *
 * _.isLength(Number.MIN_VALUE);
 * // => false
 *
 * _.isLength(Infinity);
 * // => false
 *
 * _.isLength('3');
 * // => false
 */
function isLength(value) {
  return typeof value == 'number' &&
    value > -1 && value % 1 == 0 && value <= MAX_SAFE_INTEGER$1;
}

/**
 * Checks if `value` is array-like. A value is considered array-like if it's
 * not a function and has a `value.length` that's an integer greater than or
 * equal to `0` and less than or equal to `Number.MAX_SAFE_INTEGER`.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is array-like, else `false`.
 * @example
 *
 * _.isArrayLike([1, 2, 3]);
 * // => true
 *
 * _.isArrayLike(document.body.children);
 * // => true
 *
 * _.isArrayLike('abc');
 * // => true
 *
 * _.isArrayLike(_.noop);
 * // => false
 */
function isArrayLike(value) {
  return value != null && isLength(value.length) && !isFunction$1(value);
}

/** Used for built-in method references. */
var objectProto$3 = Object.prototype;

/**
 * Checks if `value` is likely a prototype object.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a prototype, else `false`.
 */
function isPrototype(value) {
  var Ctor = value && value.constructor,
      proto = (typeof Ctor == 'function' && Ctor.prototype) || objectProto$3;

  return value === proto;
}

/**
 * The base implementation of `_.times` without support for iteratee shorthands
 * or max array length checks.
 *
 * @private
 * @param {number} n The number of times to invoke `iteratee`.
 * @param {Function} iteratee The function invoked per iteration.
 * @returns {Array} Returns the array of results.
 */
function baseTimes(n, iteratee) {
  var index = -1,
      result = Array(n);

  while (++index < n) {
    result[index] = iteratee(index);
  }
  return result;
}

/** `Object#toString` result references. */
var argsTag = '[object Arguments]';

/**
 * The base implementation of `_.isArguments`.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an `arguments` object,
 */
function baseIsArguments(value) {
  return isObjectLike(value) && baseGetTag(value) == argsTag;
}

/** Used for built-in method references. */
var objectProto$4 = Object.prototype;

/** Used to check objects for own properties. */
var hasOwnProperty$4 = objectProto$4.hasOwnProperty;

/** Built-in value references. */
var propertyIsEnumerable = objectProto$4.propertyIsEnumerable;

/**
 * Checks if `value` is likely an `arguments` object.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an `arguments` object,
 *  else `false`.
 * @example
 *
 * _.isArguments(function() { return arguments; }());
 * // => true
 *
 * _.isArguments([1, 2, 3]);
 * // => false
 */
var isArguments = baseIsArguments(function() { return arguments; }()) ? baseIsArguments : function(value) {
  return isObjectLike(value) && hasOwnProperty$4.call(value, 'callee') &&
    !propertyIsEnumerable.call(value, 'callee');
};

/**
 * This method returns `false`.
 *
 * @static
 * @memberOf _
 * @since 4.13.0
 * @category Util
 * @returns {boolean} Returns `false`.
 * @example
 *
 * _.times(2, _.stubFalse);
 * // => [false, false]
 */
function stubFalse() {
  return false;
}

/** Detect free variable `exports`. */
var freeExports = typeof exports == 'object' && exports && !exports.nodeType && exports;

/** Detect free variable `module`. */
var freeModule = freeExports && typeof module == 'object' && module && !module.nodeType && module;

/** Detect the popular CommonJS extension `module.exports`. */
var moduleExports = freeModule && freeModule.exports === freeExports;

/** Built-in value references. */
var Buffer = moduleExports ? root.Buffer : undefined;

/* Built-in method references for those with the same name as other `lodash` methods. */
var nativeIsBuffer = Buffer ? Buffer.isBuffer : undefined;

/**
 * Checks if `value` is a buffer.
 *
 * @static
 * @memberOf _
 * @since 4.3.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a buffer, else `false`.
 * @example
 *
 * _.isBuffer(new Buffer(2));
 * // => true
 *
 * _.isBuffer(new Uint8Array(2));
 * // => false
 */
var isBuffer = nativeIsBuffer || stubFalse;

/** `Object#toString` result references. */
var argsTag$1 = '[object Arguments]',
    arrayTag = '[object Array]',
    boolTag = '[object Boolean]',
    dateTag = '[object Date]',
    errorTag = '[object Error]',
    funcTag$1 = '[object Function]',
    mapTag = '[object Map]',
    numberTag = '[object Number]',
    objectTag = '[object Object]',
    regexpTag = '[object RegExp]',
    setTag = '[object Set]',
    stringTag = '[object String]',
    weakMapTag = '[object WeakMap]';

var arrayBufferTag = '[object ArrayBuffer]',
    dataViewTag = '[object DataView]',
    float32Tag = '[object Float32Array]',
    float64Tag = '[object Float64Array]',
    int8Tag = '[object Int8Array]',
    int16Tag = '[object Int16Array]',
    int32Tag = '[object Int32Array]',
    uint8Tag = '[object Uint8Array]',
    uint8ClampedTag = '[object Uint8ClampedArray]',
    uint16Tag = '[object Uint16Array]',
    uint32Tag = '[object Uint32Array]';

/** Used to identify `toStringTag` values of typed arrays. */
var typedArrayTags = {};
typedArrayTags[float32Tag] = typedArrayTags[float64Tag] =
typedArrayTags[int8Tag] = typedArrayTags[int16Tag] =
typedArrayTags[int32Tag] = typedArrayTags[uint8Tag] =
typedArrayTags[uint8ClampedTag] = typedArrayTags[uint16Tag] =
typedArrayTags[uint32Tag] = true;
typedArrayTags[argsTag$1] = typedArrayTags[arrayTag] =
typedArrayTags[arrayBufferTag] = typedArrayTags[boolTag] =
typedArrayTags[dataViewTag] = typedArrayTags[dateTag] =
typedArrayTags[errorTag] = typedArrayTags[funcTag$1] =
typedArrayTags[mapTag] = typedArrayTags[numberTag] =
typedArrayTags[objectTag] = typedArrayTags[regexpTag] =
typedArrayTags[setTag] = typedArrayTags[stringTag] =
typedArrayTags[weakMapTag] = false;

/**
 * The base implementation of `_.isTypedArray` without Node.js optimizations.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a typed array, else `false`.
 */
function baseIsTypedArray(value) {
  return isObjectLike(value) &&
    isLength(value.length) && !!typedArrayTags[baseGetTag(value)];
}

/**
 * The base implementation of `_.unary` without support for storing metadata.
 *
 * @private
 * @param {Function} func The function to cap arguments for.
 * @returns {Function} Returns the new capped function.
 */
function baseUnary(func) {
  return function(value) {
    return func(value);
  };
}

/** Detect free variable `exports`. */
var freeExports$1 = typeof exports == 'object' && exports && !exports.nodeType && exports;

/** Detect free variable `module`. */
var freeModule$1 = freeExports$1 && typeof module == 'object' && module && !module.nodeType && module;

/** Detect the popular CommonJS extension `module.exports`. */
var moduleExports$1 = freeModule$1 && freeModule$1.exports === freeExports$1;

/** Detect free variable `process` from Node.js. */
var freeProcess = moduleExports$1 && freeGlobal.process;

/** Used to access faster Node.js helpers. */
var nodeUtil = (function() {
  try {
    // Use `util.types` for Node.js 10+.
    var types = freeModule$1 && freeModule$1.require && freeModule$1.require('util').types;

    if (types) {
      return types;
    }

    // Legacy `process.binding('util')` for Node.js < 10.
    return freeProcess && freeProcess.binding && freeProcess.binding('util');
  } catch (e) {}
}());

/* Node.js helper references. */
var nodeIsTypedArray = nodeUtil && nodeUtil.isTypedArray;

/**
 * Checks if `value` is classified as a typed array.
 *
 * @static
 * @memberOf _
 * @since 3.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a typed array, else `false`.
 * @example
 *
 * _.isTypedArray(new Uint8Array);
 * // => true
 *
 * _.isTypedArray([]);
 * // => false
 */
var isTypedArray = nodeIsTypedArray ? baseUnary(nodeIsTypedArray) : baseIsTypedArray;

/** Used for built-in method references. */
var objectProto$5 = Object.prototype;

/** Used to check objects for own properties. */
var hasOwnProperty$5 = objectProto$5.hasOwnProperty;

/**
 * Creates an array of the enumerable property names of the array-like `value`.
 *
 * @private
 * @param {*} value The value to query.
 * @param {boolean} inherited Specify returning inherited property names.
 * @returns {Array} Returns the array of property names.
 */
function arrayLikeKeys(value, inherited) {
  var isArr = isArray$1(value),
      isArg = !isArr && isArguments(value),
      isBuff = !isArr && !isArg && isBuffer(value),
      isType = !isArr && !isArg && !isBuff && isTypedArray(value),
      skipIndexes = isArr || isArg || isBuff || isType,
      result = skipIndexes ? baseTimes(value.length, String) : [],
      length = result.length;

  for (var key in value) {
    if ((inherited || hasOwnProperty$5.call(value, key)) &&
        !(skipIndexes && (
           // Safari 9 has enumerable `arguments.length` in strict mode.
           key == 'length' ||
           // Node.js 0.10 has enumerable non-index properties on buffers.
           (isBuff && (key == 'offset' || key == 'parent')) ||
           // PhantomJS 2 has enumerable non-index properties on typed arrays.
           (isType && (key == 'buffer' || key == 'byteLength' || key == 'byteOffset')) ||
           // Skip index properties.
           isIndex(key, length)
        ))) {
      result.push(key);
    }
  }
  return result;
}

/**
 * Creates a unary function that invokes `func` with its argument transformed.
 *
 * @private
 * @param {Function} func The function to wrap.
 * @param {Function} transform The argument transform.
 * @returns {Function} Returns the new function.
 */
function overArg(func, transform) {
  return function(arg) {
    return func(transform(arg));
  };
}

/* Built-in method references for those with the same name as other `lodash` methods. */
var nativeKeys = overArg(Object.keys, Object);

/** Used for built-in method references. */
var objectProto$6 = Object.prototype;

/** Used to check objects for own properties. */
var hasOwnProperty$6 = objectProto$6.hasOwnProperty;

/**
 * The base implementation of `_.keys` which doesn't treat sparse arrays as dense.
 *
 * @private
 * @param {Object} object The object to query.
 * @returns {Array} Returns the array of property names.
 */
function baseKeys(object) {
  if (!isPrototype(object)) {
    return nativeKeys(object);
  }
  var result = [];
  for (var key in Object(object)) {
    if (hasOwnProperty$6.call(object, key) && key != 'constructor') {
      result.push(key);
    }
  }
  return result;
}

/**
 * Creates an array of the own enumerable property names of `object`.
 *
 * **Note:** Non-object values are coerced to objects. See the
 * [ES spec](http://ecma-international.org/ecma-262/7.0/#sec-object.keys)
 * for more details.
 *
 * @static
 * @since 0.1.0
 * @memberOf _
 * @category Object
 * @param {Object} object The object to query.
 * @returns {Array} Returns the array of property names.
 * @example
 *
 * function Foo() {
 *   this.a = 1;
 *   this.b = 2;
 * }
 *
 * Foo.prototype.c = 3;
 *
 * _.keys(new Foo);
 * // => ['a', 'b'] (iteration order is not guaranteed)
 *
 * _.keys('hi');
 * // => ['0', '1']
 */
function keys(object) {
  return isArrayLike(object) ? arrayLikeKeys(object) : baseKeys(object);
}

/** Used to match property names within property paths. */
var reIsDeepProp = /\.|\[(?:[^[\]]*|(["'])(?:(?!\1)[^\\]|\\.)*?\1)\]/,
    reIsPlainProp = /^\w*$/;

/**
 * Checks if `value` is a property name and not a property path.
 *
 * @private
 * @param {*} value The value to check.
 * @param {Object} [object] The object to query keys on.
 * @returns {boolean} Returns `true` if `value` is a property name, else `false`.
 */
function isKey(value, object) {
  if (isArray$1(value)) {
    return false;
  }
  var type = typeof value;
  if (type == 'number' || type == 'symbol' || type == 'boolean' ||
      value == null || isSymbol(value)) {
    return true;
  }
  return reIsPlainProp.test(value) || !reIsDeepProp.test(value) ||
    (object != null && value in Object(object));
}

/* Built-in method references that are verified to be native. */
var nativeCreate = getNative(Object, 'create');

/**
 * Removes all key-value entries from the hash.
 *
 * @private
 * @name clear
 * @memberOf Hash
 */
function hashClear() {
  this.__data__ = nativeCreate ? nativeCreate(null) : {};
  this.size = 0;
}

/**
 * Removes `key` and its value from the hash.
 *
 * @private
 * @name delete
 * @memberOf Hash
 * @param {Object} hash The hash to modify.
 * @param {string} key The key of the value to remove.
 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
 */
function hashDelete(key) {
  var result = this.has(key) && delete this.__data__[key];
  this.size -= result ? 1 : 0;
  return result;
}

/** Used to stand-in for `undefined` hash values. */
var HASH_UNDEFINED = '__lodash_hash_undefined__';

/** Used for built-in method references. */
var objectProto$7 = Object.prototype;

/** Used to check objects for own properties. */
var hasOwnProperty$7 = objectProto$7.hasOwnProperty;

/**
 * Gets the hash value for `key`.
 *
 * @private
 * @name get
 * @memberOf Hash
 * @param {string} key The key of the value to get.
 * @returns {*} Returns the entry value.
 */
function hashGet(key) {
  var data = this.__data__;
  if (nativeCreate) {
    var result = data[key];
    return result === HASH_UNDEFINED ? undefined : result;
  }
  return hasOwnProperty$7.call(data, key) ? data[key] : undefined;
}

/** Used for built-in method references. */
var objectProto$8 = Object.prototype;

/** Used to check objects for own properties. */
var hasOwnProperty$8 = objectProto$8.hasOwnProperty;

/**
 * Checks if a hash value for `key` exists.
 *
 * @private
 * @name has
 * @memberOf Hash
 * @param {string} key The key of the entry to check.
 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
 */
function hashHas(key) {
  var data = this.__data__;
  return nativeCreate ? (data[key] !== undefined) : hasOwnProperty$8.call(data, key);
}

/** Used to stand-in for `undefined` hash values. */
var HASH_UNDEFINED$1 = '__lodash_hash_undefined__';

/**
 * Sets the hash `key` to `value`.
 *
 * @private
 * @name set
 * @memberOf Hash
 * @param {string} key The key of the value to set.
 * @param {*} value The value to set.
 * @returns {Object} Returns the hash instance.
 */
function hashSet(key, value) {
  var data = this.__data__;
  this.size += this.has(key) ? 0 : 1;
  data[key] = (nativeCreate && value === undefined) ? HASH_UNDEFINED$1 : value;
  return this;
}

/**
 * Creates a hash object.
 *
 * @private
 * @constructor
 * @param {Array} [entries] The key-value pairs to cache.
 */
function Hash(entries) {
  var index = -1,
      length = entries == null ? 0 : entries.length;

  this.clear();
  while (++index < length) {
    var entry = entries[index];
    this.set(entry[0], entry[1]);
  }
}

// Add methods to `Hash`.
Hash.prototype.clear = hashClear;
Hash.prototype['delete'] = hashDelete;
Hash.prototype.get = hashGet;
Hash.prototype.has = hashHas;
Hash.prototype.set = hashSet;

/**
 * Removes all key-value entries from the list cache.
 *
 * @private
 * @name clear
 * @memberOf ListCache
 */
function listCacheClear() {
  this.__data__ = [];
  this.size = 0;
}

/**
 * Gets the index at which the `key` is found in `array` of key-value pairs.
 *
 * @private
 * @param {Array} array The array to inspect.
 * @param {*} key The key to search for.
 * @returns {number} Returns the index of the matched value, else `-1`.
 */
function assocIndexOf(array, key) {
  var length = array.length;
  while (length--) {
    if (eq(array[length][0], key)) {
      return length;
    }
  }
  return -1;
}

/** Used for built-in method references. */
var arrayProto$1 = Array.prototype;

/** Built-in value references. */
var splice = arrayProto$1.splice;

/**
 * Removes `key` and its value from the list cache.
 *
 * @private
 * @name delete
 * @memberOf ListCache
 * @param {string} key The key of the value to remove.
 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
 */
function listCacheDelete(key) {
  var data = this.__data__,
      index = assocIndexOf(data, key);

  if (index < 0) {
    return false;
  }
  var lastIndex = data.length - 1;
  if (index == lastIndex) {
    data.pop();
  } else {
    splice.call(data, index, 1);
  }
  --this.size;
  return true;
}

/**
 * Gets the list cache value for `key`.
 *
 * @private
 * @name get
 * @memberOf ListCache
 * @param {string} key The key of the value to get.
 * @returns {*} Returns the entry value.
 */
function listCacheGet(key) {
  var data = this.__data__,
      index = assocIndexOf(data, key);

  return index < 0 ? undefined : data[index][1];
}

/**
 * Checks if a list cache value for `key` exists.
 *
 * @private
 * @name has
 * @memberOf ListCache
 * @param {string} key The key of the entry to check.
 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
 */
function listCacheHas(key) {
  return assocIndexOf(this.__data__, key) > -1;
}

/**
 * Sets the list cache `key` to `value`.
 *
 * @private
 * @name set
 * @memberOf ListCache
 * @param {string} key The key of the value to set.
 * @param {*} value The value to set.
 * @returns {Object} Returns the list cache instance.
 */
function listCacheSet(key, value) {
  var data = this.__data__,
      index = assocIndexOf(data, key);

  if (index < 0) {
    ++this.size;
    data.push([key, value]);
  } else {
    data[index][1] = value;
  }
  return this;
}

/**
 * Creates an list cache object.
 *
 * @private
 * @constructor
 * @param {Array} [entries] The key-value pairs to cache.
 */
function ListCache(entries) {
  var index = -1,
      length = entries == null ? 0 : entries.length;

  this.clear();
  while (++index < length) {
    var entry = entries[index];
    this.set(entry[0], entry[1]);
  }
}

// Add methods to `ListCache`.
ListCache.prototype.clear = listCacheClear;
ListCache.prototype['delete'] = listCacheDelete;
ListCache.prototype.get = listCacheGet;
ListCache.prototype.has = listCacheHas;
ListCache.prototype.set = listCacheSet;

/* Built-in method references that are verified to be native. */
var Map = getNative(root, 'Map');

/**
 * Removes all key-value entries from the map.
 *
 * @private
 * @name clear
 * @memberOf MapCache
 */
function mapCacheClear() {
  this.size = 0;
  this.__data__ = {
    'hash': new Hash,
    'map': new (Map || ListCache),
    'string': new Hash
  };
}

/**
 * Checks if `value` is suitable for use as unique object key.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is suitable, else `false`.
 */
function isKeyable(value) {
  var type = typeof value;
  return (type == 'string' || type == 'number' || type == 'symbol' || type == 'boolean')
    ? (value !== '__proto__')
    : (value === null);
}

/**
 * Gets the data for `map`.
 *
 * @private
 * @param {Object} map The map to query.
 * @param {string} key The reference key.
 * @returns {*} Returns the map data.
 */
function getMapData(map, key) {
  var data = map.__data__;
  return isKeyable(key)
    ? data[typeof key == 'string' ? 'string' : 'hash']
    : data.map;
}

/**
 * Removes `key` and its value from the map.
 *
 * @private
 * @name delete
 * @memberOf MapCache
 * @param {string} key The key of the value to remove.
 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
 */
function mapCacheDelete(key) {
  var result = getMapData(this, key)['delete'](key);
  this.size -= result ? 1 : 0;
  return result;
}

/**
 * Gets the map value for `key`.
 *
 * @private
 * @name get
 * @memberOf MapCache
 * @param {string} key The key of the value to get.
 * @returns {*} Returns the entry value.
 */
function mapCacheGet(key) {
  return getMapData(this, key).get(key);
}

/**
 * Checks if a map value for `key` exists.
 *
 * @private
 * @name has
 * @memberOf MapCache
 * @param {string} key The key of the entry to check.
 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
 */
function mapCacheHas(key) {
  return getMapData(this, key).has(key);
}

/**
 * Sets the map `key` to `value`.
 *
 * @private
 * @name set
 * @memberOf MapCache
 * @param {string} key The key of the value to set.
 * @param {*} value The value to set.
 * @returns {Object} Returns the map cache instance.
 */
function mapCacheSet(key, value) {
  var data = getMapData(this, key),
      size = data.size;

  data.set(key, value);
  this.size += data.size == size ? 0 : 1;
  return this;
}

/**
 * Creates a map cache object to store key-value pairs.
 *
 * @private
 * @constructor
 * @param {Array} [entries] The key-value pairs to cache.
 */
function MapCache(entries) {
  var index = -1,
      length = entries == null ? 0 : entries.length;

  this.clear();
  while (++index < length) {
    var entry = entries[index];
    this.set(entry[0], entry[1]);
  }
}

// Add methods to `MapCache`.
MapCache.prototype.clear = mapCacheClear;
MapCache.prototype['delete'] = mapCacheDelete;
MapCache.prototype.get = mapCacheGet;
MapCache.prototype.has = mapCacheHas;
MapCache.prototype.set = mapCacheSet;

/** Error message constants. */
var FUNC_ERROR_TEXT = 'Expected a function';

/**
 * Creates a function that memoizes the result of `func`. If `resolver` is
 * provided, it determines the cache key for storing the result based on the
 * arguments provided to the memoized function. By default, the first argument
 * provided to the memoized function is used as the map cache key. The `func`
 * is invoked with the `this` binding of the memoized function.
 *
 * **Note:** The cache is exposed as the `cache` property on the memoized
 * function. Its creation may be customized by replacing the `_.memoize.Cache`
 * constructor with one whose instances implement the
 * [`Map`](http://ecma-international.org/ecma-262/7.0/#sec-properties-of-the-map-prototype-object)
 * method interface of `clear`, `delete`, `get`, `has`, and `set`.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Function
 * @param {Function} func The function to have its output memoized.
 * @param {Function} [resolver] The function to resolve the cache key.
 * @returns {Function} Returns the new memoized function.
 * @example
 *
 * var object = { 'a': 1, 'b': 2 };
 * var other = { 'c': 3, 'd': 4 };
 *
 * var values = _.memoize(_.values);
 * values(object);
 * // => [1, 2]
 *
 * values(other);
 * // => [3, 4]
 *
 * object.a = 2;
 * values(object);
 * // => [1, 2]
 *
 * // Modify the result cache.
 * values.cache.set(object, ['a', 'b']);
 * values(object);
 * // => ['a', 'b']
 *
 * // Replace `_.memoize.Cache`.
 * _.memoize.Cache = WeakMap;
 */
function memoize(func, resolver) {
  if (typeof func != 'function' || (resolver != null && typeof resolver != 'function')) {
    throw new TypeError(FUNC_ERROR_TEXT);
  }
  var memoized = function() {
    var args = arguments,
        key = resolver ? resolver.apply(this, args) : args[0],
        cache = memoized.cache;

    if (cache.has(key)) {
      return cache.get(key);
    }
    var result = func.apply(this, args);
    memoized.cache = cache.set(key, result) || cache;
    return result;
  };
  memoized.cache = new (memoize.Cache || MapCache);
  return memoized;
}

// Expose `MapCache`.
memoize.Cache = MapCache;

/** Used as the maximum memoize cache size. */
var MAX_MEMOIZE_SIZE = 500;

/**
 * A specialized version of `_.memoize` which clears the memoized function's
 * cache when it exceeds `MAX_MEMOIZE_SIZE`.
 *
 * @private
 * @param {Function} func The function to have its output memoized.
 * @returns {Function} Returns the new memoized function.
 */
function memoizeCapped(func) {
  var result = memoize(func, function(key) {
    if (cache.size === MAX_MEMOIZE_SIZE) {
      cache.clear();
    }
    return key;
  });

  var cache = result.cache;
  return result;
}

/** Used to match property names within property paths. */
var rePropName = /[^.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]|(?=(?:\.|\[\])(?:\.|\[\]|$))/g;

/** Used to match backslashes in property paths. */
var reEscapeChar = /\\(\\)?/g;

/**
 * Converts `string` to a property path array.
 *
 * @private
 * @param {string} string The string to convert.
 * @returns {Array} Returns the property path array.
 */
var stringToPath = memoizeCapped(function(string) {
  var result = [];
  if (string.charCodeAt(0) === 46 /* . */) {
    result.push('');
  }
  string.replace(rePropName, function(match, number, quote, subString) {
    result.push(quote ? subString.replace(reEscapeChar, '$1') : (number || match));
  });
  return result;
});

/**
 * Converts `value` to a string. An empty string is returned for `null`
 * and `undefined` values. The sign of `-0` is preserved.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to convert.
 * @returns {string} Returns the converted string.
 * @example
 *
 * _.toString(null);
 * // => ''
 *
 * _.toString(-0);
 * // => '-0'
 *
 * _.toString([1, 2, 3]);
 * // => '1,2,3'
 */
function toString$2(value) {
  return value == null ? '' : baseToString(value);
}

/**
 * Casts `value` to a path array if it's not one.
 *
 * @private
 * @param {*} value The value to inspect.
 * @param {Object} [object] The object to query keys on.
 * @returns {Array} Returns the cast property path array.
 */
function castPath(value, object) {
  if (isArray$1(value)) {
    return value;
  }
  return isKey(value, object) ? [value] : stringToPath(toString$2(value));
}

/** Used as references for various `Number` constants. */
var INFINITY$1 = 1 / 0;

/**
 * Converts `value` to a string key if it's not a string or symbol.
 *
 * @private
 * @param {*} value The value to inspect.
 * @returns {string|symbol} Returns the key.
 */
function toKey(value) {
  if (typeof value == 'string' || isSymbol(value)) {
    return value;
  }
  var result = (value + '');
  return (result == '0' && (1 / value) == -INFINITY$1) ? '-0' : result;
}

/**
 * The base implementation of `_.get` without support for default values.
 *
 * @private
 * @param {Object} object The object to query.
 * @param {Array|string} path The path of the property to get.
 * @returns {*} Returns the resolved value.
 */
function baseGet(object, path) {
  path = castPath(path, object);

  var index = 0,
      length = path.length;

  while (object != null && index < length) {
    object = object[toKey(path[index++])];
  }
  return (index && index == length) ? object : undefined;
}

/**
 * Gets the value at `path` of `object`. If the resolved value is
 * `undefined`, the `defaultValue` is returned in its place.
 *
 * @static
 * @memberOf _
 * @since 3.7.0
 * @category Object
 * @param {Object} object The object to query.
 * @param {Array|string} path The path of the property to get.
 * @param {*} [defaultValue] The value returned for `undefined` resolved values.
 * @returns {*} Returns the resolved value.
 * @example
 *
 * var object = { 'a': [{ 'b': { 'c': 3 } }] };
 *
 * _.get(object, 'a[0].b.c');
 * // => 3
 *
 * _.get(object, ['a', '0', 'b', 'c']);
 * // => 3
 *
 * _.get(object, 'a.b.c', 'default');
 * // => 'default'
 */
function get(object, path, defaultValue) {
  var result = object == null ? undefined : baseGet(object, path);
  return result === undefined ? defaultValue : result;
}

/**
 * Appends the elements of `values` to `array`.
 *
 * @private
 * @param {Array} array The array to modify.
 * @param {Array} values The values to append.
 * @returns {Array} Returns `array`.
 */
function arrayPush(array, values) {
  var index = -1,
      length = values.length,
      offset = array.length;

  while (++index < length) {
    array[offset + index] = values[index];
  }
  return array;
}

/**
 * Removes all key-value entries from the stack.
 *
 * @private
 * @name clear
 * @memberOf Stack
 */
function stackClear() {
  this.__data__ = new ListCache;
  this.size = 0;
}

/**
 * Removes `key` and its value from the stack.
 *
 * @private
 * @name delete
 * @memberOf Stack
 * @param {string} key The key of the value to remove.
 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
 */
function stackDelete(key) {
  var data = this.__data__,
      result = data['delete'](key);

  this.size = data.size;
  return result;
}

/**
 * Gets the stack value for `key`.
 *
 * @private
 * @name get
 * @memberOf Stack
 * @param {string} key The key of the value to get.
 * @returns {*} Returns the entry value.
 */
function stackGet(key) {
  return this.__data__.get(key);
}

/**
 * Checks if a stack value for `key` exists.
 *
 * @private
 * @name has
 * @memberOf Stack
 * @param {string} key The key of the entry to check.
 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
 */
function stackHas(key) {
  return this.__data__.has(key);
}

/** Used as the size to enable large array optimizations. */
var LARGE_ARRAY_SIZE = 200;

/**
 * Sets the stack `key` to `value`.
 *
 * @private
 * @name set
 * @memberOf Stack
 * @param {string} key The key of the value to set.
 * @param {*} value The value to set.
 * @returns {Object} Returns the stack cache instance.
 */
function stackSet(key, value) {
  var data = this.__data__;
  if (data instanceof ListCache) {
    var pairs = data.__data__;
    if (!Map || (pairs.length < LARGE_ARRAY_SIZE - 1)) {
      pairs.push([key, value]);
      this.size = ++data.size;
      return this;
    }
    data = this.__data__ = new MapCache(pairs);
  }
  data.set(key, value);
  this.size = data.size;
  return this;
}

/**
 * Creates a stack cache object to store key-value pairs.
 *
 * @private
 * @constructor
 * @param {Array} [entries] The key-value pairs to cache.
 */
function Stack(entries) {
  var data = this.__data__ = new ListCache(entries);
  this.size = data.size;
}

// Add methods to `Stack`.
Stack.prototype.clear = stackClear;
Stack.prototype['delete'] = stackDelete;
Stack.prototype.get = stackGet;
Stack.prototype.has = stackHas;
Stack.prototype.set = stackSet;

/**
 * A specialized version of `_.filter` for arrays without support for
 * iteratee shorthands.
 *
 * @private
 * @param {Array} [array] The array to iterate over.
 * @param {Function} predicate The function invoked per iteration.
 * @returns {Array} Returns the new filtered array.
 */
function arrayFilter(array, predicate) {
  var index = -1,
      length = array == null ? 0 : array.length,
      resIndex = 0,
      result = [];

  while (++index < length) {
    var value = array[index];
    if (predicate(value, index, array)) {
      result[resIndex++] = value;
    }
  }
  return result;
}

/**
 * This method returns a new empty array.
 *
 * @static
 * @memberOf _
 * @since 4.13.0
 * @category Util
 * @returns {Array} Returns the new empty array.
 * @example
 *
 * var arrays = _.times(2, _.stubArray);
 *
 * console.log(arrays);
 * // => [[], []]
 *
 * console.log(arrays[0] === arrays[1]);
 * // => false
 */
function stubArray() {
  return [];
}

/** Used for built-in method references. */
var objectProto$9 = Object.prototype;

/** Built-in value references. */
var propertyIsEnumerable$1 = objectProto$9.propertyIsEnumerable;

/* Built-in method references for those with the same name as other `lodash` methods. */
var nativeGetSymbols = Object.getOwnPropertySymbols;

/**
 * Creates an array of the own enumerable symbols of `object`.
 *
 * @private
 * @param {Object} object The object to query.
 * @returns {Array} Returns the array of symbols.
 */
var getSymbols = !nativeGetSymbols ? stubArray : function(object) {
  if (object == null) {
    return [];
  }
  object = Object(object);
  return arrayFilter(nativeGetSymbols(object), function(symbol) {
    return propertyIsEnumerable$1.call(object, symbol);
  });
};

/**
 * The base implementation of `getAllKeys` and `getAllKeysIn` which uses
 * `keysFunc` and `symbolsFunc` to get the enumerable property names and
 * symbols of `object`.
 *
 * @private
 * @param {Object} object The object to query.
 * @param {Function} keysFunc The function to get the keys of `object`.
 * @param {Function} symbolsFunc The function to get the symbols of `object`.
 * @returns {Array} Returns the array of property names and symbols.
 */
function baseGetAllKeys(object, keysFunc, symbolsFunc) {
  var result = keysFunc(object);
  return isArray$1(object) ? result : arrayPush(result, symbolsFunc(object));
}

/**
 * Creates an array of own enumerable property names and symbols of `object`.
 *
 * @private
 * @param {Object} object The object to query.
 * @returns {Array} Returns the array of property names and symbols.
 */
function getAllKeys(object) {
  return baseGetAllKeys(object, keys, getSymbols);
}

/* Built-in method references that are verified to be native. */
var DataView = getNative(root, 'DataView');

/* Built-in method references that are verified to be native. */
var Promise$1 = getNative(root, 'Promise');

/* Built-in method references that are verified to be native. */
var Set$1 = getNative(root, 'Set');

/** `Object#toString` result references. */
var mapTag$1 = '[object Map]',
    objectTag$1 = '[object Object]',
    promiseTag = '[object Promise]',
    setTag$1 = '[object Set]',
    weakMapTag$1 = '[object WeakMap]';

var dataViewTag$1 = '[object DataView]';

/** Used to detect maps, sets, and weakmaps. */
var dataViewCtorString = toSource(DataView),
    mapCtorString = toSource(Map),
    promiseCtorString = toSource(Promise$1),
    setCtorString = toSource(Set$1),
    weakMapCtorString = toSource(WeakMap);

/**
 * Gets the `toStringTag` of `value`.
 *
 * @private
 * @param {*} value The value to query.
 * @returns {string} Returns the `toStringTag`.
 */
var getTag = baseGetTag;

// Fallback for data views, maps, sets, and weak maps in IE 11 and promises in Node.js < 6.
if ((DataView && getTag(new DataView(new ArrayBuffer(1))) != dataViewTag$1) ||
    (Map && getTag(new Map) != mapTag$1) ||
    (Promise$1 && getTag(Promise$1.resolve()) != promiseTag) ||
    (Set$1 && getTag(new Set$1) != setTag$1) ||
    (WeakMap && getTag(new WeakMap) != weakMapTag$1)) {
  getTag = function(value) {
    var result = baseGetTag(value),
        Ctor = result == objectTag$1 ? value.constructor : undefined,
        ctorString = Ctor ? toSource(Ctor) : '';

    if (ctorString) {
      switch (ctorString) {
        case dataViewCtorString: return dataViewTag$1;
        case mapCtorString: return mapTag$1;
        case promiseCtorString: return promiseTag;
        case setCtorString: return setTag$1;
        case weakMapCtorString: return weakMapTag$1;
      }
    }
    return result;
  };
}

var getTag$1 = getTag;

/** Built-in value references. */
var Uint8Array = root.Uint8Array;

/** Used to stand-in for `undefined` hash values. */
var HASH_UNDEFINED$2 = '__lodash_hash_undefined__';

/**
 * Adds `value` to the array cache.
 *
 * @private
 * @name add
 * @memberOf SetCache
 * @alias push
 * @param {*} value The value to cache.
 * @returns {Object} Returns the cache instance.
 */
function setCacheAdd(value) {
  this.__data__.set(value, HASH_UNDEFINED$2);
  return this;
}

/**
 * Checks if `value` is in the array cache.
 *
 * @private
 * @name has
 * @memberOf SetCache
 * @param {*} value The value to search for.
 * @returns {number} Returns `true` if `value` is found, else `false`.
 */
function setCacheHas(value) {
  return this.__data__.has(value);
}

/**
 *
 * Creates an array cache object to store unique values.
 *
 * @private
 * @constructor
 * @param {Array} [values] The values to cache.
 */
function SetCache(values) {
  var index = -1,
      length = values == null ? 0 : values.length;

  this.__data__ = new MapCache;
  while (++index < length) {
    this.add(values[index]);
  }
}

// Add methods to `SetCache`.
SetCache.prototype.add = SetCache.prototype.push = setCacheAdd;
SetCache.prototype.has = setCacheHas;

/**
 * A specialized version of `_.some` for arrays without support for iteratee
 * shorthands.
 *
 * @private
 * @param {Array} [array] The array to iterate over.
 * @param {Function} predicate The function invoked per iteration.
 * @returns {boolean} Returns `true` if any element passes the predicate check,
 *  else `false`.
 */
function arraySome(array, predicate) {
  var index = -1,
      length = array == null ? 0 : array.length;

  while (++index < length) {
    if (predicate(array[index], index, array)) {
      return true;
    }
  }
  return false;
}

/**
 * Checks if a `cache` value for `key` exists.
 *
 * @private
 * @param {Object} cache The cache to query.
 * @param {string} key The key of the entry to check.
 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
 */
function cacheHas(cache, key) {
  return cache.has(key);
}

/** Used to compose bitmasks for value comparisons. */
var COMPARE_PARTIAL_FLAG = 1,
    COMPARE_UNORDERED_FLAG = 2;

/**
 * A specialized version of `baseIsEqualDeep` for arrays with support for
 * partial deep comparisons.
 *
 * @private
 * @param {Array} array The array to compare.
 * @param {Array} other The other array to compare.
 * @param {number} bitmask The bitmask flags. See `baseIsEqual` for more details.
 * @param {Function} customizer The function to customize comparisons.
 * @param {Function} equalFunc The function to determine equivalents of values.
 * @param {Object} stack Tracks traversed `array` and `other` objects.
 * @returns {boolean} Returns `true` if the arrays are equivalent, else `false`.
 */
function equalArrays(array, other, bitmask, customizer, equalFunc, stack) {
  var isPartial = bitmask & COMPARE_PARTIAL_FLAG,
      arrLength = array.length,
      othLength = other.length;

  if (arrLength != othLength && !(isPartial && othLength > arrLength)) {
    return false;
  }
  // Assume cyclic values are equal.
  var stacked = stack.get(array);
  if (stacked && stack.get(other)) {
    return stacked == other;
  }
  var index = -1,
      result = true,
      seen = (bitmask & COMPARE_UNORDERED_FLAG) ? new SetCache : undefined;

  stack.set(array, other);
  stack.set(other, array);

  // Ignore non-index properties.
  while (++index < arrLength) {
    var arrValue = array[index],
        othValue = other[index];

    if (customizer) {
      var compared = isPartial
        ? customizer(othValue, arrValue, index, other, array, stack)
        : customizer(arrValue, othValue, index, array, other, stack);
    }
    if (compared !== undefined) {
      if (compared) {
        continue;
      }
      result = false;
      break;
    }
    // Recursively compare arrays (susceptible to call stack limits).
    if (seen) {
      if (!arraySome(other, function(othValue, othIndex) {
            if (!cacheHas(seen, othIndex) &&
                (arrValue === othValue || equalFunc(arrValue, othValue, bitmask, customizer, stack))) {
              return seen.push(othIndex);
            }
          })) {
        result = false;
        break;
      }
    } else if (!(
          arrValue === othValue ||
            equalFunc(arrValue, othValue, bitmask, customizer, stack)
        )) {
      result = false;
      break;
    }
  }
  stack['delete'](array);
  stack['delete'](other);
  return result;
}

/**
 * Converts `map` to its key-value pairs.
 *
 * @private
 * @param {Object} map The map to convert.
 * @returns {Array} Returns the key-value pairs.
 */
function mapToArray(map) {
  var index = -1,
      result = Array(map.size);

  map.forEach(function(value, key) {
    result[++index] = [key, value];
  });
  return result;
}

/**
 * Converts `set` to an array of its values.
 *
 * @private
 * @param {Object} set The set to convert.
 * @returns {Array} Returns the values.
 */
function setToArray(set) {
  var index = -1,
      result = Array(set.size);

  set.forEach(function(value) {
    result[++index] = value;
  });
  return result;
}

/** Used to compose bitmasks for value comparisons. */
var COMPARE_PARTIAL_FLAG$1 = 1,
    COMPARE_UNORDERED_FLAG$1 = 2;

/** `Object#toString` result references. */
var boolTag$1 = '[object Boolean]',
    dateTag$1 = '[object Date]',
    errorTag$1 = '[object Error]',
    mapTag$2 = '[object Map]',
    numberTag$1 = '[object Number]',
    regexpTag$1 = '[object RegExp]',
    setTag$2 = '[object Set]',
    stringTag$1 = '[object String]',
    symbolTag$1 = '[object Symbol]';

var arrayBufferTag$1 = '[object ArrayBuffer]',
    dataViewTag$2 = '[object DataView]';

/** Used to convert symbols to primitives and strings. */
var symbolProto$1 = Symbol$1 ? Symbol$1.prototype : undefined,
    symbolValueOf = symbolProto$1 ? symbolProto$1.valueOf : undefined;

/**
 * A specialized version of `baseIsEqualDeep` for comparing objects of
 * the same `toStringTag`.
 *
 * **Note:** This function only supports comparing values with tags of
 * `Boolean`, `Date`, `Error`, `Number`, `RegExp`, or `String`.
 *
 * @private
 * @param {Object} object The object to compare.
 * @param {Object} other The other object to compare.
 * @param {string} tag The `toStringTag` of the objects to compare.
 * @param {number} bitmask The bitmask flags. See `baseIsEqual` for more details.
 * @param {Function} customizer The function to customize comparisons.
 * @param {Function} equalFunc The function to determine equivalents of values.
 * @param {Object} stack Tracks traversed `object` and `other` objects.
 * @returns {boolean} Returns `true` if the objects are equivalent, else `false`.
 */
function equalByTag(object, other, tag, bitmask, customizer, equalFunc, stack) {
  switch (tag) {
    case dataViewTag$2:
      if ((object.byteLength != other.byteLength) ||
          (object.byteOffset != other.byteOffset)) {
        return false;
      }
      object = object.buffer;
      other = other.buffer;

    case arrayBufferTag$1:
      if ((object.byteLength != other.byteLength) ||
          !equalFunc(new Uint8Array(object), new Uint8Array(other))) {
        return false;
      }
      return true;

    case boolTag$1:
    case dateTag$1:
    case numberTag$1:
      // Coerce booleans to `1` or `0` and dates to milliseconds.
      // Invalid dates are coerced to `NaN`.
      return eq(+object, +other);

    case errorTag$1:
      return object.name == other.name && object.message == other.message;

    case regexpTag$1:
    case stringTag$1:
      // Coerce regexes to strings and treat strings, primitives and objects,
      // as equal. See http://www.ecma-international.org/ecma-262/7.0/#sec-regexp.prototype.tostring
      // for more details.
      return object == (other + '');

    case mapTag$2:
      var convert = mapToArray;

    case setTag$2:
      var isPartial = bitmask & COMPARE_PARTIAL_FLAG$1;
      convert || (convert = setToArray);

      if (object.size != other.size && !isPartial) {
        return false;
      }
      // Assume cyclic values are equal.
      var stacked = stack.get(object);
      if (stacked) {
        return stacked == other;
      }
      bitmask |= COMPARE_UNORDERED_FLAG$1;

      // Recursively compare objects (susceptible to call stack limits).
      stack.set(object, other);
      var result = equalArrays(convert(object), convert(other), bitmask, customizer, equalFunc, stack);
      stack['delete'](object);
      return result;

    case symbolTag$1:
      if (symbolValueOf) {
        return symbolValueOf.call(object) == symbolValueOf.call(other);
      }
  }
  return false;
}

/** Used to compose bitmasks for value comparisons. */
var COMPARE_PARTIAL_FLAG$2 = 1;

/** Used for built-in method references. */
var objectProto$a = Object.prototype;

/** Used to check objects for own properties. */
var hasOwnProperty$9 = objectProto$a.hasOwnProperty;

/**
 * A specialized version of `baseIsEqualDeep` for objects with support for
 * partial deep comparisons.
 *
 * @private
 * @param {Object} object The object to compare.
 * @param {Object} other The other object to compare.
 * @param {number} bitmask The bitmask flags. See `baseIsEqual` for more details.
 * @param {Function} customizer The function to customize comparisons.
 * @param {Function} equalFunc The function to determine equivalents of values.
 * @param {Object} stack Tracks traversed `object` and `other` objects.
 * @returns {boolean} Returns `true` if the objects are equivalent, else `false`.
 */
function equalObjects(object, other, bitmask, customizer, equalFunc, stack) {
  var isPartial = bitmask & COMPARE_PARTIAL_FLAG$2,
      objProps = getAllKeys(object),
      objLength = objProps.length,
      othProps = getAllKeys(other),
      othLength = othProps.length;

  if (objLength != othLength && !isPartial) {
    return false;
  }
  var index = objLength;
  while (index--) {
    var key = objProps[index];
    if (!(isPartial ? key in other : hasOwnProperty$9.call(other, key))) {
      return false;
    }
  }
  // Assume cyclic values are equal.
  var stacked = stack.get(object);
  if (stacked && stack.get(other)) {
    return stacked == other;
  }
  var result = true;
  stack.set(object, other);
  stack.set(other, object);

  var skipCtor = isPartial;
  while (++index < objLength) {
    key = objProps[index];
    var objValue = object[key],
        othValue = other[key];

    if (customizer) {
      var compared = isPartial
        ? customizer(othValue, objValue, key, other, object, stack)
        : customizer(objValue, othValue, key, object, other, stack);
    }
    // Recursively compare objects (susceptible to call stack limits).
    if (!(compared === undefined
          ? (objValue === othValue || equalFunc(objValue, othValue, bitmask, customizer, stack))
          : compared
        )) {
      result = false;
      break;
    }
    skipCtor || (skipCtor = key == 'constructor');
  }
  if (result && !skipCtor) {
    var objCtor = object.constructor,
        othCtor = other.constructor;

    // Non `Object` object instances with different constructors are not equal.
    if (objCtor != othCtor &&
        ('constructor' in object && 'constructor' in other) &&
        !(typeof objCtor == 'function' && objCtor instanceof objCtor &&
          typeof othCtor == 'function' && othCtor instanceof othCtor)) {
      result = false;
    }
  }
  stack['delete'](object);
  stack['delete'](other);
  return result;
}

/** Used to compose bitmasks for value comparisons. */
var COMPARE_PARTIAL_FLAG$3 = 1;

/** `Object#toString` result references. */
var argsTag$2 = '[object Arguments]',
    arrayTag$1 = '[object Array]',
    objectTag$2 = '[object Object]';

/** Used for built-in method references. */
var objectProto$b = Object.prototype;

/** Used to check objects for own properties. */
var hasOwnProperty$a = objectProto$b.hasOwnProperty;

/**
 * A specialized version of `baseIsEqual` for arrays and objects which performs
 * deep comparisons and tracks traversed objects enabling objects with circular
 * references to be compared.
 *
 * @private
 * @param {Object} object The object to compare.
 * @param {Object} other The other object to compare.
 * @param {number} bitmask The bitmask flags. See `baseIsEqual` for more details.
 * @param {Function} customizer The function to customize comparisons.
 * @param {Function} equalFunc The function to determine equivalents of values.
 * @param {Object} [stack] Tracks traversed `object` and `other` objects.
 * @returns {boolean} Returns `true` if the objects are equivalent, else `false`.
 */
function baseIsEqualDeep(object, other, bitmask, customizer, equalFunc, stack) {
  var objIsArr = isArray$1(object),
      othIsArr = isArray$1(other),
      objTag = objIsArr ? arrayTag$1 : getTag$1(object),
      othTag = othIsArr ? arrayTag$1 : getTag$1(other);

  objTag = objTag == argsTag$2 ? objectTag$2 : objTag;
  othTag = othTag == argsTag$2 ? objectTag$2 : othTag;

  var objIsObj = objTag == objectTag$2,
      othIsObj = othTag == objectTag$2,
      isSameTag = objTag == othTag;

  if (isSameTag && isBuffer(object)) {
    if (!isBuffer(other)) {
      return false;
    }
    objIsArr = true;
    objIsObj = false;
  }
  if (isSameTag && !objIsObj) {
    stack || (stack = new Stack);
    return (objIsArr || isTypedArray(object))
      ? equalArrays(object, other, bitmask, customizer, equalFunc, stack)
      : equalByTag(object, other, objTag, bitmask, customizer, equalFunc, stack);
  }
  if (!(bitmask & COMPARE_PARTIAL_FLAG$3)) {
    var objIsWrapped = objIsObj && hasOwnProperty$a.call(object, '__wrapped__'),
        othIsWrapped = othIsObj && hasOwnProperty$a.call(other, '__wrapped__');

    if (objIsWrapped || othIsWrapped) {
      var objUnwrapped = objIsWrapped ? object.value() : object,
          othUnwrapped = othIsWrapped ? other.value() : other;

      stack || (stack = new Stack);
      return equalFunc(objUnwrapped, othUnwrapped, bitmask, customizer, stack);
    }
  }
  if (!isSameTag) {
    return false;
  }
  stack || (stack = new Stack);
  return equalObjects(object, other, bitmask, customizer, equalFunc, stack);
}

/**
 * The base implementation of `_.isEqual` which supports partial comparisons
 * and tracks traversed objects.
 *
 * @private
 * @param {*} value The value to compare.
 * @param {*} other The other value to compare.
 * @param {boolean} bitmask The bitmask flags.
 *  1 - Unordered comparison
 *  2 - Partial comparison
 * @param {Function} [customizer] The function to customize comparisons.
 * @param {Object} [stack] Tracks traversed `value` and `other` objects.
 * @returns {boolean} Returns `true` if the values are equivalent, else `false`.
 */
function baseIsEqual(value, other, bitmask, customizer, stack) {
  if (value === other) {
    return true;
  }
  if (value == null || other == null || (!isObjectLike(value) && !isObjectLike(other))) {
    return value !== value && other !== other;
  }
  return baseIsEqualDeep(value, other, bitmask, customizer, baseIsEqual, stack);
}

/** Used to compose bitmasks for value comparisons. */
var COMPARE_PARTIAL_FLAG$4 = 1,
    COMPARE_UNORDERED_FLAG$2 = 2;

/**
 * The base implementation of `_.isMatch` without support for iteratee shorthands.
 *
 * @private
 * @param {Object} object The object to inspect.
 * @param {Object} source The object of property values to match.
 * @param {Array} matchData The property names, values, and compare flags to match.
 * @param {Function} [customizer] The function to customize comparisons.
 * @returns {boolean} Returns `true` if `object` is a match, else `false`.
 */
function baseIsMatch(object, source, matchData, customizer) {
  var index = matchData.length,
      length = index,
      noCustomizer = !customizer;

  if (object == null) {
    return !length;
  }
  object = Object(object);
  while (index--) {
    var data = matchData[index];
    if ((noCustomizer && data[2])
          ? data[1] !== object[data[0]]
          : !(data[0] in object)
        ) {
      return false;
    }
  }
  while (++index < length) {
    data = matchData[index];
    var key = data[0],
        objValue = object[key],
        srcValue = data[1];

    if (noCustomizer && data[2]) {
      if (objValue === undefined && !(key in object)) {
        return false;
      }
    } else {
      var stack = new Stack;
      if (customizer) {
        var result = customizer(objValue, srcValue, key, object, source, stack);
      }
      if (!(result === undefined
            ? baseIsEqual(srcValue, objValue, COMPARE_PARTIAL_FLAG$4 | COMPARE_UNORDERED_FLAG$2, customizer, stack)
            : result
          )) {
        return false;
      }
    }
  }
  return true;
}

/**
 * Checks if `value` is suitable for strict equality comparisons, i.e. `===`.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` if suitable for strict
 *  equality comparisons, else `false`.
 */
function isStrictComparable(value) {
  return value === value && !isObject$3(value);
}

/**
 * Gets the property names, values, and compare flags of `object`.
 *
 * @private
 * @param {Object} object The object to query.
 * @returns {Array} Returns the match data of `object`.
 */
function getMatchData(object) {
  var result = keys(object),
      length = result.length;

  while (length--) {
    var key = result[length],
        value = object[key];

    result[length] = [key, value, isStrictComparable(value)];
  }
  return result;
}

/**
 * A specialized version of `matchesProperty` for source values suitable
 * for strict equality comparisons, i.e. `===`.
 *
 * @private
 * @param {string} key The key of the property to get.
 * @param {*} srcValue The value to match.
 * @returns {Function} Returns the new spec function.
 */
function matchesStrictComparable(key, srcValue) {
  return function(object) {
    if (object == null) {
      return false;
    }
    return object[key] === srcValue &&
      (srcValue !== undefined || (key in Object(object)));
  };
}

/**
 * The base implementation of `_.matches` which doesn't clone `source`.
 *
 * @private
 * @param {Object} source The object of property values to match.
 * @returns {Function} Returns the new spec function.
 */
function baseMatches(source) {
  var matchData = getMatchData(source);
  if (matchData.length == 1 && matchData[0][2]) {
    return matchesStrictComparable(matchData[0][0], matchData[0][1]);
  }
  return function(object) {
    return object === source || baseIsMatch(object, source, matchData);
  };
}

/**
 * The base implementation of `_.hasIn` without support for deep paths.
 *
 * @private
 * @param {Object} [object] The object to query.
 * @param {Array|string} key The key to check.
 * @returns {boolean} Returns `true` if `key` exists, else `false`.
 */
function baseHasIn(object, key) {
  return object != null && key in Object(object);
}

/**
 * Checks if `path` exists on `object`.
 *
 * @private
 * @param {Object} object The object to query.
 * @param {Array|string} path The path to check.
 * @param {Function} hasFunc The function to check properties.
 * @returns {boolean} Returns `true` if `path` exists, else `false`.
 */
function hasPath(object, path, hasFunc) {
  path = castPath(path, object);

  var index = -1,
      length = path.length,
      result = false;

  while (++index < length) {
    var key = toKey(path[index]);
    if (!(result = object != null && hasFunc(object, key))) {
      break;
    }
    object = object[key];
  }
  if (result || ++index != length) {
    return result;
  }
  length = object == null ? 0 : object.length;
  return !!length && isLength(length) && isIndex(key, length) &&
    (isArray$1(object) || isArguments(object));
}

/**
 * Checks if `path` is a direct or inherited property of `object`.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Object
 * @param {Object} object The object to query.
 * @param {Array|string} path The path to check.
 * @returns {boolean} Returns `true` if `path` exists, else `false`.
 * @example
 *
 * var object = _.create({ 'a': _.create({ 'b': 2 }) });
 *
 * _.hasIn(object, 'a');
 * // => true
 *
 * _.hasIn(object, 'a.b');
 * // => true
 *
 * _.hasIn(object, ['a', 'b']);
 * // => true
 *
 * _.hasIn(object, 'b');
 * // => false
 */
function hasIn(object, path) {
  return object != null && hasPath(object, path, baseHasIn);
}

/** Used to compose bitmasks for value comparisons. */
var COMPARE_PARTIAL_FLAG$5 = 1,
    COMPARE_UNORDERED_FLAG$3 = 2;

/**
 * The base implementation of `_.matchesProperty` which doesn't clone `srcValue`.
 *
 * @private
 * @param {string} path The path of the property to get.
 * @param {*} srcValue The value to match.
 * @returns {Function} Returns the new spec function.
 */
function baseMatchesProperty(path, srcValue) {
  if (isKey(path) && isStrictComparable(srcValue)) {
    return matchesStrictComparable(toKey(path), srcValue);
  }
  return function(object) {
    var objValue = get(object, path);
    return (objValue === undefined && objValue === srcValue)
      ? hasIn(object, path)
      : baseIsEqual(srcValue, objValue, COMPARE_PARTIAL_FLAG$5 | COMPARE_UNORDERED_FLAG$3);
  };
}

/**
 * The base implementation of `_.property` without support for deep paths.
 *
 * @private
 * @param {string} key The key of the property to get.
 * @returns {Function} Returns the new accessor function.
 */
function baseProperty(key) {
  return function(object) {
    return object == null ? undefined : object[key];
  };
}

/**
 * A specialized version of `baseProperty` which supports deep paths.
 *
 * @private
 * @param {Array|string} path The path of the property to get.
 * @returns {Function} Returns the new accessor function.
 */
function basePropertyDeep(path) {
  return function(object) {
    return baseGet(object, path);
  };
}

/**
 * Creates a function that returns the value at `path` of a given object.
 *
 * @static
 * @memberOf _
 * @since 2.4.0
 * @category Util
 * @param {Array|string} path The path of the property to get.
 * @returns {Function} Returns the new accessor function.
 * @example
 *
 * var objects = [
 *   { 'a': { 'b': 2 } },
 *   { 'a': { 'b': 1 } }
 * ];
 *
 * _.map(objects, _.property('a.b'));
 * // => [2, 1]
 *
 * _.map(_.sortBy(objects, _.property(['a', 'b'])), 'a.b');
 * // => [1, 2]
 */
function property(path) {
  return isKey(path) ? baseProperty(toKey(path)) : basePropertyDeep(path);
}

/**
 * The base implementation of `_.iteratee`.
 *
 * @private
 * @param {*} [value=_.identity] The value to convert to an iteratee.
 * @returns {Function} Returns the iteratee.
 */
function baseIteratee(value) {
  // Don't store the `typeof` result in a variable to avoid a JIT bug in Safari 9.
  // See https://bugs.webkit.org/show_bug.cgi?id=156034 for more details.
  if (typeof value == 'function') {
    return value;
  }
  if (value == null) {
    return identity$1;
  }
  if (typeof value == 'object') {
    return isArray$1(value)
      ? baseMatchesProperty(value[0], value[1])
      : baseMatches(value);
  }
  return property(value);
}

/**
 * Creates a base function for methods like `_.forIn` and `_.forOwn`.
 *
 * @private
 * @param {boolean} [fromRight] Specify iterating from right to left.
 * @returns {Function} Returns the new base function.
 */
function createBaseFor(fromRight) {
  return function(object, iteratee, keysFunc) {
    var index = -1,
        iterable = Object(object),
        props = keysFunc(object),
        length = props.length;

    while (length--) {
      var key = props[fromRight ? length : ++index];
      if (iteratee(iterable[key], key, iterable) === false) {
        break;
      }
    }
    return object;
  };
}

/**
 * The base implementation of `baseForOwn` which iterates over `object`
 * properties returned by `keysFunc` and invokes `iteratee` for each property.
 * Iteratee functions may exit iteration early by explicitly returning `false`.
 *
 * @private
 * @param {Object} object The object to iterate over.
 * @param {Function} iteratee The function invoked per iteration.
 * @param {Function} keysFunc The function to get the keys of `object`.
 * @returns {Object} Returns `object`.
 */
var baseFor = createBaseFor();

/**
 * The base implementation of `_.forOwn` without support for iteratee shorthands.
 *
 * @private
 * @param {Object} object The object to iterate over.
 * @param {Function} iteratee The function invoked per iteration.
 * @returns {Object} Returns `object`.
 */
function baseForOwn(object, iteratee) {
  return object && baseFor(object, iteratee, keys);
}

/**
 * Creates a `baseEach` or `baseEachRight` function.
 *
 * @private
 * @param {Function} eachFunc The function to iterate over a collection.
 * @param {boolean} [fromRight] Specify iterating from right to left.
 * @returns {Function} Returns the new base function.
 */
function createBaseEach(eachFunc, fromRight) {
  return function(collection, iteratee) {
    if (collection == null) {
      return collection;
    }
    if (!isArrayLike(collection)) {
      return eachFunc(collection, iteratee);
    }
    var length = collection.length,
        index = fromRight ? length : -1,
        iterable = Object(collection);

    while ((fromRight ? index-- : ++index < length)) {
      if (iteratee(iterable[index], index, iterable) === false) {
        break;
      }
    }
    return collection;
  };
}

/**
 * The base implementation of `_.forEach` without support for iteratee shorthands.
 *
 * @private
 * @param {Array|Object} collection The collection to iterate over.
 * @param {Function} iteratee The function invoked per iteration.
 * @returns {Array|Object} Returns `collection`.
 */
var baseEach = createBaseEach(baseForOwn);

/**
 * The base implementation of `_.map` without support for iteratee shorthands.
 *
 * @private
 * @param {Array|Object} collection The collection to iterate over.
 * @param {Function} iteratee The function invoked per iteration.
 * @returns {Array} Returns the new mapped array.
 */
function baseMap(collection, iteratee) {
  var index = -1,
      result = isArrayLike(collection) ? Array(collection.length) : [];

  baseEach(collection, function(value, key, collection) {
    result[++index] = iteratee(value, key, collection);
  });
  return result;
}

/** `Object#toString` result references. */
var mapTag$3 = '[object Map]',
    setTag$3 = '[object Set]';

/** Used for built-in method references. */
var objectProto$c = Object.prototype;

/** Used to check objects for own properties. */
var hasOwnProperty$b = objectProto$c.hasOwnProperty;

/**
 * Checks if `value` is an empty object, collection, map, or set.
 *
 * Objects are considered empty if they have no own enumerable string keyed
 * properties.
 *
 * Array-like values such as `arguments` objects, arrays, buffers, strings, or
 * jQuery-like collections are considered empty if they have a `length` of `0`.
 * Similarly, maps and sets are considered empty if they have a `size` of `0`.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is empty, else `false`.
 * @example
 *
 * _.isEmpty(null);
 * // => true
 *
 * _.isEmpty(true);
 * // => true
 *
 * _.isEmpty(1);
 * // => true
 *
 * _.isEmpty([1, 2, 3]);
 * // => false
 *
 * _.isEmpty({ 'a': 1 });
 * // => false
 */
function isEmpty(value) {
  if (value == null) {
    return true;
  }
  if (isArrayLike(value) &&
      (isArray$1(value) || typeof value == 'string' || typeof value.splice == 'function' ||
        isBuffer(value) || isTypedArray(value) || isArguments(value))) {
    return !value.length;
  }
  var tag = getTag$1(value);
  if (tag == mapTag$3 || tag == setTag$3) {
    return !value.size;
  }
  if (isPrototype(value)) {
    return !baseKeys(value).length;
  }
  for (var key in value) {
    if (hasOwnProperty$b.call(value, key)) {
      return false;
    }
  }
  return true;
}

/**
 * The base implementation of `_.sortBy` which uses `comparer` to define the
 * sort order of `array` and replaces criteria objects with their corresponding
 * values.
 *
 * @private
 * @param {Array} array The array to sort.
 * @param {Function} comparer The function to define sort order.
 * @returns {Array} Returns `array`.
 */
function baseSortBy(array, comparer) {
  var length = array.length;

  array.sort(comparer);
  while (length--) {
    array[length] = array[length].value;
  }
  return array;
}

/**
 * Compares values to sort them in ascending order.
 *
 * @private
 * @param {*} value The value to compare.
 * @param {*} other The other value to compare.
 * @returns {number} Returns the sort order indicator for `value`.
 */
function compareAscending(value, other) {
  if (value !== other) {
    var valIsDefined = value !== undefined,
        valIsNull = value === null,
        valIsReflexive = value === value,
        valIsSymbol = isSymbol(value);

    var othIsDefined = other !== undefined,
        othIsNull = other === null,
        othIsReflexive = other === other,
        othIsSymbol = isSymbol(other);

    if ((!othIsNull && !othIsSymbol && !valIsSymbol && value > other) ||
        (valIsSymbol && othIsDefined && othIsReflexive && !othIsNull && !othIsSymbol) ||
        (valIsNull && othIsDefined && othIsReflexive) ||
        (!valIsDefined && othIsReflexive) ||
        !valIsReflexive) {
      return 1;
    }
    if ((!valIsNull && !valIsSymbol && !othIsSymbol && value < other) ||
        (othIsSymbol && valIsDefined && valIsReflexive && !valIsNull && !valIsSymbol) ||
        (othIsNull && valIsDefined && valIsReflexive) ||
        (!othIsDefined && valIsReflexive) ||
        !othIsReflexive) {
      return -1;
    }
  }
  return 0;
}

/**
 * Used by `_.orderBy` to compare multiple properties of a value to another
 * and stable sort them.
 *
 * If `orders` is unspecified, all values are sorted in ascending order. Otherwise,
 * specify an order of "desc" for descending or "asc" for ascending sort order
 * of corresponding values.
 *
 * @private
 * @param {Object} object The object to compare.
 * @param {Object} other The other object to compare.
 * @param {boolean[]|string[]} orders The order to sort by for each property.
 * @returns {number} Returns the sort order indicator for `object`.
 */
function compareMultiple(object, other, orders) {
  var index = -1,
      objCriteria = object.criteria,
      othCriteria = other.criteria,
      length = objCriteria.length,
      ordersLength = orders.length;

  while (++index < length) {
    var result = compareAscending(objCriteria[index], othCriteria[index]);
    if (result) {
      if (index >= ordersLength) {
        return result;
      }
      var order = orders[index];
      return result * (order == 'desc' ? -1 : 1);
    }
  }
  // Fixes an `Array#sort` bug in the JS engine embedded in Adobe applications
  // that causes it, under certain circumstances, to provide the same value for
  // `object` and `other`. See https://github.com/jashkenas/underscore/pull/1247
  // for more details.
  //
  // This also ensures a stable sort in V8 and other engines.
  // See https://bugs.chromium.org/p/v8/issues/detail?id=90 for more details.
  return object.index - other.index;
}

/**
 * The base implementation of `_.orderBy` without param guards.
 *
 * @private
 * @param {Array|Object} collection The collection to iterate over.
 * @param {Function[]|Object[]|string[]} iteratees The iteratees to sort by.
 * @param {string[]} orders The sort orders of `iteratees`.
 * @returns {Array} Returns the new sorted array.
 */
function baseOrderBy(collection, iteratees, orders) {
  var index = -1;
  iteratees = arrayMap(iteratees.length ? iteratees : [identity$1], baseUnary(baseIteratee));

  var result = baseMap(collection, function(value, key, collection) {
    var criteria = arrayMap(iteratees, function(iteratee) {
      return iteratee(value);
    });
    return { 'criteria': criteria, 'index': ++index, 'value': value };
  });

  return baseSortBy(result, function(object, other) {
    return compareMultiple(object, other, orders);
  });
}

/**
 * This method is like `_.sortBy` except that it allows specifying the sort
 * orders of the iteratees to sort by. If `orders` is unspecified, all values
 * are sorted in ascending order. Otherwise, specify an order of "desc" for
 * descending or "asc" for ascending sort order of corresponding values.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Collection
 * @param {Array|Object} collection The collection to iterate over.
 * @param {Array[]|Function[]|Object[]|string[]} [iteratees=[_.identity]]
 *  The iteratees to sort by.
 * @param {string[]} [orders] The sort orders of `iteratees`.
 * @param- {Object} [guard] Enables use as an iteratee for methods like `_.reduce`.
 * @returns {Array} Returns the new sorted array.
 * @example
 *
 * var users = [
 *   { 'user': 'fred',   'age': 48 },
 *   { 'user': 'barney', 'age': 34 },
 *   { 'user': 'fred',   'age': 40 },
 *   { 'user': 'barney', 'age': 36 }
 * ];
 *
 * // Sort by `user` in ascending order and by `age` in descending order.
 * _.orderBy(users, ['user', 'age'], ['asc', 'desc']);
 * // => objects for [['barney', 36], ['barney', 34], ['fred', 48], ['fred', 40]]
 */
function orderBy(collection, iteratees, orders, guard) {
  if (collection == null) {
    return [];
  }
  if (!isArray$1(iteratees)) {
    iteratees = iteratees == null ? [] : [iteratees];
  }
  orders = guard ? undefined : orders;
  if (!isArray$1(orders)) {
    orders = orders == null ? [] : [orders];
  }
  return baseOrderBy(collection, iteratees, orders);
}

//

var script$c = {
	data() {
		return {
			currentTab: '',
			sortKey: 'release_date',
			sortOrder: 'desc',
			title: '',
			image: '',
			type: '',
			link: '',
			head: null,
			body: null
		}
	},
	computed: {
		showTable() {
			if (this.body) {
				if (this.sortKey == 'nb_song')
					return orderBy(
						this.body[this.currentTab],
						function (o) {
							return new Number(o.nb_song)
						},
						this.sortOrder
					)
				else return orderBy(this.body[this.currentTab], this.sortKey, this.sortOrder)
			} else return []
		}
	},
	mounted() {
		socket.on('show_artist', this.showArtist);

		EventBus.$on('artistTab:updateSelected', this.updateSelected);
		EventBus.$on('artistTab:changeTab', this.changeTab);
	},
	methods: {
		reset() {
			this.title = 'Loading...';
			this.image = '';
			this.type = '';
			this.currentTab = '';
			this.sortKey = 'release_date';
			this.sortOrder = 'desc';
			this.link = '';
			this.head = [];
			this.body = null;
		},
		addToQueue(e) {
			e.stopPropagation();
			Downloads.sendAddToQueue(e.currentTarget.dataset.link);
		},
		sortBy(key) {
			if (key == this.sortKey) {
				this.sortOrder = this.sortOrder == 'asc' ? 'desc' : 'asc';
			} else {
				this.sortKey = key;
				this.sortOrder = 'asc';
			}
		},
		changeTab(tab) {
			this.currentTab = tab;
		},
		updateSelected() {
			// Last tab opened logic
		},
		checkNewRelease(date) {
			let g1 = new Date();
			let g2 = new Date(date);
			g2.setDate(g2.getDate() + 3);
			g1.setHours(0, 0, 0, 0);

			return g1.getTime() <= g2.getTime()
		},
		showArtist(data) {
			this.reset();

			const { name, picture_xl, id, releases } = data;

			this.title = name;
			this.image = picture_xl;
			this.type = 'Artist';
			this.link = `https://www.deezer.com/artist/${id}`;
			if (this.currentTab === '') this.currentTab = Object.keys(releases)[0];
			this.sortKey = 'release_date';
			this.sortOrder = 'desc';
			this.head = [
				{ title: this.$tc('globals.listTabs.title', 1), sortKey: 'title' },
				{ title: this.$t('globals.listTabs.releaseDate'), sortKey: 'release_date' },
				{ title: this.$tc('globals.listTabs.track', 2), sortKey: 'nb_song' },
				{ title: '', width: '32px' }
			];
			if (isEmpty(releases)) {
				this.body = null;
			} else {
				this.body = releases;
			}
		}
	}
};

/* script */
const __vue_script__$c = script$c;

/* template */
var __vue_render__$d = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c(
    "div",
    {
      ref: "root",
      staticClass: "relative image_header",
      attrs: { id: "artist_tab" }
    },
    [
      _c(
        "header",
        {
          staticClass: "inline-flex",
          style: {
            "background-image":
              "linear-gradient(to bottom, transparent 0%, var(--main-background) 100%), url('" +
              _vm.image +
              "')"
          }
        },
        [
          _c("h1", { staticClass: "m-0" }, [_vm._v(_vm._s(_vm.title))]),
          _vm._v(" "),
          _c(
            "div",
            {
              staticClass: "fab right",
              attrs: {
                role: "button",
                "aria-label": "download",
                "data-link": _vm.link
              },
              on: {
                click: function($event) {
                  $event.stopPropagation();
                  return _vm.addToQueue($event)
                }
              }
            },
            [
              _c(
                "i",
                {
                  staticClass: "material-icons",
                  attrs: { title: _vm.$t("globals.download_hint") }
                },
                [_vm._v("get_app")]
              )
            ]
          )
        ]
      ),
      _vm._v(" "),
      _c(
        "div",
        { staticClass: "my-4" },
        _vm._l(_vm.body, function(item, name) {
          return _c(
            "button",
            {
              key: name,
              staticClass: "mr-2 btn bg-background-main",
              class: { "btn-primary": name === _vm.currentTab },
              attrs: { href: "#artist_" + name },
              on: {
                click: function($event) {
                  return _vm.changeTab(name)
                }
              }
            },
            [
              _vm._v(
                "\n\t\t\t" +
                  _vm._s(_vm.$tc("globals.listTabs." + name, 2)) +
                  "\n\t\t"
              )
            ]
          )
        }),
        0
      ),
      _vm._v(" "),
      _c("table", { staticClass: "table" }, [
        _c("thead", [
          _c(
            "tr",
            _vm._l(_vm.head, function(data) {
              return _c(
                "th",
                {
                  class: {
                    "sort-asc":
                      data.sortKey == _vm.sortKey && _vm.sortOrder == "asc",
                    "sort-desc":
                      data.sortKey == _vm.sortKey && _vm.sortOrder == "desc",
                    sortable: data.sortKey,
                    clickable: data.sortKey
                  },
                  style: { width: data.width ? data.width : "auto" },
                  on: {
                    click: function($event) {
                      data.sortKey ? _vm.sortBy(data.sortKey) : null;
                    }
                  }
                },
                [_vm._v("\n\t\t\t\t\t" + _vm._s(data.title) + "\n\t\t\t\t")]
              )
            }),
            0
          )
        ]),
        _vm._v(" "),
        _c(
          "tbody",
          _vm._l(_vm.showTable, function(release) {
            return _c(
              "tr",
              { key: release.id },
              [
                _c(
                  "router-link",
                  {
                    staticClass: "inline-flex clickable",
                    attrs: {
                      tag: "td",
                      to: { name: "Album", params: { id: release.id } }
                    }
                  },
                  [
                    _c("img", {
                      staticClass: "rounded coverart",
                      staticStyle: {
                        "margin-right": "16px",
                        width: "56px",
                        height: "56px"
                      },
                      attrs: { src: release.cover_small }
                    }),
                    _vm._v(" "),
                    release.explicit_lyrics
                      ? _c(
                          "i",
                          { staticClass: "material-icons explicit_icon" },
                          [_vm._v(" explicit ")]
                        )
                      : _vm._e(),
                    _vm._v(
                      "\n\t\t\t\t\t" + _vm._s(release.title) + "\n\t\t\t\t\t"
                    ),
                    _vm.checkNewRelease(release.release_date)
                      ? _c(
                          "i",
                          {
                            staticClass: "material-icons",
                            staticStyle: { color: "#ff7300" }
                          },
                          [_vm._v("\n\t\t\t\t\t\tfiber_new\n\t\t\t\t\t")]
                        )
                      : _vm._e()
                  ]
                ),
                _vm._v(" "),
                _c("td", [_vm._v(_vm._s(release.release_date))]),
                _vm._v(" "),
                _c("td", [_vm._v(_vm._s(release.nb_song))]),
                _vm._v(" "),
                _c(
                  "td",
                  {
                    staticClass: "clickable",
                    attrs: { "data-link": release.link },
                    on: {
                      click: function($event) {
                        $event.stopPropagation();
                        return _vm.addToQueue($event)
                      }
                    }
                  },
                  [
                    _c(
                      "i",
                      {
                        staticClass: "material-icons",
                        attrs: { title: _vm.$t("globals.download_hint") }
                      },
                      [_vm._v(" file_download ")]
                    )
                  ]
                )
              ],
              1
            )
          }),
          0
        )
      ])
    ]
  )
};
var __vue_staticRenderFns__$d = [];
__vue_render__$d._withStripped = true;

  /* style */
  const __vue_inject_styles__$d = undefined;
  /* scoped */
  const __vue_scope_id__$d = undefined;
  /* module identifier */
  const __vue_module_identifier__$d = undefined;
  /* functional template */
  const __vue_is_functional_template__$d = false;
  /* style inject */
  
  /* style inject SSR */
  

  
  var Artist = normalizeComponent_1(
    { render: __vue_render__$d, staticRenderFns: __vue_staticRenderFns__$d },
    __vue_inject_styles__$d,
    __vue_script__$c,
    __vue_scope_id__$d,
    __vue_is_functional_template__$d,
    __vue_module_identifier__$d,
    undefined,
    undefined
  );

let chartsData = {};
let cached$1 = false;

function getChartsData() {
	if (cached$1) {
		return chartsData
	} else {
		socket.emit('get_charts_data');

		return new Promise((resolve, reject) => {
			socket.on('init_charts', data => {
				chartsData = data;
				cached$1 = true;

				socket.off('init_charts');
				resolve(data);
			});
		})
	}
}

//

var script$d = {
	methods: {
		previewMouseEnter(e) {
			EventBus.$emit('trackPreview:previewMouseEnter', e);
		},
		previewMouseLeave(e) {
			EventBus.$emit('trackPreview:previewMouseLeave', e);
		}
	}
};

/* script */
const __vue_script__$d = script$d;

/* template */
var __vue_render__$e = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c(
    "i",
    {
      staticClass:
        "absolute top-0 right-0 flex items-center justify-center w-full h-full text-center transition-opacity duration-200 ease-in-out bg-black bg-opacity-50 rounded opacity-0 material-icons preview_controls",
      attrs: { title: _vm.$t("globals.play_hint") },
      on: {
        mouseenter: _vm.previewMouseEnter,
        mouseleave: _vm.previewMouseLeave
      }
    },
    [_vm._v("\n\tplay_arrow\n")]
  )
};
var __vue_staticRenderFns__$e = [];
__vue_render__$e._withStripped = true;

  /* style */
  const __vue_inject_styles__$e = undefined;
  /* scoped */
  const __vue_scope_id__$e = undefined;
  /* module identifier */
  const __vue_module_identifier__$e = undefined;
  /* functional template */
  const __vue_is_functional_template__$e = false;
  /* style inject */
  
  /* style inject SSR */
  

  
  var PreviewControls = normalizeComponent_1(
    { render: __vue_render__$e, staticRenderFns: __vue_staticRenderFns__$e },
    __vue_inject_styles__$e,
    __vue_script__$d,
    __vue_scope_id__$e,
    __vue_is_functional_template__$e,
    __vue_module_identifier__$e,
    undefined,
    undefined
  );

//

var script$e = {
	components: {
		PreviewControls
	},
	data() {
		return {
			country: '',
			id: 0,
			countries: [],
			chart: []
		}
	},
	computed: {
		worldwideRelease() {
			let worldwideRelease = this.countries.filter(country => {
				return country.title === 'Worldwide'
			});

			return worldwideRelease[0]
		}
	},
	async created() {
		socket.on('setChartTracks', this.setTracklist);
		this.$on('hook:destroyed', () => {
			socket.off('setChartTracks');
		});

		let chartsData = await getChartsData();
		let worldwideChart;

		chartsData = chartsData.filter(item => {
			if (item.title === 'Worldwide') {
				worldwideChart = item;
			}

			return item.title !== 'Worldwide'
		});
		chartsData.unshift(worldwideChart);

		this.initCharts(chartsData);
	},
	methods: {
		convertDuration,
		playPausePreview(e) {
			EventBus.$emit('trackPreview:playPausePreview', e);
		},
		addToQueue(e) {
			e.stopPropagation();
			sendAddToQueue(e.currentTarget.dataset.link);
		},
		getTrackList(event) {
			document.getElementById('content').scrollTo(0, 0);

			const {
				currentTarget: {
					dataset: { title }
				},
				currentTarget: {
					dataset: { id }
				}
			} = event;

			this.country = title;
			localStorage.setItem('chart', this.country);
			this.id = id;
			socket.emit('getChartTracks', this.id);
		},
		setTracklist(data) {
			this.chart = data;
		},
		onChangeCountry() {
			this.country = '';
			this.id = 0;
		},
		initCharts(chartsData) {
			this.countries = chartsData;
			this.country = localStorage.getItem('chart') || '';

			if (!this.country) return

			let i = 0;
			for (; i < this.countries.length; i++) {
				if (this.countries[i].title == this.country) break
			}

			if (i !== this.countries.length) {
				this.id = this.countries[i].id;
				socket.emit('getChartTracks', this.id);
			} else {
				this.country = '';
				localStorage.setItem('chart', this.country);
			}
		}
	}
};

/* script */
const __vue_script__$e = script$e;

/* template */
var __vue_render__$f = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", [
    _c("h1", { staticClass: "mb-8 text-5xl" }, [
      _vm._v(_vm._s(_vm.$t("charts.title")))
    ]),
    _vm._v(" "),
    _vm.country === ""
      ? _c("div", [
          _c(
            "div",
            { staticClass: "release_grid charts_grid" },
            _vm._l(_vm.countries, function(release) {
              return _c(
                "div",
                {
                  key: release.id,
                  staticClass: "w-40 h-40 release clickable",
                  attrs: {
                    role: "button",
                    "aria-label": release.title,
                    "data-title": release.title,
                    "data-id": release.id
                  },
                  on: { click: _vm.getTrackList }
                },
                [
                  _c("img", {
                    staticClass: "w-full rounded coverart",
                    attrs: { src: release.picture_medium }
                  })
                ]
              )
            }),
            0
          )
        ])
      : _c("div", [
          _c(
            "button",
            {
              staticClass: "btn btn-primary",
              on: { click: _vm.onChangeCountry }
            },
            [_vm._v(_vm._s(_vm.$t("charts.changeCountry")))]
          ),
          _vm._v(" "),
          _c(
            "button",
            {
              staticClass: "btn btn-primary",
              attrs: {
                "data-link": "https://www.deezer.com/playlist/" + _vm.id
              },
              on: {
                click: function($event) {
                  $event.stopPropagation();
                  return _vm.addToQueue($event)
                }
              }
            },
            [_vm._v("\n\t\t\t" + _vm._s(_vm.$t("charts.download")) + "\n\t\t")]
          ),
          _vm._v(" "),
          _c("table", { staticClass: "table table--charts" }, [
            _c(
              "tbody",
              _vm._l(_vm.chart, function(track) {
                return _c(
                  "tr",
                  { staticClass: "track_row" },
                  [
                    _c(
                      "td",
                      {
                        staticClass: "top-tracks-position",
                        class: { first: track.position === 1 }
                      },
                      [
                        _vm._v(
                          "\n\t\t\t\t\t\t" +
                            _vm._s(track.position) +
                            "\n\t\t\t\t\t"
                        )
                      ]
                    ),
                    _vm._v(" "),
                    _c("td", { staticClass: "table__icon table__icon--big" }, [
                      _c(
                        "a",
                        {
                          staticClass: "rounded",
                          class: { "single-cover": track.preview },
                          attrs: { href: "#", "data-preview": track.preview },
                          on: { click: _vm.playPausePreview }
                        },
                        [
                          track.preview ? _c("PreviewControls") : _vm._e(),
                          _vm._v(" "),
                          _c("img", {
                            staticClass: "rounded coverart",
                            attrs: { src: track.album.cover_small }
                          })
                        ],
                        1
                      )
                    ]),
                    _vm._v(" "),
                    _c("td", { staticClass: "table__cell--large breakline" }, [
                      _vm._v(
                        "\n\t\t\t\t\t\t" +
                          _vm._s(
                            track.title +
                              (track.title_version &&
                              track.title.indexOf(track.title_version) == -1
                                ? " " + track.title_version
                                : "")
                          ) +
                          "\n\t\t\t\t\t"
                      )
                    ]),
                    _vm._v(" "),
                    _c(
                      "router-link",
                      {
                        staticClass:
                          "table__cell table__cell--medium table__cell--center breakline clickable",
                        attrs: {
                          tag: "td",
                          to: {
                            name: "Artist",
                            params: { id: track.artist.id }
                          }
                        }
                      },
                      [
                        _vm._v(
                          "\n\t\t\t\t\t\t" +
                            _vm._s(track.artist.name) +
                            "\n\t\t\t\t\t"
                        )
                      ]
                    ),
                    _vm._v(" "),
                    _c(
                      "router-link",
                      {
                        staticClass:
                          "table__cell--medium table__cell--center breakline clickable",
                        attrs: {
                          tag: "td",
                          to: { name: "Album", params: { id: track.album.id } }
                        }
                      },
                      [
                        _vm._v(
                          "\n\t\t\t\t\t\t" +
                            _vm._s(track.album.title) +
                            "\n\t\t\t\t\t"
                        )
                      ]
                    ),
                    _vm._v(" "),
                    _c(
                      "td",
                      { staticClass: "table__cell--small table__cell--center" },
                      [
                        _vm._v(
                          "\n\t\t\t\t\t\t" +
                            _vm._s(_vm.convertDuration(track.duration)) +
                            "\n\t\t\t\t\t"
                        )
                      ]
                    ),
                    _vm._v(" "),
                    _c(
                      "td",
                      {
                        staticClass: "table__cell--download",
                        attrs: {
                          "data-link": track.link,
                          role: "button",
                          "aria-label": "download"
                        },
                        on: {
                          click: function($event) {
                            $event.stopPropagation();
                            return _vm.addToQueue($event)
                          }
                        }
                      },
                      [
                        _c(
                          "i",
                          {
                            staticClass: "material-icons",
                            attrs: { title: _vm.$t("globals.download_hint") }
                          },
                          [_vm._v("get_app")]
                        )
                      ]
                    )
                  ],
                  1
                )
              }),
              0
            )
          ])
        ])
  ])
};
var __vue_staticRenderFns__$f = [];
__vue_render__$f._withStripped = true;

  /* style */
  const __vue_inject_styles__$f = undefined;
  /* scoped */
  const __vue_scope_id__$f = undefined;
  /* module identifier */
  const __vue_module_identifier__$f = undefined;
  /* functional template */
  const __vue_is_functional_template__$f = false;
  /* style inject */
  
  /* style inject SSR */
  

  
  var Charts = normalizeComponent_1(
    { render: __vue_render__$f, staticRenderFns: __vue_staticRenderFns__$f },
    __vue_inject_styles__$f,
    __vue_script__$e,
    __vue_scope_id__$f,
    __vue_is_functional_template__$f,
    __vue_module_identifier__$f,
    undefined,
    undefined
  );

//

var script$f = {
	computed: {
		...mapGetters(['getErrors']),
		title() {
			return `${this.getErrors.artist} - ${this.getErrors.title}`
		},
		errors() {
			return this.getErrors.errors
		}
	}
};

/* script */
const __vue_script__$f = script$f;

/* template */
var __vue_render__$g = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", [
    _c("h1", { staticClass: "mb-8 text-5xl" }, [
      _vm._v(_vm._s(_vm.$t("errors.title", { name: _vm.title })))
    ]),
    _vm._v(" "),
    _c(
      "table",
      { staticClass: "table table--tracklist" },
      [
        _c("tr", [
          _c("th", [_vm._v("ID")]),
          _vm._v(" "),
          _c("th", [_vm._v(_vm._s(_vm.$tc("globals.listTabs.artist", 1)))]),
          _vm._v(" "),
          _c("th", [_vm._v(_vm._s(_vm.$tc("globals.listTabs.title", 1)))]),
          _vm._v(" "),
          _c("th", [_vm._v(_vm._s(_vm.$tc("globals.listTabs.error", 1)))])
        ]),
        _vm._v(" "),
        _vm._l(_vm.errors, function(error) {
          return _c("tr", { key: error.data.id }, [
            _c("td", [_vm._v(_vm._s(error.data.id))]),
            _vm._v(" "),
            _c("td", [_vm._v(_vm._s(error.data.artist))]),
            _vm._v(" "),
            _c("td", [_vm._v(_vm._s(error.data.title))]),
            _vm._v(" "),
            _c("td", [
              _vm._v(
                _vm._s(
                  error.errid
                    ? _vm.$t("errors.ids." + error.errid)
                    : error.message
                )
              )
            ])
          ])
        })
      ],
      2
    )
  ])
};
var __vue_staticRenderFns__$g = [];
__vue_render__$g._withStripped = true;

  /* style */
  const __vue_inject_styles__$g = function (inject) {
    if (!inject) return
    inject("data-v-53ed73a4_0", { source: "\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n", map: {"version":3,"sources":[],"names":[],"mappings":"","file":"Errors.vue"}, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$g = undefined;
  /* module identifier */
  const __vue_module_identifier__$g = undefined;
  /* functional template */
  const __vue_is_functional_template__$g = false;
  /* style inject SSR */
  

  
  var Errors = normalizeComponent_1(
    { render: __vue_render__$g, staticRenderFns: __vue_staticRenderFns__$g },
    __vue_inject_styles__$g,
    __vue_script__$f,
    __vue_scope_id__$g,
    __vue_is_functional_template__$g,
    __vue_module_identifier__$g,
    browser,
    undefined
  );

let favoritesData = {};
let cached$2 = false;

function getFavoritesData() {
	if (cached$2) {
		return favoritesData
	} else {
		socket.emit('get_favorites_data');

		return new Promise((resolve, reject) => {
			socket.on('init_favorites', data => {
				favoritesData = data;
				cached$2 = true;

				socket.off('init_favorites');
				resolve(data);
			});
		})
	}
}

//

var script$g = {
	components: {
		PreviewControls
	},
	data() {
		return {
			tracks: [],
			albums: [],
			artists: [],
			playlists: [],
			spotifyPlaylists: [],
			activeTab: 'playlist',
			tabs: ['playlist', 'album', 'artist', 'track']
		}
	},
	computed: {
		activeTabEmpty() {
			let toCheck = this.getActiveRelease();

			return toCheck.length === 0
		}
	},
	async created() {
		const favoritesData = await getFavoritesData();

		// TODO Change with isLoggedIn vuex getter
		if (Object.entries(favoritesData).length === 0) return

		this.setFavorites(favoritesData);
	},
	mounted() {
		socket.on('updated_userFavorites', this.updated_userFavorites);
		socket.on('updated_userSpotifyPlaylists', this.updated_userSpotifyPlaylists);
		socket.on('updated_userPlaylists', this.updated_userPlaylists);
		socket.on('updated_userAlbums', this.updated_userAlbums);
		socket.on('updated_userArtist', this.updated_userArtist);
		socket.on('updated_userTracks', this.updated_userTracks);

		this.$on('hook:destroyed', () => {
			socket.off('updated_userFavorites');
			socket.off('updated_userSpotifyPlaylists');
			socket.off('updated_userPlaylists');
			socket.off('updated_userAlbums');
			socket.off('updated_userArtist');
			socket.off('updated_userTracks');
		});
	},
	methods: {
		playPausePreview(e) {
			EventBus.$emit('trackPreview:playPausePreview', e);
		},
		convertDuration,
		downloadAllOfType() {
			try {
				let toDownload = this.getActiveRelease();

				if (this.activeTab === 'track') {
					let lovedTracks = this.getLovedTracksPlaylist();

					sendAddToQueue(lovedTracks.link);
				} else {
					sendAddToQueue(aggregateDownloadLinks(toDownload));
				}
			} catch (error) {
				console.error(error.message);
			}
		},
		addToQueue(e) {
			sendAddToQueue(e.currentTarget.dataset.link);
		},
		updated_userSpotifyPlaylists(data) {
			this.spotifyPlaylists = data;
		},
		updated_userPlaylists(data) {
			this.playlists = data;
		},
		updated_userAlbums(data) {
			this.albums = data;
		},
		updated_userArtist(data) {
			this.artists = data;
		},
		updated_userTracks(data) {
			this.tracks = data;
		},
		reloadTabs() {
			this.$refs.reloadButton.classList.add('spin');

			socket.emit('update_userFavorites');

			if (localStorage.getItem('spotifyUser')) {
				socket.emit('update_userSpotifyPlaylists', localStorage.getItem('spotifyUser'));
			}
		},
		updated_userFavorites(data) {
			this.setFavorites(data);

			// Removing animation class only when the animation has completed an iteration
			// Prevents animation ugly stutter
			this.$refs.reloadButton.addEventListener(
				'animationiteration',
				() => {
					this.$refs.reloadButton.classList.remove('spin');
					toast(this.$t('toasts.refreshFavs'), 'done', true);
				},
				{ once: true }
			);
		},
		setFavorites(data) {
			const { tracks, albums, artists, playlists } = data;

			this.tracks = tracks;
			this.albums = albums;
			this.artists = artists;
			this.playlists = playlists;
		},
		getActiveRelease(tab = this.activeTab) {
			let toDownload;

			switch (tab) {
				case 'playlist':
					toDownload = this.playlists;
					break
				case 'album':
					toDownload = this.albums;
					break
				case 'artist':
					toDownload = this.artists;
					break
				case 'track':
					toDownload = this.tracks;
					break
			}

			return toDownload
		},
		getLovedTracksPlaylist() {
			let lovedTracks = this.playlists.filter(playlist => {
				return playlist.is_loved_track
			});

			if (lovedTracks.length !== 0) {
				return lovedTracks[0]
			} else {
				throw new Error('No loved tracks playlist!')
			}
		}
	}
};

/* script */
const __vue_script__$g = script$g;

/* template */
var __vue_render__$h = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", [
    _c("h1", { staticClass: "mb-8 text-5xl" }, [
      _vm._v("\n\t\t" + _vm._s(_vm.$t("favorites.title")) + "\n\t\t"),
      _c(
        "div",
        {
          ref: "reloadButton",
          staticClass: "inline-block clickable reload-button",
          attrs: { role: "button", "aria-label": "reload" },
          on: { click: _vm.reloadTabs }
        },
        [_c("i", { staticClass: "material-icons" }, [_vm._v("sync")])]
      )
    ]),
    _vm._v(" "),
    _c(
      "ul",
      { staticClass: "section-tabs" },
      _vm._l(_vm.tabs, function(tab) {
        return _c(
          "li",
          {
            key: tab,
            staticClass: "section-tabs__tab favorites_tablinks",
            class: { active: _vm.activeTab === tab },
            on: {
              click: function($event) {
                _vm.activeTab = tab;
              }
            }
          },
          [
            _vm._v(
              "\n\t\t\t" +
                _vm._s(_vm.$tc("globals.listTabs." + tab, 2)) +
                "\n\t\t"
            )
          ]
        )
      }),
      0
    ),
    _vm._v(" "),
    !_vm.activeTabEmpty
      ? _c(
          "button",
          {
            staticClass: "btn btn-primary",
            staticStyle: { "margin-bottom": "2rem" },
            on: { click: _vm.downloadAllOfType }
          },
          [
            _vm._v(
              "\n\t\t" +
                _vm._s(
                  _vm.$t("globals.downloadAll", {
                    thing: _vm.$tc("globals.listTabs." + _vm.activeTab, 2)
                  })
                ) +
                "\n\t"
            )
          ]
        )
      : _vm._e(),
    _vm._v(" "),
    _c(
      "div",
      {
        staticClass: "favorites_tabcontent",
        class: { "favorites_tabcontent--active": _vm.activeTab === "playlist" }
      },
      [
        _vm.playlists.length == 0
          ? _c("div", [
              _c("h1", [_vm._v(_vm._s(_vm.$t("favorites.noPlaylists")))])
            ])
          : _vm._e(),
        _vm._v(" "),
        _vm.playlists.length > 0 || _vm.spotifyPlaylists > 0
          ? _c(
              "div",
              { staticClass: "release_grid" },
              [
                _vm._l(_vm.playlists, function(release) {
                  return _c(
                    "router-link",
                    {
                      key: release.id,
                      staticClass: "release clickable",
                      attrs: {
                        tag: "div",
                        to: { name: "Playlist", params: { id: release.id } }
                      }
                    },
                    [
                      _c("div", { staticClass: "cover_container" }, [
                        _c("img", {
                          staticClass: "rounded coverart",
                          attrs: {
                            "aria-hidden": "true",
                            src: release.picture_medium
                          }
                        }),
                        _vm._v(" "),
                        _c(
                          "button",
                          {
                            staticClass: "download_overlay",
                            attrs: {
                              role: "button",
                              "aria-label": "download",
                              "data-link": release.link,
                              tabindex: "0"
                            },
                            on: {
                              click: function($event) {
                                $event.stopPropagation();
                                return _vm.addToQueue($event)
                              }
                            }
                          },
                          [
                            _c(
                              "i",
                              {
                                staticClass: "material-icons",
                                attrs: {
                                  title: _vm.$t("globals.download_hint")
                                }
                              },
                              [_vm._v("get_app")]
                            )
                          ]
                        )
                      ]),
                      _vm._v(" "),
                      _c("p", { staticClass: "primary-text" }, [
                        _vm._v(_vm._s(release.title))
                      ]),
                      _vm._v(" "),
                      _c("p", { staticClass: "secondary-text" }, [
                        _vm._v(
                          "\n\t\t\t\t\t" +
                            _vm._s(
                              _vm.$t("globals.by", {
                                artist: release.creator.name
                              }) +
                                " - " +
                                _vm.$tc(
                                  "globals.listTabs.trackN",
                                  release.nb_tracks
                                )
                            ) +
                            "\n\t\t\t\t"
                        )
                      ])
                    ]
                  )
                }),
                _vm._v(" "),
                _vm._l(_vm.spotifyPlaylists, function(release) {
                  return _c(
                    "router-link",
                    {
                      key: release.id,
                      staticClass: "release clickable",
                      attrs: {
                        tag: "div",
                        to: {
                          name: "Spotify Playlist",
                          params: { id: release.id }
                        }
                      }
                    },
                    [
                      _c("div", { staticClass: "cover_container" }, [
                        _c("img", {
                          staticClass: "rounded coverart",
                          attrs: {
                            "aria-hidden": "true",
                            src: release.picture_medium
                          }
                        }),
                        _vm._v(" "),
                        _c(
                          "button",
                          {
                            staticClass: "download_overlay",
                            attrs: {
                              role: "button",
                              "aria-label": "download",
                              "data-link": release.link,
                              tabindex: "0"
                            },
                            on: {
                              click: function($event) {
                                $event.stopPropagation();
                                return _vm.addToQueue($event)
                              }
                            }
                          },
                          [
                            _c(
                              "i",
                              {
                                staticClass: "material-icons",
                                attrs: {
                                  title: _vm.$t("globals.download_hint")
                                }
                              },
                              [_vm._v("get_app")]
                            )
                          ]
                        )
                      ]),
                      _vm._v(" "),
                      _c("p", { staticClass: "primary-text" }, [
                        _vm._v(_vm._s(release.title))
                      ]),
                      _vm._v(" "),
                      _c("p", { staticClass: "secondary-text" }, [
                        _vm._v(
                          "\n\t\t\t\t\t" +
                            _vm._s(
                              _vm.$t("globals.by", {
                                artist: release.creator.name
                              }) +
                                " - " +
                                _vm.$tc(
                                  "globals.listTabs.trackN",
                                  release.nb_tracks
                                )
                            ) +
                            "\n\t\t\t\t"
                        )
                      ])
                    ]
                  )
                })
              ],
              2
            )
          : _vm._e()
      ]
    ),
    _vm._v(" "),
    _c(
      "div",
      {
        staticClass: "favorites_tabcontent",
        class: { "favorites_tabcontent--active": _vm.activeTab === "album" }
      },
      [
        _vm.albums.length == 0
          ? _c("div", [
              _c("h1", [_vm._v(_vm._s(_vm.$t("favorites.noAlbums")))])
            ])
          : _vm._e(),
        _vm._v(" "),
        _vm.albums.length > 0
          ? _c(
              "div",
              { staticClass: "release_grid" },
              _vm._l(_vm.albums, function(release) {
                return _c(
                  "router-link",
                  {
                    key: release.id,
                    staticClass: "release clickable",
                    attrs: {
                      tag: "div",
                      to: { name: "Album", params: { id: release.id } }
                    }
                  },
                  [
                    _c("div", { staticClass: "cover_container" }, [
                      _c("img", {
                        staticClass: "rounded coverart",
                        attrs: {
                          "aria-hidden": "true",
                          src: release.cover_medium
                        }
                      }),
                      _vm._v(" "),
                      _c(
                        "button",
                        {
                          staticClass: "download_overlay",
                          attrs: {
                            role: "button",
                            "aria-label": "download",
                            "data-link": release.link,
                            tabindex: "0"
                          },
                          on: {
                            click: function($event) {
                              $event.stopPropagation();
                              return _vm.addToQueue($event)
                            }
                          }
                        },
                        [
                          _c(
                            "i",
                            {
                              staticClass: "material-icons",
                              attrs: { title: _vm.$t("globals.download_hint") }
                            },
                            [_vm._v("get_app")]
                          )
                        ]
                      )
                    ]),
                    _vm._v(" "),
                    _c("p", { staticClass: "primary-text" }, [
                      _vm._v(_vm._s(release.title))
                    ]),
                    _vm._v(" "),
                    _c("p", { staticClass: "secondary-text" }, [
                      _vm._v(
                        _vm._s(
                          "" +
                            _vm.$t("globals.by", {
                              artist: release.artist.name
                            })
                        )
                      )
                    ])
                  ]
                )
              }),
              1
            )
          : _vm._e()
      ]
    ),
    _vm._v(" "),
    _c(
      "div",
      {
        staticClass: "favorites_tabcontent",
        class: { "favorites_tabcontent--active": _vm.activeTab === "artist" }
      },
      [
        _vm.artists.length == 0
          ? _c("div", [
              _c("h1", [_vm._v(_vm._s(_vm.$t("favorites.noArtists")))])
            ])
          : _vm._e(),
        _vm._v(" "),
        _vm.artists.length > 0
          ? _c(
              "div",
              { staticClass: "release_grid" },
              _vm._l(_vm.artists, function(release) {
                return _c(
                  "router-link",
                  {
                    key: release.id,
                    staticClass: "release clickable",
                    attrs: {
                      tag: "div",
                      to: { name: "Artist", params: { id: release.id } }
                    }
                  },
                  [
                    _c("div", { staticClass: "cover_container" }, [
                      _c("img", {
                        staticClass: "circle coverart",
                        attrs: {
                          "aria-hidden": "true",
                          src: release.picture_medium
                        }
                      }),
                      _vm._v(" "),
                      _c(
                        "button",
                        {
                          staticClass: "download_overlay",
                          attrs: {
                            role: "button",
                            "aria-label": "download",
                            "data-link": release.link,
                            tabindex: "0"
                          },
                          on: {
                            click: function($event) {
                              $event.stopPropagation();
                              return _vm.addToQueue($event)
                            }
                          }
                        },
                        [
                          _c(
                            "i",
                            {
                              staticClass: "material-icons",
                              attrs: { title: _vm.$t("globals.download_hint") }
                            },
                            [_vm._v("get_app")]
                          )
                        ]
                      )
                    ]),
                    _vm._v(" "),
                    _c("p", { staticClass: "primary-text" }, [
                      _vm._v(_vm._s(release.name))
                    ])
                  ]
                )
              }),
              1
            )
          : _vm._e()
      ]
    ),
    _vm._v(" "),
    _c(
      "div",
      {
        staticClass: "favorites_tabcontent",
        class: { "favorites_tabcontent--active": _vm.activeTab === "track" }
      },
      [
        _vm.tracks.length == 0
          ? _c("div", [
              _c("h1", [_vm._v(_vm._s(_vm.$t("favorites.noTracks")))])
            ])
          : _vm._e(),
        _vm._v(" "),
        _vm.tracks.length > 0
          ? _c(
              "table",
              { staticClass: "table" },
              _vm._l(_vm.tracks, function(track) {
                return _c(
                  "tr",
                  { staticClass: "track_row" },
                  [
                    _c(
                      "td",
                      {
                        staticClass: "top-tracks-position",
                        class: { first: track.position === 1 }
                      },
                      [
                        _vm._v(
                          "\n\t\t\t\t\t" + _vm._s(track.position) + "\n\t\t\t\t"
                        )
                      ]
                    ),
                    _vm._v(" "),
                    _c("td", [
                      _c(
                        "a",
                        {
                          staticClass: "rounded",
                          class: { "single-cover": !!track.preview },
                          attrs: { href: "#", "data-preview": track.preview },
                          on: { click: _vm.playPausePreview }
                        },
                        [
                          track.preview ? _c("PreviewControls") : _vm._e(),
                          _vm._v(" "),
                          _c("img", {
                            staticClass: "rounded coverart",
                            attrs: { src: track.album.cover_small }
                          })
                        ],
                        1
                      )
                    ]),
                    _vm._v(" "),
                    _c("td", { staticClass: "table__cell--large breakline" }, [
                      _vm._v(
                        "\n\t\t\t\t\t" +
                          _vm._s(
                            track.title +
                              (track.title_version &&
                              track.title.indexOf(track.title_version) == -1
                                ? " " + track.title_version
                                : "")
                          ) +
                          "\n\t\t\t\t"
                      )
                    ]),
                    _vm._v(" "),
                    _c(
                      "router-link",
                      {
                        staticClass:
                          "table__cell table__cell--medium table__cell--center breakline clickable",
                        attrs: {
                          tag: "td",
                          to: {
                            name: "Artist",
                            params: { id: track.artist.id }
                          }
                        }
                      },
                      [
                        _vm._v(
                          "\n\t\t\t\t\t" +
                            _vm._s(track.artist.name) +
                            "\n\t\t\t\t"
                        )
                      ]
                    ),
                    _vm._v(" "),
                    _c(
                      "router-link",
                      {
                        staticClass:
                          "table__cell--medium table__cell--center breakline clickable",
                        attrs: {
                          tag: "td",
                          to: { name: "Album", params: { id: track.album.id } }
                        }
                      },
                      [
                        _vm._v(
                          "\n\t\t\t\t\t" +
                            _vm._s(track.album.title) +
                            "\n\t\t\t\t"
                        )
                      ]
                    ),
                    _vm._v(" "),
                    _c("td", { staticClass: "table__cell--small" }, [
                      _vm._v(
                        "\n\t\t\t\t\t" +
                          _vm._s(_vm.convertDuration(track.duration)) +
                          "\n\t\t\t\t"
                      )
                    ]),
                    _vm._v(" "),
                    _c(
                      "td",
                      {
                        staticClass: "table__cell--download clickable",
                        attrs: {
                          "data-link": track.link,
                          role: "button",
                          "aria-label": "download"
                        },
                        on: {
                          click: function($event) {
                            $event.stopPropagation();
                            return _vm.addToQueue($event)
                          }
                        }
                      },
                      [
                        _c(
                          "div",
                          {
                            staticClass:
                              "table__cell-content table__cell-content--vertical-center"
                          },
                          [
                            _c(
                              "i",
                              {
                                staticClass: "material-icons",
                                attrs: {
                                  title: _vm.$t("globals.download_hint")
                                }
                              },
                              [_vm._v("get_app")]
                            )
                          ]
                        )
                      ]
                    )
                  ],
                  1
                )
              }),
              0
            )
          : _vm._e()
      ]
    )
  ])
};
var __vue_staticRenderFns__$h = [];
__vue_render__$h._withStripped = true;

  /* style */
  const __vue_inject_styles__$h = function (inject) {
    if (!inject) return
    inject("data-v-31d3f01c_0", { source: ".favorites_tabcontent[data-v-31d3f01c] {\n  display: none;\n}\n.favorites_tabcontent--active[data-v-31d3f01c] {\n    display: block;\n}\n.reload-button.spin i[data-v-31d3f01c] {\n  animation: spin 500ms infinite ease-out reverse;\n}\n\n/*# sourceMappingURL=Favorites.vue.map */", map: {"version":3,"sources":["C:\\Users\\Roberto\\Dev\\repos\\deemix-pyweb\\webui\\src\\components\\pages\\Favorites.vue","Favorites.vue"],"names":[],"mappings":"AA+NA;EACA,aAAA;AAAA;AAEA;IACA,cAAA;AAAA;AAIA;EAGA,+CAAA;AAAA;;AClOA,wCAAwC","file":"Favorites.vue","sourcesContent":["<template>\r\n\t<div>\r\n\t\t<h1 class=\"mb-8 text-5xl\">\r\n\t\t\t{{ $t('favorites.title') }}\r\n\t\t\t<div\r\n\t\t\t\t@click=\"reloadTabs\"\r\n\t\t\t\tclass=\"inline-block clickable reload-button\"\r\n\t\t\t\tref=\"reloadButton\"\r\n\t\t\t\trole=\"button\"\r\n\t\t\t\taria-label=\"reload\"\r\n\t\t\t>\r\n\t\t\t\t<i class=\"material-icons\">sync</i>\r\n\t\t\t</div>\r\n\t\t</h1>\r\n\r\n\t\t<ul class=\"section-tabs\">\r\n\t\t\t<li\r\n\t\t\t\tclass=\"section-tabs__tab favorites_tablinks\"\r\n\t\t\t\t:class=\"{ active: activeTab === tab }\"\r\n\t\t\t\t@click=\"activeTab = tab\"\r\n\t\t\t\tv-for=\"tab in tabs\"\r\n\t\t\t\t:key=\"tab\"\r\n\t\t\t>\r\n\t\t\t\t{{ $tc(`globals.listTabs.${tab}`, 2) }}\r\n\t\t\t</li>\r\n\t\t</ul>\r\n\r\n\t\t<button class=\"btn btn-primary\" v-if=\"!activeTabEmpty\" style=\"margin-bottom: 2rem\" @click=\"downloadAllOfType\">\r\n\t\t\t{{ $t('globals.downloadAll', { thing: $tc(`globals.listTabs.${activeTab}`, 2) }) }}\r\n\t\t</button>\r\n\r\n\t\t<div class=\"favorites_tabcontent\" :class=\"{ 'favorites_tabcontent--active': activeTab === 'playlist' }\">\r\n\t\t\t<div v-if=\"playlists.length == 0\">\r\n\t\t\t\t<h1>{{ $t('favorites.noPlaylists') }}</h1>\r\n\t\t\t</div>\r\n\t\t\t<div class=\"release_grid\" v-if=\"playlists.length > 0 || spotifyPlaylists > 0\">\r\n\t\t\t\t<router-link\r\n\t\t\t\t\ttag=\"div\"\r\n\t\t\t\t\tv-for=\"release in playlists\"\r\n\t\t\t\t\t:key=\"release.id\"\r\n\t\t\t\t\tclass=\"release clickable\"\r\n\t\t\t\t\t:to=\"{ name: 'Playlist', params: { id: release.id } }\"\r\n\t\t\t\t>\r\n\t\t\t\t\t<div class=\"cover_container\">\r\n\t\t\t\t\t\t<img aria-hidden=\"true\" class=\"rounded coverart\" :src=\"release.picture_medium\" />\r\n\t\t\t\t\t\t<button\r\n\t\t\t\t\t\t\trole=\"button\"\r\n\t\t\t\t\t\t\taria-label=\"download\"\r\n\t\t\t\t\t\t\t@click.stop=\"addToQueue\"\r\n\t\t\t\t\t\t\t:data-link=\"release.link\"\r\n\t\t\t\t\t\t\tclass=\"download_overlay\"\r\n\t\t\t\t\t\t\ttabindex=\"0\"\r\n\t\t\t\t\t\t>\r\n\t\t\t\t\t\t\t<i class=\"material-icons\" :title=\"$t('globals.download_hint')\">get_app</i>\r\n\t\t\t\t\t\t</button>\r\n\t\t\t\t\t</div>\r\n\t\t\t\t\t<p class=\"primary-text\">{{ release.title }}</p>\r\n\t\t\t\t\t<p class=\"secondary-text\">\r\n\t\t\t\t\t\t{{\r\n\t\t\t\t\t\t\t`${$t('globals.by', { artist: release.creator.name })} - ${$tc(\r\n\t\t\t\t\t\t\t\t'globals.listTabs.trackN',\r\n\t\t\t\t\t\t\t\trelease.nb_tracks\r\n\t\t\t\t\t\t\t)}`\r\n\t\t\t\t\t\t}}\r\n\t\t\t\t\t</p>\r\n\t\t\t\t</router-link>\r\n\t\t\t\t<router-link\r\n\t\t\t\t\ttag=\"div\"\r\n\t\t\t\t\tv-for=\"release in spotifyPlaylists\"\r\n\t\t\t\t\t:key=\"release.id\"\r\n\t\t\t\t\tclass=\"release clickable\"\r\n\t\t\t\t\t:to=\"{ name: 'Spotify Playlist', params: { id: release.id } }\"\r\n\t\t\t\t>\r\n\t\t\t\t\t<div class=\"cover_container\">\r\n\t\t\t\t\t\t<img aria-hidden=\"true\" class=\"rounded coverart\" :src=\"release.picture_medium\" />\r\n\t\t\t\t\t\t<button\r\n\t\t\t\t\t\t\trole=\"button\"\r\n\t\t\t\t\t\t\taria-label=\"download\"\r\n\t\t\t\t\t\t\t@click.stop=\"addToQueue\"\r\n\t\t\t\t\t\t\t:data-link=\"release.link\"\r\n\t\t\t\t\t\t\tclass=\"download_overlay\"\r\n\t\t\t\t\t\t\ttabindex=\"0\"\r\n\t\t\t\t\t\t>\r\n\t\t\t\t\t\t\t<i class=\"material-icons\" :title=\"$t('globals.download_hint')\">get_app</i>\r\n\t\t\t\t\t\t</button>\r\n\t\t\t\t\t</div>\r\n\t\t\t\t\t<p class=\"primary-text\">{{ release.title }}</p>\r\n\t\t\t\t\t<p class=\"secondary-text\">\r\n\t\t\t\t\t\t{{\r\n\t\t\t\t\t\t\t`${$t('globals.by', { artist: release.creator.name })} - ${$tc(\r\n\t\t\t\t\t\t\t\t'globals.listTabs.trackN',\r\n\t\t\t\t\t\t\t\trelease.nb_tracks\r\n\t\t\t\t\t\t\t)}`\r\n\t\t\t\t\t\t}}\r\n\t\t\t\t\t</p>\r\n\t\t\t\t</router-link>\r\n\t\t\t</div>\r\n\t\t</div>\r\n\r\n\t\t<div class=\"favorites_tabcontent\" :class=\"{ 'favorites_tabcontent--active': activeTab === 'album' }\">\r\n\t\t\t<div v-if=\"albums.length == 0\">\r\n\t\t\t\t<h1>{{ $t('favorites.noAlbums') }}</h1>\r\n\t\t\t</div>\r\n\t\t\t<div class=\"release_grid\" v-if=\"albums.length > 0\">\r\n\t\t\t\t<router-link\r\n\t\t\t\t\ttag=\"div\"\r\n\t\t\t\t\tclass=\"release clickable\"\r\n\t\t\t\t\tv-for=\"release in albums\"\r\n\t\t\t\t\t:key=\"release.id\"\r\n\t\t\t\t\t:to=\"{ name: 'Album', params: { id: release.id } }\"\r\n\t\t\t\t>\r\n\t\t\t\t\t<div class=\"cover_container\">\r\n\t\t\t\t\t\t<img aria-hidden=\"true\" class=\"rounded coverart\" :src=\"release.cover_medium\" />\r\n\t\t\t\t\t\t<button\r\n\t\t\t\t\t\t\trole=\"button\"\r\n\t\t\t\t\t\t\taria-label=\"download\"\r\n\t\t\t\t\t\t\t@click.stop=\"addToQueue\"\r\n\t\t\t\t\t\t\t:data-link=\"release.link\"\r\n\t\t\t\t\t\t\tclass=\"download_overlay\"\r\n\t\t\t\t\t\t\ttabindex=\"0\"\r\n\t\t\t\t\t\t>\r\n\t\t\t\t\t\t\t<i class=\"material-icons\" :title=\"$t('globals.download_hint')\">get_app</i>\r\n\t\t\t\t\t\t</button>\r\n\t\t\t\t\t</div>\r\n\t\t\t\t\t<p class=\"primary-text\">{{ release.title }}</p>\r\n\t\t\t\t\t<p class=\"secondary-text\">{{ `${$t('globals.by', { artist: release.artist.name })}` }}</p>\r\n\t\t\t\t</router-link>\r\n\t\t\t</div>\r\n\t\t</div>\r\n\r\n\t\t<div class=\"favorites_tabcontent\" :class=\"{ 'favorites_tabcontent--active': activeTab === 'artist' }\">\r\n\t\t\t<div v-if=\"artists.length == 0\">\r\n\t\t\t\t<h1>{{ $t('favorites.noArtists') }}</h1>\r\n\t\t\t</div>\r\n\t\t\t<div class=\"release_grid\" v-if=\"artists.length > 0\">\r\n\t\t\t\t<router-link\r\n\t\t\t\t\ttag=\"div\"\r\n\t\t\t\t\tclass=\"release clickable\"\r\n\t\t\t\t\tv-for=\"release in artists\"\r\n\t\t\t\t\t:key=\"release.id\"\r\n\t\t\t\t\t:to=\"{ name: 'Artist', params: { id: release.id } }\"\r\n\t\t\t\t>\r\n\t\t\t\t\t<div class=\"cover_container\">\r\n\t\t\t\t\t\t<img aria-hidden=\"true\" class=\"circle coverart\" :src=\"release.picture_medium\" />\r\n\t\t\t\t\t\t<button\r\n\t\t\t\t\t\t\trole=\"button\"\r\n\t\t\t\t\t\t\taria-label=\"download\"\r\n\t\t\t\t\t\t\t@click.stop=\"addToQueue\"\r\n\t\t\t\t\t\t\t:data-link=\"release.link\"\r\n\t\t\t\t\t\t\tclass=\"download_overlay\"\r\n\t\t\t\t\t\t\ttabindex=\"0\"\r\n\t\t\t\t\t\t>\r\n\t\t\t\t\t\t\t<i class=\"material-icons\" :title=\"$t('globals.download_hint')\">get_app</i>\r\n\t\t\t\t\t\t</button>\r\n\t\t\t\t\t</div>\r\n\t\t\t\t\t<p class=\"primary-text\">{{ release.name }}</p>\r\n\t\t\t\t</router-link>\r\n\t\t\t</div>\r\n\t\t</div>\r\n\r\n\t\t<div class=\"favorites_tabcontent\" :class=\"{ 'favorites_tabcontent--active': activeTab === 'track' }\">\r\n\t\t\t<div v-if=\"tracks.length == 0\">\r\n\t\t\t\t<h1>{{ $t('favorites.noTracks') }}</h1>\r\n\t\t\t</div>\r\n\t\t\t<table v-if=\"tracks.length > 0\" class=\"table\">\r\n\t\t\t\t<tr v-for=\"track in tracks\" class=\"track_row\">\r\n\t\t\t\t\t<td class=\"top-tracks-position\" :class=\"{ first: track.position === 1 }\">\r\n\t\t\t\t\t\t{{ track.position }}\r\n\t\t\t\t\t</td>\r\n\t\t\t\t\t<td>\r\n\t\t\t\t\t\t<a\r\n\t\t\t\t\t\t\thref=\"#\"\r\n\t\t\t\t\t\t\tclass=\"rounded\"\r\n\t\t\t\t\t\t\t:class=\"{ 'single-cover': !!track.preview }\"\r\n\t\t\t\t\t\t\t@click=\"playPausePreview\"\r\n\t\t\t\t\t\t\t:data-preview=\"track.preview\"\r\n\t\t\t\t\t\t>\r\n\t\t\t\t\t\t\t<PreviewControls v-if=\"track.preview\" />\r\n\r\n\t\t\t\t\t\t\t<img class=\"rounded coverart\" :src=\"track.album.cover_small\" />\r\n\t\t\t\t\t\t</a>\r\n\t\t\t\t\t</td>\r\n\t\t\t\t\t<td class=\"table__cell--large breakline\">\r\n\t\t\t\t\t\t{{\r\n\t\t\t\t\t\t\ttrack.title +\r\n\t\t\t\t\t\t\t(track.title_version && track.title.indexOf(track.title_version) == -1 ? ' ' + track.title_version : '')\r\n\t\t\t\t\t\t}}\r\n\t\t\t\t\t</td>\r\n\t\t\t\t\t<router-link\r\n\t\t\t\t\t\ttag=\"td\"\r\n\t\t\t\t\t\tclass=\"table__cell table__cell--medium table__cell--center breakline clickable\"\r\n\t\t\t\t\t\t:to=\"{ name: 'Artist', params: { id: track.artist.id } }\"\r\n\t\t\t\t\t>\r\n\t\t\t\t\t\t{{ track.artist.name }}\r\n\t\t\t\t\t</router-link>\r\n\t\t\t\t\t<router-link\r\n\t\t\t\t\t\ttag=\"td\"\r\n\t\t\t\t\t\tclass=\"table__cell--medium table__cell--center breakline clickable\"\r\n\t\t\t\t\t\t:to=\"{ name: 'Album', params: { id: track.album.id } }\"\r\n\t\t\t\t\t>\r\n\t\t\t\t\t\t{{ track.album.title }}\r\n\t\t\t\t\t</router-link>\r\n\t\t\t\t\t<td class=\"table__cell--small\">\r\n\t\t\t\t\t\t{{ convertDuration(track.duration) }}\r\n\t\t\t\t\t</td>\r\n\t\t\t\t\t<td\r\n\t\t\t\t\t\tclass=\"table__cell--download clickable\"\r\n\t\t\t\t\t\t@click.stop=\"addToQueue\"\r\n\t\t\t\t\t\t:data-link=\"track.link\"\r\n\t\t\t\t\t\trole=\"button\"\r\n\t\t\t\t\t\taria-label=\"download\"\r\n\t\t\t\t\t>\r\n\t\t\t\t\t\t<div class=\"table__cell-content table__cell-content--vertical-center\">\r\n\t\t\t\t\t\t\t<i class=\"material-icons\" :title=\"$t('globals.download_hint')\">get_app</i>\r\n\t\t\t\t\t\t</div>\r\n\t\t\t\t\t</td>\r\n\t\t\t\t</tr>\r\n\t\t\t</table>\r\n\t\t</div>\r\n\t</div>\r\n</template>\r\n\r\n<style lang=\"scss\" scoped>\r\n.favorites_tabcontent {\r\n\tdisplay: none;\r\n\r\n\t&--active {\r\n\t\tdisplay: block;\r\n\t}\r\n}\r\n\r\n.reload-button {\r\n\t&.spin {\r\n\t\ti {\r\n\t\t\tanimation: spin 500ms infinite ease-out reverse;\r\n\t\t}\r\n\t}\r\n}\r\n</style>\r\n\r\n<script>\r\nimport { socket } from '@/utils/socket'\r\nimport { sendAddToQueue, aggregateDownloadLinks } from '@/utils/downloads'\r\nimport { convertDuration } from '@/utils/utils'\r\nimport { toast } from '@/utils/toasts'\r\nimport { getFavoritesData } from '@/data/favorites'\r\n\r\nimport EventBus from '@/utils/EventBus'\r\nimport PreviewControls from '@components/globals/PreviewControls.vue'\r\n\r\nexport default {\r\n\tcomponents: {\r\n\t\tPreviewControls\r\n\t},\r\n\tdata() {\r\n\t\treturn {\r\n\t\t\ttracks: [],\r\n\t\t\talbums: [],\r\n\t\t\tartists: [],\r\n\t\t\tplaylists: [],\r\n\t\t\tspotifyPlaylists: [],\r\n\t\t\tactiveTab: 'playlist',\r\n\t\t\ttabs: ['playlist', 'album', 'artist', 'track']\r\n\t\t}\r\n\t},\r\n\tcomputed: {\r\n\t\tactiveTabEmpty() {\r\n\t\t\tlet toCheck = this.getActiveRelease()\r\n\r\n\t\t\treturn toCheck.length === 0\r\n\t\t}\r\n\t},\r\n\tasync created() {\r\n\t\tconst favoritesData = await getFavoritesData()\r\n\r\n\t\t// TODO Change with isLoggedIn vuex getter\r\n\t\tif (Object.entries(favoritesData).length === 0) return\r\n\r\n\t\tthis.setFavorites(favoritesData)\r\n\t},\r\n\tmounted() {\r\n\t\tsocket.on('updated_userFavorites', this.updated_userFavorites)\r\n\t\tsocket.on('updated_userSpotifyPlaylists', this.updated_userSpotifyPlaylists)\r\n\t\tsocket.on('updated_userPlaylists', this.updated_userPlaylists)\r\n\t\tsocket.on('updated_userAlbums', this.updated_userAlbums)\r\n\t\tsocket.on('updated_userArtist', this.updated_userArtist)\r\n\t\tsocket.on('updated_userTracks', this.updated_userTracks)\r\n\r\n\t\tthis.$on('hook:destroyed', () => {\r\n\t\t\tsocket.off('updated_userFavorites')\r\n\t\t\tsocket.off('updated_userSpotifyPlaylists')\r\n\t\t\tsocket.off('updated_userPlaylists')\r\n\t\t\tsocket.off('updated_userAlbums')\r\n\t\t\tsocket.off('updated_userArtist')\r\n\t\t\tsocket.off('updated_userTracks')\r\n\t\t})\r\n\t},\r\n\tmethods: {\r\n\t\tplayPausePreview(e) {\r\n\t\t\tEventBus.$emit('trackPreview:playPausePreview', e)\r\n\t\t},\r\n\t\tconvertDuration,\r\n\t\tdownloadAllOfType() {\r\n\t\t\ttry {\r\n\t\t\t\tlet toDownload = this.getActiveRelease()\r\n\r\n\t\t\t\tif (this.activeTab === 'track') {\r\n\t\t\t\t\tlet lovedTracks = this.getLovedTracksPlaylist()\r\n\r\n\t\t\t\t\tsendAddToQueue(lovedTracks.link)\r\n\t\t\t\t} else {\r\n\t\t\t\t\tsendAddToQueue(aggregateDownloadLinks(toDownload))\r\n\t\t\t\t}\r\n\t\t\t} catch (error) {\r\n\t\t\t\tconsole.error(error.message)\r\n\t\t\t}\r\n\t\t},\r\n\t\taddToQueue(e) {\r\n\t\t\tsendAddToQueue(e.currentTarget.dataset.link)\r\n\t\t},\r\n\t\tupdated_userSpotifyPlaylists(data) {\r\n\t\t\tthis.spotifyPlaylists = data\r\n\t\t},\r\n\t\tupdated_userPlaylists(data) {\r\n\t\t\tthis.playlists = data\r\n\t\t},\r\n\t\tupdated_userAlbums(data) {\r\n\t\t\tthis.albums = data\r\n\t\t},\r\n\t\tupdated_userArtist(data) {\r\n\t\t\tthis.artists = data\r\n\t\t},\r\n\t\tupdated_userTracks(data) {\r\n\t\t\tthis.tracks = data\r\n\t\t},\r\n\t\treloadTabs() {\r\n\t\t\tthis.$refs.reloadButton.classList.add('spin')\r\n\r\n\t\t\tsocket.emit('update_userFavorites')\r\n\r\n\t\t\tif (localStorage.getItem('spotifyUser')) {\r\n\t\t\t\tsocket.emit('update_userSpotifyPlaylists', localStorage.getItem('spotifyUser'))\r\n\t\t\t}\r\n\t\t},\r\n\t\tupdated_userFavorites(data) {\r\n\t\t\tthis.setFavorites(data)\r\n\r\n\t\t\t// Removing animation class only when the animation has completed an iteration\r\n\t\t\t// Prevents animation ugly stutter\r\n\t\t\tthis.$refs.reloadButton.addEventListener(\r\n\t\t\t\t'animationiteration',\r\n\t\t\t\t() => {\r\n\t\t\t\t\tthis.$refs.reloadButton.classList.remove('spin')\r\n\t\t\t\t\ttoast(this.$t('toasts.refreshFavs'), 'done', true)\r\n\t\t\t\t},\r\n\t\t\t\t{ once: true }\r\n\t\t\t)\r\n\t\t},\r\n\t\tsetFavorites(data) {\r\n\t\t\tconst { tracks, albums, artists, playlists } = data\r\n\r\n\t\t\tthis.tracks = tracks\r\n\t\t\tthis.albums = albums\r\n\t\t\tthis.artists = artists\r\n\t\t\tthis.playlists = playlists\r\n\t\t},\r\n\t\tgetActiveRelease(tab = this.activeTab) {\r\n\t\t\tlet toDownload\r\n\r\n\t\t\tswitch (tab) {\r\n\t\t\t\tcase 'playlist':\r\n\t\t\t\t\ttoDownload = this.playlists\r\n\t\t\t\t\tbreak\r\n\t\t\t\tcase 'album':\r\n\t\t\t\t\ttoDownload = this.albums\r\n\t\t\t\t\tbreak\r\n\t\t\t\tcase 'artist':\r\n\t\t\t\t\ttoDownload = this.artists\r\n\t\t\t\t\tbreak\r\n\t\t\t\tcase 'track':\r\n\t\t\t\t\ttoDownload = this.tracks\r\n\t\t\t\t\tbreak\r\n\r\n\t\t\t\tdefault:\r\n\t\t\t\t\tbreak\r\n\t\t\t}\r\n\r\n\t\t\treturn toDownload\r\n\t\t},\r\n\t\tgetLovedTracksPlaylist() {\r\n\t\t\tlet lovedTracks = this.playlists.filter(playlist => {\r\n\t\t\t\treturn playlist.is_loved_track\r\n\t\t\t})\r\n\r\n\t\t\tif (lovedTracks.length !== 0) {\r\n\t\t\t\treturn lovedTracks[0]\r\n\t\t\t} else {\r\n\t\t\t\tthrow new Error('No loved tracks playlist!')\r\n\t\t\t}\r\n\t\t}\r\n\t}\r\n}\r\n</script>\r\n",".favorites_tabcontent {\n  display: none; }\n  .favorites_tabcontent--active {\n    display: block; }\n\n.reload-button.spin i {\n  animation: spin 500ms infinite ease-out reverse; }\n\n/*# sourceMappingURL=Favorites.vue.map */"]}, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$h = "data-v-31d3f01c";
  /* module identifier */
  const __vue_module_identifier__$h = undefined;
  /* functional template */
  const __vue_is_functional_template__$h = false;
  /* style inject SSR */
  

  
  var Favorites = normalizeComponent_1(
    { render: __vue_render__$h, staticRenderFns: __vue_staticRenderFns__$h },
    __vue_inject_styles__$h,
    __vue_script__$g,
    __vue_scope_id__$h,
    __vue_is_functional_template__$h,
    __vue_module_identifier__$h,
    browser,
    undefined
  );

let homeData = {};
let cached$3 = false;

function getHomeData() {
	if (cached$3) {
		return homeData
	} else {
		socket.emit('get_home_data');

		return new Promise((resolve, reject) => {
			socket.on('init_home', data => {
				homeData = data;
				cached$3 = true;

				socket.off('init_home');
				resolve(data);
			});
		})
	}
}

//

var script$h = {
	data() {
		return {
			playlists: [],
			albums: []
		}
	},
	async created() {
		const homeData = await getHomeData();

		this.initHome(homeData);
	},
	computed: {
		...mapGetters(['isLoggedIn'])
	},
	methods: {
		addToQueue(e) {
			sendAddToQueue(e.currentTarget.dataset.link);
		},
		initHome(data) {
			const {
				playlists: { data: playlistData },
				albums: { data: albumData }
			} = data;

			this.playlists = playlistData;
			this.albums = albumData;
		}
	}
};

/* script */
const __vue_script__$h = script$h;

/* template */
var __vue_render__$i = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", { attrs: { id: "home_tab" } }, [
    _c("h1", { staticClass: "mb-8 text-5xl" }, [
      _vm._v(_vm._s(_vm.$t("globals.welcome")))
    ]),
    _vm._v(" "),
    !_vm.isLoggedIn
      ? _c(
          "section",
          {
            ref: "notLogged",
            staticClass:
              "py-6 border-0 border-t border-solid border-grayscale-500"
          },
          [
            _c(
              "p",
              { staticClass: "mb-4", attrs: { id: "home_not_logged_text" } },
              [_vm._v(_vm._s(_vm.$t("home.needTologin")))]
            ),
            _vm._v(" "),
            _c(
              "router-link",
              {
                staticClass: "btn btn-primary",
                attrs: {
                  tag: "button",
                  name: "button",
                  to: { name: "Settings" }
                }
              },
              [
                _vm._v(
                  "\n\t\t\t" + _vm._s(_vm.$t("home.openSettings")) + "\n\t\t"
                )
              ]
            )
          ],
          1
        )
      : _vm._e(),
    _vm._v(" "),
    _vm.playlists.length
      ? _c(
          "section",
          {
            staticClass:
              "py-6 border-0 border-t border-solid border-grayscale-500"
          },
          [
            _c("h2", { staticClass: "mb-6 text-3xl" }, [
              _vm._v(_vm._s(_vm.$t("home.sections.popularPlaylists")))
            ]),
            _vm._v(" "),
            _c(
              "div",
              { staticClass: "release_grid" },
              _vm._l(_vm.playlists, function(release) {
                return _c(
                  "router-link",
                  {
                    key: release.id,
                    staticClass: "release clickable",
                    attrs: {
                      tag: "div",
                      to: { name: "Playlist", params: { id: release.id } },
                      tabindex: "0"
                    },
                    nativeOn: {
                      keyup: function($event) {
                        if (
                          !$event.type.indexOf("key") &&
                          _vm._k(
                            $event.keyCode,
                            "enter",
                            13,
                            $event.key,
                            "Enter"
                          )
                        ) {
                          return null
                        }
                        return _vm.$router.push({
                          name: "Playlist",
                          params: { id: release.id }
                        })
                      }
                    }
                  },
                  [
                    _c("div", { staticClass: "cover_container" }, [
                      _c("img", {
                        staticClass: "rounded coverart",
                        attrs: {
                          "aria-hidden": "true",
                          src: release.picture_medium
                        }
                      }),
                      _vm._v(" "),
                      _c(
                        "button",
                        {
                          staticClass: "download_overlay",
                          attrs: {
                            role: "button",
                            "aria-label": "download",
                            "data-link": release.link,
                            tabindex: "0"
                          },
                          on: {
                            click: function($event) {
                              $event.stopPropagation();
                              return _vm.addToQueue($event)
                            }
                          }
                        },
                        [
                          _c(
                            "i",
                            {
                              staticClass: "material-icons",
                              attrs: { title: _vm.$t("globals.download_hint") }
                            },
                            [_vm._v("get_app")]
                          )
                        ]
                      )
                    ]),
                    _vm._v(" "),
                    _c("p", { staticClass: "primary-text" }, [
                      _vm._v(_vm._s(release.title))
                    ]),
                    _vm._v(" "),
                    _c("p", { staticClass: "secondary-text" }, [
                      _vm._v(
                        "\n\t\t\t\t\t" +
                          _vm._s(
                            _vm.$t("globals.by", {
                              artist: release.user.name
                            }) +
                              " - " +
                              _vm.$tc(
                                "globals.listTabs.trackN",
                                release.nb_tracks
                              )
                          ) +
                          "\n\t\t\t\t"
                      )
                    ])
                  ]
                )
              }),
              1
            )
          ]
        )
      : _vm._e(),
    _vm._v(" "),
    _vm.albums.length
      ? _c(
          "section",
          {
            staticClass:
              "py-6 border-0 border-t border-solid border-grayscale-500"
          },
          [
            _c("h2", { staticClass: "mb-6 text-3xl" }, [
              _vm._v(_vm._s(_vm.$t("home.sections.popularAlbums")))
            ]),
            _vm._v(" "),
            _c(
              "div",
              { staticClass: "release_grid" },
              _vm._l(_vm.albums, function(release) {
                return _c(
                  "router-link",
                  {
                    key: release.id,
                    staticClass: "release clickable",
                    attrs: {
                      tag: "div",
                      to: { name: "Album", params: { id: release.id } },
                      "data-id": release.id,
                      tabindex: "0"
                    },
                    nativeOn: {
                      keyup: function($event) {
                        if (
                          !$event.type.indexOf("key") &&
                          _vm._k(
                            $event.keyCode,
                            "enter",
                            13,
                            $event.key,
                            "Enter"
                          )
                        ) {
                          return null
                        }
                        return _vm.$router.push({
                          name: "Album",
                          params: { id: release.id }
                        })
                      }
                    }
                  },
                  [
                    _c("div", { staticClass: "cover_container" }, [
                      _c("img", {
                        staticClass: "rounded coverart",
                        attrs: {
                          "aria-hidden": "true",
                          src: release.cover_medium
                        }
                      }),
                      _vm._v(" "),
                      _c(
                        "button",
                        {
                          staticClass: "download_overlay",
                          attrs: {
                            role: "button",
                            "aria-label": "download",
                            "data-link": release.link,
                            tabindex: "0"
                          },
                          on: {
                            click: function($event) {
                              $event.stopPropagation();
                              return _vm.addToQueue($event)
                            }
                          }
                        },
                        [
                          _c(
                            "i",
                            {
                              staticClass: "material-icons",
                              attrs: { title: _vm.$t("globals.download_hint") }
                            },
                            [_vm._v("get_app")]
                          )
                        ]
                      )
                    ]),
                    _vm._v(" "),
                    _c("p", { staticClass: "primary-text" }, [
                      _vm._v(_vm._s(release.title))
                    ]),
                    _vm._v(" "),
                    _c("p", { staticClass: "secondary-text" }, [
                      _vm._v(
                        _vm._s(
                          "" +
                            _vm.$t("globals.by", {
                              artist: release.artist.name
                            })
                        )
                      )
                    ])
                  ]
                )
              }),
              1
            )
          ]
        )
      : _vm._e()
  ])
};
var __vue_staticRenderFns__$i = [];
__vue_render__$i._withStripped = true;

  /* style */
  const __vue_inject_styles__$i = function (inject) {
    if (!inject) return
    inject("data-v-ba4c745c_0", { source: "\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n", map: {"version":3,"sources":[],"names":[],"mappings":"","file":"Home.vue"}, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$i = undefined;
  /* module identifier */
  const __vue_module_identifier__$i = undefined;
  /* functional template */
  const __vue_is_functional_template__$i = false;
  /* style inject SSR */
  

  
  var Home = normalizeComponent_1(
    { render: __vue_render__$i, staticRenderFns: __vue_staticRenderFns__$i },
    __vue_inject_styles__$i,
    __vue_script__$h,
    __vue_scope_id__$i,
    __vue_is_functional_template__$i,
    __vue_module_identifier__$i,
    browser,
    undefined
  );

const COUNTRIES = {
	AF: 'Afghanistan',
	AX: '\u00c5land Islands',
	AL: 'Albania',
	DZ: 'Algeria',
	AS: 'American Samoa',
	AD: 'Andorra',
	AO: 'Angola',
	AI: 'Anguilla',
	AQ: 'Antarctica',
	AG: 'Antigua and Barbuda',
	AR: 'Argentina',
	AM: 'Armenia',
	AW: 'Aruba',
	AU: 'Australia',
	AT: 'Austria',
	AZ: 'Azerbaijan',
	BS: 'Bahamas',
	BH: 'Bahrain',
	BD: 'Bangladesh',
	BB: 'Barbados',
	BY: 'Belarus',
	BE: 'Belgium',
	BZ: 'Belize',
	BJ: 'Benin',
	BM: 'Bermuda',
	BT: 'Bhutan',
	BO: 'Bolivia, Plurinational State of',
	BQ: 'Bonaire, Sint Eustatius and Saba',
	BA: 'Bosnia and Herzegovina',
	BW: 'Botswana',
	BV: 'Bouvet Island',
	BR: 'Brazil',
	IO: 'British Indian Ocean Territory',
	BN: 'Brunei Darussalam',
	BG: 'Bulgaria',
	BF: 'Burkina Faso',
	BI: 'Burundi',
	KH: 'Cambodia',
	CM: 'Cameroon',
	CA: 'Canada',
	CV: 'Cape Verde',
	KY: 'Cayman Islands',
	CF: 'Central African Republic',
	TD: 'Chad',
	CL: 'Chile',
	CN: 'China',
	CX: 'Christmas Island',
	CC: 'Cocos (Keeling) Islands',
	CO: 'Colombia',
	KM: 'Comoros',
	CG: 'Congo',
	CD: 'Congo, the Democratic Republic of the',
	CK: 'Cook Islands',
	CR: 'Costa Rica',
	CI: "C\u00f4te d'Ivoire",
	HR: 'Croatia',
	CU: 'Cuba',
	CW: 'Cura\u00e7ao',
	CY: 'Cyprus',
	CZ: 'Czech Republic',
	DK: 'Denmark',
	DJ: 'Djibouti',
	DM: 'Dominica',
	DO: 'Dominican Republic',
	EC: 'Ecuador',
	EG: 'Egypt',
	SV: 'El Salvador',
	GQ: 'Equatorial Guinea',
	ER: 'Eritrea',
	EE: 'Estonia',
	ET: 'Ethiopia',
	FK: 'Falkland Islands (Malvinas)',
	FO: 'Faroe Islands',
	FJ: 'Fiji',
	FI: 'Finland',
	FR: 'France',
	GF: 'French Guiana',
	PF: 'French Polynesia',
	TF: 'French Southern Territories',
	GA: 'Gabon',
	GM: 'Gambia',
	GE: 'Georgia',
	DE: 'Germany',
	GH: 'Ghana',
	GI: 'Gibraltar',
	GR: 'Greece',
	GL: 'Greenland',
	GD: 'Grenada',
	GP: 'Guadeloupe',
	GU: 'Guam',
	GT: 'Guatemala',
	GG: 'Guernsey',
	GN: 'Guinea',
	GW: 'Guinea-Bissau',
	GY: 'Guyana',
	HT: 'Haiti',
	HM: 'Heard Island and McDonald Islands',
	VA: 'Holy See (Vatican City State)',
	HN: 'Honduras',
	HK: 'Hong Kong',
	HU: 'Hungary',
	IS: 'Iceland',
	IN: 'India',
	ID: 'Indonesia',
	IR: 'Iran, Islamic Republic of',
	IQ: 'Iraq',
	IE: 'Ireland',
	IM: 'Isle of Man',
	IL: 'Israel',
	IT: 'Italy',
	JM: 'Jamaica',
	JP: 'Japan',
	JE: 'Jersey',
	JO: 'Jordan',
	KZ: 'Kazakhstan',
	KE: 'Kenya',
	KI: 'Kiribati',
	KP: "Korea, Democratic People's Republic of",
	KR: 'Korea, Republic of',
	KW: 'Kuwait',
	KG: 'Kyrgyzstan',
	LA: "Lao People's Democratic Republic",
	LV: 'Latvia',
	LB: 'Lebanon',
	LS: 'Lesotho',
	LR: 'Liberia',
	LY: 'Libya',
	LI: 'Liechtenstein',
	LT: 'Lithuania',
	LU: 'Luxembourg',
	MO: 'Macao',
	MK: 'Macedonia, the Former Yugoslav Republic of',
	MG: 'Madagascar',
	MW: 'Malawi',
	MY: 'Malaysia',
	MV: 'Maldives',
	ML: 'Mali',
	MT: 'Malta',
	MH: 'Marshall Islands',
	MQ: 'Martinique',
	MR: 'Mauritania',
	MU: 'Mauritius',
	YT: 'Mayotte',
	MX: 'Mexico',
	FM: 'Micronesia, Federated States of',
	MD: 'Moldova, Republic of',
	MC: 'Monaco',
	MN: 'Mongolia',
	ME: 'Montenegro',
	MS: 'Montserrat',
	MA: 'Morocco',
	MZ: 'Mozambique',
	MM: 'Myanmar',
	NA: 'Namibia',
	NR: 'Nauru',
	NP: 'Nepal',
	NL: 'Netherlands',
	NC: 'New Caledonia',
	NZ: 'New Zealand',
	NI: 'Nicaragua',
	NE: 'Niger',
	NG: 'Nigeria',
	NU: 'Niue',
	NF: 'Norfolk Island',
	MP: 'Northern Mariana Islands',
	NO: 'Norway',
	OM: 'Oman',
	PK: 'Pakistan',
	PW: 'Palau',
	PS: 'Palestine, State of',
	PA: 'Panama',
	PG: 'Papua New Guinea',
	PY: 'Paraguay',
	PE: 'Peru',
	PH: 'Philippines',
	PN: 'Pitcairn',
	PL: 'Poland',
	PT: 'Portugal',
	PR: 'Puerto Rico',
	QA: 'Qatar',
	RE: 'R\u00e9union',
	RO: 'Romania',
	RU: 'Russian Federation',
	RW: 'Rwanda',
	BL: 'Saint Barth\u00e9lemy',
	SH: 'Saint Helena, Ascension and Tristan da Cunha',
	KN: 'Saint Kitts and Nevis',
	LC: 'Saint Lucia',
	MF: 'Saint Martin (French part)',
	PM: 'Saint Pierre and Miquelon',
	VC: 'Saint Vincent and the Grenadines',
	WS: 'Samoa',
	SM: 'San Marino',
	ST: 'Sao Tome and Principe',
	SA: 'Saudi Arabia',
	SN: 'Senegal',
	RS: 'Serbia',
	SC: 'Seychelles',
	SL: 'Sierra Leone',
	SG: 'Singapore',
	SX: 'Sint Maarten (Dutch part)',
	SK: 'Slovakia',
	SI: 'Slovenia',
	SB: 'Solomon Islands',
	SO: 'Somalia',
	ZA: 'South Africa',
	GS: 'South Georgia and the South Sandwich Islands',
	SS: 'South Sudan',
	ES: 'Spain',
	LK: 'Sri Lanka',
	SD: 'Sudan',
	SR: 'Suriname',
	SJ: 'Svalbard and Jan Mayen',
	SZ: 'Swaziland',
	SE: 'Sweden',
	CH: 'Switzerland',
	SY: 'Syrian Arab Republic',
	TW: 'Taiwan, Province of China',
	TJ: 'Tajikistan',
	TZ: 'Tanzania, United Republic of',
	TH: 'Thailand',
	TL: 'Timor-Leste',
	TG: 'Togo',
	TK: 'Tokelau',
	TO: 'Tonga',
	TT: 'Trinidad and Tobago',
	TN: 'Tunisia',
	TR: 'Turkey',
	TM: 'Turkmenistan',
	TC: 'Turks and Caicos Islands',
	TV: 'Tuvalu',
	UG: 'Uganda',
	UA: 'Ukraine',
	AE: 'United Arab Emirates',
	GB: 'United Kingdom',
	US: 'United States',
	UM: 'United States Minor Outlying Islands',
	UY: 'Uruguay',
	UZ: 'Uzbekistan',
	VU: 'Vanuatu',
	VE: 'Venezuela, Bolivarian Republic of',
	VN: 'Viet Nam',
	VG: 'Virgin Islands, British',
	VI: 'Virgin Islands, U.S.',
	WF: 'Wallis and Futuna',
	EH: 'Western Sahara',
	YE: 'Yemen',
	ZM: 'Zambia',
	ZW: 'Zimbabwe'
};

//

var script$i = {
	data() {
		return {
			link: '',
			title: '',
			subtitle: '',
			image: '',
			data: {},
			type: '',
			id: '0',
			countries: []
		}
	},
	methods: {
		convertDuration,
		reset() {
			this.title = 'Loading...';
			this.subtitle = '';
			this.image = '';
			this.data = {};
			this.type = '';
			this.link = '';
			this.countries = [];
		},
		showTrack(data) {
			this.reset();
			const {
				title,
				title_version,
				album: { cover_xl },
				link,
				available_countries,
				id
			} = data;

			this.title = title + (title_version && title.indexOf(title_version) == -1 ? ' ' + title_version : '');
			this.image = cover_xl;
			this.type = 'track';
			this.link = link;
			this.id = id;

			available_countries.forEach(cc => {
				let temp = [];
				let chars = [...cc].map(c => c.charCodeAt() + 127397);
				temp.push(String.fromCodePoint(...chars));
				temp.push(COUNTRIES[cc]);
				this.countries.push(temp);
			});

			this.data = data;
		},
		showAlbum(data) {
			this.reset();
			const { title, cover_xl, link, id } = data;

			this.title = title;
			this.image = cover_xl;
			this.type = 'album';
			this.link = link;
			this.data = data;
			this.id = id;
		},
		notSupported() {
			this.link = 'error';
		},
		addToQueue(e) {
			sendAddToQueue(e.currentTarget.dataset.link);
		}
	},
	mounted() {
		EventBus.$on('linkAnalyzerTab:reset', this.reset);

		socket.on('analyze_track', this.showTrack);
		socket.on('analyze_album', this.showAlbum);
		socket.on('analyze_notSupported', this.notSupported);
	}
};

/* script */
const __vue_script__$i = script$i;

/* template */
var __vue_render__$j = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c(
    "div",
    { ref: "root", staticClass: "image_header", attrs: { id: "analyzer_tab" } },
    [
      _c("h1", { staticClass: "mb-8 text-5xl capitalize" }, [
        _vm._v(_vm._s(_vm.$t("sidebar.linkAnalyzer")))
      ]),
      _vm._v(" "),
      _vm.link === ""
        ? _c("div", [
            _c("p", [
              _vm._v(
                "\n\t\t\t" + _vm._s(_vm.$t("linkAnalyzer.info")) + "\n\t\t"
              )
            ]),
            _vm._v(" "),
            _c("p", [
              _vm._v(
                "\n\t\t\t" + _vm._s(_vm.$t("linkAnalyzer.useful")) + "\n\t\t"
              )
            ])
          ])
        : _vm.link === "error"
        ? _c("div", [
            _c("h2", [_vm._v(_vm._s(_vm.$t("linkAnalyzer.linkNotSupported")))]),
            _vm._v(" "),
            _c("p", [
              _vm._v(_vm._s(_vm.$t("linkAnalyzer.linkNotSupportedYet")))
            ])
          ])
        : _c("div", [
            _c(
              "header",
              {
                staticClass: "inline-flex",
                style: {
                  "background-image":
                    "linear-gradient(to bottom, transparent 0%, var(--main-background) 100%), url('" +
                    _vm.image +
                    "')"
                }
              },
              [
                _c("div", [
                  _c("h1", { staticClass: "m-0" }, [_vm._v(_vm._s(_vm.title))]),
                  _vm._v(" "),
                  _vm.type === "track"
                    ? _c(
                        "h2",
                        { staticClass: "m-0 mb-3 text-lg" },
                        [
                          _c(
                            "i18n",
                            { attrs: { path: "globals.by", tag: "span" } },
                            [
                              _c(
                                "router-link",
                                {
                                  staticClass: "clickable",
                                  attrs: {
                                    tag: "span",
                                    place: "artist",
                                    to: {
                                      name: "Artist",
                                      params: { id: _vm.data.artist.id }
                                    }
                                  }
                                },
                                [
                                  _vm._v(
                                    "\n\t\t\t\t\t\t\t" +
                                      _vm._s(_vm.data.artist.name) +
                                      "\n\t\t\t\t\t\t"
                                  )
                                ]
                              )
                            ],
                            1
                          ),
                          _vm._v("\n\t\t\t\t\t•\n\t\t\t\t\t"),
                          _c(
                            "i18n",
                            { attrs: { path: "globals.in", tag: "span" } },
                            [
                              _c(
                                "router-link",
                                {
                                  staticClass: "clickable",
                                  attrs: {
                                    tag: "span",
                                    place: "album",
                                    to: {
                                      name: "Album",
                                      params: { id: _vm.data.album.id }
                                    }
                                  }
                                },
                                [
                                  _vm._v(
                                    "\n\t\t\t\t\t\t\t" +
                                      _vm._s(_vm.data.album.title) +
                                      "\n\t\t\t\t\t\t"
                                  )
                                ]
                              )
                            ],
                            1
                          )
                        ],
                        1
                      )
                    : _vm.type === "album"
                    ? _c(
                        "h2",
                        { staticClass: "m-0 mb-3 text-lg" },
                        [
                          _c(
                            "i18n",
                            { attrs: { path: "globals.by", tag: "span" } },
                            [
                              _c(
                                "router-link",
                                {
                                  staticClass: "clickable",
                                  attrs: {
                                    tag: "span",
                                    place: "artist",
                                    to: {
                                      name: "Artist",
                                      params: { id: _vm.data.artist.id }
                                    }
                                  }
                                },
                                [
                                  _vm._v(
                                    "\n\t\t\t\t\t\t\t" +
                                      _vm._s(_vm.data.artist.name) +
                                      "\n\t\t\t\t\t\t"
                                  )
                                ]
                              )
                            ],
                            1
                          ),
                          _vm._v(
                            "\n\t\t\t\t\t" +
                              _vm._s(
                                " • " +
                                  _vm.$tc(
                                    "globals.listTabs.trackN",
                                    _vm.data.nb_tracks
                                  )
                              ) +
                              "\n\t\t\t\t"
                          )
                        ],
                        1
                      )
                    : _vm._e()
                ]),
                _vm._v(" "),
                _c(
                  "div",
                  {
                    staticClass: "fab right",
                    attrs: {
                      role: "button",
                      "aria-label": "download",
                      "data-link": _vm.link
                    },
                    on: {
                      contextmenu: function($event) {
                        $event.preventDefault();
                        return _vm.openQualityModal($event)
                      },
                      click: function($event) {
                        $event.stopPropagation();
                        return _vm.addToQueue($event)
                      }
                    }
                  },
                  [
                    _c(
                      "i",
                      {
                        staticClass: "material-icons",
                        attrs: { title: _vm.$t("globals.download_hint") }
                      },
                      [_vm._v("get_app")]
                    )
                  ]
                )
              ]
            ),
            _vm._v(" "),
            _c("table", { staticClass: "table" }, [
              _vm.data.id
                ? _c("tr", [
                    _c("td", [_vm._v(_vm._s(_vm.$t("linkAnalyzer.table.id")))]),
                    _vm._v(" "),
                    _c("td", [_vm._v(_vm._s(_vm.data.id))])
                  ])
                : _vm._e(),
              _vm._v(" "),
              _vm.data.isrc
                ? _c("tr", [
                    _c("td", [
                      _vm._v(_vm._s(_vm.$t("linkAnalyzer.table.isrc")))
                    ]),
                    _vm._v(" "),
                    _c("td", [_vm._v(_vm._s(_vm.data.isrc))])
                  ])
                : _vm._e(),
              _vm._v(" "),
              _vm.data.upc
                ? _c("tr", [
                    _c("td", [
                      _vm._v(_vm._s(_vm.$t("linkAnalyzer.table.upc")))
                    ]),
                    _vm._v(" "),
                    _c("td", [_vm._v(_vm._s(_vm.data.upc))])
                  ])
                : _vm._e(),
              _vm._v(" "),
              _vm.data.duration
                ? _c("tr", [
                    _c("td", [
                      _vm._v(_vm._s(_vm.$t("linkAnalyzer.table.duration")))
                    ]),
                    _vm._v(" "),
                    _c("td", [
                      _vm._v(_vm._s(_vm.convertDuration(_vm.data.duration)))
                    ])
                  ])
                : _vm._e(),
              _vm._v(" "),
              _vm.data.disk_number
                ? _c("tr", [
                    _c("td", [
                      _vm._v(_vm._s(_vm.$t("linkAnalyzer.table.diskNumber")))
                    ]),
                    _vm._v(" "),
                    _c("td", [_vm._v(_vm._s(_vm.data.disk_number))])
                  ])
                : _vm._e(),
              _vm._v(" "),
              _vm.data.track_position
                ? _c("tr", [
                    _c("td", [
                      _vm._v(_vm._s(_vm.$t("linkAnalyzer.table.trackNumber")))
                    ]),
                    _vm._v(" "),
                    _c("td", [_vm._v(_vm._s(_vm.data.track_position))])
                  ])
                : _vm._e(),
              _vm._v(" "),
              _vm.data.release_date
                ? _c("tr", [
                    _c("td", [
                      _vm._v(_vm._s(_vm.$t("linkAnalyzer.table.releaseDate")))
                    ]),
                    _vm._v(" "),
                    _c("td", [_vm._v(_vm._s(_vm.data.release_date))])
                  ])
                : _vm._e(),
              _vm._v(" "),
              _vm.data.bpm
                ? _c("tr", [
                    _c("td", [
                      _vm._v(_vm._s(_vm.$t("linkAnalyzer.table.bpm")))
                    ]),
                    _vm._v(" "),
                    _c("td", [_vm._v(_vm._s(_vm.data.bpm))])
                  ])
                : _vm._e(),
              _vm._v(" "),
              _vm.data.label
                ? _c("tr", [
                    _c("td", [
                      _vm._v(_vm._s(_vm.$t("linkAnalyzer.table.label")))
                    ]),
                    _vm._v(" "),
                    _c("td", [_vm._v(_vm._s(_vm.data.label))])
                  ])
                : _vm._e(),
              _vm._v(" "),
              _vm.data.record_type
                ? _c("tr", [
                    _c("td", [
                      _vm._v(_vm._s(_vm.$t("linkAnalyzer.table.recordType")))
                    ]),
                    _vm._v(" "),
                    _c("td", [
                      _vm._v(
                        _vm._s(
                          _vm.$tc("globals.listTabs." + _vm.data.record_type, 1)
                        )
                      )
                    ])
                  ])
                : _vm._e(),
              _vm._v(" "),
              _vm.data.genres && _vm.data.genres.data.length
                ? _c("tr", [
                    _c("td", [
                      _vm._v(_vm._s(_vm.$t("linkAnalyzer.table.genres")))
                    ]),
                    _vm._v(" "),
                    _c("td", [
                      _vm._v(
                        _vm._s(
                          _vm.data.genres.data
                            .map(function(x) {
                              return x.name
                            })
                            .join("; ")
                        )
                      )
                    ])
                  ])
                : _vm._e()
            ]),
            _vm._v(" "),
            _vm.type == "album"
              ? _c(
                  "div",
                  [
                    _c(
                      "router-link",
                      {
                        attrs: {
                          tag: "button",
                          to: { name: "Album", params: { id: _vm.id } }
                        }
                      },
                      [
                        _vm._v(
                          "\n\t\t\t\t" +
                            _vm._s(_vm.$t("linkAnalyzer.table.tracklist")) +
                            "\n\t\t\t"
                        )
                      ]
                    )
                  ],
                  1
                )
              : _vm._e(),
            _vm._v(" "),
            _vm.countries.length
              ? _c(
                  "div",
                  _vm._l(_vm.countries, function(country) {
                    return _c("p", [
                      _vm._v(_vm._s(country[0]) + " - " + _vm._s(country[1]))
                    ])
                  }),
                  0
                )
              : _vm._e()
          ])
    ]
  )
};
var __vue_staticRenderFns__$j = [];
__vue_render__$j._withStripped = true;

  /* style */
  const __vue_inject_styles__$j = function (inject) {
    if (!inject) return
    inject("data-v-22f04408_0", { source: "\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n", map: {"version":3,"sources":[],"names":[],"mappings":"","file":"LinkAnalyzer.vue"}, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$j = undefined;
  /* module identifier */
  const __vue_module_identifier__$j = undefined;
  /* functional template */
  const __vue_is_functional_template__$j = false;
  /* style inject SSR */
  

  
  var LinkAnalyzer = normalizeComponent_1(
    { render: __vue_render__$j, staticRenderFns: __vue_staticRenderFns__$j },
    __vue_inject_styles__$j,
    __vue_script__$i,
    __vue_scope_id__$j,
    __vue_is_functional_template__$j,
    __vue_module_identifier__$j,
    browser,
    undefined
  );

/**
 * @param {string}	text
 */
const upperCaseFirstLowerCaseRest = text => text.charAt(0).toUpperCase() + text.slice(1).toLowerCase();

//

var script$j = {
	props: ['results'],
	computed: {
		topResultType() {
			return this.results.allTab.TOP_RESULT[0].type
		},
		noResults() {
			return this.results.allTab.ORDER.every(section =>
				section == 'TOP_RESULT'
					? this.results.allTab[section].length == 0
					: this.results.allTab[section].data.length == 0
			)
		},
		fansNumber() {
			let number;

			try {
				number = this.$n(this.results.allTab.TOP_RESULT[0].nb_fan);
			} catch (error) {
				number = this.$n(this.results.allTab.TOP_RESULT[0].nb_fan, { locale: 'en' });
			}

			return this.results.allTab.TOP_RESULT[0].type == 'artist'
				? this.$t('search.fans', { n: number })
				: this.$t('globals.by', { artist: this.results.allTab.TOP_RESULT[0].artist }) +
						' - ' +
						this.$tc('globals.listTabs.trackN', this.results.allTab.TOP_RESULT[0].nb_song)
		}
	},
	methods: {
		convertDuration,
		upperCaseFirstLowerCaseRest
	}
};

/* script */
const __vue_script__$j = script$j;

/* template */
var __vue_render__$k = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c(
    "div",
    { staticClass: "search_tabcontent", attrs: { id: "main_search" } },
    [
      _vm._l(_vm.results.allTab.ORDER, function(section) {
        return [
          (section != "TOP_RESULT" &&
            _vm.results.allTab[section].data.length > 0) ||
          _vm.results.allTab[section].length > 0
            ? _c(
                "section",
                { staticClass: "search_section" },
                [
                  _c(
                    "h2",
                    {
                      staticClass: "search_header",
                      class: { top_result_header: section === "TOP_RESULT" },
                      on: {
                        click: function($event) {
                          return _vm.$emit("change-search-tab", section)
                        }
                      }
                    },
                    [
                      _vm._v(
                        "\n\t\t\t\t" +
                          _vm._s(
                            _vm.$tc(
                              "globals.listTabs." + section.toLowerCase(),
                              2
                            )
                          ) +
                          "\n\t\t\t"
                      )
                    ]
                  ),
                  _vm._v(" "),
                  section == "TOP_RESULT"
                    ? _c(
                        "router-link",
                        {
                          staticClass: "top_result clickable",
                          attrs: {
                            tag: "div",
                            to: {
                              name: _vm.upperCaseFirstLowerCaseRest(
                                _vm.topResultType
                              ),
                              params: {
                                id: _vm.results.allTab.TOP_RESULT[0].id
                              }
                            }
                          }
                        },
                        [
                          _c("div", { staticClass: "cover_container" }, [
                            _c("img", {
                              class:
                                (_vm.results.allTab.TOP_RESULT[0].type ==
                                "artist"
                                  ? "circle"
                                  : "rounded") + " coverart",
                              attrs: {
                                "aria-hidden": "true",
                                src: _vm.results.allTab.TOP_RESULT[0].picture
                              }
                            }),
                            _vm._v(" "),
                            _c(
                              "button",
                              {
                                staticClass: "download_overlay",
                                attrs: {
                                  role: "button",
                                  "aria-label": "download",
                                  "data-link":
                                    _vm.results.allTab.TOP_RESULT[0].link,
                                  tabindex: "0"
                                },
                                on: {
                                  click: function($event) {
                                    $event.stopPropagation();
                                    return _vm.$emit("add-to-queue", $event)
                                  }
                                }
                              },
                              [
                                _c(
                                  "i",
                                  {
                                    staticClass: "material-icons",
                                    attrs: {
                                      title: _vm.$t("globals.download_hint")
                                    }
                                  },
                                  [_vm._v("get_app")]
                                )
                              ]
                            )
                          ]),
                          _vm._v(" "),
                          _c("div", { staticClass: "info_box" }, [
                            _c("p", { staticClass: "primary-text" }, [
                              _vm._v(
                                _vm._s(_vm.results.allTab.TOP_RESULT[0].title)
                              )
                            ]),
                            _vm._v(" "),
                            _c("p", { staticClass: "secondary-text" }, [
                              _vm._v(
                                "\n\t\t\t\t\t\t" +
                                  _vm._s(_vm.fansNumber) +
                                  "\n\t\t\t\t\t"
                              )
                            ]),
                            _vm._v(" "),
                            _c("span", { staticClass: "tag" }, [
                              _vm._v(
                                _vm._s(
                                  _vm.$tc(
                                    "globals.listTabs." +
                                      _vm.results.allTab.TOP_RESULT[0].type,
                                    1
                                  )
                                )
                              )
                            ])
                          ])
                        ]
                      )
                    : section == "TRACK"
                    ? _c("div", [
                        _c("table", { staticClass: "table table--tracks" }, [
                          _c(
                            "tbody",
                            _vm._l(
                              _vm.results.allTab.TRACK.data.slice(0, 6),
                              function(track) {
                                return _c(
                                  "tr",
                                  { key: track.SNG_ID },
                                  [
                                    _c(
                                      "td",
                                      {
                                        staticClass: "table__icon",
                                        attrs: { "aria-hidden": "true" }
                                      },
                                      [
                                        _c("img", {
                                          staticClass: "rounded coverart",
                                          attrs: {
                                            src:
                                              "https://e-cdns-images.dzcdn.net/images/cover/" +
                                              track.ALB_PICTURE +
                                              "/32x32-000000-80-0-0.jpg"
                                          }
                                        })
                                      ]
                                    ),
                                    _vm._v(" "),
                                    _c(
                                      "td",
                                      {
                                        staticClass:
                                          "table__cell table__cell--large breakline"
                                      },
                                      [
                                        _c(
                                          "div",
                                          {
                                            staticClass:
                                              "table__cell-content table__cell-content--vertical-center"
                                          },
                                          [
                                            track.EXPLICIT_LYRICS == 1
                                              ? _c(
                                                  "i",
                                                  {
                                                    staticClass:
                                                      "material-icons explicit_icon"
                                                  },
                                                  [_vm._v(" explicit ")]
                                                )
                                              : _vm._e(),
                                            _vm._v(
                                              "\n\t\t\t\t\t\t\t\t\t" +
                                                _vm._s(
                                                  track.SNG_TITLE +
                                                    (track.VERSION
                                                      ? " " + track.VERSION
                                                      : "")
                                                ) +
                                                "\n\t\t\t\t\t\t\t\t"
                                            )
                                          ]
                                        )
                                      ]
                                    ),
                                    _vm._v(" "),
                                    _c(
                                      "td",
                                      {
                                        staticClass:
                                          "table__cell table__cell--medium table__cell--center breakline"
                                      },
                                      _vm._l(track.ARTISTS, function(artist) {
                                        return _c(
                                          "router-link",
                                          {
                                            key: artist.ART_ID,
                                            staticClass: "clickable",
                                            attrs: {
                                              tag: "span",
                                              to: {
                                                name: "Artist",
                                                params: { id: artist.ART_ID }
                                              }
                                            }
                                          },
                                          [
                                            _vm._v(
                                              "\n\t\t\t\t\t\t\t\t\t" +
                                                _vm._s(artist.ART_NAME) +
                                                "\n\t\t\t\t\t\t\t\t"
                                            )
                                          ]
                                        )
                                      }),
                                      1
                                    ),
                                    _vm._v(" "),
                                    _c(
                                      "router-link",
                                      {
                                        staticClass:
                                          "table__cell--medium table__cell--center breakline clickable",
                                        attrs: {
                                          tag: "td",
                                          to: {
                                            name: "Album",
                                            params: { id: track.ALB_ID }
                                          }
                                        }
                                      },
                                      [
                                        _vm._v(
                                          "\n\t\t\t\t\t\t\t\t" +
                                            _vm._s(track.ALB_TITLE) +
                                            "\n\t\t\t\t\t\t\t"
                                        )
                                      ]
                                    ),
                                    _vm._v(" "),
                                    _c(
                                      "td",
                                      {
                                        staticClass:
                                          "table__cell table__cell--center"
                                      },
                                      [
                                        _vm._v(
                                          "\n\t\t\t\t\t\t\t\t" +
                                            _vm._s(
                                              _vm.convertDuration(
                                                track.DURATION
                                              )
                                            ) +
                                            "\n\t\t\t\t\t\t\t"
                                        )
                                      ]
                                    ),
                                    _vm._v(" "),
                                    _c(
                                      "td",
                                      {
                                        staticClass:
                                          "table__cell--download table__cell--center clickable",
                                        attrs: {
                                          "data-link":
                                            "https://www.deezer.com/track/" +
                                            track.SNG_ID,
                                          role: "button",
                                          "aria-label": "download"
                                        },
                                        on: {
                                          click: function($event) {
                                            $event.stopPropagation();
                                            return _vm.$emit(
                                              "add-to-queue",
                                              $event
                                            )
                                          }
                                        }
                                      },
                                      [
                                        _c(
                                          "i",
                                          {
                                            staticClass: "material-icons",
                                            attrs: {
                                              title: _vm.$t(
                                                "globals.download_hint"
                                              )
                                            }
                                          },
                                          [_vm._v(" get_app ")]
                                        )
                                      ]
                                    )
                                  ],
                                  1
                                )
                              }
                            ),
                            0
                          )
                        ])
                      ])
                    : section == "ARTIST"
                    ? _c(
                        "div",
                        { staticClass: "release_grid firstrow_only" },
                        _vm._l(
                          _vm.results.allTab.ARTIST.data.slice(0, 10),
                          function(release) {
                            return _c(
                              "router-link",
                              {
                                key: release.ART_ID,
                                staticClass: "release clickable",
                                attrs: {
                                  tag: "div",
                                  to: {
                                    name: "Artist",
                                    params: { id: release.ART_ID }
                                  }
                                }
                              },
                              [
                                _c("div", { staticClass: "cover_container" }, [
                                  _c("img", {
                                    staticClass: "circle coverart",
                                    attrs: {
                                      "aria-hidden": "true",
                                      src:
                                        "https://e-cdns-images.dzcdn.net/images/artist/" +
                                        release.ART_PICTURE +
                                        "/156x156-000000-80-0-0.jpg"
                                    }
                                  }),
                                  _vm._v(" "),
                                  _c(
                                    "button",
                                    {
                                      staticClass: "download_overlay",
                                      attrs: {
                                        role: "button",
                                        "aria-label": "download",
                                        "data-link":
                                          "https://deezer.com/artist/" +
                                          release.ART_ID,
                                        tabindex: "0"
                                      },
                                      on: {
                                        click: function($event) {
                                          $event.stopPropagation();
                                          return _vm.$emit(
                                            "add-to-queue",
                                            $event
                                          )
                                        }
                                      }
                                    },
                                    [
                                      _c(
                                        "i",
                                        {
                                          staticClass: "material-icons",
                                          attrs: {
                                            title: _vm.$t(
                                              "globals.download_hint"
                                            )
                                          }
                                        },
                                        [_vm._v("get_app")]
                                      )
                                    ]
                                  )
                                ]),
                                _vm._v(" "),
                                _c("p", { staticClass: "primary-text" }, [
                                  _vm._v(_vm._s(release.ART_NAME))
                                ]),
                                _vm._v(" "),
                                _c("p", { staticClass: "secondary-text" }, [
                                  _vm._v(
                                    _vm._s(
                                      _vm.$t("search.fans", {
                                        n: _vm.$n(release.NB_FAN)
                                      })
                                    )
                                  )
                                ])
                              ]
                            )
                          }
                        ),
                        1
                      )
                    : section == "ALBUM"
                    ? _c(
                        "div",
                        { staticClass: "release_grid firstrow_only" },
                        _vm._l(
                          _vm.results.allTab.ALBUM.data.slice(0, 10),
                          function(release) {
                            return _c(
                              "router-link",
                              {
                                key: release.ALB_ID,
                                staticClass: "release clickable",
                                attrs: {
                                  tag: "div",
                                  to: {
                                    name: "Album",
                                    params: { id: release.ALB_ID }
                                  }
                                }
                              },
                              [
                                _c("div", { staticClass: "cover_container" }, [
                                  _c("img", {
                                    staticClass: "rounded coverart",
                                    attrs: {
                                      "aria-hidden": "true",
                                      src:
                                        "https://e-cdns-images.dzcdn.net/images/cover/" +
                                        release.ALB_PICTURE +
                                        "/156x156-000000-80-0-0.jpg"
                                    }
                                  }),
                                  _vm._v(" "),
                                  _c(
                                    "button",
                                    {
                                      staticClass: "download_overlay",
                                      attrs: {
                                        role: "button",
                                        "aria-label": "download",
                                        "data-link":
                                          "https://deezer.com/album/" +
                                          release.ALB_ID,
                                        tabindex: "0"
                                      },
                                      on: {
                                        click: function($event) {
                                          $event.stopPropagation();
                                          return _vm.$emit(
                                            "add-to-queue",
                                            $event
                                          )
                                        }
                                      }
                                    },
                                    [
                                      _c(
                                        "i",
                                        {
                                          staticClass: "material-icons",
                                          attrs: {
                                            title: _vm.$t(
                                              "globals.download_hint"
                                            )
                                          }
                                        },
                                        [_vm._v("get_app")]
                                      )
                                    ]
                                  )
                                ]),
                                _vm._v(" "),
                                _c(
                                  "p",
                                  { staticClass: "primary-text inline-flex" },
                                  [
                                    [1, 4].indexOf(
                                      release.EXPLICIT_ALBUM_CONTENT
                                        .EXPLICIT_LYRICS_STATUS
                                    ) != -1
                                      ? _c(
                                          "i",
                                          {
                                            staticClass:
                                              "material-icons explicit_icon"
                                          },
                                          [_vm._v("explicit")]
                                        )
                                      : _vm._e(),
                                    _vm._v(
                                      "\n\t\t\t\t\t\t" +
                                        _vm._s(release.ALB_TITLE) +
                                        "\n\t\t\t\t\t"
                                    )
                                  ]
                                ),
                                _vm._v(" "),
                                _c("p", { staticClass: "secondary-text" }, [
                                  _vm._v(
                                    "\n\t\t\t\t\t\t" +
                                      _vm._s(
                                        release.ART_NAME +
                                          " - " +
                                          _vm.$tc(
                                            "globals.listTabs.trackN",
                                            release.NUMBER_TRACK
                                          )
                                      ) +
                                      "\n\t\t\t\t\t"
                                  )
                                ])
                              ]
                            )
                          }
                        ),
                        1
                      )
                    : section == "PLAYLIST"
                    ? _c(
                        "div",
                        { staticClass: "release_grid firstrow_only" },
                        _vm._l(
                          _vm.results.allTab.PLAYLIST.data.slice(0, 10),
                          function(release) {
                            return _c(
                              "router-link",
                              {
                                key: release.PLAYLIST_ID,
                                staticClass: "release clickable",
                                attrs: {
                                  tag: "div",
                                  to: {
                                    name: "Playlist",
                                    params: { id: release.PLAYLIST_ID }
                                  }
                                }
                              },
                              [
                                _c("div", { staticClass: "cover_container" }, [
                                  _c("img", {
                                    staticClass: "rounded coverart",
                                    attrs: {
                                      "aria-hidden": "true",
                                      src:
                                        "https://e-cdns-images.dzcdn.net/images/" +
                                        release.PICTURE_TYPE +
                                        "/" +
                                        release.PLAYLIST_PICTURE +
                                        "/156x156-000000-80-0-0.jpg"
                                    }
                                  }),
                                  _vm._v(" "),
                                  _c(
                                    "button",
                                    {
                                      staticClass: "download_overlay",
                                      attrs: {
                                        role: "button",
                                        "aria-label": "download",
                                        "data-link":
                                          "https://deezer.com/playlist/" +
                                          release.PLAYLIST_ID,
                                        tabindex: "0"
                                      },
                                      on: {
                                        click: function($event) {
                                          $event.stopPropagation();
                                          return _vm.$emit(
                                            "add-to-queue",
                                            $event
                                          )
                                        }
                                      }
                                    },
                                    [
                                      _c(
                                        "i",
                                        {
                                          staticClass: "material-icons",
                                          attrs: {
                                            title: _vm.$t(
                                              "globals.download_hint"
                                            )
                                          }
                                        },
                                        [_vm._v("get_app")]
                                      )
                                    ]
                                  )
                                ]),
                                _vm._v(" "),
                                _c("p", { staticClass: "primary-text" }, [
                                  _vm._v(_vm._s(release.TITLE))
                                ]),
                                _vm._v(" "),
                                _c("p", { staticClass: "secondary-text" }, [
                                  _vm._v(
                                    _vm._s(
                                      _vm.$tc(
                                        "globals.listTabs.trackN",
                                        release.NB_SONG
                                      )
                                    )
                                  )
                                ])
                              ]
                            )
                          }
                        ),
                        1
                      )
                    : _vm._e()
                ],
                1
              )
            : _vm._e()
        ]
      }),
      _vm._v(" "),
      _vm.noResults
        ? _c("div", [_c("h1", [_vm._v(_vm._s(_vm.$t("search.noResults")))])])
        : _vm._e()
    ],
    2
  )
};
var __vue_staticRenderFns__$k = [];
__vue_render__$k._withStripped = true;

  /* style */
  const __vue_inject_styles__$k = undefined;
  /* scoped */
  const __vue_scope_id__$k = undefined;
  /* module identifier */
  const __vue_module_identifier__$k = undefined;
  /* functional template */
  const __vue_is_functional_template__$k = false;
  /* style inject */
  
  /* style inject SSR */
  

  
  var ResultsAll = normalizeComponent_1(
    { render: __vue_render__$k, staticRenderFns: __vue_staticRenderFns__$k },
    __vue_inject_styles__$k,
    __vue_script__$j,
    __vue_scope_id__$k,
    __vue_is_functional_template__$k,
    __vue_module_identifier__$k,
    undefined,
    undefined
  );

//

var script$k = {
	props: ['results'],
	components: {
		BaseLoadingPlaceholder
	}
};

/* script */
const __vue_script__$k = script$k;

/* template */
var __vue_render__$l = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c(
    "div",
    { staticClass: "search_tabcontent", attrs: { id: "album_search" } },
    [
      !_vm.results.albumTab.loaded
        ? _c("BaseLoadingPlaceholder")
        : _vm.results.albumTab.data.length == 0
        ? _c("div", [
            _c("h1", [_vm._v(_vm._s(_vm.$t("search.noResultsAlbum")))])
          ])
        : _vm._e(),
      _vm._v(" "),
      _vm.results.albumTab.data.length > 0
        ? _c(
            "div",
            { staticClass: "release_grid" },
            _vm._l(_vm.results.albumTab.data, function(release) {
              return _c(
                "router-link",
                {
                  key: release.id,
                  staticClass: "release clickable",
                  attrs: {
                    tag: "div",
                    to: { name: "Album", params: { id: release.id } }
                  }
                },
                [
                  _c("div", { staticClass: "cover_container" }, [
                    _c("img", {
                      staticClass: "rounded coverart",
                      attrs: {
                        "aria-hidden": "true",
                        src: release.cover_medium
                      }
                    }),
                    _vm._v(" "),
                    _c(
                      "button",
                      {
                        staticClass: "download_overlay",
                        attrs: {
                          role: "button",
                          "aria-label": "download",
                          "data-link": release.link,
                          tabindex: "0"
                        },
                        on: {
                          click: function($event) {
                            $event.stopPropagation();
                            return _vm.$emit("add-to-queue", $event)
                          }
                        }
                      },
                      [
                        _c(
                          "i",
                          {
                            staticClass: "material-icons",
                            attrs: { title: _vm.$t("globals.download_hint") }
                          },
                          [_vm._v("get_app")]
                        )
                      ]
                    )
                  ]),
                  _vm._v(" "),
                  _c("p", { staticClass: "primary-text inline-flex" }, [
                    release.explicit_lyrics
                      ? _c(
                          "i",
                          { staticClass: "material-icons explicit_icon" },
                          [_vm._v("explicit")]
                        )
                      : _vm._e(),
                    _vm._v("\n\t\t\t\t" + _vm._s(release.title) + "\n\t\t\t")
                  ]),
                  _vm._v(" "),
                  _c("p", { staticClass: "secondary-text" }, [
                    _vm._v(
                      "\n\t\t\t\t" +
                        _vm._s(
                          _vm.$t("globals.by", {
                            artist: release.artist.name
                          }) +
                            " - " +
                            _vm.$tc(
                              "globals.listTabs.trackN",
                              release.nb_tracks
                            )
                        ) +
                        "\n\t\t\t"
                    )
                  ])
                ]
              )
            }),
            1
          )
        : _vm._e()
    ],
    1
  )
};
var __vue_staticRenderFns__$l = [];
__vue_render__$l._withStripped = true;

  /* style */
  const __vue_inject_styles__$l = undefined;
  /* scoped */
  const __vue_scope_id__$l = undefined;
  /* module identifier */
  const __vue_module_identifier__$l = undefined;
  /* functional template */
  const __vue_is_functional_template__$l = false;
  /* style inject */
  
  /* style inject SSR */
  

  
  var ResultsAlbums = normalizeComponent_1(
    { render: __vue_render__$l, staticRenderFns: __vue_staticRenderFns__$l },
    __vue_inject_styles__$l,
    __vue_script__$k,
    __vue_scope_id__$l,
    __vue_is_functional_template__$l,
    __vue_module_identifier__$l,
    undefined,
    undefined
  );

//

var script$l = {
	props: ['results'],
	components: {
		BaseLoadingPlaceholder
	}
};

/* script */
const __vue_script__$l = script$l;

/* template */
var __vue_render__$m = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c(
    "div",
    { staticClass: "search_tabcontent", attrs: { id: "artist_search" } },
    [
      !_vm.results.artistTab.loaded
        ? _c("BaseLoadingPlaceholder")
        : _vm.results.artistTab.data.length == 0
        ? _c("div", [
            _c("h1", [_vm._v(_vm._s(_vm.$t("search.noResultsArtist")))])
          ])
        : _vm._e(),
      _vm._v(" "),
      _vm.results.artistTab.data.length > 0
        ? _c(
            "div",
            { staticClass: "release_grid" },
            _vm._l(_vm.results.artistTab.data, function(release) {
              return _c(
                "router-link",
                {
                  key: release.id,
                  staticClass: "release clickable",
                  attrs: {
                    tag: "div",
                    to: { name: "Artist", params: { id: release.id } }
                  }
                },
                [
                  _c("div", { staticClass: "cover_container" }, [
                    _c("img", {
                      staticClass: "circle coverart",
                      attrs: {
                        "aria-hidden": "true",
                        src: release.picture_medium
                      }
                    }),
                    _vm._v(" "),
                    _c(
                      "button",
                      {
                        staticClass: "download_overlay",
                        attrs: {
                          role: "button",
                          "aria-label": "download",
                          "data-link": release.link,
                          tabindex: "0"
                        },
                        on: {
                          click: function($event) {
                            $event.stopPropagation();
                            return _vm.$emit("add-to-queue", $event)
                          }
                        }
                      },
                      [
                        _c(
                          "i",
                          {
                            staticClass: "material-icons",
                            attrs: { title: _vm.$t("globals.download_hint") }
                          },
                          [_vm._v("get_app")]
                        )
                      ]
                    )
                  ]),
                  _vm._v(" "),
                  _c("p", { staticClass: "primary-text" }, [
                    _vm._v(_vm._s(release.name))
                  ]),
                  _vm._v(" "),
                  _c("p", { staticClass: "secondary-text" }, [
                    _vm._v(
                      _vm._s(
                        _vm.$tc("globals.listTabs.releaseN", release.nb_album)
                      )
                    )
                  ])
                ]
              )
            }),
            1
          )
        : _vm._e()
    ],
    1
  )
};
var __vue_staticRenderFns__$m = [];
__vue_render__$m._withStripped = true;

  /* style */
  const __vue_inject_styles__$m = undefined;
  /* scoped */
  const __vue_scope_id__$m = undefined;
  /* module identifier */
  const __vue_module_identifier__$m = undefined;
  /* functional template */
  const __vue_is_functional_template__$m = false;
  /* style inject */
  
  /* style inject SSR */
  

  
  var ResultsArtists = normalizeComponent_1(
    { render: __vue_render__$m, staticRenderFns: __vue_staticRenderFns__$m },
    __vue_inject_styles__$m,
    __vue_script__$l,
    __vue_scope_id__$m,
    __vue_is_functional_template__$m,
    __vue_module_identifier__$m,
    undefined,
    undefined
  );

//

var script$m = {
	props: ['results'],
	components: {
		BaseLoadingPlaceholder
	}
};

/* script */
const __vue_script__$m = script$m;

/* template */
var __vue_render__$n = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c(
    "div",
    { staticClass: "search_tabcontent", attrs: { id: "playlist_search" } },
    [
      !_vm.results.playlistTab.loaded
        ? _c("BaseLoadingPlaceholder")
        : _vm.results.playlistTab.data.length == 0
        ? _c("div", [
            _c("h1", [_vm._v(_vm._s(_vm.$t("search.noResultsPlaylist")))])
          ])
        : _vm._e(),
      _vm._v(" "),
      _vm.results.playlistTab.data.length > 0
        ? _c(
            "div",
            { staticClass: "release_grid" },
            _vm._l(_vm.results.playlistTab.data, function(release) {
              return _c(
                "router-link",
                {
                  key: release.id,
                  staticClass: "release clickable",
                  attrs: {
                    tag: "div",
                    to: { name: "Playlist", params: { id: release.id } }
                  }
                },
                [
                  _c("div", { staticClass: "cover_container" }, [
                    _c("img", {
                      staticClass: "rounded coverart",
                      attrs: {
                        "aria-hidden": "true",
                        src: release.picture_medium
                      }
                    }),
                    _vm._v(" "),
                    _c(
                      "button",
                      {
                        staticClass: "download_overlay",
                        attrs: {
                          role: "button",
                          "aria-label": "download",
                          "data-link": release.link,
                          tabindex: "0"
                        },
                        on: {
                          click: function($event) {
                            $event.stopPropagation();
                            return _vm.$emit("add-to-queue", $event)
                          }
                        }
                      },
                      [
                        _c(
                          "i",
                          {
                            staticClass: "material-icons",
                            attrs: { title: _vm.$t("globals.download_hint") }
                          },
                          [_vm._v("get_app")]
                        )
                      ]
                    )
                  ]),
                  _vm._v(" "),
                  _c("p", { staticClass: "primary-text" }, [
                    _vm._v(_vm._s(release.title))
                  ]),
                  _vm._v(" "),
                  _c("p", { staticClass: "secondary-text" }, [
                    _vm._v(
                      "\n\t\t\t\t" +
                        _vm._s(
                          _vm.$t("globals.by", { artist: release.user.name }) +
                            " - " +
                            _vm.$tc(
                              "globals.listTabs.trackN",
                              release.nb_tracks
                            )
                        ) +
                        "\n\t\t\t"
                    )
                  ])
                ]
              )
            }),
            1
          )
        : _vm._e()
    ],
    1
  )
};
var __vue_staticRenderFns__$n = [];
__vue_render__$n._withStripped = true;

  /* style */
  const __vue_inject_styles__$n = undefined;
  /* scoped */
  const __vue_scope_id__$n = undefined;
  /* module identifier */
  const __vue_module_identifier__$n = undefined;
  /* functional template */
  const __vue_is_functional_template__$n = false;
  /* style inject */
  
  /* style inject SSR */
  

  
  var ResultsPlaylists = normalizeComponent_1(
    { render: __vue_render__$n, staticRenderFns: __vue_staticRenderFns__$n },
    __vue_inject_styles__$n,
    __vue_script__$m,
    __vue_scope_id__$n,
    __vue_is_functional_template__$n,
    __vue_module_identifier__$n,
    undefined,
    undefined
  );

//

var script$n = {
	props: ['results'],
	components: {
		BaseLoadingPlaceholder,
		PreviewControls
	},
	methods: {
		convertDuration,
		playPausePreview(e) {
			EventBus.$emit('trackPreview:playPausePreview', e);
		}
	}
};

/* script */
const __vue_script__$n = script$n;

/* template */
var __vue_render__$o = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c(
    "div",
    { staticClass: "search_tabcontent", attrs: { id: "track_search" } },
    [
      !_vm.results.trackTab.loaded
        ? _c("BaseLoadingPlaceholder")
        : _vm.results.trackTab.data.length == 0
        ? _c("div", [
            _c("h1", [_vm._v(_vm._s(_vm.$t("search.noResultsTrack")))])
          ])
        : _vm._e(),
      _vm._v(" "),
      _vm.results.trackTab.data.length > 0
        ? _c("table", { staticClass: "table table--tracks" }, [
            _c("thead", [
              _c("tr", [
                _c("th", { attrs: { colspan: "2" } }, [
                  _vm._v(_vm._s(_vm.$tc("globals.listTabs.title", 1)))
                ]),
                _vm._v(" "),
                _c("th", [
                  _vm._v(_vm._s(_vm.$tc("globals.listTabs.artist", 1)))
                ]),
                _vm._v(" "),
                _c("th", [
                  _vm._v(_vm._s(_vm.$tc("globals.listTabs.album", 1)))
                ]),
                _vm._v(" "),
                _vm._m(0),
                _vm._v(" "),
                _c("th", { staticStyle: { width: "56px" } })
              ])
            ]),
            _vm._v(" "),
            _c(
              "tbody",
              _vm._l(_vm.results.trackTab.data, function(track) {
                return _c(
                  "tr",
                  [
                    _c("td", { staticClass: "table__icon table__icon--big" }, [
                      _c(
                        "a",
                        {
                          class:
                            "rounded" + (track.preview ? " single-cover" : ""),
                          attrs: { href: "#", "data-preview": track.preview },
                          on: { click: _vm.playPausePreview }
                        },
                        [
                          track.preview ? _c("PreviewControls") : _vm._e(),
                          _vm._v(" "),
                          _c("img", {
                            staticClass: "rounded coverart",
                            attrs: { src: track.album.cover_small }
                          })
                        ],
                        1
                      )
                    ]),
                    _vm._v(" "),
                    _c(
                      "td",
                      {
                        staticClass: "table__cell table__cell--large breakline"
                      },
                      [
                        _c(
                          "div",
                          {
                            staticClass:
                              "table__cell-content table__cell-content--vertical-center"
                          },
                          [
                            track.explicit_lyrics
                              ? _c(
                                  "i",
                                  {
                                    staticClass: "material-icons explicit_icon"
                                  },
                                  [_vm._v(" explicit ")]
                                )
                              : _vm._e(),
                            _vm._v(
                              "\n\t\t\t\t\t\t" +
                                _vm._s(
                                  track.title +
                                    (track.title_version &&
                                    track.title.indexOf(track.title_version) ==
                                      -1
                                      ? " " + track.title_version
                                      : "")
                                ) +
                                "\n\t\t\t\t\t"
                            )
                          ]
                        )
                      ]
                    ),
                    _vm._v(" "),
                    _c(
                      "router-link",
                      {
                        staticClass:
                          "table__cell table__cell--medium table__cell--center breakline clickable",
                        attrs: {
                          tag: "td",
                          to: {
                            name: "Artist",
                            params: { id: track.artist.id }
                          }
                        }
                      },
                      [
                        _vm._v(
                          "\n\t\t\t\t\t" +
                            _vm._s(track.artist.name) +
                            "\n\t\t\t\t"
                        )
                      ]
                    ),
                    _vm._v(" "),
                    _c(
                      "router-link",
                      {
                        staticClass:
                          "table__cell table__cell--medium table__cell--center breakline clickable",
                        attrs: {
                          tag: "td",
                          to: { name: "Album", params: { id: track.album.id } }
                        }
                      },
                      [
                        _vm._v(
                          "\n\t\t\t\t\t" +
                            _vm._s(track.album.title) +
                            "\n\t\t\t\t"
                        )
                      ]
                    ),
                    _vm._v(" "),
                    _c(
                      "td",
                      {
                        staticClass:
                          "table__cell table__cell--small table__cell--center"
                      },
                      [
                        _vm._v(
                          "\n\t\t\t\t\t" +
                            _vm._s(_vm.convertDuration(track.duration)) +
                            "\n\t\t\t\t"
                        )
                      ]
                    ),
                    _vm._v(" "),
                    _c(
                      "td",
                      {
                        staticClass:
                          "table__cell--download table__cell--center clickable",
                        attrs: {
                          "data-link": track.link,
                          role: "button",
                          "aria-label": "download"
                        },
                        on: {
                          click: function($event) {
                            $event.stopPropagation();
                            return _vm.$emit("add-to-queue", $event)
                          }
                        }
                      },
                      [
                        _c(
                          "i",
                          {
                            staticClass: "material-icons",
                            attrs: { title: _vm.$t("globals.download_hint") }
                          },
                          [_vm._v(" get_app ")]
                        )
                      ]
                    )
                  ],
                  1
                )
              }),
              0
            )
          ])
        : _vm._e()
    ],
    1
  )
};
var __vue_staticRenderFns__$o = [
  function() {
    var _vm = this;
    var _h = _vm.$createElement;
    var _c = _vm._self._c || _h;
    return _c("th", [
      _c("i", { staticClass: "material-icons" }, [_vm._v(" timer ")])
    ])
  }
];
__vue_render__$o._withStripped = true;

  /* style */
  const __vue_inject_styles__$o = undefined;
  /* scoped */
  const __vue_scope_id__$o = undefined;
  /* module identifier */
  const __vue_module_identifier__$o = undefined;
  /* functional template */
  const __vue_is_functional_template__$o = false;
  /* style inject */
  
  /* style inject SSR */
  

  
  var ResultsTracks = normalizeComponent_1(
    { render: __vue_render__$o, staticRenderFns: __vue_staticRenderFns__$o },
    __vue_inject_styles__$o,
    __vue_script__$n,
    __vue_scope_id__$o,
    __vue_is_functional_template__$o,
    __vue_module_identifier__$o,
    undefined,
    undefined
  );

//

var script$o = {
	components: {
		BaseLoadingPlaceholder
	},
	data() {
		const $t = this.$t.bind(this);
		const $tc = this.$tc.bind(this);

		return {
			currentTab: {
				name: '',
				component: {}
			},
			tabs: [
				{
					name: $t('globals.listTabs.all'),
					searchType: 'all',
					component: ResultsAll
				},
				{
					name: $tc('globals.listTabs.track', 2),
					searchType: 'track',
					component: ResultsTracks
				},
				{
					name: $tc('globals.listTabs.album', 2),
					searchType: 'album',
					component: ResultsAlbums
				},
				{
					name: $tc('globals.listTabs.artist', 2),
					searchType: 'artist',
					component: ResultsArtists
				},
				{
					name: $tc('globals.listTabs.playlist', 2),
					searchType: 'playlist',
					component: ResultsPlaylists
				}
			],
			results: {
				query: '',
				allTab: {
					ORDER: [],
					TOP_RESULT: [],
					ALBUM: {},
					ARTIST: {},
					TRACK: {},
					PLAYLIST: {}
				},
				trackTab: {
					data: [],
					next: 0,
					total: 0,
					loaded: false
				},
				albumTab: {
					data: [],
					next: 0,
					total: 0,
					loaded: false
				},
				artistTab: {
					data: [],
					next: 0,
					total: 0,
					loaded: false
				},
				playlistTab: {
					data: [],
					next: 0,
					total: 0,
					loaded: false
				}
			}
		}
	},
	computed: {
		showSearchTab() {
			return this.results.query !== ''
		},
		loadedTabs() {
			const loaded = [];

			for (const resultKey in this.results) {
				if (this.results.hasOwnProperty(resultKey)) {
					const result = this.results[resultKey];

					if (result.loaded) {
						loaded.push(resultKey.replace(/Tab/g, ''));
					}
				}
			}

			return loaded
		}
	},
	props: {
		performScrolledSearch: {
			type: Boolean,
			required: false
		}
	},
	created() {
		this.currentTab = this.tabs[0];
	},
	mounted() {
		EventBus.$on('mainSearch:checkLoadMoreContent', this.checkLoadMoreContent);
		this.$root.$on('mainSearch:showNewResults', this.checkIfShowNewResults);
		this.$root.$on('mainSearch:updateResults', this.checkIfUpdateResults);

		socket.on('mainSearch', this.handleMainSearch);
		socket.on('search', this.handleSearch);
	},
	methods: {
		changeSearchTab(sectionName) {
			sectionName = sectionName.toLowerCase();

			let newTab = this.tabs.find(tab => {
				return tab.searchType === sectionName
			});

			if (!newTab) {
				console.error(`No tab ${sectionName} found`);
				return
			}

			window.scrollTo(0, 0);
			this.currentTab = newTab;
		},
		checkIfShowNewResults(term, mainSelected) {
			let needToPerformNewSearch = term !== this.results.query; /* || mainSelected == 'search_tab' */

			if (needToPerformNewSearch) {
				this.showNewResults(term);
			}
		},
		checkIfUpdateResults(term) {
			let needToUpdateSearch = term === this.results.query && this.currentTab.searchType !== 'all';

			if (needToUpdateSearch) {
				let resetObj = { data: [], next: 0, total: 0, loaded: false };
				this.results[this.currentTab.searchType + 'Tab'] = { ...resetObj };
				this.search(this.currentTab.searchType);
			}
		},
		showNewResults(term) {
			socket.emit('mainSearch', { term });

			// Showing loading placeholder
			this.$root.$emit('updateSearchLoadingState', true);
			this.currentTab = this.tabs[0];
		},
		checkLoadMoreContent(searchSelected) {
			if (this.results[searchSelected.split('_')[0] + 'Tab'].data.length !== 0) return

			this.search(searchSelected.split('_')[0]);
		},
		addToQueue(e) {
			sendAddToQueue(e.currentTarget.dataset.link);
		},
		numberWithDots,
		convertDuration,
		search(type) {
			socket.emit('search', {
				term: this.results.query,
				type,
				start: this.results[`${type}Tab`].next,
				nb: 30
			});
		},
		scrolledSearch() {
			if (this.currentTab.searchType === 'all') return

			let currentTab = `${this.currentTab.searchType}Tab`;

			if (this.results[currentTab].next < this.results[currentTab].total) {
				this.search(this.currentTab.searchType);
			}
		},
		handleMainSearch(result) {
			// Hiding loading placeholder
			this.$root.$emit('updateSearchLoadingState', false);

			let resetObj = { data: [], next: 0, total: 0, loaded: false };

			this.results.allTab = result;
			this.results.trackTab = { ...resetObj };
			this.results.albumTab = { ...resetObj };
			this.results.artistTab = { ...resetObj };
			this.results.playlistTab = { ...resetObj };
			this.results.query = result.QUERY;
		},
		handleSearch(result) {
			const { next: nextResult, total, type, data } = result;

			let currentTab = type + 'Tab';
			let next = 0;

			if (nextResult) {
				next = parseInt(nextResult.match(/index=(\d*)/)[1]);
			} else {
				next = total;
			}

			if (this.results[currentTab].total != total) {
				this.results[currentTab].total = total;
			}

			if (this.results[currentTab].next != next) {
				this.results[currentTab].next = next;
				this.results[currentTab].data = this.results[currentTab].data.concat(data);
			}

			this.results[currentTab].loaded = true;
		},
		isTabLoaded(tab) {
			return this.loadedTabs.indexOf(tab.searchType) !== -1 || tab.searchType === 'all'
		}
	},
	watch: {
		performScrolledSearch(needToSearch) {
			if (!needToSearch) return

			this.scrolledSearch(needToSearch);
		},
		currentTab(newTab) {
			if (this.isTabLoaded(newTab)) return

			this.search(newTab.searchType);
		}
	}
};

/* script */
const __vue_script__$o = script$o;

/* template */
var __vue_render__$p = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", { ref: "root", attrs: { id: "search_tab" } }, [
    _c(
      "div",
      {
        directives: [
          {
            name: "show",
            rawName: "v-show",
            value: !_vm.showSearchTab,
            expression: "!showSearchTab"
          }
        ]
      },
      [
        _c("h2", [_vm._v(_vm._s(_vm.$t("search.startSearching")))]),
        _vm._v(" "),
        _c("p", [_vm._v(_vm._s(_vm.$t("search.description")))])
      ]
    ),
    _vm._v(" "),
    _c(
      "div",
      {
        directives: [
          {
            name: "show",
            rawName: "v-show",
            value: _vm.showSearchTab,
            expression: "showSearchTab"
          }
        ]
      },
      [
        _c(
          "ul",
          { staticClass: "section-tabs" },
          _vm._l(_vm.tabs, function(tab) {
            return _c(
              "li",
              {
                key: tab.name,
                staticClass: "section-tabs__tab",
                class: { active: _vm.currentTab.name === tab.name },
                on: {
                  click: function($event) {
                    _vm.currentTab = tab;
                  }
                }
              },
              [_vm._v("\n\t\t\t\t" + _vm._s(tab.name) + "\n\t\t\t")]
            )
          }),
          0
        ),
        _vm._v(" "),
        _c(
          "keep-alive",
          [
            _c(_vm.currentTab.component, {
              tag: "component",
              attrs: { results: _vm.results },
              on: {
                "add-to-queue": _vm.addToQueue,
                "change-search-tab": _vm.changeSearchTab
              }
            })
          ],
          1
        )
      ],
      1
    )
  ])
};
var __vue_staticRenderFns__$p = [];
__vue_render__$p._withStripped = true;

  /* style */
  const __vue_inject_styles__$p = function (inject) {
    if (!inject) return
    inject("data-v-dfc9e7d0_0", { source: "\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n", map: {"version":3,"sources":[],"names":[],"mappings":"","file":"Search.vue"}, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$p = undefined;
  /* module identifier */
  const __vue_module_identifier__$p = undefined;
  /* functional template */
  const __vue_is_functional_template__$p = false;
  /* style inject SSR */
  

  
  var Search = normalizeComponent_1(
    { render: __vue_render__$p, staticRenderFns: __vue_staticRenderFns__$p },
    __vue_inject_styles__$p,
    __vue_script__$o,
    __vue_scope_id__$p,
    __vue_is_functional_template__$p,
    __vue_module_identifier__$p,
    browser,
    undefined
  );

let settingsData = {};
let defaultSettingsData = {};
let spotifyCredentials = {};

function getSettingsData() {
	{
		socket.emit('get_settings_data');

		return new Promise((resolve, reject) => {
			socket.on('init_settings', (settings, credentials, defaults) => {
				settingsData = settings;
				defaultSettingsData = defaults;
				spotifyCredentials = credentials;
				// cached = true

				socket.off('init_settings');
				resolve({ settingsData, defaultSettingsData, spotifyCredentials });
			});
		})
	}
}

var it$1 = "<svg xmlns=\"http://www.w3.org/2000/svg\" id=\"flag-icon-css-it\" viewBox=\"0 0 640 480\">\n  <g fill-rule=\"evenodd\" stroke-width=\"1pt\">\n    <path fill=\"#fff\" d=\"M0 0h640v480H0z\"/>\n    <path fill=\"#009246\" d=\"M0 0h213.3v480H0z\"/>\n    <path fill=\"#ce2b37\" d=\"M426.7 0H640v480H426.7z\"/>\n  </g>\n</svg>";

var gb = "<svg xmlns=\"http://www.w3.org/2000/svg\" id=\"flag-icon-css-gb\" viewBox=\"0 0 640 480\">\n  <path fill=\"#012169\" d=\"M0 0h640v480H0z\"/>\n  <path fill=\"#FFF\" d=\"M75 0l244 181L562 0h78v62L400 241l240 178v61h-80L320 301 81 480H0v-60l239-178L0 64V0h75z\"/>\n  <path fill=\"#C8102E\" d=\"M424 281l216 159v40L369 281h55zm-184 20l6 35L54 480H0l240-179zM640 0v3L391 191l2-44L590 0h50zM0 0l239 176h-60L0 42V0z\"/>\n  <path fill=\"#FFF\" d=\"M241 0v480h160V0H241zM0 160v160h640V160H0z\"/>\n  <path fill=\"#C8102E\" d=\"M0 193v96h640v-96H0zM273 0v480h96V0h-96z\"/>\n</svg>";

var es$1 = "<svg xmlns=\"http://www.w3.org/2000/svg\" id=\"flag-icon-css-es\" viewBox=\"0 0 640 480\">\n  <path fill=\"#AA151B\" d=\"M0 0h640v480H0z\"/>\n  <path fill=\"#F1BF00\" d=\"M0 120h640v240H0z\"/>\n  <path fill=\"#ad1519\" d=\"M127.3 213.3l-.8-.1-1-1-.7-.4-.6-.8s-.7-1.1-.4-2c.3-.9.9-1.2 1.4-1.5a12 12 0 011.5-.5l1-.4 1.3-.3.5-.3c.2 0 .7 0 1-.2l1-.2 1.6.1h4.8c.4 0 1.2.3 1.4.4a35 35 0 002 .7c.5.1 1.6.3 2.2.6.5.3.9.7 1.1 1l.5 1v1.1l-.5.8-.6 1-.8.6s-.5.5-1 .4c-.4 0-4.8-.8-7.6-.8s-7.3.9-7.3.9\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-linejoin=\"round\" stroke-width=\".3\" d=\"M127.3 213.3l-.8-.1-1-1-.7-.4-.6-.8s-.7-1.1-.4-2c.3-.9.9-1.2 1.4-1.5a12 12 0 011.5-.5l1-.4 1.3-.3.5-.3c.2 0 .7 0 1-.2l1-.2 1.6.1h4.8c.4 0 1.2.3 1.4.4a35 35 0 002 .7c.5.1 1.6.3 2.2.6.5.3.9.7 1.1 1l.5 1v1.1l-.5.8-.6 1-.8.6s-.5.5-1 .4c-.4 0-4.8-.8-7.6-.8s-7.3.9-7.3.9z\"/>\n  <path fill=\"#c8b100\" d=\"M133.3 207c0-1.3.6-2.3 1.3-2.3.8 0 1.4 1 1.4 2.4 0 1.3-.6 2.4-1.4 2.4s-1.3-1.1-1.3-2.5\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M133.3 207c0-1.3.6-2.3 1.3-2.3.8 0 1.4 1 1.4 2.4 0 1.3-.6 2.4-1.4 2.4s-1.3-1.1-1.3-2.5z\"/>\n  <path fill=\"#c8b100\" d=\"M134 207c0-1.2.3-2.1.7-2.1.3 0 .6 1 .6 2.1 0 1.3-.3 2.2-.6 2.2-.4 0-.6-1-.6-2.2\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M134 207c0-1.2.3-2.1.7-2.1.3 0 .6 1 .6 2.1 0 1.3-.3 2.2-.6 2.2-.4 0-.6-1-.6-2.2z\"/>\n  <path fill=\"#c8b100\" d=\"M133.8 204.5c0-.4.4-.8.8-.8s1 .4 1 .8c0 .5-.5.9-1 .9s-.8-.4-.8-.9\"/>\n  <path fill=\"#c8b100\" d=\"M135.3 204.2v.6h-1.4v-.6h.5V203h-.7v-.6h.7v-.5h.5v.5h.6v.6h-.6v1.2h.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M135.3 204.2v.6h-1.4v-.6h.5V203h-.7v-.6h.7v-.5h.5v.5h.6v.6h-.6v1.2h.4\"/>\n  <path fill=\"#c8b100\" d=\"M135.9 204.2v.6h-2.5v-.6h1V203h-.7v-.6h.7v-.5h.5v.5h.6v.6h-.6v1.2h1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M135.9 204.2v.6h-2.5v-.6h1V203h-.7v-.6h.7v-.5h.5v.5h.6v.6h-.6v1.2h1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M134.9 203.7c.4.1.6.4.6.8 0 .5-.4.9-.8.9s-1-.4-1-.9c0-.4.3-.7.7-.8\"/>\n  <path fill=\"#c8b100\" d=\"M134.7 213.2H130v-1.1l-.3-1.2-.2-1.5c-1.3-1.7-2.5-2.8-2.9-2.5.1-.3.2-.6.5-.7 1.1-.7 3.5 1 5.2 3.6l.5.7h3.8l.4-.7c1.8-2.7 4.1-4.3 5.2-3.6.3.1.4.4.5.7-.4-.3-1.6.8-2.9 2.5l-.2 1.5-.2 1.2-.1 1.1h-4.7\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M134.7 213.2H130v-1.1l-.3-1.2-.2-1.5c-1.3-1.7-2.5-2.8-2.9-2.5.1-.3.2-.6.5-.7 1.1-.7 3.5 1 5.2 3.6l.5.7h3.8l.4-.7c1.8-2.7 4.1-4.3 5.2-3.6.3.1.4.4.5.7-.4-.3-1.6.8-2.9 2.5l-.2 1.5-.2 1.2-.1 1.1h-4.7z\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M126.8 206.8c1-.5 3 1.1 4.6 3.6m11-3.6c-.8-.5-2.8 1.1-4.5 3.6\"/>\n  <path fill=\"#c8b100\" d=\"M127.8 215.3l-.5-1a27.3 27.3 0 0114.7 0l-.5.8a5.7 5.7 0 00-.3.8 22.9 22.9 0 00-6.6-.8c-2.6 0-5.2.3-6.5.8l-.3-.6\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M127.8 215.3l-.5-1a27.3 27.3 0 0114.7 0l-.5.8a5.7 5.7 0 00-.3.8 22.9 22.9 0 00-6.6-.8c-2.6 0-5.2.3-6.5.8l-.3-.6\"/>\n  <path fill=\"#c8b100\" d=\"M134.6 217.7c2.4 0 5-.4 5.9-.6.6-.2 1-.5 1-.8 0-.2-.2-.3-.4-.4-1.4-.5-4-.8-6.5-.8s-5 .3-6.4.8c-.2 0-.3.2-.4.3 0 .4.3.7 1 .9 1 .2 3.5.6 5.8.6\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M134.6 217.7c2.4 0 5-.4 5.9-.6.6-.2 1-.5 1-.8 0-.2-.2-.3-.4-.4-1.4-.5-4-.8-6.5-.8s-5 .3-6.4.8c-.2 0-.3.2-.4.3 0 .4.3.7 1 .9 1 .2 3.5.6 5.8.6z\"/>\n  <path fill=\"#c8b100\" d=\"M142.1 213.2l-.5-.5s-.6.3-1.3.2c-.6 0-.9-1-.9-1s-.7.7-1.3.7c-.7 0-1-.6-1-.6s-.7.5-1.3.4c-.6 0-1.2-.8-1.2-.8s-.6.8-1.2.8c-.6.1-1-.5-1-.5s-.4.6-1.1.7-1.4-.6-1.4-.6-.5.7-1 1c-.5 0-1.2-.4-1.2-.4l-.2.5-.3.1.2.5a27 27 0 017.2-.9c3 0 5.5.4 7.4 1l.2-.6\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M142.1 213.2l-.5-.5s-.6.3-1.3.2c-.6 0-.9-1-.9-1s-.7.7-1.3.7c-.7 0-1-.6-1-.6s-.7.5-1.3.4c-.6 0-1.2-.8-1.2-.8s-.6.8-1.2.8c-.6.1-1-.5-1-.5s-.4.6-1.1.7-1.4-.6-1.4-.6-.5.7-1 1c-.5 0-1.2-.4-1.2-.4l-.2.5-.3.1.2.5a27 27 0 017.2-.9c3 0 5.5.4 7.4 1l.2-.6z\"/>\n  <path fill=\"#c8b100\" d=\"M134.7 210.7h.2a1 1 0 000 .4c0 .6.4 1 1 1a1 1 0 001-.7l.2-.3v.4c.1.5.6.8 1.1.8.6 0 1-.4 1-1v-.1l.4-.4.2.5a.9.9 0 00-.1.4 1 1 0 001 1c.4 0 .7-.2.9-.5l.2-.2v.3c0 .3.1.6.4.7 0 0 .4 0 1-.4l.7-.7v.4s-.5.8-1 1c-.2.2-.5.4-.8.3-.3 0-.6-.3-.7-.6-.2.2-.4.2-.7.2-.6 0-1.2-.3-1.4-.8-.3.3-.7.5-1.1.5a1.6 1.6 0 01-1.2-.6 1.6 1.6 0 01-1 .4 1.6 1.6 0 01-1.3-.6 1.6 1.6 0 01-2.4.2 1.6 1.6 0 01-1.2.6 1.5 1.5 0 01-1.1-.5c-.2.5-.8.8-1.4.8-.2 0-.5 0-.7-.2-.1.3-.4.6-.7.6-.3 0-.6 0-.9-.2l-1-1 .1-.5.8.7c.5.4.9.4.9.4.3 0 .4-.4.4-.7v-.3l.2.2c.2.3.5.5.9.5a1 1 0 001-1 .9.9 0 000-.4v-.5l.4.4a.7.7 0 000 .1c0 .6.5 1 1 1 .6 0 1-.3 1.1-.9v-.3l.2.3c.2.4.6.7 1 .7.7 0 1.1-.4 1.1-1a1 1 0 000-.3h.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M134.7 210.7h.2a1 1 0 000 .4c0 .6.4 1 1 1a1 1 0 001-.7l.2-.3v.4c.1.5.6.8 1.1.8.6 0 1-.4 1-1v-.1l.4-.4.2.5a.9.9 0 00-.1.4 1 1 0 001 1c.4 0 .7-.2.9-.5l.2-.2v.3c0 .3.1.6.4.7 0 0 .4 0 1-.4l.7-.7v.4s-.5.8-1 1c-.2.2-.5.4-.8.3-.3 0-.6-.3-.7-.6-.2.2-.4.2-.7.2-.6 0-1.2-.3-1.4-.8-.3.3-.7.5-1.1.5a1.6 1.6 0 01-1.2-.6 1.6 1.6 0 01-1 .4 1.6 1.6 0 01-1.3-.6 1.6 1.6 0 01-2.4.2 1.6 1.6 0 01-1.2.6 1.5 1.5 0 01-1.1-.5c-.2.5-.8.8-1.4.8-.2 0-.5 0-.7-.2-.1.3-.4.6-.7.6-.3 0-.6 0-.9-.2l-1-1 .1-.5.8.7c.5.4.9.4.9.4.3 0 .4-.4.4-.7v-.3l.2.2c.2.3.5.5.9.5a1 1 0 001-1 .9.9 0 000-.4v-.5l.4.4a.7.7 0 000 .1c0 .6.5 1 1 1 .6 0 1-.3 1.1-.9v-.3l.2.3c.2.4.6.7 1 .7.7 0 1.1-.4 1.1-1a1 1 0 000-.3h.3z\"/>\n  <path fill=\"#c8b100\" d=\"M134.6 213.3c-2.9 0-5.5.4-7.3 1l-.3-.2.1-.3a27 27 0 017.5-1c3 0 5.7.4 7.6 1 0 0 .2.2.1.3l-.3.2a27.3 27.3 0 00-7.4-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-linejoin=\"round\" stroke-width=\".3\" d=\"M134.6 213.3c-2.9 0-5.5.4-7.3 1l-.3-.2.1-.3a27 27 0 017.5-1c3 0 5.7.4 7.6 1 0 0 .2.2.1.3l-.3.2a27.3 27.3 0 00-7.4-1z\"/>\n  <path fill=\"#fff\" d=\"M131.8 214.4c0-.3.2-.4.5-.4a.4.4 0 01.4.4c0 .2-.2.4-.4.4a.4.4 0 01-.5-.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M131.8 214.4c0-.3.2-.4.5-.4a.4.4 0 01.4.4c0 .2-.2.4-.4.4a.4.4 0 01-.5-.4z\"/>\n  <path fill=\"#ad1519\" d=\"M134.7 214.5h-1c-.1 0-.3 0-.3-.3l.3-.3h2a.3.3 0 01.2.3.3.3 0 01-.3.3h-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M134.7 214.5h-1c-.1 0-.3 0-.3-.3l.3-.3h2a.3.3 0 01.2.3.3.3 0 01-.3.3h-1\"/>\n  <path fill=\"#058e6e\" d=\"M130 214.9h-.7c-.1 0-.3 0-.3-.2a.3.3 0 01.2-.3l.7-.1.7-.1c.2 0 .3 0 .4.2a.3.3 0 01-.3.4h-.7\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M130 214.9h-.7c-.1 0-.3 0-.3-.2a.3.3 0 01.2-.3l.7-.1.7-.1c.2 0 .3 0 .4.2a.3.3 0 01-.3.4h-.7\"/>\n  <path fill=\"#ad1519\" d=\"M127.3 215.3l.3-.4h.7l-.4.6-.6-.2\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M127.3 215.3l.3-.4h.7l-.4.6-.6-.2\"/>\n  <path fill=\"#fff\" d=\"M136.6 214.4c0-.3.2-.4.4-.4a.4.4 0 01.5.4.4.4 0 01-.5.4.4.4 0 01-.4-.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M136.6 214.4c0-.3.2-.4.4-.4a.4.4 0 01.5.4.4.4 0 01-.5.4.4.4 0 01-.4-.4z\"/>\n  <path fill=\"#058e6e\" d=\"M139.3 214.9h.6a.3.3 0 00.4-.2.3.3 0 00-.3-.3l-.6-.1-.7-.1c-.2 0-.3 0-.4.2 0 .2.1.3.3.4h.7\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M139.3 214.9h.6a.3.3 0 00.4-.2.3.3 0 00-.3-.3l-.6-.1-.7-.1c-.2 0-.3 0-.4.2 0 .2.1.3.3.4h.7\"/>\n  <path fill=\"#ad1519\" d=\"M142 215.4l-.3-.5h-.7l.3.6.6-.1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M142 215.4l-.3-.5h-.7l.3.6.6-.1\"/>\n  <path fill=\"#ad1519\" d=\"M134.6 217.1a25 25 0 01-6-.6 25.5 25.5 0 0112.1 0c-1.6.4-3.7.6-6 .6\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-linejoin=\"round\" stroke-width=\".3\" d=\"M134.6 217.1a25 25 0 01-6-.6 25.5 25.5 0 0112.1 0c-1.6.4-3.7.6-6 .6z\"/>\n  <path fill=\"#c8b100\" d=\"M142 212l-.1-.3c-.2 0-.3 0-.4.2 0 .2 0 .4.2.4 0 0 .2 0 .3-.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M142 212l-.1-.3c-.2 0-.3 0-.4.2 0 .2 0 .4.2.4 0 0 .2 0 .3-.3z\"/>\n  <path fill=\"#c8b100\" d=\"M137.3 211.2c0-.2 0-.4-.2-.4 0 0-.2.1-.2.3 0 .2 0 .4.2.4l.3-.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M137.3 211.2c0-.2 0-.4-.2-.4 0 0-.2.1-.2.3 0 .2 0 .4.2.4l.3-.3z\"/>\n  <path fill=\"#c8b100\" d=\"M132 211.2l.1-.4c.2 0 .3.1.3.3 0 .2 0 .4-.2.4l-.2-.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M132 211.2l.1-.4c.2 0 .3.1.3.3 0 .2 0 .4-.2.4l-.2-.3z\"/>\n  <path fill=\"#c8b100\" d=\"M127.3 212l.1-.3c.2 0 .3 0 .4.2 0 .2 0 .4-.2.4 0 0-.2 0-.3-.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M127.3 212l.1-.3c.2 0 .3 0 .4.2 0 .2 0 .4-.2.4 0 0-.2 0-.3-.3z\"/>\n  <path fill=\"#c8b100\" d=\"M134.6 208.5l-.8.5.6 1.3.2.1.2-.1.7-1.3-.9-.5\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M134.6 208.5l-.8.5.6 1.3.2.1.2-.1.7-1.3-.9-.5\"/>\n  <path fill=\"#c8b100\" d=\"M132.8 210.5l.4.5 1.3-.4.1-.2-.1-.2-1.3-.3-.4.6\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M132.8 210.5l.4.5 1.3-.4.1-.2-.1-.2-1.3-.3-.4.6\"/>\n  <path fill=\"#c8b100\" d=\"M136.4 210.5l-.3.5-1.3-.4-.2-.2.2-.2 1.3-.3.3.6\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M136.4 210.5l-.3.5-1.3-.4-.2-.2.2-.2 1.3-.3.3.6\"/>\n  <path fill=\"#c8b100\" d=\"M129.3 209l-.7.7.9 1 .2.1.1-.1.3-1.3-.8-.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M129.3 209l-.7.7.9 1 .2.1.1-.1.3-1.3-.8-.3\"/>\n  <path fill=\"#c8b100\" d=\"M128 211.2l.4.5 1.2-.6v-.2l-.1-.2-1.3-.1-.3.6\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M128 211.2l.4.5 1.2-.6v-.2l-.1-.2-1.3-.1-.3.6\"/>\n  <path fill=\"#c8b100\" d=\"M131.5 210.5l-.3.6H130l-.2-.2.1-.3 1.2-.6.5.5\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M131.5 210.5l-.3.6H130l-.2-.2.1-.3 1.2-.6.5.5\"/>\n  <path fill=\"#c8b100\" d=\"M126.6 211.4v.6l-1.4.2-.2-.1v-.2l1-.9.6.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M126.6 211.4v.6l-1.4.2-.2-.1v-.2l1-.9.6.4\"/>\n  <path fill=\"#c8b100\" d=\"M129.2 210.9c0-.3.2-.5.5-.5s.5.2.5.5a.5.5 0 01-.5.4.5.5 0 01-.5-.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M129.2 210.9c0-.3.2-.5.5-.5s.5.2.5.5a.5.5 0 01-.5.4.5.5 0 01-.5-.4z\"/>\n  <path fill=\"#c8b100\" d=\"M140 209l.7.7-.9 1-.2.1-.1-.1-.3-1.3.8-.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M140 209l.7.7-.9 1-.2.1-.1-.1-.3-1.3.8-.3\"/>\n  <path fill=\"#c8b100\" d=\"M141.4 211.2l-.5.5-1.2-.6v-.2l.1-.2 1.3-.1.3.6\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M141.4 211.2l-.5.5-1.2-.6v-.2l.1-.2 1.3-.1.3.6\"/>\n  <path fill=\"#c8b100\" d=\"M137.8 210.5l.3.6h1.3l.2-.2-.1-.3-1.2-.6-.5.5\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M137.8 210.5l.3.6h1.3l.2-.2-.1-.3-1.2-.6-.5.5\"/>\n  <path fill=\"#c8b100\" d=\"M142.5 211.4l.1.6 1.3.2.2-.1v-.2l-1-.9-.6.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M142.5 211.4l.1.6 1.3.2.2-.1v-.2l-1-.9-.6.4\"/>\n  <path fill=\"#c8b100\" d=\"M134.2 210.4a.5.5 0 01.4-.4c.3 0 .5.2.5.4a.5.5 0 01-.5.5.5.5 0 01-.4-.5\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M134.2 210.4a.5.5 0 01.4-.4c.3 0 .5.2.5.4a.5.5 0 01-.5.5.5.5 0 01-.4-.5z\"/>\n  <path fill=\"#c8b100\" d=\"M139.1 210.9c0-.3.3-.5.5-.5a.5.5 0 01.5.5.5.5 0 01-.5.4.5.5 0 01-.5-.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M139.1 210.9c0-.3.3-.5.5-.5a.5.5 0 01.5.5.5.5 0 01-.5.4.5.5 0 01-.5-.4z\"/>\n  <path fill=\"#c8b100\" d=\"M124.8 212.2l-.6-.7c-.2-.2-.7-.3-.7-.3 0-.1.3-.3.6-.3a.5.5 0 01.4.2v-.2s.3 0 .4.3v1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M124.8 212.2l-.6-.7c-.2-.2-.7-.3-.7-.3 0-.1.3-.3.6-.3a.5.5 0 01.4.2v-.2s.3 0 .4.3v1z\"/>\n  <path fill=\"#c8b100\" d=\"M124.8 212c.1-.2.4-.2.5 0 .2.1.3.3.2.5l-.5-.1c-.2-.1-.3-.4-.2-.5\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M124.8 212c.1-.2.4-.2.5 0 .2.1.3.3.2.5l-.5-.1c-.2-.1-.3-.4-.2-.5z\"/>\n  <path fill=\"#c8b100\" d=\"M144.3 212.2l.6-.7c.2-.2.7-.3.7-.3 0-.1-.3-.3-.6-.3a.6.6 0 00-.4.2v-.2s-.3 0-.4.3v.7l.1.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M144.3 212.2l.6-.7c.2-.2.7-.3.7-.3 0-.1-.3-.3-.6-.3a.6.6 0 00-.4.2v-.2s-.3 0-.4.3v.7l.1.3z\"/>\n  <path fill=\"#c8b100\" d=\"M144.3 212c0-.2-.3-.2-.5 0-.2.1-.2.3-.1.5l.5-.1c.2-.1.2-.4.1-.5\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M144.3 212c0-.2-.3-.2-.5 0-.2.1-.2.3-.1.5l.5-.1c.2-.1.2-.4.1-.5z\"/>\n  <path fill=\"#c8b100\" d=\"M124 223h21.4v-5.5H124v5.6z\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M124 223h21.4v-5.5H124v5.6z\"/>\n  <path fill=\"#c8b100\" d=\"M126.2 226.8a1 1 0 01.4 0h16.5a1.4 1.4 0 01-1-1.2c0-.6.5-1.1 1-1.3a1.7 1.7 0 01-.4 0h-16a1.4 1.4 0 01-.5 0c.6.2 1 .7 1 1.3a1.3 1.3 0 01-1 1.2\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-linejoin=\"round\" stroke-width=\".4\" d=\"M126.2 226.8a1 1 0 01.4 0h16.5a1.4 1.4 0 01-1-1.2c0-.6.5-1.1 1-1.3a1.7 1.7 0 01-.4 0h-16a1.4 1.4 0 01-.5 0c.6.2 1 .7 1 1.3a1.3 1.3 0 01-1 1.2z\"/>\n  <path fill=\"#c8b100\" d=\"M126.6 226.8h16c.6 0 1 .3 1 .7 0 .4-.4.8-1 .8h-16c-.5 0-1-.4-1-.8s.5-.8 1-.8\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M126.6 226.8h16c.6 0 1 .3 1 .7 0 .4-.4.8-1 .8h-16c-.5 0-1-.4-1-.8s.5-.8 1-.8z\"/>\n  <path fill=\"#c8b100\" d=\"M126.6 223h16c.6 0 1 .4 1 .7 0 .4-.4.6-1 .6h-16c-.5 0-1-.2-1-.6 0-.3.5-.6 1-.6\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M126.6 223h16c.6 0 1 .4 1 .7 0 .4-.4.6-1 .6h-16c-.5 0-1-.2-1-.6 0-.3.5-.6 1-.6z\"/>\n  <path fill=\"#005bbf\" d=\"M149.6 317.4c-1.4 0-2.8-.3-3.7-.8a8.4 8.4 0 00-3.8-.8c-1.4 0-2.7.3-3.7.8a8.3 8.3 0 01-3.8.8c-1.5 0-2.8-.3-3.7-.8a8.4 8.4 0 00-3.7-.8 8 8 0 00-3.7.8 8.3 8.3 0 01-3.8.8v2.4c1.5 0 2.8-.4 3.8-.9a8.2 8.2 0 013.7-.8c1.4 0 2.7.3 3.7.8s2.2.9 3.7.9a8.4 8.4 0 003.8-.9c1-.5 2.3-.8 3.7-.8 1.5 0 2.8.3 3.8.8s2.2.9 3.7.9v-2.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M149.6 317.4c-1.4 0-2.8-.3-3.7-.8a8.4 8.4 0 00-3.8-.8c-1.4 0-2.7.3-3.7.8a8.3 8.3 0 01-3.8.8c-1.5 0-2.8-.3-3.7-.8a8.4 8.4 0 00-3.7-.8 8 8 0 00-3.7.8 8.3 8.3 0 01-3.8.8v2.4c1.5 0 2.8-.4 3.8-.9a8.2 8.2 0 013.7-.8c1.4 0 2.7.3 3.7.8s2.2.9 3.7.9a8.4 8.4 0 003.8-.9c1-.5 2.3-.8 3.7-.8 1.5 0 2.8.3 3.8.8s2.2.9 3.7.9v-2.4z\"/>\n  <path fill=\"#ccc\" d=\"M149.6 319.8a8 8 0 01-3.7-.9 8.3 8.3 0 00-3.8-.8c-1.4 0-2.7.3-3.7.8s-2.3.9-3.8.9-2.8-.4-3.7-.9a8.4 8.4 0 00-3.7-.8 8.2 8.2 0 00-3.7.8c-1 .5-2.3.9-3.8.9v2.3c1.5 0 2.8-.4 3.8-.9a8.1 8.1 0 013.7-.7c1.4 0 2.7.2 3.7.7a8.3 8.3 0 007.5 0 8.5 8.5 0 017.5.1 8.1 8.1 0 003.7.8v-2.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M149.6 319.8a8 8 0 01-3.7-.9 8.3 8.3 0 00-3.8-.8c-1.4 0-2.7.3-3.7.8s-2.3.9-3.8.9-2.8-.4-3.7-.9a8.4 8.4 0 00-3.7-.8 8.2 8.2 0 00-3.7.8c-1 .5-2.3.9-3.8.9v2.3c1.5 0 2.8-.4 3.8-.9a8.1 8.1 0 013.7-.7c1.4 0 2.7.2 3.7.7a8.3 8.3 0 007.5 0 8.5 8.5 0 017.5.1 8.1 8.1 0 003.7.8v-2.3\"/>\n  <path fill=\"#005bbf\" d=\"M149.6 322a7 7 0 01-3.7-.8 8.3 8.3 0 00-3.8-.7c-1.4 0-2.7.2-3.7.7-1 .6-2.3.9-3.8.9s-2.8-.4-3.7-.9a8.4 8.4 0 00-3.7-.8 8 8 0 00-3.7.8c-1 .5-2.3.9-3.8.9v2.3c1.5 0 2.8-.3 3.8-.9a10.2 10.2 0 017.4 0 7 7 0 003.7.9 8.4 8.4 0 003.8-.8c1-.5 2.3-.8 3.7-.8 1.5 0 2.8.3 3.8.8s2.2.8 3.7.8V322\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M149.6 322a7 7 0 01-3.7-.8 8.3 8.3 0 00-3.8-.7c-1.4 0-2.7.2-3.7.7-1 .6-2.3.9-3.8.9s-2.8-.4-3.7-.9a8.4 8.4 0 00-3.7-.8 8 8 0 00-3.7.8c-1 .5-2.3.9-3.8.9v2.3c1.5 0 2.8-.3 3.8-.9a10.2 10.2 0 017.4 0 7 7 0 003.7.9 8.4 8.4 0 003.8-.8c1-.5 2.3-.8 3.7-.8 1.5 0 2.8.3 3.8.8s2.2.8 3.7.8V322\"/>\n  <path fill=\"#ccc\" d=\"M149.6 326.7a8 8 0 01-3.7-.8c-1-.5-2.3-.8-3.7-.8a8.4 8.4 0 00-3.8.8c-1 .5-2.3.8-3.8.8a7 7 0 01-3.7-.9 8.4 8.4 0 00-3.7-.7c-1.4 0-2.7.3-3.7.8s-2.3.8-3.8.8v-2.3a8.3 8.3 0 003.8-.9 10.2 10.2 0 017.4 0 8 8 0 003.7.9 8.4 8.4 0 003.8-.8c1-.5 2.3-.8 3.8-.8 1.4 0 2.7.3 3.7.8s2.3.8 3.7.8v2.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M149.6 326.7a8 8 0 01-3.7-.8c-1-.5-2.3-.8-3.7-.8a8.4 8.4 0 00-3.8.8c-1 .5-2.3.8-3.8.8a7 7 0 01-3.7-.9 8.4 8.4 0 00-3.7-.7c-1.4 0-2.7.3-3.7.8s-2.3.8-3.8.8v-2.3a8.3 8.3 0 003.8-.9 10.2 10.2 0 017.4 0 8 8 0 003.7.9 8.4 8.4 0 003.8-.8c1-.5 2.3-.8 3.8-.8 1.4 0 2.7.3 3.7.8s2.3.8 3.7.8v2.3\"/>\n  <path fill=\"#005bbf\" d=\"M149.6 329a8.1 8.1 0 01-3.7-.8c-1-.5-2.3-.8-3.7-.8a8.4 8.4 0 00-3.8.8c-1 .5-2.3.8-3.8.8a7 7 0 01-3.7-.9 8.4 8.4 0 00-3.7-.7c-1.4 0-2.7.3-3.7.8s-2.3.8-3.8.8v-2.3a8.3 8.3 0 003.8-.8c1-.5 2.3-.8 3.7-.8 1.4 0 2.7.3 3.7.7a8.4 8.4 0 007.5 0c1-.4 2.3-.7 3.8-.7 1.4 0 2.7.3 3.7.8s2.2.8 3.7.8v2.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M149.6 329a8.1 8.1 0 01-3.7-.8c-1-.5-2.3-.8-3.7-.8a8.4 8.4 0 00-3.8.8c-1 .5-2.3.8-3.8.8a7 7 0 01-3.7-.9 8.4 8.4 0 00-3.7-.7c-1.4 0-2.7.3-3.7.8s-2.3.8-3.8.8v-2.3a8.3 8.3 0 003.8-.8c1-.5 2.3-.8 3.7-.8 1.4 0 2.7.3 3.7.7a8.4 8.4 0 007.5 0c1-.4 2.3-.7 3.8-.7 1.4 0 2.7.3 3.7.8s2.2.8 3.7.8v2.3z\"/>\n  <path fill=\"#c8b100\" d=\"M126.2 308l.2.5c0 1.5-1.3 2.6-2.7 2.6h22a2.7 2.7 0 01-2.7-2.6v-.5a1.3 1.3 0 01-.3 0h-16a1.4 1.4 0 01-.5 0\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-linejoin=\"round\" stroke-width=\".4\" d=\"M126.2 308l.2.5c0 1.5-1.3 2.6-2.7 2.6h22a2.7 2.7 0 01-2.7-2.6v-.5a1.3 1.3 0 01-.3 0h-16a1.4 1.4 0 01-.5 0z\"/>\n  <path fill=\"#c8b100\" d=\"M126.6 306.5h16c.6 0 1 .3 1 .8 0 .4-.4.7-1 .7h-16c-.5 0-1-.3-1-.8 0-.4.5-.7 1-.7\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M126.6 306.5h16c.6 0 1 .3 1 .8 0 .4-.4.7-1 .7h-16c-.5 0-1-.3-1-.8 0-.4.5-.7 1-.7z\"/>\n  <path fill=\"#c8b100\" d=\"M123.7 316.7h22V311h-22v5.6z\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M123.7 316.7h22V311h-22v5.6z\"/>\n  <path fill=\"#ad1519\" d=\"M122 286.7c-2.2 1.2-3.7 2.5-3.4 3.2 0 .6.8 1 1.8 1.6 1.5 1.1 2.5 3 1.7 4a5.5 5.5 0 00-.1-8.8\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M122 286.7c-2.2 1.2-3.7 2.5-3.4 3.2 0 .6.8 1 1.8 1.6 1.5 1.1 2.5 3 1.7 4a5.5 5.5 0 00-.1-8.8z\"/>\n  <path fill=\"#ccc\" d=\"M126.8 305.6h15.6V229h-15.6v76.5z\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M138 229.2v76.3m1.7-76.3v76.3m-12.9 0h15.6v-76.4h-15.6v76.5z\"/>\n  <path fill=\"#ad1519\" d=\"M158.4 257.7a49.6 49.6 0 00-23.3-2c-9.4 1.6-16.5 5.3-15.9 8.4v.2l-3.5-8.2c-.6-3.3 7.2-7.5 17.6-9.2a43 43 0 019.2-.7c6.6 0 12.4.8 15.8 2.1v9.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-linejoin=\"round\" stroke-width=\".4\" d=\"M158.4 257.7a49.6 49.6 0 00-23.3-2c-9.4 1.6-16.5 5.3-15.9 8.4v.2l-3.5-8.2c-.6-3.3 7.2-7.5 17.6-9.2a43 43 0 019.2-.7c6.6 0 12.4.8 15.8 2.1v9.4\"/>\n  <path fill=\"#ad1519\" d=\"M126.8 267.3c-4.3-.3-7.3-1.4-7.6-3.2-.3-1.5 1.2-3 3.8-4.5 1.2.1 2.5.3 3.8.3v7.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M126.8 267.3c-4.3-.3-7.3-1.4-7.6-3.2-.3-1.5 1.2-3 3.8-4.5 1.2.1 2.5.3 3.8.3v7.4\"/>\n  <path fill=\"#ad1519\" d=\"M142.5 261.5c2.7.4 4.7 1 5.7 1.9l.1.2c.5 1-1.9 3-5.9 5.4v-7.5\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M142.5 261.5c2.7.4 4.7 1 5.7 1.9l.1.2c.5 1-1.9 3-5.9 5.4v-7.5\"/>\n  <path fill=\"#ad1519\" d=\"M117.1 282c-.4-1.2 3.8-3.6 9.8-5.8l7.8-3.2c8.3-3.7 14.4-7.9 13.6-9.4v-.2c.4.4 1 8 1 8 .8 1.3-4.8 5.5-12.4 9.1-2.5 1.2-7.6 3-10 4-4.4 1.4-8.7 4.3-8.3 5.3l-1.5-7.7\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-linejoin=\"round\" stroke-width=\".4\" d=\"M117.1 282c-.4-1.2 3.8-3.6 9.8-5.8l7.8-3.2c8.3-3.7 14.4-7.9 13.6-9.4v-.2c.4.4 1 8 1 8 .8 1.3-4.8 5.5-12.4 9.1-2.5 1.2-7.6 3-10 4-4.4 1.4-8.7 4.3-8.3 5.3l-1.5-7.7z\"/>\n  <path fill=\"#c8b100\" d=\"M125.8 254c1.9-.6 3.1-1.5 2.5-3-.4-1-1.4-1-2.8-.6l-2.6 1 2.3 5.8.8-.3.8-.3-1-2.5zm-1.2-2.7l.7-.3c.5-.2 1.2.1 1.4.8.2.5.2 1-.5 1.5a4.4 4.4 0 01-.6.3l-1-2.3m7.3-2.5l-.9.3h-.8l1.3 6.1 4.3-.8-.2-.4v-.4l-2.5.6-1.2-5.3m8.4 5.2c.8-2.2 1.7-4.3 2.7-6.4a5.3 5.3 0 01-1 0 54.8 54.8 0 01-1.8 4.6l-2.4-4.3-1 .1h-1a131.4 131.4 0 013.5 6h1m8.8-4.7l.4-.9a3.4 3.4 0 00-1.7-.6c-1.7-.1-2.7.6-2.8 1.7-.2 2.1 3.2 2 3 3.4 0 .6-.7.9-1.4.8-.8 0-1.4-.5-1.4-1.2h-.3a7.3 7.3 0 01-.4 1.1 4 4 0 001.8.6c1.7.2 3-.5 3.2-1.7.2-2-3.3-2.1-3.1-3.4 0-.5.4-.8 1.3-.7.7 0 1 .4 1.2.9h.2\"/>\n  <path fill=\"#ad1519\" d=\"M277.9 211.6s-.7.8-1.3.9c-.5 0-1.1-.5-1.1-.5s-.5.5-1 .6c-.6.1-1.4-.6-1.4-.6l-1 1c-.6 0-1.1-.3-1.1-.3s-.3.4-.7.6h-.4l-.6-.4-.7-.7-.5-.3-.4-1v-.5c-.1-.6.8-1.4 2.2-1.7a3.9 3.9 0 012 0c.5-.5 1.7-.8 3-.8s2.4.3 3 .7a5.5 5.5 0 012.9-.7c1.3 0 2.5.3 3 .8.5-.2 1.2-.2 2 0 1.4.3 2.3 1 2.2 1.7v.5l-.4 1-.6.3-.6.7-.6.3s-.3.2-.4 0c-.4-.1-.7-.5-.7-.5s-.6.4-1 .2c-.5-.2-1-1-1-1s-.9.8-1.4.7c-.6-.1-1-.6-1-.6s-.7.6-1.2.5c-.5-.1-1.2-.9-1.2-.9\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M277.9 211.6s-.7.8-1.3.9c-.5 0-1.1-.5-1.1-.5s-.5.5-1 .6c-.6.1-1.4-.6-1.4-.6l-1 1c-.6 0-1.1-.3-1.1-.3s-.3.4-.7.6h-.4l-.6-.4-.7-.7-.5-.3-.4-1v-.5c-.1-.6.8-1.4 2.2-1.7a3.9 3.9 0 012 0c.5-.5 1.7-.8 3-.8s2.4.3 3 .7a5.5 5.5 0 012.9-.7c1.3 0 2.5.3 3 .8.5-.2 1.2-.2 2 0 1.4.3 2.3 1 2.2 1.7v.5l-.4 1-.6.3-.6.7-.6.3s-.3.2-.4 0c-.4-.1-.7-.5-.7-.5s-.6.4-1 .2c-.5-.2-1-1-1-1s-.9.8-1.4.7c-.6-.1-1-.6-1-.6s-.7.6-1.2.5c-.5-.1-1.2-.9-1.2-.9z\"/>\n  <path fill=\"#c8b100\" d=\"M276.5 207.6c0-1 .6-2 1.3-2 .8 0 1.3 1 1.3 2s-.5 1.8-1.3 1.8c-.7 0-1.3-.8-1.3-1.9\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M276.5 207.6c0-1 .6-2 1.3-2 .8 0 1.3 1 1.3 2s-.5 1.8-1.3 1.8c-.7 0-1.3-.8-1.3-1.9z\"/>\n  <path fill=\"#c8b100\" d=\"M277.3 207.6c0-1 .2-1.8.5-1.8.4 0 .7.8.7 1.8s-.3 1.7-.6 1.7c-.4 0-.6-.8-.6-1.8\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M277.3 207.6c0-1 .2-1.8.5-1.8.4 0 .7.8.7 1.8s-.3 1.7-.6 1.7c-.4 0-.6-.8-.6-1.8z\"/>\n  <path fill=\"#c8b100\" d=\"M271 215.3a4.5 4.5 0 00-.5-1 27.4 27.4 0 0114.8 0l-.6.8a5.2 5.2 0 00-.3.8 22.9 22.9 0 00-6.6-.8c-2.6 0-5.2.3-6.6.8l-.2-.6\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M271 215.3a4.5 4.5 0 00-.5-1 27.4 27.4 0 0114.8 0l-.6.8a5.2 5.2 0 00-.3.8 22.9 22.9 0 00-6.6-.8c-2.6 0-5.2.3-6.6.8l-.2-.6\"/>\n  <path fill=\"#c8b100\" d=\"M277.8 217.7c2.4 0 5-.4 5.9-.6.6-.2 1-.5 1-.8 0-.2-.2-.3-.4-.4a24.1 24.1 0 00-6.5-.8c-2.5 0-5 .3-6.4.8-.2 0-.3.2-.4.3 0 .4.3.7 1 .9 1 .2 3.5.6 5.8.6\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M277.8 217.7c2.4 0 5-.4 5.9-.6.6-.2 1-.5 1-.8 0-.2-.2-.3-.4-.4a24.1 24.1 0 00-6.5-.8c-2.5 0-5 .3-6.4.8-.2 0-.3.2-.4.3 0 .4.3.7 1 .9 1 .2 3.5.6 5.8.6z\"/>\n  <path fill=\"#fff\" d=\"M283.5 208.4c0-.2.2-.4.4-.4s.5.2.5.4-.2.4-.5.4a.4.4 0 01-.4-.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".2\" d=\"M283.5 208.4c0-.2.2-.4.4-.4s.5.2.5.4-.2.4-.5.4a.4.4 0 01-.4-.4zm-.2-1.4a.4.4 0 01.4-.4c.2 0 .4.1.4.4s-.2.4-.4.4a.4.4 0 01-.4-.4zm-1.1-1c0-.2.2-.3.4-.3s.4.1.4.4c0 .2-.2.4-.4.4a.4.4 0 01-.4-.5zm-1.4-.4c0-.2.2-.4.4-.4.3 0 .5.2.5.4s-.2.4-.4.4-.5-.2-.5-.4zm-1.4 0c0-.2.2-.3.5-.3s.4.1.4.4c0 .2-.2.4-.4.4a.4.4 0 01-.5-.4z\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-linecap=\"round\" stroke-width=\".3\" d=\"M287.8 211.2l.2-1a2.7 2.7 0 00-2.7-2.8c-.5 0-1 .1-1.3.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M283 209.2l.2-.8c0-1.1-1.1-2-2.5-2-.6 0-1.2.2-1.6.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".2\" d=\"M288.2 210c0-.3.2-.5.4-.5s.4.2.4.4c0 .3-.2.4-.4.4s-.4-.1-.4-.4zm-.2-1.6c0-.2.2-.4.4-.4a.4.4 0 01.5.4c0 .2-.2.4-.4.4-.3 0-.5-.2-.5-.4zm-1-1.1a.4.4 0 01.5-.4c.2 0 .4.1.4.4a.4.4 0 01-.4.4.4.4 0 01-.5-.4zm-1.3-.7c0-.2.2-.4.5-.4s.4.2.4.4c0 .3-.2.5-.4.5a.4.4 0 01-.5-.5zm-1.4.1c0-.2.2-.4.5-.4s.4.2.4.4-.2.4-.4.4-.5-.2-.5-.4z\"/>\n  <path fill=\"#c8b100\" d=\"M285.3 213.2l-.5-.5s-.6.3-1.3.2c-.6 0-.9-1-.9-1s-.7.7-1.3.7c-.7 0-1-.6-1-.6s-.7.5-1.3.4c-.6 0-1.2-.8-1.2-.8s-.6.8-1.2.8c-.6.1-1-.5-1-.5s-.3.6-1.1.7-1.4-.6-1.4-.6-.4.7-1 1c-.5 0-1.2-.4-1.2-.4l-.1.5-.3.1.1.5a27 27 0 017.3-.9c2.8 0 5.4.4 7.3 1l.2-.6\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M285.3 213.2l-.5-.5s-.6.3-1.3.2c-.6 0-.9-1-.9-1s-.7.7-1.3.7c-.7 0-1-.6-1-.6s-.7.5-1.3.4c-.6 0-1.2-.8-1.2-.8s-.6.8-1.2.8c-.6.1-1-.5-1-.5s-.3.6-1.1.7-1.4-.6-1.4-.6-.4.7-1 1c-.5 0-1.2-.4-1.2-.4l-.1.5-.3.1.1.5a27 27 0 017.3-.9c2.8 0 5.4.4 7.3 1l.2-.6z\"/>\n  <path fill=\"#fff\" d=\"M271.3 208.4c0-.2.2-.4.4-.4s.4.2.4.4a.4.4 0 01-.4.4.4.4 0 01-.4-.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".2\" d=\"M271.3 208.4c0-.2.2-.4.4-.4s.4.2.4.4a.4.4 0 01-.4.4.4.4 0 01-.4-.4zm.2-1.4c0-.3.2-.4.4-.4s.5.1.5.4-.2.4-.5.4a.4.4 0 01-.4-.4zm1-1c0-.2.3-.3.5-.3s.5.1.5.4c0 .2-.2.4-.5.4a.4.4 0 01-.4-.5zm1.4-.4c0-.2.2-.4.5-.4s.4.2.4.4-.2.4-.4.4-.5-.2-.5-.4zm1.4 0c0-.2.2-.3.5-.3.2 0 .4.1.4.4 0 .2-.2.4-.4.4a.4.4 0 01-.5-.4z\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-linecap=\"round\" stroke-width=\".3\" d=\"M267.8 211.2a2.8 2.8 0 01-.2-1 2.7 2.7 0 012.7-2.8c.5 0 1 .1 1.4.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M272.7 209.2a1.7 1.7 0 01-.3-.8c0-1 1.2-2 2.6-2a3 3 0 011.5.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".2\" d=\"M266.6 210c0-.3.2-.5.4-.5.3 0 .4.2.4.4a.4.4 0 01-.4.4c-.2 0-.4-.1-.4-.4zm.1-1.6c0-.2.3-.4.5-.4s.4.2.4.4-.2.4-.4.4-.4-.2-.4-.4zm1-1.1c0-.3.2-.4.5-.4a.4.4 0 01.4.4.4.4 0 01-.4.4.4.4 0 01-.5-.4zm1.3-.7c0-.2.2-.4.5-.4.2 0 .4.2.4.4 0 .3-.2.5-.4.5a.4.4 0 01-.5-.5zm1.4.1c0-.2.2-.4.5-.4a.4.4 0 01.4.4.4.4 0 01-.4.4c-.3 0-.5-.2-.5-.4z\"/>\n  <path fill=\"#c8b100\" d=\"M277.9 210.7h.2a1 1 0 000 .4c0 .6.5 1 1 1a1 1 0 001-.7l.2-.3v.4c.1.5.6.8 1.1.8.6 0 1-.4 1-1a.7.7 0 000-.1l.4-.4.2.5a1 1 0 00-.1.4 1 1 0 001 1c.4 0 .7-.2.9-.5l.2-.2v.3c0 .3.1.6.4.7 0 0 .4 0 1-.4s.7-.7.7-.7v.4s-.5.8-1 1c-.2.2-.5.4-.8.3-.3 0-.6-.3-.7-.6a1.5 1.5 0 01-.7.2c-.6 0-1.2-.3-1.4-.8a1.5 1.5 0 01-1.1.5c-.5 0-1-.2-1.2-.6a1.5 1.5 0 01-1 .4c-.6 0-1-.2-1.4-.6-.2.4-.7.6-1.2.6-.4 0-.8-.1-1-.4a1.6 1.6 0 01-1.3.6c-.4 0-.8-.2-1.1-.5-.2.5-.8.8-1.4.8-.2 0-.5 0-.7-.2-.1.3-.4.6-.7.6-.3 0-.6 0-.9-.2a4.2 4.2 0 01-1-1l.1-.5.8.7c.5.4.9.4.9.4.3 0 .4-.4.4-.7v-.3l.2.2c.2.3.5.5.9.5a1 1 0 001-1 1 1 0 000-.4v-.5l.4.4v.1c0 .6.5 1 1 1 .6 0 1-.3 1.1-.9v-.3l.2.3c.2.4.6.7 1 .7.6 0 1.1-.4 1.1-1a1 1 0 000-.3h.2\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M277.9 210.7h.2a1 1 0 000 .4c0 .6.5 1 1 1a1 1 0 001-.7l.2-.3v.4c.1.5.6.8 1.1.8.6 0 1-.4 1-1a.7.7 0 000-.1l.4-.4.2.5a1 1 0 00-.1.4 1 1 0 001 1c.4 0 .7-.2.9-.5l.2-.2v.3c0 .3.1.6.4.7 0 0 .4 0 1-.4s.7-.7.7-.7v.4s-.5.8-1 1c-.2.2-.5.4-.8.3-.3 0-.6-.3-.7-.6a1.5 1.5 0 01-.7.2c-.6 0-1.2-.3-1.4-.8a1.5 1.5 0 01-1.1.5c-.5 0-1-.2-1.2-.6a1.5 1.5 0 01-1 .4c-.6 0-1-.2-1.4-.6-.2.4-.7.6-1.2.6-.4 0-.8-.1-1-.4a1.6 1.6 0 01-1.3.6c-.4 0-.8-.2-1.1-.5-.2.5-.8.8-1.4.8-.2 0-.5 0-.7-.2-.1.3-.4.6-.7.6-.3 0-.6 0-.9-.2a4.2 4.2 0 01-1-1l.1-.5.8.7c.5.4.9.4.9.4.3 0 .4-.4.4-.7v-.3l.2.2c.2.3.5.5.9.5a1 1 0 001-1 1 1 0 000-.4v-.5l.4.4v.1c0 .6.5 1 1 1 .6 0 1-.3 1.1-.9v-.3l.2.3c.2.4.6.7 1 .7.6 0 1.1-.4 1.1-1a1 1 0 000-.3h.2z\"/>\n  <path fill=\"#c8b100\" d=\"M277.8 213.3c-2.9 0-5.5.4-7.3 1l-.3-.2.1-.3c2-.6 4.6-1 7.5-1 3 0 5.7.4 7.6 1 0 0 .2.2.1.3l-.3.2a27 27 0 00-7.4-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M277.8 213.3c-2.9 0-5.5.4-7.3 1l-.3-.2.1-.3c2-.6 4.6-1 7.5-1 3 0 5.7.4 7.6 1 0 0 .2.2.1.3l-.3.2a27 27 0 00-7.4-1z\"/>\n  <path fill=\"#fff\" d=\"M275 214.4c0-.3.2-.4.5-.4a.4.4 0 01.4.4.4.4 0 01-.4.4c-.3 0-.5-.2-.5-.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M275 214.4c0-.3.2-.4.5-.4a.4.4 0 01.4.4.4.4 0 01-.4.4c-.3 0-.5-.2-.5-.4z\"/>\n  <path fill=\"#ad1519\" d=\"M277.9 214.5h-1c-.1 0-.3 0-.3-.3l.3-.3h2a.3.3 0 01.2.3.3.3 0 01-.3.3h-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M277.9 214.5h-1c-.1 0-.3 0-.3-.3l.3-.3h2a.3.3 0 01.2.3.3.3 0 01-.3.3h-1\"/>\n  <path fill=\"#058e6e\" d=\"M273.2 214.9h-.6a.3.3 0 01-.4-.2.3.3 0 01.3-.3l.6-.1.7-.1c.2 0 .3 0 .4.2a.3.3 0 01-.3.4h-.7\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M273.2 214.9h-.6a.3.3 0 01-.4-.2.3.3 0 01.3-.3l.6-.1.7-.1c.2 0 .3 0 .4.2a.3.3 0 01-.3.4h-.7\"/>\n  <path fill=\"#ad1519\" d=\"M270.5 215.3l.3-.4h.7l-.4.6-.6-.2\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M270.5 215.3l.3-.4h.7l-.4.6-.6-.2\"/>\n  <path fill=\"#fff\" d=\"M279.8 214.4c0-.3.2-.4.4-.4.3 0 .5.1.5.4 0 .2-.2.4-.5.4a.4.4 0 01-.4-.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M279.8 214.4c0-.3.2-.4.4-.4.3 0 .5.1.5.4 0 .2-.2.4-.5.4a.4.4 0 01-.4-.4z\"/>\n  <path fill=\"#058e6e\" d=\"M282.5 214.9h.7a.3.3 0 00.3-.2.3.3 0 00-.2-.3l-.7-.1-.7-.1c-.2 0-.3 0-.4.2 0 .2.1.3.3.4h.7\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M282.5 214.9h.7a.3.3 0 00.3-.2.3.3 0 00-.2-.3l-.7-.1-.7-.1c-.2 0-.3 0-.4.2 0 .2.1.3.3.4h.7\"/>\n  <path fill=\"#ad1519\" d=\"M285.1 215.4l-.2-.5h-.7l.3.6.6-.1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M285.1 215.4l-.2-.5h-.7l.3.6.6-.1\"/>\n  <path fill=\"#ad1519\" d=\"M277.8 217.1a25 25 0 01-6-.6 25.4 25.4 0 016-.7c2.4 0 4.5.3 6.1.7-1.6.4-3.7.6-6 .6\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-linejoin=\"round\" stroke-width=\".3\" d=\"M277.8 217.1a25 25 0 01-6-.6 25.4 25.4 0 016-.7c2.4 0 4.5.3 6.1.7-1.6.4-3.7.6-6 .6z\"/>\n  <path fill=\"#c8b100\" d=\"M285.2 212l-.1-.3c-.2 0-.3 0-.4.2l.1.4c.2 0 .3 0 .4-.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M285.2 212l-.1-.3c-.2 0-.3 0-.4.2l.1.4c.2 0 .3 0 .4-.3z\"/>\n  <path fill=\"#c8b100\" d=\"M280.6 211.2c0-.2-.1-.4-.3-.4 0 0-.2.1-.2.3 0 .2 0 .4.2.4l.3-.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M280.6 211.2c0-.2-.1-.4-.3-.4 0 0-.2.1-.2.3 0 .2 0 .4.2.4l.3-.3z\"/>\n  <path fill=\"#c8b100\" d=\"M275.2 211.2c0-.2 0-.4.2-.4l.3.3-.2.4c-.2 0-.3-.2-.3-.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M275.2 211.2c0-.2 0-.4.2-.4l.3.3-.2.4c-.2 0-.3-.2-.3-.3z\"/>\n  <path fill=\"#c8b100\" d=\"M270.5 212l.1-.3c.2 0 .3 0 .4.2l-.1.4c-.2 0-.3 0-.4-.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M270.5 212l.1-.3c.2 0 .3 0 .4.2l-.1.4c-.2 0-.3 0-.4-.3z\"/>\n  <path fill=\"#c8b100\" d=\"M277.8 208.5l-.8.5.6 1.3.2.1.3-.1.6-1.3-.9-.5\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M277.8 208.5l-.8.5.6 1.3.2.1.3-.1.6-1.3-.9-.5\"/>\n  <path fill=\"#c8b100\" d=\"M276 210.5l.4.5 1.3-.4.1-.2-.1-.2-1.3-.3-.4.6\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M276 210.5l.4.5 1.3-.4.1-.2-.1-.2-1.3-.3-.4.6\"/>\n  <path fill=\"#c8b100\" d=\"M279.6 210.5l-.3.5-1.3-.4-.1-.2v-.2l1.4-.3.4.6\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M279.6 210.5l-.3.5-1.3-.4-.1-.2v-.2l1.4-.3.4.6\"/>\n  <path fill=\"#c8b100\" d=\"M272.5 209l-.7.7.9 1 .2.1.2-.1.2-1.3-.8-.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M272.5 209l-.7.7.9 1 .2.1.2-.1.2-1.3-.8-.3\"/>\n  <path fill=\"#c8b100\" d=\"M271.1 211.2l.5.5 1.2-.6v-.2l-.1-.2-1.3-.1-.3.6\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M271.1 211.2l.5.5 1.2-.6v-.2l-.1-.2-1.3-.1-.3.6\"/>\n  <path fill=\"#c8b100\" d=\"M274.7 210.5l-.3.6h-1.3l-.2-.2.1-.3 1.2-.6.5.5\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M274.7 210.5l-.3.6h-1.3l-.2-.2.1-.3 1.2-.6.5.5\"/>\n  <path fill=\"#c8b100\" d=\"M269.8 211.4v.6l-1.4.2-.2-.1v-.2l1-.9.6.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M269.8 211.4v.6l-1.4.2-.2-.1v-.2l1-.9.6.4\"/>\n  <path fill=\"#c8b100\" d=\"M272.4 210.9c0-.3.2-.5.5-.5a.5.5 0 01.5.5.5.5 0 01-.5.4.5.5 0 01-.5-.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M272.4 210.9c0-.3.2-.5.5-.5a.5.5 0 01.5.5.5.5 0 01-.5.4.5.5 0 01-.5-.4z\"/>\n  <path fill=\"#c8b100\" d=\"M283.2 209l.7.7-.9 1-.2.1-.1-.1-.3-1.3.8-.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M283.2 209l.7.7-.9 1-.2.1-.1-.1-.3-1.3.8-.3\"/>\n  <path fill=\"#c8b100\" d=\"M284.6 211.2l-.5.5-1.2-.6v-.2l.1-.2 1.3-.1.3.6\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M284.6 211.2l-.5.5-1.2-.6v-.2l.1-.2 1.3-.1.3.6\"/>\n  <path fill=\"#c8b100\" d=\"M281 210.5l.3.6h1.3l.2-.2-.1-.3-1.2-.6-.5.5\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M281 210.5l.3.6h1.3l.2-.2-.1-.3-1.2-.6-.5.5\"/>\n  <path fill=\"#c8b100\" d=\"M285.7 211.4v.6l1.4.2.2-.1v-.2l-1-.9-.6.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M285.7 211.4v.6l1.4.2.2-.1v-.2l-1-.9-.6.4\"/>\n  <path fill=\"#c8b100\" d=\"M277.4 210.4c0-.2.2-.4.5-.4.2 0 .4.2.4.4 0 .3-.2.5-.4.5a.5.5 0 01-.5-.5\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M277.4 210.4c0-.2.2-.4.5-.4.2 0 .4.2.4.4 0 .3-.2.5-.4.5a.5.5 0 01-.5-.5z\"/>\n  <path fill=\"#c8b100\" d=\"M282.3 210.9c0-.3.3-.5.5-.5.3 0 .5.2.5.5s-.2.4-.5.4a.5.5 0 01-.5-.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M282.3 210.9c0-.3.3-.5.5-.5.3 0 .5.2.5.5s-.2.4-.5.4a.5.5 0 01-.5-.4z\"/>\n  <path fill=\"#c8b100\" d=\"M277 205.4c0-.5.4-.8.8-.8s1 .3 1 .8-.5.8-1 .8a.9.9 0 01-.8-.8\"/>\n  <path fill=\"#c8b100\" d=\"M278.5 205.1v.6H277v-.6h.4v-1.3h-.5v-.5h.5v-.6h.6v.6h.6v.6h-.6v1.2h.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M278.5 205.1v.6H277v-.6h.4v-1.3h-.5v-.5h.5v-.6h.6v.6h.6v.6h-.6v1.2h.4z\"/>\n  <path fill=\"#c8b100\" d=\"M279 205.1v.6h-2.4v-.6h1v-1.3h-.7v-.5h.6v-.6h.6v.6h.6v.6h-.6v1.2h1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M278.1 204.6c.4 0 .6.4.6.8 0 .5-.4.8-.9.8a.9.9 0 01-.8-.8c0-.4.2-.7.6-.8\"/>\n  <path fill=\"#c8b100\" d=\"M268 212.2l-.6-.7a2.3 2.3 0 00-.7-.3c0-.1.3-.3.6-.3.2 0 .3 0 .4.2v-.2s.3 0 .4.3v1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M268 212.2l-.6-.7a2.3 2.3 0 00-.7-.3c0-.1.3-.3.6-.3.2 0 .3 0 .4.2v-.2s.3 0 .4.3v1z\"/>\n  <path fill=\"#c8b100\" d=\"M268 212c.1-.2.4-.2.5 0 .2.1.3.3.1.5l-.5-.1c-.1-.1-.2-.4 0-.5\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M268 212c.1-.2.4-.2.5 0 .2.1.3.3.1.5l-.5-.1c-.1-.1-.2-.4 0-.5z\"/>\n  <path fill=\"#c8b100\" d=\"M287.5 212.2l.6-.7c.2-.2.7-.3.7-.3 0-.1-.3-.3-.6-.3a.6.6 0 00-.4.2v-.2s-.3 0-.4.3v.7l.1.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M287.5 212.2l.6-.7c.2-.2.7-.3.7-.3 0-.1-.3-.3-.6-.3a.6.6 0 00-.4.2v-.2s-.3 0-.4.3v.7l.1.3z\"/>\n  <path fill=\"#c8b100\" d=\"M287.5 212c-.1-.2-.3-.2-.5 0-.2.1-.2.3-.1.5l.5-.1c.2-.1.2-.4.1-.5\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M287.5 212c-.1-.2-.3-.2-.5 0-.2.1-.2.3-.1.5l.5-.1c.2-.1.2-.4.1-.5z\"/>\n  <path fill=\"#c8b100\" d=\"M267.2 223h21.4v-5.5h-21.4v5.6z\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M267.2 223h21.4v-5.5h-21.4v5.6z\"/>\n  <path fill=\"#c8b100\" d=\"M286.3 226.8a1 1 0 00-.4 0h-16.5c.6-.2 1-.7 1-1.2 0-.6-.4-1.1-1-1.3h17-.1c-.6.2-1 .7-1 1.3 0 .5.4 1 1 1.2\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-linejoin=\"round\" stroke-width=\".4\" d=\"M286.3 226.8a1 1 0 00-.4 0h-16.5c.6-.2 1-.7 1-1.2 0-.6-.4-1.1-1-1.3h17-.1c-.6.2-1 .7-1 1.3 0 .5.4 1 1 1.2z\"/>\n  <path fill=\"#c8b100\" d=\"M269.9 226.8h16c.6 0 1 .3 1 .7 0 .4-.4.8-1 .8h-16c-.6 0-1-.4-1-.8s.5-.8 1-.8\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M269.9 226.8h16c.6 0 1 .3 1 .7 0 .4-.4.8-1 .8h-16c-.6 0-1-.4-1-.8s.5-.8 1-.8z\"/>\n  <path fill=\"#c8b100\" d=\"M269.9 223h16c.6 0 1 .4 1 .7 0 .4-.4.6-1 .6h-16c-.6 0-1-.2-1-.6 0-.3.4-.6 1-.6\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M269.9 223h16c.6 0 1 .4 1 .7 0 .4-.4.6-1 .6h-16c-.6 0-1-.2-1-.6 0-.3.4-.6 1-.6z\"/>\n  <path fill=\"#005bbf\" d=\"M263 317.4c1.4 0 2.7-.3 3.7-.8a8.4 8.4 0 013.7-.8c1.4 0 2.8.3 3.8.8s2.3.8 3.7.8c1.5 0 2.8-.3 3.8-.8a8.4 8.4 0 013.6-.8 8 8 0 013.7.8c1 .5 2.4.8 3.8.8v2.4a8.3 8.3 0 01-3.8-.9 8.2 8.2 0 00-3.7-.8c-1.4 0-2.7.3-3.6.8-1 .5-2.3.9-3.8.9a8 8 0 01-3.7-.9 8.4 8.4 0 00-3.8-.8 8.3 8.3 0 00-3.7.8c-1 .5-2.3.9-3.8.9v-2.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M263 317.4c1.4 0 2.7-.3 3.7-.8a8.4 8.4 0 013.7-.8c1.4 0 2.8.3 3.8.8s2.3.8 3.7.8c1.5 0 2.8-.3 3.8-.8a8.4 8.4 0 013.6-.8 8 8 0 013.7.8c1 .5 2.4.8 3.8.8v2.4a8.3 8.3 0 01-3.8-.9 8.2 8.2 0 00-3.7-.8c-1.4 0-2.7.3-3.6.8-1 .5-2.3.9-3.8.9a8 8 0 01-3.7-.9 8.4 8.4 0 00-3.8-.8 8.3 8.3 0 00-3.7.8c-1 .5-2.3.9-3.8.9v-2.4z\"/>\n  <path fill=\"#ccc\" d=\"M263 319.8c1.4 0 2.7-.4 3.7-.9s2.3-.8 3.7-.8c1.4 0 2.8.3 3.8.8s2.3.9 3.7.9a8.2 8.2 0 003.8-.9 8.4 8.4 0 013.6-.8c1.5 0 2.8.3 3.7.8 1 .5 2.4.9 3.8.9v2.3a8.3 8.3 0 01-3.8-.9 8.1 8.1 0 00-3.7-.7c-1.4 0-2.7.2-3.6.7-1 .5-2.3.9-3.8.9a7 7 0 01-3.7-.9c-1-.4-2.3-.7-3.8-.7a8.3 8.3 0 00-3.7.7 8.1 8.1 0 01-3.8.9v-2.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M263 319.8c1.4 0 2.7-.4 3.7-.9s2.3-.8 3.7-.8c1.4 0 2.8.3 3.8.8s2.3.9 3.7.9a8.2 8.2 0 003.8-.9 8.4 8.4 0 013.6-.8c1.5 0 2.8.3 3.7.8 1 .5 2.4.9 3.8.9v2.3a8.3 8.3 0 01-3.8-.9 8.1 8.1 0 00-3.7-.7c-1.4 0-2.7.2-3.6.7-1 .5-2.3.9-3.8.9a7 7 0 01-3.7-.9c-1-.4-2.3-.7-3.8-.7a8.3 8.3 0 00-3.7.7 8.1 8.1 0 01-3.8.9v-2.3\"/>\n  <path fill=\"#005bbf\" d=\"M263 322c1.4 0 2.7-.2 3.7-.8 1-.4 2.3-.7 3.7-.7 1.4 0 2.8.2 3.8.7s2.3.9 3.7.9a8.2 8.2 0 003.8-.9 8.4 8.4 0 013.6-.8 8 8 0 013.7.8c1 .5 2.4.9 3.8.9v2.3a8.3 8.3 0 01-3.8-.9 8.2 8.2 0 00-3.7-.7c-1.4 0-2.7.3-3.6.7-1 .6-2.3.9-3.8.9-1.4 0-2.8-.3-3.7-.8a8.4 8.4 0 00-3.8-.8 8.3 8.3 0 00-3.7.8c-1 .5-2.3.8-3.8.8V322\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M263 322c1.4 0 2.7-.2 3.7-.8 1-.4 2.3-.7 3.7-.7 1.4 0 2.8.2 3.8.7s2.3.9 3.7.9a8.2 8.2 0 003.8-.9 8.4 8.4 0 013.6-.8 8 8 0 013.7.8c1 .5 2.4.9 3.8.9v2.3a8.3 8.3 0 01-3.8-.9 8.2 8.2 0 00-3.7-.7c-1.4 0-2.7.3-3.6.7-1 .6-2.3.9-3.8.9-1.4 0-2.8-.3-3.7-.8a8.4 8.4 0 00-3.8-.8 8.3 8.3 0 00-3.7.8c-1 .5-2.3.8-3.8.8V322\"/>\n  <path fill=\"#ccc\" d=\"M263 326.7a8 8 0 003.7-.8c1-.5 2.3-.8 3.7-.8 1.4 0 2.8.3 3.8.8s2.3.8 3.7.8c1.5 0 2.8-.3 3.8-.9a8.4 8.4 0 013.6-.7c1.5 0 2.8.3 3.7.8a8.3 8.3 0 003.8.8v-2.3a8.3 8.3 0 01-3.8-.9 8.2 8.2 0 00-3.7-.7c-1.4 0-2.7.3-3.6.7-1 .5-2.3.9-3.8.9-1.4 0-2.8-.3-3.7-.8a8.4 8.4 0 00-3.8-.8 8.3 8.3 0 00-3.7.8c-1 .5-2.3.8-3.8.8v2.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M263 326.7a8 8 0 003.7-.8c1-.5 2.3-.8 3.7-.8 1.4 0 2.8.3 3.8.8s2.3.8 3.7.8c1.5 0 2.8-.3 3.8-.9a8.4 8.4 0 013.6-.7c1.5 0 2.8.3 3.7.8a8.3 8.3 0 003.8.8v-2.3a8.3 8.3 0 01-3.8-.9 8.2 8.2 0 00-3.7-.7c-1.4 0-2.7.3-3.6.7-1 .5-2.3.9-3.8.9-1.4 0-2.8-.3-3.7-.8a8.4 8.4 0 00-3.8-.8 8.3 8.3 0 00-3.7.8c-1 .5-2.3.8-3.8.8v2.3\"/>\n  <path fill=\"#005bbf\" d=\"M263 329a8.1 8.1 0 003.7-.8c1-.5 2.3-.8 3.7-.8 1.4 0 2.8.3 3.8.8s2.3.8 3.7.8a8.2 8.2 0 003.8-.9 8.4 8.4 0 013.6-.7c1.5 0 2.8.3 3.7.8 1 .5 2.4.8 3.8.8v-2.3a8.3 8.3 0 01-3.8-.8 8.2 8.2 0 00-3.7-.8 8.4 8.4 0 00-3.6.7 8.2 8.2 0 01-3.8.9c-1.4 0-2.8-.3-3.7-.8-1-.5-2.3-.8-3.8-.8-1.4 0-2.7.3-3.7.8s-2.3.8-3.8.8v2.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M263 329a8.1 8.1 0 003.7-.8c1-.5 2.3-.8 3.7-.8 1.4 0 2.8.3 3.8.8s2.3.8 3.7.8a8.2 8.2 0 003.8-.9 8.4 8.4 0 013.6-.7c1.5 0 2.8.3 3.7.8 1 .5 2.4.8 3.8.8v-2.3a8.3 8.3 0 01-3.8-.8 8.2 8.2 0 00-3.7-.8 8.4 8.4 0 00-3.6.7 8.2 8.2 0 01-3.8.9c-1.4 0-2.8-.3-3.7-.8-1-.5-2.3-.8-3.8-.8-1.4 0-2.7.3-3.7.8s-2.3.8-3.8.8v2.3z\"/>\n  <path fill=\"#c8b100\" d=\"M286.3 308l-.1.5c0 1.5 1.2 2.6 2.7 2.6h-22c1.5 0 2.7-1.2 2.7-2.6l-.1-.5h16.8\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-linejoin=\"round\" stroke-width=\".4\" d=\"M286.3 308l-.1.5c0 1.5 1.2 2.6 2.7 2.6h-22c1.5 0 2.7-1.2 2.7-2.6l-.1-.5h16.8z\"/>\n  <path fill=\"#c8b100\" d=\"M269.9 306.5h16c.6 0 1 .3 1 .8 0 .4-.4.7-1 .7h-16c-.6 0-1-.3-1-.8 0-.4.5-.7 1-.7\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M269.9 306.5h16c.6 0 1 .3 1 .8 0 .4-.4.7-1 .7h-16c-.6 0-1-.3-1-.8 0-.4.5-.7 1-.7z\"/>\n  <path fill=\"#c8b100\" d=\"M266.9 316.7h22V311h-22v5.6z\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M266.9 316.7h22V311h-22v5.6z\"/>\n  <path fill=\"#ad1519\" d=\"M290.6 286.7c2.1 1.2 3.6 2.5 3.4 3.2-.1.6-.8 1-1.8 1.6-1.6 1.1-2.5 3-1.8 4a5.5 5.5 0 01.2-8.8\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M290.6 286.7c2.1 1.2 3.6 2.5 3.4 3.2-.1.6-.8 1-1.8 1.6-1.6 1.1-2.5 3-1.8 4a5.5 5.5 0 01.2-8.8z\"/>\n  <path fill=\"#ccc\" d=\"M270.1 305.6h15.6V229h-15.6v76.5z\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M281.4 229.1v76.3m1.8-76.3v76.3m-13 .2h15.5V229h-15.6v76.5z\"/>\n  <path fill=\"#ad1519\" d=\"M254.2 257.7a49.6 49.6 0 0123.3-2c9.3 1.6 16.4 5.3 15.9 8.4v.2l3.5-8.2c.6-3.3-7.3-7.5-17.6-9.2a53.5 53.5 0 00-9.2-.7c-6.7 0-12.4.8-15.9 2.1v9.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-linejoin=\"round\" stroke-width=\".4\" d=\"M254.2 257.7a49.6 49.6 0 0123.3-2c9.3 1.6 16.4 5.3 15.9 8.4v.2l3.5-8.2c.6-3.3-7.3-7.5-17.6-9.2a53.5 53.5 0 00-9.2-.7c-6.7 0-12.4.8-15.9 2.1v9.4\"/>\n  <path fill=\"#ad1519\" d=\"M285.7 267.3c4.4-.3 7.3-1.4 7.7-3.2.2-1.5-1.2-3-3.8-4.5-1.2.1-2.5.3-3.9.3v7.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M285.7 267.3c4.4-.3 7.3-1.4 7.7-3.2.2-1.5-1.2-3-3.8-4.5-1.2.1-2.5.3-3.9.3v7.4\"/>\n  <path fill=\"#ad1519\" d=\"M270 261.5a13 13 0 00-5.7 1.9v.2c-.5 1 1.8 3 5.8 5.4v-7.5\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M270 261.5a13 13 0 00-5.7 1.9v.2c-.5 1 1.8 3 5.8 5.4v-7.5\"/>\n  <path fill=\"#ad1519\" d=\"M295.4 282c.4-1.2-3.8-3.6-9.7-5.8-2.8-1-5-2-7.8-3.2-8.3-3.7-14.4-7.9-13.6-9.4v-.2c-.4.4-1 8-1 8-.8 1.3 4.8 5.5 12.4 9.1 2.4 1.2 7.6 3 10 4 4.3 1.4 8.7 4.3 8.3 5.3l1.4-7.7\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-linejoin=\"round\" stroke-width=\".4\" d=\"M295.4 282c.4-1.2-3.8-3.6-9.7-5.8-2.8-1-5-2-7.8-3.2-8.3-3.7-14.4-7.9-13.6-9.4v-.2c-.4.4-1 8-1 8-.8 1.3 4.8 5.5 12.4 9.1 2.4 1.2 7.6 3 10 4 4.3 1.4 8.7 4.3 8.3 5.3l1.4-7.7z\"/>\n  <path fill=\"#c8b100\" d=\"M263.9 254.4c.6-2.3 1.4-4.4 2.1-6.6h-.5a5.2 5.2 0 01-.5.1 52.8 52.8 0 01-1.4 4.8c-1-1.4-2-2.7-2.7-4.1l-1 .2h-1a131.3 131.3 0 014 5.7h.5l.5-.1m6-6.6h-1a8 8 0 01-.8 0v6.2h4.2v-.7h-2.6l.1-5.5m6.8 1l2 .3v-.7l-5.8-.5v.8a19.3 19.3 0 012 0l-.4 5.6h1.6l.5-5.4m2.4 6c.3 0 .5 0 .8.2l.8.2.7-2.9.6 1.2.8 2.1 1 .2c.4 0 .7.2 1 .3l-.3-.7c-.4-1-1-1.9-1.3-2.9 1 0 1.9-.3 2.1-1.2.1-.6 0-1-.7-1.5-.4-.3-1.2-.4-1.7-.5l-2.4-.5-1.4 6m3-5.2c.7.2 1.5.3 1.5 1v.5c-.3.9-1 1.2-2 .9l.5-2.4m8 7l-.2 2 .8.5.9.5.5-7a3.4 3.4 0 01-.7-.3l-6.1 3.8.5.3.4.2 1.7-1.2 2.3 1.3zm-1.7-1.5l2-1.4-.2 2.3-1.8-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".1\" d=\"M182.2 192.4c0-1 1-2 2-2s2.2 1 2.2 2c0 1.1-1 2-2.1 2a2 2 0 01-2.1-2z\"/>\n  <path fill=\"#ad1519\" stroke=\"#000\" stroke-width=\".3\" d=\"M205.7 175.4c6.3 0 12 1 15.7 2.4a31.7 31.7 0 0014.6 2.3c2.7 0 6.5.8 10.3 2.4a27.3 27.3 0 017.4 4.7l-1.5 1.4-.4 3.8-4.1 4.7-2 1.8-5 3.9-2.5.2-.7 2.1-31.6-3.7-31.7 3.7-.8-2.1-2.5-.2-4.9-4-2-1.7-4.1-4.7-.5-3.8-1.5-1.4a27.6 27.6 0 017.5-4.7 26 26 0 0110.2-2.4c2 .2 4.2.1 6.6-.2a30 30 0 008-2c3.7-1.5 9-2.5 15.5-2.5z\"/>\n  <path fill=\"#c8b100\" stroke=\"#000\" stroke-width=\".4\" d=\"M206.2 217.1c-11.8 0-22.4-1.4-29.9-3.6a1.1 1.1 0 01-.8-1.2c0-.5.3-1 .8-1.2a109 109 0 0129.9-3.6c11.7 0 22.3 1.4 29.8 3.6a1.3 1.3 0 010 2.4c-7.5 2.2-18 3.6-29.8 3.6\"/>\n  <path fill=\"#ad1519\" d=\"M206.1 215.6c-10.6 0-20.2-1.2-27.5-3.1 7.3-2 16.9-3 27.5-3.1a115 115 0 0127.6 3c-7.3 2-17 3.2-27.6 3.2\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".1\" d=\"M206.9 215.7v-6.3m-1.7 6.3v-6.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".2\" d=\"M203.6 215.7v-6.3m-1.6 6.3v-6.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M200.6 215.7v-6.3m-2.8 5.9v-5.7m1.3 5.8v-6m-3.8 5.6v-5.2m1.3 5.4v-5.6\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M192 214.8V210m1 4.7V210m1.2 5v-5m-3.4 4.7v-4.5\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".5\" d=\"M189.7 214.5v-4.2m-1.2 4.1v-4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".6\" d=\"M186 214v-3m1.3 3.2v-3.5m-2.5 3.1V211\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".7\" d=\"M183.7 213.6v-2.3m-1.3 2v-1.8m-1.2 1.6v-1.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".9\" d=\"M179.8 212.8v-.7\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".1\" d=\"M213.7 215.3v-5.8m-2.9 6v-6.1m-2.1 6.2v-6.3\"/>\n  <path fill=\"#c8b100\" stroke=\"#000\" stroke-width=\".4\" d=\"M206 207.4a108 108 0 00-30 3.9c.6-.3.5-1-.3-3-1-2.5-2.4-2.4-2.4-2.4 8.3-2.5 20-4 32.8-4a123 123 0 0133 4s-1.5-.1-2.5 2.3c-.8 2-.8 2.8-.2 3-7.5-2.2-18.4-3.7-30.3-3.7\"/>\n  <path fill=\"#c8b100\" stroke=\"#000\" stroke-width=\".4\" d=\"M206.1 201.9c-12.9 0-24.5 1.5-32.8 4a1 1 0 01-1.3-.6 1 1 0 01.7-1.3 121 121 0 0133.4-4.2c13.2 0 25.2 1.7 33.5 4.2.6.2.9.8.7 1.3-.2.5-.8.8-1.3.6-8.4-2.5-20-4-32.9-4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-linejoin=\"round\" stroke-width=\".4\" d=\"M206.1 215.6c-10.6 0-20.2-1.2-27.5-3.1 7.3-2 16.9-3 27.5-3.1a115 115 0 0127.6 3c-7.3 2-17 3.2-27.6 3.2z\"/>\n  <path fill=\"#fff\" stroke=\"#000\" stroke-width=\".4\" d=\"M197 204.8c0-.5.4-1 1-1 .5 0 1 .5 1 1s-.4 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"#ad1519\" stroke=\"#000\" stroke-width=\".4\" d=\"M206.1 205.6H203a1 1 0 010-2h6.4c.5 0 1 .5 1 1s-.5 1-1 1h-3.2\"/>\n  <path fill=\"#058e6e\" stroke=\"#000\" stroke-width=\".4\" d=\"M190.3 206.5l-2.3.2c-.6.1-1-.3-1.2-.8a1 1 0 011-1.1l2.2-.3 2.4-.3c.5 0 1 .3 1.1.9.1.5-.3 1-.9 1l-2.3.4\"/>\n  <path fill=\"#fff\" stroke=\"#000\" stroke-width=\".4\" d=\"M181 206.7c0-.6.5-1 1.1-1 .6 0 1 .4 1 1 0 .5-.4 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"#ad1519\" stroke=\"#000\" stroke-width=\".4\" d=\"M174 208.5l1.2-1.6 3.3.4-2.6 2-1.8-.8\"/>\n  <path fill=\"#058e6e\" stroke=\"#000\" stroke-width=\".4\" d=\"M222 206.5l2.3.2c.5.1 1-.3 1.1-.8a1 1 0 00-.9-1.1l-2.2-.3-2.4-.3a1 1 0 00-1.1.9c-.1.5.3 1 .9 1l2.3.4\"/>\n  <path fill=\"#fff\" stroke=\"#000\" stroke-width=\".4\" d=\"M213.3 204.8c0-.5.4-1 1-1s1 .5 1 1-.4 1-1 1a1 1 0 01-1-1m15.8 1.9c0-.6.5-1 1-1 .6 0 1.1.4 1.1 1 0 .5-.4 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"#ad1519\" stroke=\"#000\" stroke-width=\".4\" d=\"M238.2 208.5l-1.1-1.6-3.3.4 2.6 2 1.8-.8\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M177.3 212.8c7.4-2.1 17.6-3.4 28.8-3.4 11.3 0 21.4 1.3 28.9 3.4\"/>\n  <path fill=\"#c8b100\" d=\"M182.3 183.8l1.4 1 2-3.2a7.4 7.4 0 01-3.6-7.2c.2-4.1 5.2-7.6 11.7-7.6 3.3 0 6.3 1 8.5 2.4 0-.6 0-1.2.2-1.8a17.4 17.4 0 00-8.7-2.1c-7.4 0-13.2 4.1-13.5 9.1a8.9 8.9 0 003 7.6l-1 1.8\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M182.3 183.8l1.4 1 2-3.2a7.4 7.4 0 01-3.6-7.2c.2-4.1 5.2-7.6 11.7-7.6 3.3 0 6.3 1 8.5 2.4 0-.6 0-1.2.2-1.8a17.4 17.4 0 00-8.7-2.1c-7.4 0-13.2 4.1-13.5 9.1a8.9 8.9 0 003 7.6l-1 1.8\"/>\n  <path fill=\"#c8b100\" d=\"M182.4 183.8a9.3 9.3 0 01-4-7.3c0-3.2 2-6.1 5.3-8a8.5 8.5 0 00-3.4 6.8 8.9 8.9 0 003 6.7l-.9 1.8\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M182.4 183.8a9.3 9.3 0 01-4-7.3c0-3.2 2-6.1 5.3-8a8.5 8.5 0 00-3.4 6.8 8.9 8.9 0 003 6.7l-.9 1.8\"/>\n  <path fill=\"#c8b100\" d=\"M160.1 187.1a8.8 8.8 0 01-2.3-5.9c0-1.3.3-2.6 1-3.8 2-4.2 8.4-7.2 16-7.2 2 0 4 .2 5.9.6l-1 1.4a25.5 25.5 0 00-4.9-.4c-7 0-12.8 2.7-14.5 6.3a7 7 0 00-.7 3.1 7.3 7.3 0 002.7 5.6l-2.6 4.1-1.3-1 1.7-2.8\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M160.1 187.1a8.8 8.8 0 01-2.3-5.9c0-1.3.3-2.6 1-3.8 2-4.2 8.4-7.2 16-7.2 2 0 4 .2 5.9.6l-1 1.4a25.5 25.5 0 00-4.9-.4c-7 0-12.8 2.7-14.5 6.3a7 7 0 00-.7 3.1 7.3 7.3 0 002.7 5.6l-2.6 4.1-1.3-1 1.7-2.8z\"/>\n  <path fill=\"#c8b100\" d=\"M162.7 173.3a10.5 10.5 0 00-4 4.1 8.6 8.6 0 00-.9 3.8c0 2.3.9 4.3 2.3 5.9l-1.5 2.5a10.4 10.4 0 01-2.3-6.5c0-4 2.5-7.5 6.4-9.8\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M162.7 173.3a10.5 10.5 0 00-4 4.1 8.6 8.6 0 00-.9 3.8c0 2.3.9 4.3 2.3 5.9l-1.5 2.5a10.4 10.4 0 01-2.3-6.5c0-4 2.5-7.5 6.4-9.8z\"/>\n  <path fill=\"#c8b100\" d=\"M206 164.4c1.7 0 3.2 1.1 3.5 2.6.3 1.4.4 2.9.4 4.5v1.1c.1 3.3.6 6.3 1.3 8.1l-5.2 5-5.2-5c.7-1.8 1.2-4.8 1.3-8.1v-1.1c0-1.6.2-3.1.4-4.5.3-1.5 1.8-2.6 3.5-2.6\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M206 164.4c1.7 0 3.2 1.1 3.5 2.6.3 1.4.4 2.9.4 4.5v1.1c.1 3.3.6 6.3 1.3 8.1l-5.2 5-5.2-5c.7-1.8 1.2-4.8 1.3-8.1v-1.1c0-1.6.2-3.1.4-4.5.3-1.5 1.8-2.6 3.5-2.6z\"/>\n  <path fill=\"#c8b100\" d=\"M206 166c1 0 1.7.6 1.8 1.4.2 1.2.4 2.6.4 4.2v1c.1 3.2.6 6 1.2 7.7l-3.4 3.2-3.4-3.2c.7-1.7 1.1-4.5 1.2-7.7v-1a28.1 28.1 0 01.4-4.2 2 2 0 011.8-1.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M206 166c1 0 1.7.6 1.8 1.4.2 1.2.4 2.6.4 4.2v1c.1 3.2.6 6 1.2 7.7l-3.4 3.2-3.4-3.2c.7-1.7 1.1-4.5 1.2-7.7v-1a28.1 28.1 0 01.4-4.2 2 2 0 011.8-1.4z\"/>\n  <path fill=\"#c8b100\" d=\"M229.7 183.8l-1.3 1-2-3.2a7.4 7.4 0 003.6-6.3 7 7 0 000-.9c-.2-4.1-5.3-7.6-11.7-7.6a15 15 0 00-8.5 2.4 23 23 0 00-.2-1.8 17.4 17.4 0 018.7-2.1c7.4 0 13.2 4.1 13.4 9.1a8.9 8.9 0 01-3 7.6l1 1.8\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M229.7 183.8l-1.3 1-2-3.2a7.4 7.4 0 003.6-6.3 7 7 0 000-.9c-.2-4.1-5.3-7.6-11.7-7.6a15 15 0 00-8.5 2.4 23 23 0 00-.2-1.8 17.4 17.4 0 018.7-2.1c7.4 0 13.2 4.1 13.4 9.1a8.9 8.9 0 01-3 7.6l1 1.8\"/>\n  <path fill=\"#c8b100\" d=\"M229.6 183.8a9.1 9.1 0 004.1-7.3c0-3.2-2.1-6.1-5.3-8a8.5 8.5 0 013.4 6.8 8.9 8.9 0 01-3.2 6.7l1 1.8\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M229.6 183.8a9.1 9.1 0 004.1-7.3c0-3.2-2.1-6.1-5.3-8a8.5 8.5 0 013.4 6.8 8.9 8.9 0 01-3.2 6.7l1 1.8\"/>\n  <path fill=\"#c8b100\" d=\"M252 187.1a8.8 8.8 0 002.2-5.9 8.7 8.7 0 00-.9-3.8c-2-4.2-8.4-7.2-16-7.2a29 29 0 00-6 .6l1 1.4a25.4 25.4 0 015-.4c7 0 12.8 2.7 14.4 6.3.5 1 .7 2 .7 3.1a7.3 7.3 0 01-2.6 5.6l2.5 4.1 1.3-1-1.7-2.8\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M252 187.1a8.8 8.8 0 002.2-5.9 8.7 8.7 0 00-.9-3.8c-2-4.2-8.4-7.2-16-7.2a29 29 0 00-6 .6l1 1.4a25.4 25.4 0 015-.4c7 0 12.8 2.7 14.4 6.3.5 1 .7 2 .7 3.1a7.3 7.3 0 01-2.6 5.6l2.5 4.1 1.3-1-1.7-2.8z\"/>\n  <path fill=\"#c8b100\" d=\"M249.3 173.3a10.6 10.6 0 014 4.1 8.7 8.7 0 01.9 3.8 8.8 8.8 0 01-2.3 5.9l1.6 2.5a10.4 10.4 0 002.3-6.5c0-4-2.6-7.5-6.5-9.8\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M249.3 173.3a10.6 10.6 0 014 4.1 8.7 8.7 0 01.9 3.8 8.8 8.8 0 01-2.3 5.9l1.6 2.5a10.4 10.4 0 002.3-6.5c0-4-2.6-7.5-6.5-9.8z\"/>\n  <path fill=\"#fff\" d=\"M204.2 181.4c0-1 .8-1.8 1.8-1.8s1.9.8 1.9 1.8-.9 1.7-1.9 1.7a1.8 1.8 0 01-1.8-1.7\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M204.2 181.4c0-1 .8-1.8 1.8-1.8s1.9.8 1.9 1.8-.9 1.7-1.9 1.7a1.8 1.8 0 01-1.8-1.7z\"/>\n  <path fill=\"#fff\" stroke=\"#000\" stroke-width=\".4\" d=\"M204.2 178c0-1 .8-1.8 1.8-1.8s1.9.8 1.9 1.8-.9 1.7-1.9 1.7a1.8 1.8 0 01-1.8-1.7m.4-3.7c0-.7.6-1.3 1.4-1.3.8 0 1.5.6 1.5 1.3 0 .8-.7 1.4-1.5 1.4s-1.4-.6-1.4-1.4m.4-3.3c0-.5.4-1 1-1s1 .5 1 1-.4 1-1 1a1 1 0 01-1-1m.2-2.8c0-.5.4-.8.8-.8.5 0 .9.3.9.8 0 .4-.4.8-.9.8a.8.8 0 01-.8-.8\"/>\n  <path fill=\"#c8b100\" stroke=\"#000\" stroke-width=\".4\" d=\"M206.2 191.8l1.2.2a4.6 4.6 0 004.5 6 4.7 4.7 0 004.4-3c.1 0 .5-1.7.7-1.7.2 0 .1 1.8.2 1.7.3 2.3 2.4 3.8 4.7 3.8a4.6 4.6 0 004.7-5l1.5-1.5.7 2a4 4 0 00-.4 1.9 4.4 4.4 0 004.5 4.2c1.6 0 3-.7 3.8-1.9l.9-1.2v1.5c0 1.5.6 2.8 2 3 0 0 1.7.1 4-1.6 2.1-1.7 3.3-3.1 3.3-3.1l.2 1.7s-1.8 2.8-3.8 4c-1 .6-2.7 1.3-4 1-1.4-.2-2.4-1.3-3-2.6a6.7 6.7 0 01-3.3 1 6.5 6.5 0 01-6.1-3.7 7 7 0 01-10.4-.3 7 7 0 01-4.6 1.8 6.9 6.9 0 01-5.7-3 6.9 6.9 0 01-5.7 3 7 7 0 01-4.7-1.8 7 7 0 01-10.4.3 6.5 6.5 0 01-6 3.7 6.7 6.7 0 01-3.4-1c-.6 1.3-1.5 2.4-3 2.7-1.2.2-2.9-.5-4-1.1-2-1.2-3.8-4-3.8-4l.2-1.7s1.2 1.4 3.4 3.1c2.2 1.8 3.9 1.6 3.9 1.6 1.4-.2 2-1.5 2-3v-1.5l1 1.2a4.6 4.6 0 003.7 2c2.5 0 4.5-2 4.5-4.3a4 4 0 00-.4-2l.8-1.9 1.5 1.5a4.4 4.4 0 000 .6c0 2.4 2 4.4 4.6 4.4 2.4 0 4.4-1.5 4.7-3.8 0 0 0-1.6.2-1.7.2 0 .6 1.7.7 1.6a4.7 4.7 0 004.5 3.1 4.6 4.6 0 004.5-6l1.2-.2\"/>\n  <path fill=\"#fff\" stroke=\"#000\" stroke-width=\".4\" d=\"M238.6 197.7c.3-.8 0-1.6-.6-1.8-.5-.2-1.2.3-1.5 1.1-.3.8 0 1.6.6 1.8.5.2 1.2-.3 1.5-1.1m-20.5-4c0-.8-.3-1.6-1-1.6-.5-.1-1 .5-1.2 1.4-.1.8.3 1.5.9 1.6.6 0 1.2-.6 1.3-1.4m-23.9 0c0-.8.4-1.6 1-1.6.6-.1 1.1.5 1.2 1.4.1.8-.3 1.5-.9 1.6-.6 0-1.1-.6-1.2-1.4m-20.6 4c-.2-.8 0-1.6.6-1.8.6-.2 1.2.3 1.5 1.1.3.8 0 1.6-.5 1.8-.6.2-1.3-.3-1.6-1.1\"/>\n  <path fill=\"#c8b100\" stroke=\"#000\" stroke-width=\".4\" d=\"M182.7 184a5.1 5.1 0 012.2 2.9s0-.3.6-.6 1-.3 1-.3l-.1 1.3-.3 2.2a7.4 7.4 0 01-.7 1.6 1.9 1.9 0 00-1.5-.4 1.8 1.8 0 00-1.2.9s-.7-.6-1.2-1.3l-1.1-2-.7-1.1s.5-.2 1.1 0c.6 0 .8.2.8.2a4.9 4.9 0 011-3.4m.4 9.8a1.8 1.8 0 01-.6-1c0-.5 0-.9.3-1.2 0 0-.9-.5-1.8-.7-.7-.2-2-.2-2.3-.2h-1l.2.5c.2.5.5.7.5.7a5 5 0 00-3 2 5.3 5.3 0 003.5 1l-.2.8v.6l1-.4c.3-.1 1.5-.5 2-1 .8-.4 1.5-1.1 1.5-1.1m2.7-.5a1.6 1.6 0 00.2-1.1 1.7 1.7 0 00-.6-1l1.4-1.3a10 10 0 012-.9l1.1-.4v.6a5.7 5.7 0 01-.2.8 5 5 0 013.4 1 5 5 0 01-2.9 2 6.4 6.4 0 00.7 1.2h-1c-.4 0-1.6 0-2.3-.2a11 11 0 01-1.8-.7\"/>\n  <path fill=\"#ad1519\" stroke=\"#000\" stroke-width=\".4\" d=\"M182.2 192.4c0-1 1-2 2-2s2.2 1 2.2 2c0 1.1-1 2-2.1 2a2 2 0 01-2.1-2\"/>\n  <path fill=\"#c8b100\" stroke=\"#000\" stroke-width=\".4\" d=\"M206.1 180.8a5.7 5.7 0 011.9 3.7s.2-.3.9-.5c.7-.3 1.2-.2 1.2-.2l-.5 1.4-.8 2.4a8.2 8.2 0 01-1 1.7 2.1 2.1 0 00-1.7-.7c-.6 0-1.2.3-1.6.7 0 0-.6-.7-1-1.7l-.8-2.4-.5-1.4 1.2.2c.7.2.9.5.9.5 0-1.4.8-2.8 1.8-3.7\"/>\n  <path fill=\"#c8b100\" stroke=\"#000\" stroke-width=\".4\" d=\"M204.6 191.8a2 2 0 01-.5-1.2c0-.5.1-1 .4-1.3 0 0-.8-.7-1.8-1-.7-.4-2-.7-2.5-.7l-1.2-.2.2.6.4.9a5.9 5.9 0 00-3.7 1.7c1 .9 2.3 1.6 3.7 1.6l-.4 1-.2.6 1.2-.2c.4-.1 1.8-.4 2.5-.7 1-.4 1.9-1 1.9-1m3 0a1.9 1.9 0 00.1-2.6s.9-.7 1.8-1a8 8 0 012.5-.7l1.2-.3-.1.7-.4.9c1.4 0 2.7.8 3.6 1.7a5.9 5.9 0 01-3.6 1.6 6.9 6.9 0 00.5 1.6l-1.2-.2-2.5-.7c-1-.4-1.8-1-1.8-1m22-8a5.2 5.2 0 00-2.2 3l-.7-.6c-.6-.3-1-.3-1-.3l.2 1.3c0 .3 0 1.3.3 2.2.2 1 .6 1.6.6 1.6a2 2 0 011.5-.4c.6.1 1 .5 1.3.9l1.1-1.3c.6-.8 1-1.7 1.1-2l.7-1.1s-.4-.2-1 0c-.7 0-1 .2-1 .2a4.9 4.9 0 00-1-3.4m-.3 9.8c.3-.3.5-.6.6-1a1.6 1.6 0 00-.2-1.2s.8-.5 1.7-.7c.7-.2 2-.2 2.3-.2h1.1l-.3.5a6.2 6.2 0 01-.4.7 5 5 0 012.9 2 5.3 5.3 0 01-3.5 1l.2.8v.6l-1-.4c-.3-.1-1.4-.5-2-1-.8-.4-1.4-1.1-1.4-1.1m-2.8-.5a1.7 1.7 0 01-.2-1.1c0-.5.3-.8.6-1 0 0-.6-.8-1.4-1.3-.6-.4-1.7-.8-2-.9a171.4 171.4 0 01-1-.4v.6c0 .5.2.8.2.8a5.2 5.2 0 00-3.5 1c.7.9 1.7 1.7 3 2 0 0-.3.2-.5.7l-.3.5h1c.4 0 1.7 0 2.3-.2a11.1 11.1 0 001.8-.7\"/>\n  <path fill=\"#ad1519\" stroke=\"#000\" stroke-width=\".4\" d=\"M226 192.4c0-1 1-2 2-2s2.1 1 2.1 2a2 2 0 01-2 2 2 2 0 01-2.1-2m23.2 4.4c-.4-.5-1.4-.4-2.2.2-.8.7-1 1.6-.5 2.2.5.5 1.5.4 2.3-.3.7-.6 1-1.6.5-2\"/>\n  <path fill=\"#c8b100\" stroke=\"#000\" stroke-width=\".4\" d=\"M246.3 198l.7-1c.7-.6 1.8-.7 2.3-.2l.1.2s1-2 2.3-2.6c1.3-.7 3.4-.5 3.4-.5a2.8 2.8 0 00-2.9-2.8 3 3 0 00-2.4 1l-.2-1s-1.3.3-1.9 1.8c-.6 1.5 0 3.6 0 3.6s-.3-.9-.7-1.5a8 8 0 00-2.4-1.6l-1.3-.7-.1.5a5 5 0 000 .8 7.9 7.9 0 00-3.7.5 4.7 4.7 0 002.5 2.2l-.8.7a4 4 0 00-.4.5l1.3.2 2.5.2a14.5 14.5 0 001.7-.2m-80.3 0c0-.4-.3-.7-.7-1-.7-.7-1.7-.8-2.2-.3l-.2.3s-1-2-2.3-2.7c-1.2-.7-3.3-.5-3.3-.5a2.8 2.8 0 012.8-2.8c1 0 1.9.4 2.4 1l.2-1s1.3.3 2 1.8c.5 1.5-.1 3.6-.1 3.6s.3-.9.8-1.5a8 8 0 012.4-1.6l1.3-.7v1.3a7.9 7.9 0 013.7.5 4.7 4.7 0 01-2.5 2.2l.8.7.4.5-1.2.2-2.6.2a14.7 14.7 0 01-1.7-.2\"/>\n  <path fill=\"#ad1519\" stroke=\"#000\" stroke-width=\".4\" d=\"M163 196.8c.6-.5 1.6-.4 2.4.3.7.6 1 1.5.4 2-.5.6-1.5.5-2.2-.2-.8-.6-1-1.6-.5-2m41-6.3c0-1.1.9-2 2-2s2.1.9 2.1 2c0 1-1 2-2 2a2 2 0 01-2.1-2\"/>\n  <path fill=\"#005bbf\" stroke=\"#000\" stroke-width=\".3\" d=\"M201.8 160.6c0-2.2 1.9-4 4.3-4s4.2 1.8 4.2 4-1.9 4-4.3 4a4.1 4.1 0 01-4.2-4\"/>\n  <path fill=\"#c8b100\" stroke=\"#000\" stroke-width=\".3\" d=\"M205 149.3v2.2h-2.4v2.2h2.3v6.3H202l-.2.6c0 .6.1 1.1.3 1.6h7.9c.2-.5.3-1 .3-1.6l-.2-.6h-2.8v-6.3h2.3v-2.2h-2.3v-2.2h-2.4z\"/>\n  <path fill=\"#ccc\" d=\"M206.5 330.6a82 82 0 01-35.5-8.2 22.7 22.7 0 01-12.8-20.4v-32h96.4v32a22.7 22.7 0 01-12.8 20.4 81 81 0 01-35.3 8.2\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".5\" d=\"M206.5 330.6a82 82 0 01-35.5-8.2 22.7 22.7 0 01-12.8-20.4v-32h96.4v32a22.7 22.7 0 01-12.8 20.4 81 81 0 01-35.3 8.2z\"/>\n  <path fill=\"#ccc\" d=\"M206.3 270h48.3v-53.5h-48.3V270z\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".5\" d=\"M206.3 270h48.3v-53.5h-48.3V270z\"/>\n  <path fill=\"#ad1519\" d=\"M206.3 302c0 12.6-10.7 22.9-24 22.9s-24.2-10.3-24.2-23v-32h48.2v32\"/>\n  <path fill=\"#c8b100\" stroke=\"#000\" stroke-width=\".5\" d=\"M168.6 320.9c1.5.8 3.6 2 5.8 2.6l-.1-54.7h-5.7v52z\"/>\n  <path fill=\"#c8b100\" stroke=\"#000\" stroke-linejoin=\"round\" stroke-width=\".5\" d=\"M158 301.6a24.4 24.4 0 005.5 15v-47.5h-5.4v32.5z\"/>\n  <path fill=\"#c7b500\" stroke=\"#000\" stroke-width=\".5\" d=\"M179.4 324.7a26.6 26.6 0 005.6 0v-55.9h-5.6v56z\"/>\n  <path fill=\"#c8b100\" stroke=\"#000\" stroke-width=\".5\" d=\"M190 323.5a19 19 0 005.8-2.5v-52.2H190l-.1 54.7z\"/>\n  <path fill=\"#ad1519\" d=\"M158.1 270h48.2v-53.5H158V270z\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".5\" d=\"M158.1 270h48.2v-53.5H158V270z\"/>\n  <path fill=\"#c8b100\" stroke=\"#000\" stroke-width=\".5\" d=\"M201 316c2.4-2 4.6-6.8 5.4-12.2l.1-35H201l.1 47.3z\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".5\" d=\"M206.3 302c0 12.6-10.7 22.9-24 22.9s-24.2-10.3-24.2-23v-32h48.2v32\"/>\n  <path fill=\"#ad1519\" d=\"M254.6 270v32c0 12.6-10.8 22.9-24.1 22.9s-24.2-10.3-24.2-23v-32h48.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".5\" d=\"M254.6 270v32c0 12.6-10.8 22.9-24.1 22.9s-24.2-10.3-24.2-23v-32h48.3\"/>\n  <path fill=\"#c8b100\" d=\"M215.1 294.1l.1.5c0 .6-.5 1-1.1 1a1 1 0 01-1.1-1v-.5h-1.5a2.5 2.5 0 001.8 2.9v3.9h1.6V297a2.6 2.6 0 001.7-1.6h4.4v-1.2h-6m21.8 0v1.2h-4a2.5 2.5 0 01-.3.6l4.6 5.2-1.2 1-4.6-5.3-.2.1v8.7h-1.6V297h-.2l-4.8 5.2-1.2-1 4.7-5.3a2.1 2.1 0 01-.2-.4h-4V294h13zm2.6 0v1.2h4.4c.3.8.9 1.4 1.7 1.6v3.9h1.6V297a2.5 2.5 0 001.8-2.4 2 2 0 000-.5h-1.6l.1.5c0 .6-.5 1-1 1-.7 0-1.2-.4-1.2-1a1 1 0 01.1-.5h-5.9m-6.7 22.1a15.6 15.6 0 003.7-1l.8 1.4a17.6 17.6 0 01-4.3 1.2 2.6 2.6 0 01-2.6 2 2.6 2.6 0 01-2.5-2 17.5 17.5 0 01-4.6-1.2l.8-1.4c1.3.5 2.6.9 4 1a2.5 2.5 0 011.5-1.3v-6.7h1.6v6.7c.7.2 1.3.7 1.6 1.4zm-11-2.2l-.8 1.4a16.6 16.6 0 01-3.6-3.1c-.9.2-1.8 0-2.5-.5a2.4 2.4 0 01-.3-3.5l.1-.1a15.3 15.3 0 01-1.3-4.8h1.7a13.1 13.1 0 001 4c.5 0 1 0 1.4.2l4.1-4.5 1.3 1-4.1 4.5c.5.9.5 2-.1 2.8a15.2 15.2 0 003.1 2.6zm-6-4.8c.3-.4 1-.5 1.5 0s.5 1 .1 1.4a1.2 1.2 0 01-1.6.1 1 1 0 010-1.5zm-2.2-4.5l-1.6-.3-.3-4.3 1.7-.6v2.5c0 1 0 1.8.2 2.7zm1.4-5.3l1.7.4v2.2c0-.8.3 2.1.3 2.1l-1.7.6a14 14 0 01-.3-2.7v-2.6zm5.6 13.7a15.7 15.7 0 004.8 2.6l.4-1.6a13.7 13.7 0 01-4-2l-1.2 1m-.8 1.4a17.4 17.4 0 004.8 2.6l-1.2 1.1a18.7 18.7 0 01-4-2l.4-1.7m2.2-9.4l1.6.7 3-3.3-1-1.4-3.6 4m-1.3-1l-1-1.4 3-3.3 1.6.7-3.6 4m18.1 9.9l.8 1.4a16.7 16.7 0 003.6-3.1c.9.2 1.8 0 2.5-.5a2.4 2.4 0 00.3-3.5l-.1-.1a15 15 0 001.3-4.8h-1.7a13.3 13.3 0 01-1 4 3 3 0 00-1.4.2l-4.1-4.5-1.3 1 4.1 4.5a2.4 2.4 0 00.1 2.8 15 15 0 01-3.1 2.6zm6-4.8a1.2 1.2 0 00-1.5 0 1 1 0 00-.1 1.4 1.2 1.2 0 001.6.1 1 1 0 000-1.5zm2.2-4.5l1.6-.3.3-4.3-1.7-.6v2.5c0 1 0 1.9-.2 2.8zm-1.4-5.3l-1.7.4v2.2c0-.8-.3 2.1-.3 2.1l1.7.6.3-2.7v-2.6m-5.6 13.7a15.7 15.7 0 01-4.8 2.6l-.4-1.6a13.7 13.7 0 004-2l1.2 1m.8 1.4a17.4 17.4 0 01-4.8 2.6l1.2 1.1a18.6 18.6 0 004-2l-.4-1.7m-2.2-9.4l-1.6.7-2.9-3.3 1-1.4 3.5 4m1.3-1l1-1.4-3-3.3-1.6.7 3.6 4m-20.1-8.7l.5 1.6h4.5l.5-1.6h-5.5m21.1 0l-.5 1.6h-4.5l-.5-1.6h5.5m-11.6 21.9c0-.6.5-1 1.1-1a1 1 0 011.1 1c0 .6-.5 1-1 1a1.1 1.1 0 01-1.2-1zm1.9-7.8l1.7-.4v-4.3l-1.7-.5v5.2m-1.6 0l-1.7-.4v-4.3l1.7-.5v5.2\"/>\n  <path fill=\"#c8b100\" d=\"M211.5 294.2c.2-1 1-1.6 1.8-2V287h1.6v5.3c.8.3 1.5.9 1.7 1.6h4.4v.3h-6a1.2 1.2 0 00-1-.6c-.4 0-.7.3-1 .6h-1.5m12.2 0v-.3h4.1a2.4 2.4 0 01.2-.3l-5-5.7 1.2-1 5 5.6.2-.1V285h1.6v7.3h.3l4.9-5.5 1.2 1-4.9 5.5.3.6h4v.3h-13zm21.6 0a1.1 1.1 0 011-.6c.5 0 .8.3 1 .6h1.6c-.2-1-.9-1.6-1.8-2V287h-1.6v5.3c-.8.3-1.4.8-1.7 1.6h-4.4v.3h6m-30.2-15l6 6.8 1.3-1-6.1-6.7.3-.6h4.4V276h-4.4a2.6 2.6 0 00-2.5-1.7 2.6 2.6 0 00-2.7 2.5 2.5 2.5 0 001.8 2.4v5.2h1.6v-5.2h.3zm32 0v5.3h-1.7v-5.2a2.5 2.5 0 01-.4-.2l-6 6.8-1.3-1 6.2-6.9-.1-.3h-4.5V276h4.5a2.6 2.6 0 012.4-1.7 2.6 2.6 0 012.7 2.5 2.5 2.5 0 01-1.9 2.4zm-16.1 0v3.3h-1.7v-3.2a2.6 2.6 0 01-1.7-1.6h-4V276h4a2.6 2.6 0 012.5-1.7c1.2 0 2.2.7 2.5 1.7h4v1.6h-4a2.5 2.5 0 01-1.6 1.6zm-17.8 4l-1.7.4v4.3l1.7.5v-5.2m1.6 0l1.7.4v4.3l-1.7.5v-5.2m30.6 0l-1.7.4v4.3l1.7.5v-5.2m1.6 0l1.7.4v4.3l-1.7.5v-5.2m-25.5.8l1.6-.7 2.9 3.3-1 1.4-3.5-4m-1.3 1l-1 1.4 3 3.3 1.6-.7-3.6-4m18.5-1.1l-1.6-.7-3 3.3 1 1.4 3.6-4m1.2 1l1 1.4-3 3.3-1.5-.7 3.5-4m-20.3 9l.5-1.6h4.5l.5 1.6h-5.5m-6.7-17c0-.6.5-1 1.2-1a1 1 0 011 1c0 .6-.4 1-1 1a1.1 1.1 0 01-1.2-1zm12.1.8l-.5 1.6h-4.5l-.5-1.6h5.5m0-1.6l-.5-1.6h-4.5l-.5 1.6h5.5m15.7 17.8l-.5-1.6h-4.5l-.5 1.6h5.5m4.4-17c0-.6.5-1 1.1-1a1 1 0 011.1 1c0 .6-.5 1-1 1a1.1 1.1 0 01-1.2-1zm-16.1 0c0-.6.5-1 1.1-1a1 1 0 011.1 1c0 .6-.5 1-1.1 1a1.1 1.1 0 01-1.1-1zm6.2.8l.5 1.6h4.6l.5-1.6h-5.6m0-1.6l.5-1.6h4.6l.5 1.6h-5.6m-5.9 5l-1.7.5v4.3l1.7.5V281m1.7 0l1.6.5v4.3l-1.6.5V281\"/>\n  <path fill=\"none\" stroke=\"#c8b100\" stroke-width=\".3\" d=\"M232.7 316.3a15.6 15.6 0 003.7-1.1l.8 1.4a17.6 17.6 0 01-4.3 1.2 2.6 2.6 0 01-2.6 2 2.6 2.6 0 01-2.5-2 17.5 17.5 0 01-4.6-1.2l.8-1.4c1.3.5 2.6.9 4 1a2.5 2.5 0 011.5-1.3v-6.7h1.6v6.7c.7.2 1.3.7 1.6 1.4zm-4.7-20.4a2.3 2.3 0 01-.2-.5h-4V294h4a2.6 2.6 0 01.2-.4l-5-5.6 1.2-1 5 5.5a2.2 2.2 0 01.2 0V285h1.7v7.3h.2l4.9-5.5 1.2 1-4.9 5.5.3.6h4v1.5h-4c0 .2-.2.4-.3.5l4.7 5.3-1.3 1-4.6-5.3-.2.1v8.7h-1.6V297l-.2-.1-4.8 5.3-1.2-1 4.7-5.3m-12.8-16.7l6 6.8 1.3-1-6.1-6.7.3-.6h4.4V276h-4.4a2.6 2.6 0 00-2.5-1.7 2.6 2.6 0 00-2.6 2.5 2.5 2.5 0 001.7 2.4v5.2h1.6v-5.2h.3zm6.5 34.8l-.8 1.4a16.6 16.6 0 01-3.6-3.1c-.9.2-1.8 0-2.5-.5a2.4 2.4 0 01-.3-3.5l.1-.1a15.3 15.3 0 01-1.2-4.8h1.6a13.1 13.1 0 001 4c.5 0 1 0 1.4.2l4.1-4.5 1.3 1-4.1 4.5c.6.9.5 2-.1 2.8a15.2 15.2 0 003.1 2.6zm-8.4-13.1V297a2.5 2.5 0 01-1.8-2.4c0-1 .8-2 1.8-2.4V287h1.6v5.3c.8.2 1.5.8 1.7 1.6h4.4v1.5h-4.4a2.6 2.6 0 01-1.6 1.6v3.9h-1.7m2.3 8.3c.4-.4 1.1-.5 1.6 0s.5 1 .1 1.4a1.2 1.2 0 01-1.6.1 1 1 0 010-1.5zm-2-4.5l-1.7-.3-.3-4.3 1.7-.6v2.5c0 1 0 1.8.3 2.7zm1.4-5.3l1.6.4v2.2c0-.8.3 2.1.3 2.1l-1.7.6-.3-2.7v-2.6zm5.5 13.7a15.7 15.7 0 004.8 2.6l.4-1.6a13.7 13.7 0 01-4-2l-1.2 1m-.8 1.4a17.4 17.4 0 004.8 2.6l-1.2 1.1a18.7 18.7 0 01-4-2l.4-1.7\"/>\n  <path fill=\"none\" stroke=\"#c8b100\" stroke-width=\".3\" d=\"M221.9 305.1l1.6.7 3-3.3-1-1.4-3.6 4m-1.3-1l-1-1.4 3-3.3 1.6.7-3.6 4m-7.6-9.5c0-.6.5-1 1-1 .7 0 1.2.5 1.2 1 0 .6-.5 1.1-1.1 1.1a1 1 0 01-1.1-1zm25.7 19.4l.8 1.4a16.7 16.7 0 003.6-3.1c.9.2 1.8 0 2.6-.5a2.4 2.4 0 00.2-3.5l-.1-.1a15 15 0 001.3-4.8h-1.7a13.3 13.3 0 01-1 4 3 3 0 00-1.4.2l-4.1-4.5-1.3 1 4.1 4.5a2.4 2.4 0 00.1 2.8 15 15 0 01-3 2.6zm8.4-13.1V297a2.5 2.5 0 001.8-2.4c0-1-.7-2-1.8-2.4V287h-1.6v5.3c-.8.2-1.4.8-1.7 1.6h-4.4v1.5h4.4c.3.8.9 1.3 1.7 1.6v3.9h1.6zm-2.3 8.3a1.2 1.2 0 00-1.6 0 1 1 0 00-.1 1.4 1.2 1.2 0 001.6.1 1 1 0 000-1.5zm2-4.5l1.7-.3.3-4.3-1.7-.6v2.5c0 1 0 1.8-.2 2.7zm-1.3-5.3l-1.7.4v2.2c0-.8-.3 2.1-.3 2.1l1.7.6.3-2.7v-2.6m1.6-20.1v5.2h-1.6v-5.2a2.3 2.3 0 01-.4-.2l-6 6.8-1.2-1 6-7v-.2h-4.5V276h4.4a2.6 2.6 0 012.5-1.7 2.6 2.6 0 012.6 2.5 2.5 2.5 0 01-1.8 2.4zm-16 0v3.2h-1.7v-3.2a2.6 2.6 0 01-1.7-1.6h-4V276h4c.4-1 1.3-1.7 2.5-1.7s2.2.7 2.5 1.7h4v1.6h-4a2.5 2.5 0 01-1.6 1.6zm8.8 33.8a15.7 15.7 0 01-4.8 2.6l-.4-1.6a13.7 13.7 0 004-2l1.2 1m.8 1.4a17.4 17.4 0 01-4.8 2.6l1.2 1.1a18.7 18.7 0 004-2l-.4-1.7m-27.4-31.4l-1.7.5v4.3l1.7.5v-5.2m1.7 0l1.6.4v4.3l-1.6.5V283m30.5 0l-1.7.5v4.3l1.7.5V283\"/>\n  <path fill=\"none\" stroke=\"#c8b100\" stroke-width=\".3\" d=\"M247.1 283.1l1.7.5v4.3l-1.7.5V283m-8.6 22l-1.6.7-2.9-3.3 1-1.4 3.5 4m1.3-1l1-1.4-3-3.3-1.6.7 3.6 4m-18.2-20l1.6-.7 3 3.3-1 1.4-3.6-4m-1.3 1l-1 1.4 3 3.3 1.6-.7-3.6-4m18.5-1.1l-1.6-.7-3 3.3 1 1.4 3.6-4m1.2 1l1 1.4-3 3.2-1.5-.6 3.5-4m-20.3 9l.5-1.6h4.5l.5 1.6h-5.5m0 1.5l.5 1.6h4.5l.5-1.6h-5.5M213 277c0-.6.5-1 1.2-1 .6 0 1 .4 1 1s-.4 1-1 1a1 1 0 01-1.2-1zm12.1.8l-.5 1.6h-4.5l-.5-1.6h5.5m0-1.6l-.5-1.6h-4.5l-.5 1.6h5.5m20.1 18.5c0-.5.5-1 1.1-1 .6 0 1.1.5 1.1 1 0 .6-.5 1.1-1 1.1a1 1 0 01-1.2-1zm-4.4-.7l-.5-1.6h-4.5l-.5 1.6h5.5m0 1.5l-.5 1.6h-4.5l-.5-1.6h5.5m-11.6 21.9c0-.6.5-1 1.1-1 .6 0 1.1.4 1.1 1s-.5 1-1 1a1.1 1.1 0 01-1.2-1zm1.9-7.8l1.7-.4v-4.3l-1.7-.5v5.2m-1.6 0l-1.7-.4v-4.3l1.7-.5v5.2m15.7-32.6c0-.6.5-1 1.1-1a1 1 0 011.1 1c0 .6-.5 1-1 1a1.1 1.1 0 01-1.2-1zm-16.1 0c0-.6.5-1 1.1-1a1 1 0 011.1 1c0 .6-.5 1-1 1a1.1 1.1 0 01-1.2-1zm6.2.8l.5 1.6h4.6l.5-1.6h-5.5m0-1.6l.4-1.6h4.6l.5 1.6h-5.5m-6 5l-1.6.5v4.3l1.6.5V281m1.7 0l1.6.5v4.3l-1.6.5V281\"/>\n  <path fill=\"#058e6e\" d=\"M227.7 294.7a2.6 2.6 0 012.6-2.5 2.6 2.6 0 012.6 2.5 2.6 2.6 0 01-2.6 2.4c-1.4 0-2.6-1-2.6-2.4\"/>\n  <path fill=\"#db4446\" d=\"M230.9 229.7v-.6l.1-.3-2.3-.1a5.9 5.9 0 01-2.3-1.2c-.8-.7-1.1-1-1.6-1.2-1.3-.2-2.3.4-2.3.4s1 .4 1.7 1.3 1.5 1.3 1.8 1.4c.6.2 2.6 0 3.1.1l1.8.2\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M230.9 229.7v-.6l.1-.3-2.3-.1a5.9 5.9 0 01-2.3-1.2c-.8-.7-1.1-1-1.6-1.2-1.3-.2-2.3.4-2.3.4s1 .4 1.7 1.3 1.5 1.3 1.8 1.4c.6.2 2.6 0 3.1.1l1.8.2z\"/>\n  <path fill=\"#ed72aa\" stroke=\"#000\" stroke-width=\".4\" d=\"M238.1 227.5v1.4c.2.6-.1 1.2 0 1.5 0 .4.1.6.3.9l.2.9-.7-.5-.6-.4v1c.1.2.3.8.6 1.1l1 1.3c.2.5.1 1.4.1 1.4s-.4-.7-.8-.8l-1.2-.7s.7.8.7 1.5c0 .8-.3 1.6-.3 1.6s-.3-.7-.8-1.1l-1-.9s.4 1.2.4 2v2.3l-.9-1-1-.7c0-.2.5.6.6 1.1 0 .5.3 2.3 1.8 4.5 1 1.3 2.3 3.6 5.3 2.9 3-.8 1.9-4.8 1.3-6.7a16.8 16.8 0 01-1-4.6c0-.8.6-2.9.5-3.3a8 8 0 01.2-3.1c.4-1.3.7-1.8.9-2.3.2-.6.4-.9.4-1.3l.1-1.3.7 1.3.1 1.5s.1-1 1-1.6c.8-.6 1.8-1.1 2-1.4.3-.3.3-.5.3-.5s0 1.8-.6 2.6l-1.7 2s.7-.3 1.2-.3h.9s-.6.4-1.4 1.6c-.8 1-.5 1.2-1 2.1-.6 1-1 1-1.7 1.5-1 .8-.5 4.2-.4 4.7.2.5 2 4.5 2 5.5s.2 3.2-1.5 4.6c-1.1 1-3 1-3.4 1.2-.4.3-1.2 1.1-1.2 2.8 0 1.7.6 2 1 2.4.6.5 1.2.2 1.3.6.2.3.2.5.5.7.2.2.3.4.2.8 0 .3-.8 1.1-1.1 1.7l-.8 2.4c0 .2-.1 1 .1 1.3 0 0 .9 1 .3 1.2-.4.2-.8-.2-1-.2l-.9.5c-.3-.1-.3-.3-.4-.8l-.1-.7c-.2 0-.3.2-.4.5 0 .2 0 .8-.3.8-.2 0-.5-.4-.8-.5-.2 0-.8-.2-.8-.4 0-.3.4-.9.7-1 .4 0 .8-.3.5-.5s-.5-.2-.7 0-.8 0-.7-.2v-.8c0-.2-.4-.5.1-.8.6-.3.8.2 1.4.1.6 0 .8-.3 1-.6.2-.3.2-1-.2-1.4-.4-.5-.7-.5-.9-.8l-.3-.9v2.2l-.7-.8c-.3-.3-.6-1.3-.6-1.3v1.3c0 .4.3.7.2.8-.1.1-.8-.7-1-.8a3.7 3.7 0 01-1-1l-.4-1.4a4.2 4.2 0 010-1.5l.4-1h-1.4c-.7 0-1.2-.3-1.5.2-.3.5-.2 1.5.2 2.8.3 1.2.5 1.9.4 2.1a3 3 0 01-.7.8h-.9a2.5 2.5 0 00-1.2-.3h-1.3l-1.1-.3c-.3.1-.8.3-.6.7.2.6-.2.7-.5.7l-.9-.2c-.4-.1-.9 0-.8-.4 0-.4.2-.4.4-.7.2-.3.2-.5 0-.5h-.6c-.2.2-.5.5-.8.4-.2-.1-.4-.4-.4-1s-.7-1.2 0-1.1c.5 0 1.3.4 1.4 0 .2-.3 0-.4-.2-.7s-.8-.4-.3-.7l.7-.5c.1-.2.4-.8.7-.6.6.2 0 .7.6 1.3.6.7 1 1 2 .8 1 0 1.3-.2 1.3-.5l-.1-1v-1s-.4.3-.5.6l-.4.8v-2a8 8 0 00-.2-.8l-.3.9-.1 1s-.7-.5-.5-1.5c.1-.7-.1-1.6.1-2 .2-.3.7-1.5 2-1.6h2.6l2-.3s-2.8-1.4-3.5-1.9a9.5 9.5 0 01-2-2l-.6-1.6s-.5 0-1 .3a5 5 0 00-1.2 1l-.7 1 .1-1.2v-.8s-.4 1.2-1 1.7l-1.4 1v-.8l.2-1s-.4.8-1.1 1c-.7 0-1.8 0-1.9.4 0 .5.2 1 0 1.4 0 .3-.4.5-.4.5l-.8-.4c-.4 0-.7.2-.7.2s-.3-.4-.2-.7c.1-.2.7-.6.5-.8l-.8.2c-.3.1-.8.3-.8-.2 0-.4.2-.7 0-1 0-.3 0-.5.2-.6l1.2-.1c0-.2-.2-.5-.8-.6-.6-.1-.8-.5-.5-.8.3-.2.3-.3.5-.6.1-.2.2-.7.7-.5.5.3.4.8 1 1a4 4 0 002-.2l1.5-1 1.5-1-1-.8c-.3-.3-.7-.9-1-1a8.3 8.3 0 00-1.8-.6 9 9 0 01-1.7-.5l.8-.3c.2-.2.6-.6.8-.6h.3-1.4c-.3-.1-1-.6-1.3-.6l-.8.1s.8-.4 1.4-.5l1-.1s-.9-.3-1.1-.6l-.6-1c-.2-.1-.3-.5-.6-.5l-1 .3c-.4 0-.6-.2-.6-.6l-.1-.5c-.2-.3-.6-.8-.2-1h1.4c0-.2-.5-.6-.8-.8-.4-.2-1-.5-.7-.8l.8-.5c.2-.3.3-1 .7-.7.4.2.8 1.2 1.1 1.1.3 0 .3-.8.3-1 0-.4 0-1 .2-.9.3 0 .5.4 1 .5.4 0 1-.1 1 .2 0 .3-.3.7-.6 1-.3.3-.4 1-.3 1.4.2.5.7 1.2 1.2 1.4.4.3 1.2.5 1.7.9.5.3 1.7 1.2 2.1 1.3l.8.4s.5-.2 1.1-.2c.7 0 2.1 0 2.6-.2.6-.2 1.3-.6 1-1-.1-.6-1.3-1-1.2-1.4 0-.4.5-.4 1.2-.4.8 0 1.8.1 2-1 .2-1 .2-1.5-.8-1.8-1-.2-1.8-.2-2-1-.2-.7-.4-.9-.2-1.1.3-.2.6-.3 1.4-.4.8 0 1.6 0 1.9-.2.2-.2.3-.7.6-.9.3-.2 1.4-.4 1.4-.4s1.4.7 2.7 1.7a15 15 0 012.2 2.1\"/>\n  <path d=\"M228.1 226.8l-.2-.6v-.3s.8 0 .7.3c0 .2-.2.2-.3.3l-.2.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M228.1 226.8l-.2-.6v-.3s.8 0 .7.3c0 .2-.2.2-.3.3l-.2.3z\"/>\n  <path d=\"M232 225.4v-.4s.7 0 1 .3c.5.4.9 1 .9 1l-.8-.4h-.5l-.3-.1v-.3h-.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".1\" d=\"M232 225.4v-.4s.7 0 1 .3c.5.4.9 1 .9 1l-.8-.4h-.5l-.3-.1v-.3h-.3z\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M237.3 231.3l-.4-.7a8 8 0 01-.3-.4\"/>\n  <path fill=\"#db4446\" d=\"M217.4 226.6s.5.4.8.4h.8s.2-.5.1-.8c-.2-1.2-1.2-1.4-1.2-1.4s.3.7.1 1a2 2 0 01-.6.8\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M217.4 226.6s.5.4.8.4h.8s.2-.5.1-.8c-.2-1.2-1.2-1.4-1.2-1.4s.3.7.1 1a2 2 0 01-.6.8z\"/>\n  <path fill=\"#db4446\" d=\"M215.2 227.6s-.4-.7-1.3-.6c-.8 0-1.4.8-1.4.8h1.2c.3.3.4 1 .4 1l.7-.6a7.2 7.2 0 00.4-.6\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M215.2 227.6s-.4-.7-1.3-.6c-.8 0-1.4.8-1.4.8h1.2c.3.3.4 1 .4 1l.7-.6a7.2 7.2 0 00.4-.6z\"/>\n  <path fill=\"#db4446\" d=\"M214.2 230.6s-.8.1-1.2.6c-.4.5-.3 1.3-.3 1.3s.4-.5.9-.5l1 .2-.1-.8-.3-.8\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M214.2 230.6s-.8.1-1.2.6c-.4.5-.3 1.3-.3 1.3s.4-.5.9-.5l1 .2-.1-.8-.3-.8z\"/>\n  <path d=\"M228.2 230.5l.3-.5.3.5h-.7\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M228.2 230.5l.3-.5.3.5h-.7\"/>\n  <path d=\"M229 230.5l.3-.5.4.5h-.8\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M229 230.5l.3-.5.4.5h-.8\"/>\n  <path d=\"M228.6 227.3l.8.3-.7.4-.1-.6\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M228.6 227.3l.8.3-.7.4-.1-.6\"/>\n  <path d=\"M229.5 227.6l.7.2-.5.4-.2-.6\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M229.5 227.6l.7.2-.5.4-.2-.6\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M224.2 233.7s-.7.2-1 .6c-.4.5-.3 1-.3 1s.6-.5 1.5-.3l1.2.3 1.3-.3s-.7.8-.7 1.3l.2 1.1c0 .7-.6 1.6-.6 1.6l1-.3a4.6 4.6 0 001.7-.8l.9-1s-.2 1 0 1.4l.2 1.6.8-.6c.2-.1.7-.4.9-.7l.3-1s0 .8.4 1.3l.6 1.6s.3-.8.6-1.1c.3-.4.7-.8.7-1a4.3 4.3 0 00-.1-.9l.4.8m-11 .6s.5-.8 1-1l1.1-.8.9-.4m1 5l1.3-.8a4 4 0 001-1\"/>\n  <path fill=\"#db4446\" d=\"M216.6 240.4s-.4-.5-1.1-.3c-.7 0-1.2.9-1.2.9s.6-.2 1-.1.6.4.6.4l.4-.4.3-.6\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M216.6 240.4s-.4-.5-1.1-.3c-.7 0-1.2.9-1.2.9s.6-.2 1-.1.6.4.6.4l.4-.4.3-.6z\"/>\n  <path fill=\"#db4446\" d=\"M215.8 243.2s-.6 0-1.1.3c-.5.4-.5 1.2-.5 1.2s.4-.4.8-.3l.9.2v-.6c.2-.4-.1-.8-.1-.8\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M215.8 243.2s-.6 0-1.1.3c-.5.4-.5 1.2-.5 1.2s.4-.4.8-.3l.9.2v-.6c.2-.4-.1-.8-.1-.8z\"/>\n  <path fill=\"#db4446\" d=\"M217.2 245.8s0 .8.3 1.3c.4.5 1.1.5 1.1.5l-.3-.7c0-.4.3-.8.3-.8s-.3-.3-.7-.3h-.7\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M217.2 245.8s0 .8.3 1.3c.4.5 1.1.5 1.1.5l-.3-.7c0-.4.3-.8.3-.8s-.3-.3-.7-.3h-.7zm16 1.3s2 1.2 1.9 2.2c0 1-1 2.3-1 2.3\"/>\n  <path fill=\"#db4446\" d=\"M224.2 252.6s-.4-.6-1.1-.6c-.7 0-1.4.7-1.4.7s.8-.1 1 .2l.5.6.5-.3.5-.6\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M224.2 252.6s-.4-.6-1.1-.6c-.7 0-1.4.7-1.4.7s.8-.1 1 .2l.5.6.5-.3.5-.6z\"/>\n  <path fill=\"#db4446\" d=\"M222.2 255.3s-1-.1-1.4.3c-.4.5-.4 1.3-.4 1.3s.6-.6 1-.5c.5 0 1 .3 1 .3v-.7l-.3-.7\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M222.2 255.3s-1-.1-1.4.3c-.4.5-.4 1.3-.4 1.3s.6-.6 1-.5c.5 0 1 .3 1 .3v-.7l-.3-.7z\"/>\n  <path fill=\"#db4446\" d=\"M224 258.1s-.3.7 0 1.1c.3.5 1 .8 1 .8s-.3-.4-.2-.8c.1-.3.7-.8.7-.8l-1.4-.2\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M224 258.1s-.3.7 0 1.1c.3.5 1 .8 1 .8s-.3-.4-.2-.8c.1-.3.7-.8.7-.8l-1.4-.2z\"/>\n  <path fill=\"#db4446\" d=\"M236 259.3s-.8-.2-1.2 0c-.5.3-.8 1.4-.8 1.4s.7-.6 1.2-.5c.5 0 1 .3 1 .3v-.8l-.2-.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M236 259.3s-.8-.2-1.2 0c-.5.3-.8 1.4-.8 1.4s.7-.6 1.2-.5c.5 0 1 .3 1 .3v-.8l-.2-.4z\"/>\n  <path fill=\"#db4446\" d=\"M236.4 262.2s-.6.6-.4 1.1l.6 1s0-.7.2-1l1-.3-.7-.5a15.8 15.8 0 01-.7-.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M236.4 262.2s-.6.6-.4 1.1l.6 1s0-.7.2-1l1-.3-.7-.5a15.8 15.8 0 01-.7-.3z\"/>\n  <path fill=\"#db4446\" d=\"M239.4 263s-.3.8.2 1.3c.6.5 1 .5 1 .5s-.3-.7-.2-1.1c.1-.5.5-.7.5-.7l-.8-.2-.7.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M239.4 263s-.3.8.2 1.3c.6.5 1 .5 1 .5s-.3-.7-.2-1.1c.1-.5.5-.7.5-.7l-.8-.2-.7.3z\"/>\n  <path fill=\"#ffd691\" stroke=\"#000\" stroke-width=\".5\" d=\"M208.8 316.4c2 .6 3 2 3 3.8 0 2.3-2.2 4-5 4-3 0-5.3-1.7-5.3-4 0-1.7 1-3.6 3-3.8l-.2-.4-.7-.7h1.2l.8.5.5-.7c.3-.4.6-.5.6-.5l.6.6.3.5.7-.4.8-.3s0 .4-.2.7l-.1.7\"/>\n  <path fill=\"#058e6e\" stroke=\"#000\" stroke-width=\".5\" d=\"M206.3 326.7s-3.8-2.6-5.5-3c-2-.4-4.5 0-5.5 0 0 0 1.2.8 1.8 1.4.5.5 2.3 1.5 3.3 1.8 3 .8 6-.2 6-.2m1 .2s2.4-2.5 5-2.9c3-.4 5 .3 6.2.6l-1.5.8c-.5.3-2 1.5-4 1.6-2 0-4.4-.3-4.8-.2l-.9.1\"/>\n  <path fill=\"#ad1519\" stroke=\"#000\" stroke-width=\".5\" d=\"M206.7 323.8a4.8 4.8 0 010-7.1 4.8 4.8 0 011.5 3.5 4.9 4.9 0 01-1.5 3.6\"/>\n  <path fill=\"#058e6e\" stroke=\"#000\" stroke-width=\".5\" d=\"M205.7 329s.6-1.5.6-2.7l-.1-2.1h.8s.3 1.1.3 2l-.1 2.4-.7.1-.8.3\"/>\n  <path fill=\"#fff\" d=\"M254 190.7c0-.5.5-1 1-1 .6 0 1.1.5 1.1 1 0 .6-.5 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M254 190.7c0-.5.5-1 1-1 .6 0 1.1.5 1.1 1 0 .6-.5 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M255.4 188.2c0-.6.5-1 1.1-1 .6 0 1 .4 1 1s-.4 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M255.4 188.2c0-.6.5-1 1.1-1 .6 0 1 .4 1 1s-.4 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M256.4 185.2c0-.5.5-1 1-1 .6 0 1.1.5 1.1 1s-.5 1-1 1a1 1 0 01-1.1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M256.4 185.2c0-.5.5-1 1-1 .6 0 1.1.5 1.1 1s-.5 1-1 1a1 1 0 01-1.1-1z\"/>\n  <path fill=\"#fff\" d=\"M256.5 182c0-.5.5-1 1-1 .6 0 1.1.5 1.1 1 0 .6-.5 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M256.5 182c0-.5.5-1 1-1 .6 0 1.1.5 1.1 1 0 .6-.5 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M255.7 179c0-.6.5-1 1-1 .7 0 1.2.4 1.2 1s-.5 1-1.1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M255.7 179c0-.6.5-1 1-1 .7 0 1.2.4 1.2 1s-.5 1-1.1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M254.1 176.1c0-.5.5-1 1-1 .7 0 1.1.5 1.1 1s-.4 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M254.1 176.1c0-.5.5-1 1-1 .7 0 1.1.5 1.1 1s-.4 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M252 173.8c0-.6.4-1 1-1s1 .4 1 1-.4 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M252 173.8c0-.6.4-1 1-1s1 .4 1 1-.4 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M249.4 171.8c0-.5.5-1 1.1-1a1 1 0 010 2c-.6 0-1-.4-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M249.4 171.8c0-.5.5-1 1.1-1a1 1 0 010 2c-.6 0-1-.4-1-1z\"/>\n  <path fill=\"#fff\" d=\"M246.5 170.3c0-.6.4-1 1-1s1 .4 1 1-.4 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M246.5 170.3c0-.6.4-1 1-1s1 .4 1 1-.4 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M243.3 169.1c0-.5.5-1 1.1-1a1 1 0 010 2 1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M243.3 169.1c0-.5.5-1 1.1-1a1 1 0 010 2 1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M239.9 168.5c0-.5.4-1 1-1s1 .5 1 1-.4 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M239.9 168.5c0-.5.4-1 1-1s1 .5 1 1-.4 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M236.6 168.3c0-.5.4-1 1-1s1 .5 1 1-.4 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M236.6 168.3c0-.5.4-1 1-1s1 .5 1 1-.4 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M233.3 168.5c0-.6.5-1 1-1 .7 0 1.1.4 1.1 1s-.4 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M233.3 168.5c0-.6.5-1 1-1 .7 0 1.1.4 1.1 1s-.4 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M230.1 168.5c0-.6.5-1 1-1 .6 0 1.1.4 1.1 1s-.5 1-1 1a1 1 0 01-1.1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M230.1 168.5c0-.6.5-1 1-1 .6 0 1.1.4 1.1 1s-.5 1-1 1a1 1 0 01-1.1-1z\"/>\n  <path fill=\"#fff\" stroke=\"#000\" stroke-width=\".4\" d=\"M231.7 171.2c0-.5.5-1 1-1 .7 0 1.1.5 1.1 1s-.4 1-1 1a1 1 0 01-1-1m.6 3.1c0-.6.4-1 1-1s1 .4 1 1c0 .5-.4 1-1 1a1 1 0 01-1-1m0 3c0-.5.6-1 1.1-1a1 1 0 010 2 1 1 0 01-1-1m-1 2.8c0-.5.5-1 1-1 .7 0 1.1.5 1.1 1 0 .6-.4 1-1 1a1 1 0 01-1-1m-1.9 2.6c0-.5.5-1 1-1 .7 0 1.2.5 1.2 1s-.5 1-1.1 1c-.6 0-1-.4-1-1\"/>\n  <path fill=\"#fff\" d=\"M227.6 166.5c0-.5.5-1 1.1-1a1 1 0 010 2 1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M227.6 166.5c0-.5.5-1 1.1-1a1 1 0 010 2 1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M224.8 165c0-.6.4-1 1-1s1 .4 1 1-.4 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M224.8 165c0-.6.4-1 1-1s1 .4 1 1-.4 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M221.6 164c0-.6.5-1 1-1 .6 0 1.1.4 1.1 1 0 .5-.5 1-1 1-.6 0-1.1-.5-1.1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M221.6 164c0-.6.5-1 1-1 .6 0 1.1.4 1.1 1 0 .5-.5 1-1 1-.6 0-1.1-.5-1.1-1z\"/>\n  <path fill=\"#fff\" d=\"M218.3 163.4c0-.5.5-1 1-1 .6 0 1.1.5 1.1 1s-.5 1-1 1a1 1 0 01-1.1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M218.3 163.4c0-.5.5-1 1-1 .6 0 1.1.5 1.1 1s-.5 1-1 1a1 1 0 01-1.1-1z\"/>\n  <path fill=\"#fff\" d=\"M215 163.5c0-.6.5-1 1.1-1 .6 0 1 .4 1 1 0 .5-.4 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M215 163.5c0-.6.5-1 1.1-1 .6 0 1 .4 1 1 0 .5-.4 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M211.7 164c0-.5.5-1 1-1 .7 0 1.1.5 1.1 1s-.4 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M211.7 164c0-.5.5-1 1-1 .7 0 1.1.5 1.1 1s-.4 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M208.6 165.1c0-.5.5-1 1-1 .6 0 1.1.5 1.1 1s-.5 1-1 1a1 1 0 01-1.1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M208.6 165.1c0-.5.5-1 1-1 .6 0 1.1.5 1.1 1s-.5 1-1 1a1 1 0 01-1.1-1z\"/>\n  <path fill=\"#fff\" d=\"M156 190.7c0-.5.4-1 1-1s1 .5 1 1c0 .6-.4 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M156 190.7c0-.5.4-1 1-1s1 .5 1 1c0 .6-.4 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M154.5 188.2c0-.6.5-1 1-1 .6 0 1 .4 1 1s-.4 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M154.5 188.2c0-.6.5-1 1-1 .6 0 1 .4 1 1s-.4 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M153.5 185.2c0-.5.5-1 1-1 .7 0 1.1.5 1.1 1s-.4 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M153.5 185.2c0-.5.5-1 1-1 .7 0 1.1.5 1.1 1s-.4 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M153.4 182c0-.5.5-1 1-1 .6 0 1.1.5 1.1 1 0 .6-.5 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M153.4 182c0-.5.5-1 1-1 .6 0 1.1.5 1.1 1 0 .6-.5 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M154.2 179c0-.6.5-1 1-1 .6 0 1 .4 1 1s-.4 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M154.2 179c0-.6.5-1 1-1 .6 0 1 .4 1 1s-.4 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M155.8 176.1c0-.5.5-1 1-1 .6 0 1.1.5 1.1 1s-.5 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M155.8 176.1c0-.5.5-1 1-1 .6 0 1.1.5 1.1 1s-.5 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M158 173.8c0-.6.4-1 1-1s1 .4 1 1-.4 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M158 173.8c0-.6.4-1 1-1s1 .4 1 1-.4 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M160.5 171.8c0-.5.4-1 1-1s1 .5 1 1-.4 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M160.5 171.8c0-.5.4-1 1-1s1 .5 1 1-.4 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M163.5 170.3c0-.6.4-1 1-1s1 .4 1 1-.4 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M163.5 170.3c0-.6.4-1 1-1s1 .4 1 1-.4 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M166.6 169.1c0-.5.5-1 1-1a1 1 0 010 2 1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M166.6 169.1c0-.5.5-1 1-1a1 1 0 010 2 1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M170 168.5c0-.5.5-1 1.1-1a1 1 0 010 2c-.6 0-1-.4-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M170 168.5c0-.5.5-1 1.1-1a1 1 0 010 2c-.6 0-1-.4-1-1z\"/>\n  <path fill=\"#fff\" d=\"M173.4 168.3c0-.5.4-1 1-1s1 .5 1 1-.4 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M173.4 168.3c0-.5.4-1 1-1s1 .5 1 1-.4 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M176.6 168.5c0-.6.5-1 1-1 .6 0 1.1.4 1.1 1s-.5 1-1 1a1 1 0 01-1.1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M176.6 168.5c0-.6.5-1 1-1 .6 0 1.1.4 1.1 1s-.5 1-1 1a1 1 0 01-1.1-1z\"/>\n  <path fill=\"#fff\" d=\"M179.8 168.5c0-.6.5-1 1-1 .7 0 1.2.4 1.2 1s-.5 1-1.1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M179.8 168.5c0-.6.5-1 1-1 .7 0 1.2.4 1.2 1s-.5 1-1.1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" stroke=\"#000\" stroke-width=\".4\" d=\"M178.2 171.2c0-.5.5-1 1-1 .7 0 1.1.5 1.1 1s-.4 1-1 1a1 1 0 01-1-1m-.7 3.1c0-.6.4-1 1-1s1 .4 1 1c0 .5-.4 1-1 1a1 1 0 01-1-1m-.2 3c0-.5.5-1 1-1 .7 0 1.1.5 1.1 1s-.4 1-1 1a1 1 0 01-1-1m.9 2.8c0-.5.5-1 1-1 .6 0 1.1.5 1.1 1 0 .6-.5 1-1 1a1 1 0 01-1.1-1m1.8 2.6c0-.5.5-1 1-1a1 1 0 010 2 1 1 0 01-1-1\"/>\n  <path fill=\"#fff\" d=\"M182.3 166.5c0-.5.5-1 1-1a1 1 0 010 2 1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M182.3 166.5c0-.5.5-1 1-1a1 1 0 010 2 1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M185.2 165c0-.6.4-1 1-1s1 .4 1 1-.4 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M185.2 165c0-.6.4-1 1-1s1 .4 1 1-.4 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M188.3 164c0-.6.5-1 1-1 .7 0 1.1.4 1.1 1 0 .5-.4 1-1 1s-1-.5-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M188.3 164c0-.6.5-1 1-1 .7 0 1.1.4 1.1 1 0 .5-.4 1-1 1s-1-.5-1-1z\"/>\n  <path fill=\"#fff\" d=\"M191.6 163.4c0-.5.5-1 1-1 .7 0 1.1.5 1.1 1s-.4 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M191.6 163.4c0-.5.5-1 1-1 .7 0 1.1.5 1.1 1s-.4 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M194.9 163.5c0-.6.4-1 1-1s1 .4 1 1c0 .5-.4 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M194.9 163.5c0-.6.4-1 1-1s1 .4 1 1c0 .5-.4 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M198.2 164c0-.5.5-1 1-1 .7 0 1.1.5 1.1 1s-.4 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M198.2 164c0-.5.5-1 1-1 .7 0 1.1.5 1.1 1s-.4 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#fff\" d=\"M201.3 165.1c0-.5.5-1 1-1 .7 0 1.1.5 1.1 1s-.4 1-1 1a1 1 0 01-1-1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".4\" d=\"M201.3 165.1c0-.5.5-1 1-1 .7 0 1.1.5 1.1 1s-.4 1-1 1a1 1 0 01-1-1z\"/>\n  <path fill=\"#c8b100\" stroke=\"#000\" stroke-width=\".4\" d=\"M174.7 228.9h-1v-1h-1.5v3.6h1.6v2.5h-3.4v7h1.8v14.3h-3.5v7.3h27.2v-7.3h-3.5V241h1.8v-7h-3.4v-2.5h1.6V228h-1.6v.9h-.8v-1h-1.6v1h-1.1v-1h-1.6v3.6h1.6v2.5H184v-7.8h1.7v-3.5H184v.9h-1v-1h-1.5v1h-.9v-1H179v3.6h1.7v7.8h-3.3v-2.5h1.6V228h-1.6v.9h-.9v-1h-1.8v1zm-6 33.7H196m-27.3-1.8H196m-27.3-1.8H196m-27.3-1.7H196m-27.3-2H196m-23.8-1.6h20.2m-20.2-1.8h20.2m-20.2-2h20.2m-20.2-1.7h20.2m-20.2-1.8h20.2m-20.2-1.8h20.2m-20.2-1.7h20.2m-22-1.8h23.8m-23.8-1.8h23.8m-23.8-1.8h23.8m-23.8-1.8h23.8m-20.4-1.7h17m-10.2-1.8h3.4m-3.4-1.8h3.4m-3.4-1.8h3.4m-3.4-1.7h3.4m-5.1-2.2h6.8m-12 7.5h3.6m-5-2.2h6.6m-6.7 32.6v-1.8m0-1.8v-1.7m-1.8 1.7v1.8m3.4 0V259m1.7 3.6v-1.8m0-1.8v-1.7m0-2v-1.6m0-1.8v-2m-1.7 7.4v-2m-3.4 2v-2m7 0v2m1.5-2v-1.6m-5.1-1.8v1.8m3.5-1.8v1.8m3.3-1.8v1.8M179 252v-2m1.7-1.7v1.7m0-5.3v1.8m-1.7-3.6v1.8m1.7-3.5v1.7m-3.3-1.7v1.7m-3.5-1.7v1.7m-1.6-3.5v1.8m3.3-1.8v1.8m3.4-1.8v1.8m1.7-3.6v1.8m-3.3-1.8v1.8m-3.5-1.8v1.8m-1.6-3.6v1.8m6.7-1.8v1.8m-3.4-5.3v1.8m15.3-1.8h-3.5m5-2.2h-6.6m6.7 32.6v-1.8m0-1.8v-1.7m1.8 1.7v1.8m-3.4 0V259m-1.7 3.6v-1.8m0-1.8v-1.7m0-2v-1.6m0-1.8v-2m1.7 7.4v-2m3.4 2v-2m-7 0v2m-1.5-2v-1.6m5.1-1.8v1.8m-3.5-1.8v1.8m-3.3-1.8v1.8m1.7-1.8v-2m-1.7-1.7v1.7m0-5.3v1.8m1.7-3.6v1.8m-1.7-3.5v1.7m3.3-1.7v1.7m3.5-1.7v1.7m1.6-3.5v1.8m-3.3-1.8v1.8m-3.4-1.8v1.8m-1.7-3.6v1.8m3.3-1.8v1.8m3.5-1.8v1.8m1.6-3.6v1.8m-6.7-1.8v1.8m3.4-5.3v1.8m-7 18v-2m0-5.4v-1.8m0 5.4v-1.8m0-5.3v-1.8m0-1.8v-1.7m0-3.6v-1.8m0-1.7v-1.8m-8.3 4.6h3.5m3.3-5.3h3.4m3.3 5.3h3.5\"/>\n  <path fill=\"#c8b100\" stroke=\"#000\" stroke-width=\".4\" d=\"M186.8 262.6v-4.7c0-.8-.4-3.5-4.6-3.5-4 0-4.4 2.7-4.4 3.5v4.7h9z\"/>\n  <path fill=\"#c8b100\" stroke=\"#000\" stroke-width=\".4\" d=\"M179.3 258.2l-2.2-.3c0-.9.2-2.2.9-2.6l2 1.5c-.3.2-.7 1-.7 1.4zm6 0l2.2-.3c0-.9-.2-2.2-.9-2.6l-2 1.5c.3.2.7 1 .7 1.4zm-2.2-2.3l1-2a5.3 5.3 0 00-2-.4l-1.7.4 1.1 2h1.6zm-4.2-5.5v-4.9c0-1.3-1-2.4-2.5-2.4s-2.4 1-2.4 2.4v4.9h4.9zm6.8 0v-4.9c0-1.3 1-2.4 2.5-2.4s2.4 1 2.4 2.4v4.9h-4.9zm-1.7-12l.4-4.4h-4.2l.2 4.4h3.6zm3.3 0l-.4-4.4h4.4l-.5 4.4h-3.5zm-10 0l.2-4.4h-4.2l.5 4.4h3.5z\"/>\n  <path fill=\"#0039f0\" d=\"M185.3 262.6v-4c0-.7-.5-2.7-3.1-2.7-2.4 0-2.9 2-2.9 2.7v4h6zm-6.9-12.7v-4.2c0-1-.6-2.2-2-2.2s-2 1.1-2 2.2v4.3h4zm7.8 0v-4.2c0-1 .7-2.2 2-2.2s2 1.1 2 2.2v4.3h-4z\"/>\n  <path fill=\"#ad1519\" d=\"M190.8 269.8c0-9.7 7-17.6 15.6-17.6s15.6 7.9 15.6 17.6-7 17.5-15.6 17.5-15.6-7.8-15.6-17.5\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".6\" d=\"M190.8 269.8c0-9.7 7-17.6 15.6-17.6s15.6 7.9 15.6 17.6-7 17.5-15.6 17.5-15.6-7.8-15.6-17.5z\"/>\n  <path fill=\"#005bbf\" d=\"M195.4 269.7c0-7 5-12.8 11-12.8s11 5.7 11 12.8c0 7.2-5 13-11 13s-11-5.8-11-13\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".6\" d=\"M195.4 269.7c0-7 5-12.8 11-12.8s11 5.7 11 12.8c0 7.2-5 13-11 13s-11-5.8-11-13z\"/>\n  <path fill=\"#c8b100\" d=\"M201.2 260.9s-1.3 1.4-1.3 2.7a6 6 0 00.6 2.4c-.2-.5-.8-.8-1.4-.8-.8 0-1.4.6-1.4 1.3l.2.8.5.9c.1-.3.5-.5 1-.5s1 .4 1 1a.9.9 0 010 .2h-1.2v1h1l-.8 1.5 1-.4.8.9.8-.9 1 .4-.7-1.5h1v-1h-1.1a.9.9 0 010-.3 1 1 0 011-1c.4 0 .7.3 1 .6l.4-1 .2-.7a1.4 1.4 0 00-1.4-1.3c-.7 0-1.2.3-1.4.9 0 0 .6-1.2.6-2.5s-1.4-2.7-1.4-2.7\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-linejoin=\"round\" stroke-width=\".3\" d=\"M201.2 260.9s-1.3 1.4-1.3 2.7a6 6 0 00.6 2.4c-.2-.5-.8-.8-1.4-.8-.8 0-1.4.6-1.4 1.3l.2.8.5.9c.1-.3.5-.5 1-.5s1 .4 1 1a.9.9 0 010 .2h-1.2v1h1l-.8 1.5 1-.4.8.9.8-.9 1 .4-.7-1.5h1v-1h-1.1a.9.9 0 010-.3 1 1 0 011-1c.4 0 .7.3 1 .6l.4-1 .2-.7a1.4 1.4 0 00-1.4-1.3c-.7 0-1.2.3-1.4.9 0 0 .6-1.2.6-2.5s-1.4-2.7-1.4-2.7z\"/>\n  <path fill=\"#c8b100\" d=\"M199.2 269.9h4.1v-1h-4.1v1z\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M199.2 269.9h4.1v-1h-4.1v1z\"/>\n  <path fill=\"#c8b100\" d=\"M211.4 260.9s-1.3 1.4-1.3 2.7c0 1.3.6 2.4.6 2.4-.2-.5-.7-.8-1.4-.8-.8 0-1.4.6-1.4 1.3l.2.8.5.9c.2-.3.5-.5 1-.5a1 1 0 011 1 .9.9 0 010 .2h-1.2v1h1l-.8 1.5 1-.4.8.9.8-.9 1 .4-.7-1.5h1v-1h-1.1a.8.8 0 010-.3 1 1 0 011-1c.4 0 .8.3 1 .6l.4-1 .2-.7a1.4 1.4 0 00-1.4-1.3c-.6 0-1.2.3-1.4.9 0 0 .6-1.2.6-2.5s-1.4-2.7-1.4-2.7\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-linejoin=\"round\" stroke-width=\".3\" d=\"M211.4 260.9s-1.3 1.4-1.3 2.7c0 1.3.6 2.4.6 2.4-.2-.5-.7-.8-1.4-.8-.8 0-1.4.6-1.4 1.3l.2.8.5.9c.2-.3.5-.5 1-.5a1 1 0 011 1 .9.9 0 010 .2h-1.2v1h1l-.8 1.5 1-.4.8.9.8-.9 1 .4-.7-1.5h1v-1h-1.1a.8.8 0 010-.3 1 1 0 011-1c.4 0 .8.3 1 .6l.4-1 .2-.7a1.4 1.4 0 00-1.4-1.3c-.6 0-1.2.3-1.4.9 0 0 .6-1.2.6-2.5s-1.4-2.7-1.4-2.7z\"/>\n  <path fill=\"#c8b100\" d=\"M209.4 269.9h4.1v-1h-4.1v1z\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M209.4 269.9h4.1v-1h-4.1v1z\"/>\n  <path fill=\"#c8b100\" d=\"M206.3 269.6s-1.3 1.5-1.3 2.8.6 2.4.6 2.4c-.2-.5-.7-.9-1.4-.9-.8 0-1.4.6-1.4 1.4l.2.7.5 1c.1-.4.5-.6 1-.6a1 1 0 011 1 .9.9 0 010 .3h-1.2v1h1l-.8 1.5 1-.4.8.9.8-1 1 .5-.7-1.5h1v-1h-1.1a.9.9 0 010-.3 1 1 0 011-1c.4 0 .7.2.9.6l.5-1 .2-.7a1.4 1.4 0 00-1.4-1.4c-.7 0-1.2.4-1.4 1 0 0 .6-1.2.6-2.5s-1.4-2.7-1.4-2.7\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-linejoin=\"round\" stroke-width=\".3\" d=\"M206.3 269.6s-1.3 1.5-1.3 2.8.6 2.4.6 2.4c-.2-.5-.7-.9-1.4-.9-.8 0-1.4.6-1.4 1.4l.2.7.5 1c.1-.4.5-.6 1-.6a1 1 0 011 1 .9.9 0 010 .3h-1.2v1h1l-.8 1.5 1-.4.8.9.8-1 1 .5-.7-1.5h1v-1h-1.1a.9.9 0 010-.3 1 1 0 011-1c.4 0 .7.2.9.6l.5-1 .2-.7a1.4 1.4 0 00-1.4-1.4c-.7 0-1.2.4-1.4 1 0 0 .6-1.2.6-2.5s-1.4-2.7-1.4-2.7z\"/>\n  <path fill=\"#c8b100\" d=\"M204.3 278.6h4.1v-1h-4.1v1z\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M204.3 278.6h4.1v-1h-4.1v1z\"/>\n  <path fill=\"#c8b100\" d=\"M237.6 223.4h-.3a1.5 1.5 0 01-.3.4c-.2.2-.6.2-.8 0a.5.5 0 01-.1-.4.5.5 0 01-.5 0c-.3-.1-.3-.5-.1-.7v-.5h-.3l-.1.2c-.2.3-.5.3-.7.2a.6.6 0 010-.2h-.3c-.5.2-.7-1-.7-1.2l-.2.2s.2.7.1 1.2c0 .6-.3 1.2-.3 1.2a9 9 0 012.9 1.6 9 9 0 012.2 2.3l1.2-.5c.6-.2 1.3-.2 1.3-.2l.2-.2c-.3 0-1.5.1-1.5-.4v-.2a.7.7 0 01-.2 0c-.2-.2-.2-.4 0-.7l.2-.1v-.3h-.3l-.2.1c-.2.3-.6.3-.8 0a.4.4 0 01-.1-.4.6.6 0 01-.5 0c-.2-.2-.3-.5 0-.8l.2-.3v-.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M237.6 223.4h-.3a1.5 1.5 0 01-.3.4c-.2.2-.6.2-.8 0a.5.5 0 01-.1-.4.5.5 0 01-.5 0c-.3-.1-.3-.5-.1-.7v-.5h-.3l-.1.2c-.2.3-.5.3-.7.2a.6.6 0 010-.2h-.3c-.5.2-.7-1-.7-1.2l-.2.2s.2.7.1 1.2c0 .6-.3 1.2-.3 1.2a9 9 0 012.9 1.6 9 9 0 012.2 2.3l1.2-.5c.6-.2 1.3-.2 1.3-.2l.2-.2c-.3 0-1.5.1-1.5-.4v-.2a.7.7 0 01-.2 0c-.2-.2-.2-.4 0-.7l.2-.1v-.3h-.3l-.2.1c-.2.3-.6.3-.8 0a.4.4 0 01-.1-.4.6.6 0 01-.5 0c-.2-.2-.3-.5 0-.8l.2-.3v-.3z\"/>\n  <path d=\"M235.4 224h.2v.3h-.1c-.1 0-.1-.2 0-.2\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".1\" d=\"M235.4 224h.2v.3h-.1c-.1 0-.1-.2 0-.2z\"/>\n  <path d=\"M236.3 224.8l-.3-.2v-.2h.1l.4.3.3.2v.2h-.2l-.3-.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".1\" d=\"M236.3 224.8l-.3-.2v-.2h.1l.4.3.3.2v.2h-.2l-.3-.3\"/>\n  <path d=\"M234.6 223.7l-.2-.2s-.1 0 0-.1l.3.1.3.1v.2h-.1l-.3-.1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".1\" d=\"M234.6 223.7l-.2-.2s-.1 0 0-.1l.3.1.3.1v.2h-.1l-.3-.1\"/>\n  <path d=\"M233.7 223h.2v.2h-.2s-.1-.1 0-.2\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".1\" d=\"M233.7 223h.2v.2h-.2s-.1-.1 0-.2z\"/>\n  <path d=\"M237.3 225.5v-.2h-.3l.1.2h.2\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".1\" d=\"M237.3 225.5v-.2h-.3l.1.2h.2z\"/>\n  <path d=\"M237.9 226.2l.2.2h.1c.1 0 0-.1 0-.2l-.2-.2-.2-.2h-.1v.2l.2.2\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".1\" d=\"M237.9 226.2l.2.2h.1c.1 0 0-.1 0-.2l-.2-.2-.2-.2h-.1v.2l.2.2\"/>\n  <path d=\"M238.8 227v-.3h-.3v.2h.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".1\" d=\"M238.8 227v-.3h-.3v.2h.3z\"/>\n  <path fill=\"#c8b100\" d=\"M236.2 221.1h-.6l-.1.9v.1h.2l.7-.5-.3-.5\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M236.2 221.1h-.6l-.1.9v.1h.2l.7-.5-.3-.5\"/>\n  <path fill=\"#c8b100\" d=\"M234.6 221.6v.5l.9.1h.1v-.2l-.5-.7-.5.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M234.6 221.6v.5l.9.1h.1v-.2l-.5-.7-.5.3\"/>\n  <path fill=\"#c8b100\" d=\"M236.4 222.6l-.4.3-.6-.7v-.1h1.1v.5\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M236.4 222.6l-.4.3-.6-.7v-.1h1.1v.5\"/>\n  <path fill=\"#c8b100\" d=\"M235.3 222a.3.3 0 01.4 0 .3.3 0 010 .3.3.3 0 01-.3 0 .3.3 0 01-.1-.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M235.3 222a.3.3 0 01.4 0 .3.3 0 010 .3.3.3 0 01-.3 0 .3.3 0 01-.1-.3z\"/>\n  <path fill=\"#c8b100\" d=\"M233.2 221.1l-.2-.7-.4-.4s.4-.2.8.1c.4.3 0 .9 0 .9l-.2.1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M233.2 221.1l-.2-.7-.4-.4s.4-.2.8.1c.4.3 0 .9 0 .9l-.2.1z\"/>\n  <path fill=\"#c8b100\" d=\"M234.2 221.4l-.4.4-.6-.6v-.2h1v.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M234.2 221.4l-.4.4-.6-.6v-.2h1v.4\"/>\n  <path fill=\"#c8b100\" d=\"M233.1 221l.3-.1v.3c0 .2-.1.2-.2.2l-.1-.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M233.1 221l.3-.1v.3c0 .2-.1.2-.2.2l-.1-.3z\"/>\n  <path fill=\"#c8b100\" d=\"M238.3 222.5h-.5l-.3.7v.2h.2l.8-.4-.2-.5\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M238.3 222.5h-.5l-.3.7v.2h.2l.8-.4-.2-.5\"/>\n  <path fill=\"#c8b100\" d=\"M236.7 222.8v.5l.8.2h.1v-.2l-.4-.7-.5.2\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M236.7 222.8v.5l.8.2h.1v-.2l-.4-.7-.5.2\"/>\n  <path fill=\"#c8b100\" d=\"M238.4 224l-.5.2-.4-.7v-.2h.1l.9.2-.1.5\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M238.4 224l-.5.2-.4-.7v-.2h.1l.9.2-.1.5\"/>\n  <path fill=\"#c8b100\" d=\"M237.3 223.2h.4a.3.3 0 010 .4.3.3 0 01-.3 0 .3.3 0 010-.4\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M237.3 223.2h.4a.3.3 0 010 .4.3.3 0 01-.3 0 .3.3 0 010-.4z\"/>\n  <path fill=\"#c8b100\" d=\"M240.2 224.3l.1.5-.8.3h-.2v-.2l.4-.8.5.2\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M240.2 224.3l.1.5-.8.3h-.2v-.2l.4-.8.5.2\"/>\n  <path fill=\"#c8b100\" d=\"M240 225.8l-.5.1-.3-.8v-.1h.2l.8.3-.1.5\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M240 225.8l-.5.1-.3-.8v-.1h.2l.8.3-.1.5\"/>\n  <path fill=\"#c8b100\" d=\"M238.6 224.3l-.2.5.9.3h.1v-.1l-.3-.8-.5.1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M238.6 224.3l-.2.5.9.3h.1v-.1l-.3-.8-.5.1\"/>\n  <path fill=\"#c8b100\" d=\"M239.5 225.2a.3.3 0 000-.3.3.3 0 00-.4 0 .3.3 0 000 .3.3.3 0 00.4 0\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M239.5 225.2a.3.3 0 000-.3.3.3 0 00-.4 0 .3.3 0 000 .3.3.3 0 00.4 0z\"/>\n  <path fill=\"#c8b100\" d=\"M240.8 227h.8l.5.3s.1-.4-.3-.7c-.3-.3-.8.2-.8.2l-.2.2\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M240.8 227h.8l.5.3s.1-.4-.3-.7c-.3-.3-.8.2-.8.2l-.2.2z\"/>\n  <path fill=\"#c8b100\" d=\"M240.3 226.1l-.3.5.8.5v-.1h.2l-.1-1-.6.1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M240.3 226.1l-.3.5.8.5v-.1h.2l-.1-1-.6.1\"/>\n  <path fill=\"#c8b100\" d=\"M241 227s.1-.1 0-.2h-.3c-.2 0-.2.1-.1.2h.3\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".3\" d=\"M241 227s.1-.1 0-.2h-.3c-.2 0-.2.1-.1.2h.3zm38-21.9v.6h-2.4v-.6h1v-1.3h-.7v-.5h.6v-.6h.6v.6h.6v.6h-.6v1.2h1\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\"0\" d=\"M134.4 217.1v-1.2m-.4 1.2v-1.2m-.2 1.2v-1.2m-.3 1.2v-1.2\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".1\" d=\"M133.2 217.1v-1.2m-.5 1.1v-1m.2 1v-1m-.7 1v-1m.2 1v-1m-.9 1v-1m.2 1v-1m.3 1v-1m-.7 1v-1m-.3.9v-.8m-.1.8v-.8m-.5.7v-.6m.2.6v-.6m-.4.5v-.5m-.2.5v-.4m-.3.3v-.3m-.3.3v-.2\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".2\" d=\"M129.2 216.6v-.2\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\"0\" d=\"M135.7 217v-1m-.5 1v-1m-.4 1.2V216m143 1.1V216m-.4 1.1V216m-.3 1.1V216m-.3 1.2V216\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".1\" d=\"M276.6 217.1V216m-.6 1v-1m.3 1v-1m-.8 1v-1m.3 1v-1m-.9 1v-1m.2 1v-1m.2 1v-1m-.6 1v-1m-.3.9v-.8m-.2.8v-.8m-.4.7v-.6m.2.6v-.6m-.5.6v-.6m-.2.5v-.4m-.3.4v-.4m-.2.3v-.2\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\".2\" d=\"M272.6 216.6v-.2\"/>\n  <path fill=\"none\" stroke=\"#000\" stroke-width=\"0\" d=\"M279.1 217v-1m-.6 1v-1m-.4 1.1V216\"/>\n</svg>";

var de$1 = "<svg xmlns=\"http://www.w3.org/2000/svg\" id=\"flag-icon-css-de\" viewBox=\"0 0 640 480\">\n  <path fill=\"#ffce00\" d=\"M0 320h640v160H0z\"/>\n  <path d=\"M0 0h640v160H0z\"/>\n  <path fill=\"#d00\" d=\"M0 160h640v160H0z\"/>\n</svg>";

var fr$1 = "<svg xmlns=\"http://www.w3.org/2000/svg\" id=\"flag-icon-css-fr\" viewBox=\"0 0 640 480\">\n  <g fill-rule=\"evenodd\" stroke-width=\"1pt\">\n    <path fill=\"#fff\" d=\"M0 0h640v480H0z\"/>\n    <path fill=\"#00267f\" d=\"M0 0h213.3v480H0z\"/>\n    <path fill=\"#f31830\" d=\"M426.7 0H640v480H426.7z\"/>\n  </g>\n</svg>";

var id$1 = "<svg xmlns=\"http://www.w3.org/2000/svg\" id=\"flag-icon-css-id\" viewBox=\"0 0 640 480\">\n  <g fill-rule=\"evenodd\" stroke-width=\"1pt\">\n    <path fill=\"#e70011\" d=\"M0 0h640v249H0z\"/>\n    <path fill=\"#fff\" d=\"M0 240h640v240H0z\"/>\n  </g>\n</svg>";

var pt$1 = "<svg xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" id=\"flag-icon-css-pt\" viewBox=\"0 0 640 480\">\n  <path fill=\"red\" d=\"M256 0h384v480H256z\"/>\n  <path fill=\"#060\" d=\"M0 0h256v480H0z\"/>\n  <g fill=\"#ff0\" fill-rule=\"evenodd\" stroke=\"#000\" stroke-linecap=\"round\" stroke-linejoin=\"round\" stroke-width=\".6\">\n    <path d=\"M339.5 306.2c-32.3-1-180-93.2-181-108l8.1-13.5c14.7 21.3 165.7 111 180.6 107.8l-7.7 13.7\"/>\n    <path d=\"M164.9 182.8c-2.9 7.8 38.6 33.4 88.4 63.8 49.9 30.3 92.9 49 96 46.4l1.5-2.8c-.6 1-2 1.3-4.3.6-13.5-3.9-48.6-20-92.1-46.4-43.6-26.4-81.4-50.7-87.3-61a6.3 6.3 0 01-.6-3.1h-.2l-1.2 2.2-.2.3zm175.3 123.8c-.5 1-1.6 1-3.5.8-12-1.3-48.6-19.1-91.9-45-50.4-30.2-92-57.6-87.4-64.8l1.2-2.2.2.1c-4 12.2 82.1 61.4 87.2 64.6 49.8 30.8 91.8 48.9 95.5 44.2l-1.3 2.3z\"/>\n    <path d=\"M256.2 207.2c32.2-.3 72-4.4 95-13.6l-5-8c-13.5 7.5-53.5 12.5-90.3 13.2-43.4-.4-74.1-4.5-89.5-14.8l-4.6 8.6c28.2 12 57.2 14.5 94.4 14.6\"/>\n    <path d=\"M352.5 193.8c-.8 1.3-15.8 6.4-37.8 10.2a381.2 381.2 0 01-58.6 4.3 416.1 416.1 0 01-56.2-3.6c-23.1-3.6-35-8.6-39.5-10.4l1.1-2.2c12.7 5 24.7 8 38.7 10.2A411.5 411.5 0 00256 206a391.8 391.8 0 0058.3-4.3c22.5-3.7 34.8-8.4 36.6-10.5l1.6 2.7zm-4.4-8.1c-2.4 2-14.6 6.3-36 9.7a388.2 388.2 0 01-55.8 4c-22 0-40.1-1.6-53.8-3.6-21.8-2.8-33.4-8-37.6-9.4l1.3-2.2c3.3 1.7 14.4 6.2 36.5 9.3a385 385 0 0053.6 3.4 384 384 0 0055.4-4c21.5-3 33.1-8.4 34.9-9.8l1.5 2.6zM150.3 246c19.8 10.7 63.9 16 105.6 16.4 38 .1 87.4-5.8 105.9-15.6l-.5-10.7c-5.8 9-58.8 17.7-105.8 17.4-47-.4-90.7-7.6-105.3-17v9.5\"/>\n    <path d=\"M362.8 244.5v2.5c-2.8 3.4-20.2 8.4-42 12a434 434 0 01-65.4 4.4 400 400 0 01-62-4.3 155 155 0 01-44.4-12v-2.9c9.7 6.4 35.9 11.2 44.7 12.6 15.8 2.4 36.1 4.2 61.7 4.2 26.9 0 48.4-1.9 65-4.4 15.7-2.3 38-8.2 42.4-12.1zm0-9v2.5c-2.8 3.3-20.2 8.3-42 11.9a434 434 0 01-65.4 4.5 414 414 0 01-62-4.3 155 155 0 01-44.4-12v-3c9.7 6.5 36 11.2 44.7 12.6a408 408 0 0061.7 4.3c26.9 0 48.5-2 65-4.5 15.7-2.2 38-8.1 42.4-12zm-107 68.8c-45.6-.2-84.7-12.4-93-14.4l6 9.4a249.8 249.8 0 0087.4 14.3c34.7-1 65-3.7 86.3-14.1l6.2-9.8c-14.5 6.9-64 14.6-93 14.6\"/>\n    <path d=\"M344.9 297.3a143 143 0 01-2.8 4c-10 3.6-26 7.4-32.6 8.4a295.5 295.5 0 01-53.7 5c-40.4-.6-73.5-8.5-89-15.3l-1.3-2.1.2-.4 2.1.9a286.5 286.5 0 0088.2 14.5c18.8 0 37.5-2.1 52.6-4.8 23.2-4.7 32.6-8.2 35.5-9.8l.7-.4zm5.3-8.8a287.2 287.2 0 01-2 3.5c-5.4 2-20 6.2-41.3 9.2-14 1.9-22.7 3.8-50.6 4.3a347.4 347.4 0 01-94.2-14L161 289a390 390 0 0095.4 14c25.5-.5 36.4-2.4 50.3-4.3 24.8-3.8 37.3-8 41-9.1a2.9 2.9 0 000-.2l2.6-1z\"/>\n    <path d=\"M350.8 237.6c.1 30-15.3 57-27.6 68.8a99.3 99.3 0 01-67.8 28.2c-30.3.5-58.8-19.2-66.5-27.9a101 101 0 01-27.5-67.4c1.8-32.8 14.7-55.6 33.3-71.3a99.6 99.6 0 0164.2-22.7 98.2 98.2 0 0171 35.6c12.5 15.2 18 31.7 20.9 56.7zM255.6 135a106 106 0 01106 105.2 105.6 105.6 0 11-211.4 0c-.1-58 47.3-105.2 105.4-105.2\"/>\n    <path d=\"M255.9 134.5c58.2 0 105.6 47.4 105.6 105.6S314.1 345.7 256 345.7s-105.6-47.4-105.6-105.6c0-58.2 47.4-105.6 105.6-105.6zM152.6 240c0 56.8 46.7 103.3 103.3 103.3 56.6 0 103.3-46.5 103.3-103.3s-46.7-103.3-103.3-103.3S152.6 183.2 152.6 240z\"/>\n    <path d=\"M256 143.3a97 97 0 0196.7 96.7 97.1 97.1 0 01-96.7 96.8c-53 0-96.7-43.6-96.7-96.8a97.1 97.1 0 0196.7-96.7zM161.6 240c0 52 42.6 94.4 94.4 94.4s94.4-42.5 94.4-94.4c0-52-42.6-94.4-94.4-94.4a94.8 94.8 0 00-94.4 94.4z\"/>\n    <path d=\"M260.3 134h-9.1v212.3h9z\"/>\n    <path d=\"M259.3 132.8h2.3v214.7h-2.2V132.8zm-9 0h2.4v214.7h-2.3V132.8z\"/>\n    <path d=\"M361.6 244.2v-7.8l-6.4-6-36.3-9.6-52.2-5.3-63 3.2-44.8 10.6-9 6.7v7.9l22.9-10.3 54.4-8.5h52.3l38.4 4.2 26.6 6.4z\"/>\n    <path d=\"M256 223.8c24.9 0 49 2.3 68.3 6 19.8 4 33.7 9 38.5 14.5v2.8c-5.8-7-24.5-12-39-15-19-3.6-43-6-67.9-6-26.1 0-50.5 2.6-69.3 6.2-15 3-35.1 9-37.6 14.8v-2.9c1.3-4 16.3-10 37.3-14.3 18.9-3.7 43.3-6.1 69.6-6.1zm0-9.1a383 383 0 0168.3 6c19.8 4 33.7 9 38.5 14.6v2.7c-5.8-6.9-24.5-12-39-14.9-19-3.7-43-6-67.9-6a376 376 0 00-69.2 6.2c-14.5 2.7-35.4 8.9-37.7 14.7v-2.8c1.4-4 16.6-10.3 37.3-14.3 19-3.7 43.3-6.2 69.7-6.2zm-.6-46.2c39.3-.2 73.6 5.5 89.3 13.5l5.7 10c-13.6-7.4-50.6-15-94.9-14-36.1.3-74.7 4-94 14.4l6.8-11.4c15.9-8.3 53.3-12.5 87.1-12.5\"/>\n    <path d=\"M256 176.7a354 354 0 0161.3 4.3c16 3 31.3 7.4 33.5 9.8l1.7 3c-5.3-3.4-18.6-7.3-35.6-10.5s-38.7-4.3-61-4.2c-25.3-.1-45 1.2-61.8 4.2a108.9 108.9 0 00-33.3 10.3l1.7-3.1c6-3 15.3-6.7 31.1-9.6 17.5-3.2 37.4-4.1 62.4-4.2zm0-9c21.4-.2 42.6 1 59.1 4a96 96 0 0130.6 10l2.5 4c-4.2-4.7-20-9.2-34.1-11.6-16.4-2.9-36.7-4-58.1-4.2a361 361 0 00-59.5 4.4 97.3 97.3 0 00-29.6 9.1l2.2-3.3c5.8-3 15.2-5.8 27-8.1a357 357 0 0159.9-4.4zM308.4 284a276.4 276.4 0 00-52.5-4c-65.5.8-86.6 13.5-89.2 17.3l-5-8c16.8-12 52.4-18.8 94.6-18.2 21.9.4 40.8 1.9 56.6 5l-4.5 8\"/>\n    <path d=\"M255.6 278.9c18.2.3 36 1 53.3 4.2l-1.2 2.2c-16-3-33.2-4-52-4-24.3-.2-48.7 2.1-70 8.2-6.7 1.9-17.8 6.2-19 9.8l-1.2-2c.4-2.2 7-6.6 19.6-10 24.4-7 47.2-8.3 70.5-8.4zm.8-9.2a327 327 0 0157.3 5l-1.3 2.3a299 299 0 00-56-4.9c-24.2 0-49.9 1.8-73.3 8.6-7.5 2.2-20.6 7-21 10.7l-1.2-2.2c.2-3.4 11.5-7.9 21.7-10.8 23.5-6.9 49.3-8.6 73.8-8.7z\"/>\n    <path d=\"M349.4 290.5l-7.8 12.3-22.7-20.1-58.6-39.5-66.2-36.3-34.3-11.7 7.3-13.6 2.5-1.3 21.3 5.3 70.4 36.3 40.6 25.6L336 272l13.9 16z\"/>\n    <path d=\"M158.6 195.5c6-4 50.2 15.6 96.6 43.6 46.1 28 90.3 59.6 86.3 65.5l-1.3 2.1-.6.5c.1-.1.8-1 0-3.1-2-6.5-33.4-31.5-85.3-62.9-50.7-30.1-92.9-48.3-97-43.1l1.3-2.6zM351 290.4c3.8-7.6-37.2-38.5-88.1-68.6-52-29.5-89.6-46.9-96.5-41.7L165 183c0 .1 0-.2.4-.5 1.2-1 3.3-1 4.2-1 11.8.2 45.5 15.7 92.8 42.8 20.8 12 87.6 55 87.3 67 0 1 .1 1.2-.3 1.8l1.7-2.6z\"/>\n  </g>\n  <g transform=\"translate(0 26.7) scale(1.06667)\">\n    <path fill=\"#fff\" stroke=\"#000\" stroke-width=\".7\" d=\"M180.6 211a58.7 58.7 0 0017.5 41.7 59 59 0 0041.8 17.6 59.4 59.4 0 0042-17.4 59 59 0 0017.4-41.8v-79.2l-118.7-.2V211z\"/>\n    <path fill=\"red\" stroke=\"#000\" stroke-width=\".5\" d=\"M182.8 211.1a56.4 56.4 0 0016.8 40 57 57 0 0040.2 16.8 56.9 56.9 0 0040.2-16.6 56.4 56.4 0 0016.7-40v-77H183v76.8m91-53.7v48.9l-.1 5.1a33.2 33.2 0 01-10 24 34 34 0 01-24 10c-9.4 0-17.7-4-23.9-10.2a34 34 0 01-10-24v-54l68 .2z\"/>\n    <g id=\"e\">\n      <g id=\"d\" fill=\"#ff0\" stroke=\"#000\" stroke-width=\".5\">\n        <path stroke=\"none\" d=\"M190.2 154.4c.1-5.5 4-6.8 4-6.8.1 0 4.3 1.4 4.3 6.9h-8.3\"/>\n        <path d=\"M186.8 147.7l-.7 6.3h4.2c0-5.2 4-6 4-6 .1 0 4 1.1 4.1 6h4.2l-.8-6.4h-15zm-1 6.4h17c.3 0 .6.3.6.7 0 .5-.3.8-.6.8h-17c-.3 0-.6-.3-.6-.8 0-.4.3-.7.7-.7z\"/>\n        <path d=\"M192 154c0-3.3 2.3-4.2 2.3-4.2s2.3 1 2.3 4.2H192m-5.8-9h16.3c.3 0 .6.4.6.8 0 .3-.3.6-.6.6h-16.3c-.3 0-.6-.3-.6-.7 0-.3.3-.6.6-.6zm.4 1.5H202c.3 0 .6.3.6.7 0 .4-.3.7-.6.7h-15.5c-.4 0-.6-.3-.6-.7 0-.4.2-.7.6-.7zm5-10.6h1.2v.8h.9v-.8h1.3v.9h.9v-1h1.2v2c0 .4-.2.6-.5.6h-4.4c-.3 0-.6-.2-.6-.5v-2zm4.6 2.7l.3 6.4h-4.3l.3-6.5h3.7\"/>\n        <path id=\"a\" d=\"M191 141.6v3.4h-4v-3.4h4z\"/>\n        <use width=\"100%\" height=\"100%\" x=\"10.6\" xlink:href=\"#a\"/>\n        <path id=\"b\" d=\"M186.3 139h1.2v1h.9v-1h1.2v1h.9v-1h1.2v2c0 .4-.2.6-.5.6h-4.3a.6.6 0 01-.6-.6v-2z\"/>\n        <use width=\"100%\" height=\"100%\" x=\"10.6\" xlink:href=\"#b\"/>\n        <path fill=\"#000\" stroke=\"none\" d=\"M193.9 140.6c0-.6.9-.6.9 0v1.6h-.9v-1.6\"/>\n        <path id=\"c\" fill=\"#000\" stroke=\"none\" d=\"M188.6 142.8c0-.6.8-.6.8 0v1.2h-.8v-1.2\"/>\n        <use width=\"100%\" height=\"100%\" x=\"10.6\" xlink:href=\"#c\"/>\n      </g>\n      <use width=\"100%\" height=\"100%\" y=\"46.3\" xlink:href=\"#d\"/>\n      <use width=\"100%\" height=\"100%\" transform=\"rotate(-45.2 312.8 180)\" xlink:href=\"#d\"/>\n    </g>\n    <use width=\"100%\" height=\"100%\" x=\"45.7\" xlink:href=\"#d\"/>\n    <use width=\"100%\" height=\"100%\" transform=\"matrix(-1 0 0 1 479.8 0)\" xlink:href=\"#e\"/>\n    <g id=\"f\" fill=\"#fff\">\n      <path fill=\"#039\" d=\"M232.6 202.4a8.3 8.3 0 002.2 5.7 7.2 7.2 0 005.3 2.4c2.1 0 4-1 5.3-2.4a8.3 8.3 0 002.2-5.7v-10.8h-15v10.8\"/>\n      <circle cx=\"236.1\" cy=\"195.7\" r=\"1.5\"/>\n      <circle cx=\"244.4\" cy=\"195.7\" r=\"1.5\"/>\n      <circle cx=\"240.2\" cy=\"199.7\" r=\"1.5\"/>\n      <circle cx=\"236.1\" cy=\"203.9\" r=\"1.5\"/>\n      <circle cx=\"244.4\" cy=\"203.9\" r=\"1.5\"/>\n    </g>\n    <use width=\"100%\" height=\"100%\" y=\"-26\" xlink:href=\"#f\"/>\n    <use width=\"100%\" height=\"100%\" x=\"-20.8\" xlink:href=\"#f\"/>\n    <use width=\"100%\" height=\"100%\" x=\"20.8\" xlink:href=\"#f\"/>\n    <use width=\"100%\" height=\"100%\" y=\"25.8\" xlink:href=\"#f\"/>\n  </g>\n</svg>";

var br = "<svg xmlns=\"http://www.w3.org/2000/svg\" id=\"flag-icon-css-br\" viewBox=\"0 0 640 480\">\n  <g stroke-width=\"1pt\">\n    <path fill=\"#229e45\" fill-rule=\"evenodd\" d=\"M0 0h640v480H0z\"/>\n    <path fill=\"#f8e509\" fill-rule=\"evenodd\" d=\"M321.4 436l301.5-195.7L319.6 44 17.1 240.7 321.4 436z\"/>\n    <path fill=\"#2b49a3\" fill-rule=\"evenodd\" d=\"M452.8 240c0 70.3-57.1 127.3-127.6 127.3A127.4 127.4 0 11452.8 240z\"/>\n    <path fill=\"#ffffef\" fill-rule=\"evenodd\" d=\"M283.3 316.3l-4-2.3-4 2 .9-4.5-3.2-3.4 4.5-.5 2.2-4 1.9 4.2 4.4.8-3.3 3m86 26.3l-3.9-2.3-4 2 .8-4.5-3.1-3.3 4.5-.5 2.1-4.1 2 4.2 4.4.8-3.4 3.1m-36.2-30l-3.4-2-3.5 1.8.8-3.9-2.8-2.9 4-.4 1.8-3.6 1.6 3.7 3.9.7-3 2.7m87-8.5l-3.4-2-3.5 1.8.8-3.9-2.7-2.8 3.9-.4 1.8-3.5 1.6 3.6 3.8.7-2.9 2.6m-87.3-22l-4-2.2-4 2 .8-4.6-3.1-3.3 4.5-.5 2.1-4.1 2 4.2 4.4.8-3.4 3.2m-104.6-35l-4-2.2-4 2 1-4.6-3.3-3.3 4.6-.5 2-4.1 2 4.2 4.4.8-3.3 3.1m13.3 57.2l-4-2.3-4 2 .9-4.5-3.2-3.3 4.5-.6 2.1-4 2 4.2 4.4.8-3.3 3.1m132-67.3l-3.6-2-3.6 1.8.8-4-2.8-3 4-.5 1.9-3.6 1.7 3.8 4 .7-3 2.7m-6.7 38.3l-2.7-1.6-2.9 1.4.6-3.2-2.2-2.3 3.2-.4 1.5-2.8 1.3 3 3 .5-2.2 2.2m-142.2 50.4l-2.7-1.5-2.7 1.3.6-3-2.1-2.2 3-.4 1.4-2.7 1.3 2.8 3 .6-2.3 2M419 299.8l-2.2-1.1-2.2 1 .5-2.3-1.7-1.6 2.4-.3 1.2-2 1 2 2.5.5-1.9 1.5\"/>\n    <path fill=\"#ffffef\" fill-rule=\"evenodd\" d=\"M219.3 287.6l-2.7-1.5-2.7 1.3.6-3-2.1-2.2 3-.4 1.4-2.7 1.3 2.8 3 .6-2.3 2\"/>\n    <path fill=\"#ffffef\" fill-rule=\"evenodd\" d=\"M219.3 287.6l-2.7-1.5-2.7 1.3.6-3-2.1-2.2 3-.4 1.4-2.7 1.3 2.8 3 .6-2.3 2m42.3 3l-2.6-1.4-2.7 1.3.6-3-2.1-2.2 3-.4 1.4-2.7 1.3 2.8 3 .5-2.3 2.1m-4.8 17l-2.6-1.5-2.7 1.4.6-3-2.1-2.3 3-.4 1.4-2.7 1.3 2.8 3 .6-2.3 2m87.4-22.2l-2.6-1.6-2.8 1.4.6-3-2-2.3 3-.3 1.4-2.7 1.2 2.8 3 .5-2.2 2.1m-25.1 3l-2.7-1.5-2.7 1.4.6-3-2-2.3 3-.3 1.4-2.8 1.2 2.9 3 .5-2.2 2.1m-68.8-5.8l-1.7-1-1.7.8.4-1.9-1.3-1.4 1.9-.2.8-1.7.8 1.8 1.9.3-1.4 1.3m167.8 45.4l-2.6-1.5-2.7 1.4.6-3-2.1-2.3 3-.4 1.4-2.7 1.3 2.8 3 .6-2.3 2m-20.8 6l-2.2-1.4-2.3 1.2.5-2.6-1.7-1.8 2.5-.3 1.2-2.3 1 2.4 2.5.4-1.9 1.8m10.4 2.3l-2-1.2-2.1 1 .4-2.3-1.6-1.7 2.3-.3 1.1-2 1 2 2.3.5-1.7 1.6m29.1-22.8l-2-1-2 1 .5-2.3-1.6-1.7 2.3-.3 1-2 1 2.1 2.1.4-1.6 1.6m-38.8 41.8l-2.5-1.4-2.7 1.2.6-2.8-2-2 3-.3 1.3-2.5 1.2 2.6 3 .5-2.3 1.9m.6 14.2l-2.4-1.4-2.4 1.3.6-2.8-1.9-2 2.7-.4 1.2-2.5 1.1 2.6 2.7.5-2 2m-19-23.1l-1.9-1.2-2 1 .4-2.2-1.5-1.7 2.2-.2 1-2 1 2 2.2.4-1.6 1.6m-17.8 2.3l-2-1.2-2 1 .5-2.2-1.6-1.7 2.3-.2 1-2 1 2 2.1.4-1.6 1.6m-30.4-24.6l-2-1.1-2 1 .5-2.3-1.6-1.6 2.2-.3 1-2 1 2 2.2.5-1.6 1.5m3.7 57l-1.6-.9-1.8.9.4-2-1.3-1.4 1.9-.2.9-1.7.8 1.8 1.9.3-1.4 1.3m-46.2-86.6l-4-2.3-4 2 .9-4.5-3.2-3.3 4.5-.6 2.2-4 1.9 4.2 4.4.8-3.3 3.1\"/>\n    <path fill=\"#fff\" fill-rule=\"evenodd\" d=\"M444.4 285.8a124.6 124.6 0 005.8-19.8c-67.8-59.5-143.3-90-238.7-83.7a124.5 124.5 0 00-8.5 20.9c113-10.8 196 39.2 241.4 82.6z\"/>\n    <path fill=\"#309e3a\" d=\"M414 252.4l2.3 1.3a3.4 3.4 0 00-.3 2.2 3 3 0 001.4 1.7c.7.5 1.4.8 2 .7.6 0 1-.3 1.3-.7a1.3 1.3 0 00.2-.9 2.3 2.3 0 00-.5-1c-.2-.3-.7-1-1.5-1.8a7.7 7.7 0 01-1.8-3 3.7 3.7 0 012-4.4 3.8 3.8 0 012.3-.2 7 7 0 012.6 1.2c1.4 1 2.3 2 2.6 3.2a4.1 4.1 0 01-.6 3.3l-2.4-1.5c.3-.6.4-1.2.2-1.7-.1-.5-.5-1-1.2-1.4a3.2 3.2 0 00-1.8-.7 1 1 0 00-.9.5c-.2.3-.2.6-.1 1s.6 1.2 1.6 2.2c1 1 1.6 1.9 2 2.5a3.9 3.9 0 01-.3 4.2 4.1 4.1 0 01-1.9 1.5 4 4 0 01-2.4.3c-.9-.2-1.8-.6-2.8-1.3-1.5-1-2.4-2.1-2.7-3.3a5.4 5.4 0 01.6-4zm-11.6-7.6l2.5 1.3a3.4 3.4 0 00-.2 2.2 3 3 0 001.4 1.6c.8.5 1.4.7 2 .6.6 0 1-.3 1.3-.8a1.3 1.3 0 00.2-.8c0-.3-.2-.7-.5-1a34.6 34.6 0 00-1.6-1.8c-1.1-1.1-1.8-2-2-2.8a3.7 3.7 0 01.4-3.1 3.6 3.6 0 011.6-1.4 3.8 3.8 0 012.2-.3 7 7 0 012.6 1c1.5 1 2.4 2 2.7 3.1a4.1 4.1 0 01-.4 3.4l-2.5-1.4c.3-.7.4-1.2.2-1.7s-.6-1-1.3-1.4a3.2 3.2 0 00-1.9-.6 1 1 0 00-.8.5c-.2.3-.2.6-.1 1s.7 1.2 1.7 2.2c1 1 1.7 1.8 2 2.4a3.9 3.9 0 010 4.2 4.2 4.2 0 01-1.8 1.6 4 4 0 01-2.4.3 8 8 0 01-2.9-1.1 6 6 0 01-2.8-3.2 5.4 5.4 0 01.4-4zm-14.2-3.8l7.3-12 8.8 5.5-1.2 2-6.4-4-1.6 2.7 6 3.7-1.3 2-6-3.7-2 3.3 6.7 4-1.2 2-9-5.5zm-20.7-17l1.1-2 5.4 2.7-2.5 5c-.8.2-1.8.3-3 .2a9.4 9.4 0 01-3.3-1 7.7 7.7 0 01-3-2.6 6 6 0 01-1-3.5 8.6 8.6 0 011-3.7 8 8 0 012.6-3 6.2 6.2 0 013.6-1.1c1 0 2 .3 3.2 1 1.6.7 2.6 1.7 3.1 2.8a5 5 0 01.3 3.5l-2.7-.8a3 3 0 00-.2-2c-.3-.6-.8-1-1.6-1.4a3.8 3.8 0 00-3.1-.3c-1 .3-1.9 1.2-2.6 2.6-.7 1.4-1 2.7-.7 3.8a3.7 3.7 0 002 2.4c.5.3 1.1.5 1.7.5a6 6 0 001.8 0l.8-1.6-2.9-1.5zm-90.2-22.3l2-14 4.2.7 1.1 9.8 3.9-9 4.2.6-2 13.8-2.7-.4 1.7-10.9-4.4 10.5-2.7-.4-1.1-11.3-1.6 11-2.6-.4zm-14.1-1.7l1.3-14 10.3 1-.2 2.4-7.5-.7-.3 3 7 .7-.3 2.4-7-.7-.3 3.8 7.8.7-.2 2.4-10.6-1z\"/>\n    <g stroke-opacity=\".5\">\n      <path fill=\"#309e3a\" d=\"M216.5 191.3c0-1.5.3-2.6.7-3.6a6.7 6.7 0 011.4-1.9 5.4 5.4 0 011.8-1.2c1-.3 2-.5 3-.5 2.1 0 3.7.8 5 2a7.4 7.4 0 011.6 5.5c0 2.2-.7 4-2 5.3a6.5 6.5 0 01-5 1.7 6.6 6.6 0 01-4.8-2 7.3 7.3 0 01-1.7-5.3z\"/>\n      <path fill=\"#f7ffff\" d=\"M219.4 191.3c0 1.5.3 2.7 1 3.6.7.8 1.6 1.3 2.8 1.3a3.5 3.5 0 002.8-1.1c.7-.8 1-2 1.1-3.7 0-1.6-.2-2.8-1-3.6a3.5 3.5 0 00-2.7-1.3 3.6 3.6 0 00-2.8 1.2c-.8.8-1.1 2-1.2 3.6z\"/>\n    </g>\n    <g stroke-opacity=\".5\">\n      <path fill=\"#309e3a\" d=\"M233 198.5l.2-14h6c1.5 0 2.5.2 3.2.5.7.2 1.2.7 1.6 1.3s.6 1.4.6 2.3a3.8 3.8 0 01-1 2.6 4.5 4.5 0 01-2.7 1.2l1.5 1.2c.4.4.9 1.2 1.5 2.3l1.7 2.8h-3.4l-2-3.2-1.4-2a2.1 2.1 0 00-.9-.6 5 5 0 00-1.4-.2h-.6v5.8H233z\"/>\n      <path fill=\"#fff\" d=\"M236 190.5h2c1.4 0 2.3 0 2.6-.2.3 0 .6-.3.8-.5s.3-.7.3-1c0-.6-.1-1-.4-1.2-.2-.3-.6-.5-1-.6h-2l-2.3-.1v3.5z\"/>\n    </g>\n    <g stroke-opacity=\".5\">\n      <path fill=\"#309e3a\" d=\"M249 185.2l5.2.3c1.1 0 2 .1 2.6.3a4.7 4.7 0 012 1.4 6 6 0 011.2 2.4c.3.9.4 2 .3 3.3a9.3 9.3 0 01-.5 3c-.4 1-1 1.8-1.7 2.4a5 5 0 01-2 1c-.6.2-1.5.2-2.5.2l-5.3-.3.7-14z\"/>\n      <path fill=\"#fff\" d=\"M251.7 187.7l-.5 9.3h3.8c.5 0 .9-.2 1.2-.5.3-.3.6-.7.8-1.3.2-.6.4-1.5.4-2.6l-.1-2.5a3.2 3.2 0 00-.8-1.4 2.7 2.7 0 00-1.2-.7 13 13 0 00-2.3-.3h-1.3z\"/>\n    </g>\n    <g stroke-opacity=\".5\">\n      <path fill=\"#309e3a\" d=\"M317.6 210.2l3.3-13.6 4.4 1 3.2 1c.7.4 1.3 1 1.6 1.9.4.8.4 1.7.2 2.8-.2.8-.5 1.5-1 2a3.9 3.9 0 01-3 1.4c-.7 0-1.7-.2-3-.5l-1.7-.5-1.2 5.2-2.8-.7z\"/>\n      <path fill=\"#fff\" d=\"M323 199.6l-.8 3.8 1.5.4c1 .2 1.8.4 2.2.3a1.9 1.9 0 001.6-1.5c0-.5 0-.9-.2-1.3a2 2 0 00-1-.9l-1.9-.5-1.3-.3z\"/>\n    </g>\n    <g stroke-opacity=\".5\">\n      <path fill=\"#309e3a\" d=\"M330.6 214.1l4.7-13.2 5.5 2c1.5.5 2.4 1 3 1.4.5.5.9 1 1 1.8s.2 1.5 0 2.3c-.4 1-1 1.7-1.8 2.2-.8.4-1.8.5-3 .3.4.5.8 1 1 1.6l.8 2.7.6 3.1-3.1-1.1-1-3.6a19.5 19.5 0 00-.7-2.4 2.1 2.1 0 00-.6-.8c-.2-.3-.6-.5-1.3-.7l-.5-.2-2 5.6-2.6-1z\"/>\n      <path fill=\"#fff\" d=\"M336 207.4l1.9.7c1.3.5 2.1.7 2.5.7.3 0 .6 0 .9-.3.3-.2.5-.5.6-.9.2-.4.2-.8 0-1.2a1.7 1.7 0 00-.8-.9l-2-.7-2-.7-1.2 3.3z\"/>\n    </g>\n    <g stroke-opacity=\".5\">\n      <path fill=\"#309e3a\" d=\"M347 213.6a9 9 0 011.7-3.2 6.6 6.6 0 011.8-1.5 6 6 0 012-.7c1 0 2 0 3.1.4a6.5 6.5 0 014.2 3.3c.8 1.6.8 3.5.2 5.7a7.4 7.4 0 01-3.4 4.5c-1.5.9-3.3 1-5.2.4a6.6 6.6 0 01-4.2-3.3 7.3 7.3 0 01-.2-5.6z\"/>\n      <path fill=\"#fff\" d=\"M349.8 214.4c-.4 1.5-.5 2.8 0 3.8s1.2 1.6 2.3 2c1 .3 2 .2 3-.4 1-.5 1.6-1.6 2.1-3.2.5-1.5.5-2.7 0-3.7a3.5 3.5 0 00-2.2-2 3.6 3.6 0 00-3 .3c-1 .6-1.7 1.6-2.2 3.2z\"/>\n    </g>\n    <g stroke-opacity=\".5\">\n      <path fill=\"#309e3a\" d=\"M374.3 233.1l6.4-12.4 5.3 2.7a10 10 0 012.7 1.9c.5.5.8 1.1.8 1.9s0 1.5-.4 2.2a3.8 3.8 0 01-2 2c-1 .2-2 .2-3.1-.2.4.6.6 1.2.8 1.7.2.6.3 1.5.4 2.8l.2 3.2-3-1.5-.4-3.7a20 20 0 00-.3-2.5 2 2 0 00-.5-1l-1.2-.7-.5-.3-2.7 5.2-2.5-1.3z\"/>\n      <path fill=\"#fff\" d=\"M380.5 227.2l1.9 1c1.2.6 2 1 2.3 1 .3 0 .7 0 1-.2.3-.1.5-.4.7-.8.2-.4.3-.8.2-1.2a2 2 0 00-.7-1 23.7 23.7 0 00-1.8-1l-2-1-1.6 3.2z\"/>\n    </g>\n    <g stroke-opacity=\".5\">\n      <path fill=\"#309e3a\" d=\"M426.1 258.7a8.9 8.9 0 012.5-2.6 6.6 6.6 0 012.2-.9 5.5 5.5 0 012.2 0c1 .2 1.9.6 2.8 1.2a6.6 6.6 0 013 4.4c.3 1.7-.2 3.6-1.4 5.5a7.3 7.3 0 01-4.5 3.3 6.5 6.5 0 01-5.2-1.1 6.6 6.6 0 01-3-4.4c-.3-1.8.2-3.6 1.4-5.4z\"/>\n      <path fill=\"#fff\" d=\"M428.6 260.3c-1 1.3-1.3 2.5-1.1 3.6a3.6 3.6 0 001.6 2.5c1 .7 2 .9 3 .6 1-.3 2-1 2.9-2.4.9-1.4 1.3-2.6 1.1-3.6-.1-1-.7-1.9-1.6-2.6s-2-.8-3-.5c-1 .2-2 1-3 2.4z\"/>\n    </g>\n    <path fill=\"#309e3a\" d=\"M301.8 204.5l2.3-9.8 7.2 1.7-.3 1.6-5.3-1.2-.5 2.2 4.9 1.1-.4 1.7-4.9-1.2-.6 2.7 5.5 1.3-.4 1.6-7.5-1.7z\"/>\n  </g>\n</svg>";

var ru$1 = "<svg xmlns=\"http://www.w3.org/2000/svg\" id=\"flag-icon-css-ru\" viewBox=\"0 0 640 480\">\n  <g fill-rule=\"evenodd\" stroke-width=\"1pt\">\n    <path fill=\"#fff\" d=\"M0 0h640v480H0z\"/>\n    <path fill=\"#0039a6\" d=\"M0 160h640v320H0z\"/>\n    <path fill=\"#d52b1e\" d=\"M0 320h640v160H0z\"/>\n  </g>\n</svg>";

var tr$1 = "<svg xmlns=\"http://www.w3.org/2000/svg\" id=\"flag-icon-css-tr\" viewBox=\"0 0 640 480\">\n  <g fill-rule=\"evenodd\">\n    <path fill=\"#e30a17\" d=\"M0 0h640v480H0z\"/>\n    <path fill=\"#fff\" d=\"M407 247.5c0 66.2-54.6 119.9-122 119.9s-122-53.7-122-120 54.6-119.8 122-119.8 122 53.7 122 119.9z\"/>\n    <path fill=\"#e30a17\" d=\"M413 247.5c0 53-43.6 95.9-97.5 95.9s-97.6-43-97.6-96 43.7-95.8 97.6-95.8 97.6 42.9 97.6 95.9z\"/>\n    <path fill=\"#fff\" d=\"M430.7 191.5l-1 44.3-41.3 11.2 40.8 14.5-1 40.7 26.5-31.8 40.2 14-23.2-34.1 28.3-33.9-43.5 12-25.8-37z\"/>\n  </g>\n</svg>";

var vn$1 = "<svg xmlns=\"http://www.w3.org/2000/svg\" id=\"flag-icon-css-vn\" viewBox=\"0 0 640 480\">\n  <defs>\n    <clipPath id=\"vn-a\">\n      <path fill-opacity=\".7\" d=\"M-85.3 0h682.6v512H-85.3z\"/>\n    </clipPath>\n  </defs>\n  <g fill-rule=\"evenodd\" clip-path=\"url(#vn-a)\" transform=\"translate(80) scale(.9375)\">\n    <path fill=\"#ec0015\" d=\"M-128 0h768v512h-768z\"/>\n    <path fill=\"#ff0\" d=\"M349.6 381L260 314.3l-89 67.3L204 272l-89-67.7 110.1-1 34.2-109.4L294 203l110.1.1-88.5 68.4 33.9 109.6z\"/>\n  </g>\n</svg>";

var hr$1 = "<svg xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" id=\"flag-icon-css-hr\" viewBox=\"0 0 640 480\">\n  <path fill=\"#171796\" d=\"M0 0h640v480H0z\"/>\n  <path fill=\"#fff\" d=\"M0 0h640v320H0z\"/>\n  <path fill=\"red\" d=\"M0 0h640v160H0zm320 364.1c51.3 0 93.3-42 93.3-93.3V160H226.7v110.8c0 51.4 42 93.4 93.3 93.4z\"/>\n  <path fill=\"#fff\" d=\"M320 362.6a91.8 91.8 0 0091.6-91.5V161.8H228.5V271a91.8 91.8 0 0091.5 91.5z\"/>\n  <g fill=\"red\">\n    <path d=\"M267.1 165.2H232v38.7h35.2zm0 77.4h35.3v-38.7H267zM232 270.9c0 3.5.2 7 .6 10.4h34.6v-38.7H232v28.3zm105.7-28.3h-35.2v38.7h35.2zm0 77.4h35.2v-38.7h-35.2zm35.2 21.2A89.2 89.2 0 00393 320h-20v21.2zM267.1 320h35.3v-38.7H267zm-20.1 0a89.2 89.2 0 0020.1 21.2V320H247zm79.1 38.7c4-.3 7.7-.8 11.5-1.6V320h-35.2v37.1a87 87 0 0011.4 1.6c4.1.3 8.2.2 12.3 0z\"/>\n    <path d=\"M407.4 281.3c.4-3.4.6-6.9.6-10.4v-28.3h-35.2v38.7h34.6zm-69.8-38.7h35.2v-38.7h-35.2zm0-77.4h-35.2v38.7h35.2zm70.4 38.7v-38.7h-35.2v38.7z\"/>\n  </g>\n  <path fill=\"#fff\" d=\"M410 158.8l21.8-49.5-16.6-26.8-27.6 10.2-19.4-22.2-25.4 14.7L320 66.5l-22.7 18.6-25.5-14.6-19.4 22.2-27.6-10.3-16.6 27 21.8 49.4a217.8 217.8 0 0190-19.3c32 0 62.5 6.9 90 19.3z\"/>\n  <path fill=\"#0093dd\" d=\"M253 94.8l-27.4-10-15.3 24.7 5.9 13.3 14.8 33.7a219.7 219.7 0 0134.6-12L253 94.8z\"/>\n  <path fill=\"#fff\" stroke=\"#000\" stroke-width=\".3\" d=\"M251.4 119.3a13.3 13.3 0 011.6 6.2c0 7.3-6 13.3-13.4 13.3a13.4 13.4 0 01-13.1-10.8 13.4 13.4 0 0011.7 6.9 13.4 13.4 0 0013.2-15.6z\"/>\n  <path d=\"M227.6 114l1-4.9-3.8-3.2-.1-.1.2-.1 4.6-1.6 1-4.8v-.2l.2.1 3.7 3.2 4.6-1.6h.2v.2l-1 4.8 3.7 3.2.2.2h-.3l-4.6 1.6-1 4.8v.2l-.1-.1-3.7-3.2-4.6 1.6h-.3z\"/>\n  <path fill=\"#f7db17\" d=\"M233.6 107.6l3.5 3 4.3-1.5zm0-.2l7.8 1.6-3.4-3zm-8.3-1.6l7.8 1.5-3.5-3zm7.8 1.7l-7.8-1.5 3.4 3zm.4-.3l5.2-6-4.3 1.5zm-5.6 6.4l5.2-6-4.3 1.5zm5.3-5.9l-5.2 6 4.3-1.5zm5.6-6.4l-5.2 6 4.3-1.5zm-5.6 6l-2.6-7.6-.9 4.5zm2.7 8l-2.5-7.5-.9 4.5zm-2.4-7.6l2.6 7.5.9-4.5zm-2.7-8l2.5 7.5 1-4.5z\"/>\n  <path fill=\"#171796\" d=\"M297.5 87.4L272.1 73 253 94.9l12.6 49.6a219.8 219.8 0 0136.1-6l-4.2-51.1z\"/>\n  <path fill=\"red\" d=\"M262.5 132.2a232.3 232.3 0 0138.2-6.4l-1-12.9a245.6 245.6 0 00-40.4 6.7l3.2 12.6zm-6.3-25a258 258 0 0142.4-7l-1.1-12.7a270.7 270.7 0 00-44.5 7.4l3.2 12.3z\"/>\n  <g transform=\"translate(-160) scale(.00237)\">\n    <path fill=\"#0093dd\" d=\"M212105 36890l-23 13-9517-7794-9497 7778 1788 21560c2543-210 5113-322 7709-322 2608 0 5190 113 7744 325l1795-21560z\"/>\n    <g id=\"a\">\n      <path d=\"M202545 46585c-18-2-44 10-69 45-186 250-359 469-545 720-195 61-242 180-167 348-261-26-291 193-302 432-250-379-522-482-814-307-11-230-187-338-439-392-180-10-319-65-436-145-60-42-110-64-170-106-126-88-226-5-172 74 267 434 535 868 802 1302-14 80 6 151 88 204 47 133 93 265 140 397-11 38-21 75-32 113-221-105-443-118-664-133-170-8-287-50-361-137-54-63-91-26-92 82-3 534 162 1014 599 1492-231 4-462 11-694 21-79 6-95 39-73 104 126 304 339 579 822 766-208 112-327 285-357 520-9 224-75 382-212 455-60 32-81 65-24 106 253 185 565 193 895 112-157 270-226 553-198 850 208 56 412 15 614-52-29 61-44 175-52 309-7 115-41 229-104 343-32 33-65 84 4 102 336 91 648 52 915-47 0 243 2 487 76 727 18 58 70 102 125 26 155-214 322-396 527-517 31 90 75 168 156 215 96 55 147 170 153 343 0 30-2 60 35 90 149 7 514-380 589-597 206 121 284 246 439 461 55 76 99 29 128-25 62-243 67-481 66-724 267 99 579 138 915 47 69-19 36-70 4-102-62-114-105-250-113-365-9-133-14-226-43-287 202 68 405 108 614 52 29-297-53-579-211-850 330 80 655 73 908-112 57-41 35-74-24-106-136-73-203-231-212-455-30-235-149-409-357-520 483-187 696-463 822-766 22-66 6-99-73-104-231-10-480-24-711-27 437-478 606-961 604-1495-1-108-38-146-92-82-74 87-179 137-348 146-222 15-435 24-656 128-11-38-21-75-32-113 46-132 106-260 153-393 82-53 102-123 88-204 267-434 513-868 781-1302 54-79-46-162-171-74-60 42-110 64-170 106-117 80-257 134-437 145-251 54-417 167-428 397-293-175-564-73-814 307-11-239-41-457-302-432 75-168 17-291-178-352-186-250-458-470-644-720-31-35-51-47-69-45z\"/>\n      <g fill=\"#f7db17\">\n        <path d=\"M205075 47978c-51-26-124 17-162 95s-33 170 19 196c40 20 84-6 119-56l22-36c2-3 4-6 5-9 38-78 49-163-2-188zm-5008 0c52-26 124 17 162 95s39 165-13 191-103-24-141-102-60-158-9-184zm4539 905c-32 0-59 27-59 59s26 59 59 59 59-26 59-59c0-32-26-59-59-59zm-4032 0a59.1 59.1 0 10.2 118.2 59.1 59.1 0 00-.2-118.2zm4294-304c-754-91-1506-133-2260-133s-1509 41-2269 115c-26 8-21 90 14 86 756-73 1507-113 2256-113 743 0 1485 40 2228 129 39 4 54-80 32-84z\"/>\n        <path d=\"M200319 48495c768-75 1530-117 2289-116 754 0 1507 42 2261 133l111-184c-32 10-62 9-90-5-76-38-92-161-36-274 56-114 164-175 240-138 39 19 62 62 68 114l446-739c-204 130-328 214-581 252-281 41-409 139-368 307 38 156-57 133-201 54-314-171-541 71-652 353-73 186-159 181-168-13-4-70 0-131-7-200-21-223-89-286-216-224-161 78-175 25-137-58 28-60 86-128 66-221-9-67-66-92-151-98-182-244-467-483-649-727-182 244-374 483-556 727-86 5-142 30-152 98-20 93 52 157 80 217 38 82 23 135-137 57-127-61-186-3-207 220-7 69-10 139-13 209-9 194-95 199-168 13-111-282-352-524-667-353-145 79-203 102-182-54 23-172-107-266-388-307-253-37-377-122-581-252l419 682c12-25 29-45 53-57 76-38 184 24 240 138 56 113 40 237-36 274-10 5-21 8-32 10l100 163zm4389 911c-7 3-7 4-24 11-46 19-80 66-134 124-57 60-128 125-211 188-12 10-25 19-44-6s-7-35 6-44c80-62 149-124 204-182 30-32 56-63 77-92-95-11-190-21-284-30-79 24-157 55-222 95-59 35-107 77-137 125-8 14-16 27-44 11-27-16-19-30-11-44 35-58 91-107 158-147 33-20 69-38 106-54-107-9-214-18-321-25-22 13-42 29-61 47-20 19-39 42-56 67-9 13-18 26-44 8s-18-31-8-44c19-29 41-54 64-77l9-9c-80-5-161-10-241-14-2 2-5 5-8 7a340.4 340.4 0 00-93 126c-6 15-12 29-41 18-29-12-23-26-17-41 12-29 27-55 45-81 8-11 18-22 27-33-115-5-230-9-344-12-4 5-9 8-14 11-25 15-47 32-66 51s-35 40-48 63c-8 14-16 28-43 12-28-16-20-29-12-43 16-28 35-54 59-77 7-7 14-13 21-19-122-2-244-4-365-4-120 0-240 1-360 3 8 7 15 13 22 20 23 23 42 49 59 77 8 14 16 27-12 43s-35 2-44-12c-13-23-29-44-48-63s-41-36-66-51c-6-3-12-7-15-12-115 2-230 6-345 11 11 11 20 23 29 35 19 25 33 52 45 81 6 15 12 29-17 41s-35-3-41-18c-9-24-22-46-38-67-15-21-34-41-55-59-4-3-7-6-10-10-81 4-162 8-243 13 4 4 9 8 13 12 24 23 45 48 64 77 9 13 18 26-8 44s-35 5-44-8c-18-26-36-48-56-67s-41-35-64-49c-1-1-3-2-5-3-110 7-220 14-330 23 43 18 85 38 122 61 67 40 124 89 158 147 8 14 16 27-11 44-27 16-35 3-44-11-29-48-78-90-137-125-72-44-159-77-246-102h-2c-90 7-179 15-268 24 22 33 51 68 86 106 55 58 124 120 204 182 13 9 25 19 6 44s-32 15-44 6c-83-64-155-128-211-188-37-38-99-111-135-140-196-90-354-127-575-147-153-14-318-9-458-79 36 85 75 164 126 229 53 68 120 121 209 147 8 2 21 16 22 25 28 157 84 286 169 386 52 60 114 110 188 149-75-81-132-166-172-251-67-142-90-286-77-420 1-16 3-32 34-29 32 3 30 19 29 35-11 123 9 256 72 387 56 118 159 237 291 346 24 19 0 63-29 55-154-44-290-123-383-231-89-104-149-237-180-397-94-32-165-90-222-164-47-60-85-131-118-205 28 428 182 801 456 1137 61 75 165 182 255 216 92 35 95 100-20 101-34 1-69 1-105 1 84 31 164 66 233 105 127 73 217 162 224 273 1 16 2 32-29 34-32 2-33-14-34-29-6-86-82-160-192-223-113-65-259-117-402-160-154 0-312-1-459 3 39 28 80 57 131 84 82 44 188 86 343 122 89 21 166 52 233 91 71 42 130 93 177 150 10 12 20 25-5 45s-34 8-45-5c-42-52-95-98-159-135-61-36-133-64-216-84-161-38-272-81-358-128-75-40-131-82-184-123 180 393 450 573 835 689 23 7 43 13 61 19 3 1 6 1 9 2 86 21 175 40 266 55 92 15 166 28 261 37 16 1 32 3 29 34-3 32-19 30-34 29-99-9-174-22-266-38-58-10-115-21-171-33-26 6-64 9-107 12-232 14-420 225-435 494 0 5 0 11-1 16 88-80 179-157 273-212 117-68 239-103 364-69 15 4 31 8 22 39-8 31-23 27-39 22-106-28-212 3-316 63-108 63-213 158-315 253-24 147-82 285-205 377 61 34 104 65 163 45 86-39 172-78 261-108 91-31 184-52 282-57 16-1 32-1 33 31s-14 32-31 33c-91 4-179 24-264 53-75 26-149 58-222 91 221 47 460-1 667-79 60-22 105-42 133-41 51-30 112-53 172-79 66-28 132-51 182-57 16-2 32-4 35 28 4 32-12 33-28 35-112 13-127 21-222 79 0 21-66 57-126 96-36 24-70 52-87 67-95 86-144 181-188 287-29 70-52 145-68 224 55-108 121-211 201-303 94-108 208-201 345-265 14-7 29-13 42 15 13 29-1 35-15 42-129 60-236 147-324 250-90 103-161 222-219 345-31 64-8 1-42 86 110-122 212-224 323-307 132-100 283-157 418-133 15 3 31 6 26 37s-21 28-37 26c-116-21-250 32-369 121-121 92-244 223-366 361 184 26 366-26 542-85 91-30 183-135 239-152 19-24 38-46 57-67 33-37 67-71 102-100 12-10 24-20 45 4s8 34-4 45c-33 28-65 60-96 94-32 35-62 73-92 113-6 8-13 17-24 16-60 70-151 162-172 240-57 210-25 370-122 576 71-38 128-81 175-134 53-60 94-135 128-230 37-104 95-195 167-270 75-77 165-136 261-172 15-5 30-11 41 19s-4 35-19 41c-87 32-169 86-238 157-66 68-119 151-153 247-37 102-81 183-141 250-44 50-95 91-156 127 52-3 78-10 121-7 79-6 211-66 279-119 66-51 116-120 154-206 6-15 13-29 42-16s23 27 16 42c-42 96-99 174-173 231-56 43-121 75-196 93 161-5 311-42 467-100 65-24 87-168 127-208 32-58 66-112 105-158 47-56 101-101 164-127 15-6 29-12 41 18 12 29-3 35-17 41-52 21-98 60-139 108-36 42-68 93-98 147 10 73-51 228-53 305-7 205-2 409 53 612 53-71 107-134 162-192 0-5 0-10 1-15 18-106 33-219 40-332 7-112 7-223-6-329-2-16-4-32 27-35 32-4 34 12 35 28 14 111 14 226 7 340-6 90-16 180-30 269 54-51 53-51 77-103 37-80 59-159 67-237 9-80 5-157-13-230-4-15-7-31 24-38s35 8 38 24c19 80 25 165 14 252-8 65-24 132-49 199 56-42 114-82 178-122-4-75-5-153-3-227 2-68 7-134 18-190 4-20 7-40 47-33s37 27 33 48c-9 50-14 111-16 177-2 78 0 162 4 243 5 82 49 185 125 230 103 62 158 163 186 274 16-145 17-280 3-400-17-143-55-267-114-368-8-14-16-27 12-44 27-16 35-2 43 12 63 110 104 241 122 393 17 146 13 310-13 488 102-82 381-258 352-594-7-27-16-52-28-75-7-14-14-28 14-42s35 0 42 14c17 33 30 69 39 110 5 24 8 49 11 76 13-7 45-43 51-39 24 16 58 38 80 54-21-60-35-120-42-178-10-87-5-172 14-252 4-15 7-31 38-24s27 23 24 38c-18 73-22 151-13 230 9 77 31 157 67 237 4 8 8 16 5 25 24 21 47 42 70 65-13-84-22-170-28-255-8-115-7-230 7-341 2-16 4-32 35-28s29 20 27 35c-13 106-13 217-6 329 7 113 22 225 40 332 1 2 1 5 1 7 54 59 95 120 152 196 55-203 73-407 66-612-2-76-69-227-65-302-30-55-63-107-100-151-41-49-87-87-139-108-15-6-29-12-18-41 12-29 27-24 41-18 62 26 117 71 164 127 38 45 72 98 103 154 57 7 78 179 143 212 154 57 298 94 453 100-75-19-140-50-195-93-74-57-131-135-173-231-6-15-13-29 16-42s35 2 42 16c38 86 88 156 154 206 85 66 289 124 400 127-61-37-113-78-157-128-59-67-104-148-141-250-34-95-87-179-153-247a642 642 0 00-238-157c-15-6-29-11-19-41 11-29 26-24 41-19 96 36 186 94 261 172 72 74 130 166 167 270 34 95 75 169 128 230 47 54 105 98 177 135-98-207-66-367-122-577-35-129-232-277-193-320 45-51 133 88 248 127 175 59 357 111 540 85-122-138-244-269-366-361-119-90-237-140-352-120-16 3-31 6-37-26-5-31 10-34 26-37 135-24 269 32 401 132 111 84 201 175 311 298-18-47 0-14-30-77-59-123-130-241-220-345-89-102-196-189-324-250-14-7-28-13-15-42 13-28 28-22 42-15 137 65 251 157 345 265 81 93 147 198 203 307-15-81-39-157-68-227-44-106-93-201-188-287-62-56-209-140-208-179-29-15-33-11-63-24-61-26-121-46-164-52-16-2-32-4-28-35 4-32 19-30 35-28 50 6 115 28 182 56 33 14 66 43 98 60 53 4 139 47 208 74 206 78 446 126 666 79-73-33-147-65-223-91-85-29-172-49-264-53-16-1-32-1-31-33s17-31 33-31c98 4 191 26 282 57 89 30 175 69 261 108 59 27 101-7 163-45-123-92-181-230-205-376l-2-2c-102-95-207-190-315-253-104-60-210-91-316-63-15 4-31 8-39-22-8-31 7-35 22-39 125-33 247 1 364 69 94 55 186 132 274 213 0-6-1-11-1-17-15-270-203-480-435-494-78-5-189 21-186-32 4-59 97-44 234-86 385-116 655-296 836-690-54 41-110 83-186 124-86 47-198 91-358 128-82 19-154 48-216 84-64 38-117 84-159 135-10 12-20 25-45 5s-14-32-5-45c47-57 106-108 177-150 67-39 145-70 233-91 155-36 261-78 343-122 51-27 92-55 131-84-148-4-305-3-459-3-143 44-289 96-402 160-110 63-186 136-192 223-1 16-2 32-34 29-32-2-31-18-29-34 8-111 97-200 224-273 69-39 149-74 233-105-35 0-70 0-104-1-116-2-112-66-20-101 90-34 190-141 251-216 271-334 412-714 456-1130-33 72-69 140-115 198-57 73-128 131-222 164-31 160-91 293-180 397-92 108-216 185-369 230-29 8-52-35-29-55 132-109 221-226 278-344 62-131 83-264 72-387-1-16-3-32 29-35 31-3 33 13 34 29 12 134-10 278-78 420-40 85-97 170-172 251 73-39 136-89 187-149 85-100 141-229 170-386 1-8 14-22 22-25 89-27 155-79 209-147 51-65 90-143 126-228-140 69-304 64-457 78-213 19-369 68-554 152z\"/>\n        <path d=\"M204649 49231c-680-88-1359-113-2041-114-684 0-1369 40-2058 112-20 6-15 33-14 46 2 28 37 35 121 27 643-60 1285-93 1932-93 674 0 1351 21 2038 102 33 9 77-85 22-81z\"/>\n        <path fill-rule=\"evenodd\" d=\"M200570 49160c683-71 1362-110 2038-110 675 0 1349 40 2025 127l31-127c-17 9-37 15-58 15a123 123 0 11113-171l60-170c-724-84-1446-122-2171-122-729 0-1459 38-2193 107l58 164c22-32 59-54 101-54a123 123 0 110 246c-12 0-25-2-36-6l33 94-2 7zm3067-416a123 123 0 100 246 123 123 0 100-246zm0 64a59.1 59.1 0 000 118c32 0 59-27 59-59s-26-59-59-59zm-1082-91a123 123 0 10123 123c0-68-55-123-123-123zm0 64a59.1 59.1 0 10.2 118.2 59.1 59.1 0 00-.2-118.2zm-1064-40a123 123 0 10-.2 245.8 123 123 0 00.2-245.8zm0 64c-33 0-59 26-59 59s26 59 59 59a59.1 59.1 0 000-118z\"/>\n      </g>\n      <path d=\"M202601 47974c-14-68-49-129-100-175-51-47-116-78-187-88-33-4-39-58-7-68 60-20 114-67 157-133 45-69 79-157 95-256 5-34 64-35 69-1 15 84 51 153 97 208 55 66 125 112 193 138 31 12 25 63-8 68-59 9-105 42-141 87-50 62-81 145-100 221-8 33-62 31-69-2zm33-118c20-52 47-103 81-146 28-34 60-64 99-84-51-30-100-70-143-120-28-34-53-73-73-116-19 59-45 112-75 158-31 47-67 86-108 116 50 19 95 47 134 82 34 31 63 68 85 110zm799 5115l-515 206c-17 7-35 14-48-21-14-34 4-41 21-48l515-206c17-7 35-14 48 21 14 34-4 41-21 48zm59-326l-604 328c-16 9-33 18-51-15s-1-42 15-51l604-328c16-9 33-18 51 15s1 42-15 51zm-1826-65l604 328c16 9 33 18 15 51s-34 24-51 15l-604-328c-16-9-33-18-15-51s34-24 51-15zm51 322l515 206c18 7 35 14 21 48-14 35-31 28-49 21l-515-206c-17-7-34-14-21-48 14-35 31-28 48-21zm224 434c137 33 261 48 358 31 88-16 155-60 191-146v-493c-107-1-212-15-303-41-109-31-170-98-201-178-41-107-27-235-4-329 5-18 9-36 45-27s32 27 27 45c-20 82-33 194 1 284 23 60 69 110 152 133 91 25 198 38 307 38 107 0 214-13 304-40 82-24 148-69 192-123s65-117 57-176c-5-36-24-62-49-80-34-24-82-35-128-37-47-2-94 7-142 16-25 5-50 9-77 13-19 2-37 5-42-32s14-40 32-42c23-3 48-8 73-12 52-10 105-20 159-18 60 2 121 18 168 51 42 29 72 72 80 131 11 80-16 163-73 233-53 65-131 119-229 147-83 24-178 38-274 42v483c3 5 3 11 2 16 37 82 102 125 188 141 97 18 221 2 358-31 18-5 36-9 45 27 8 37-9 41-28 45-146 35-279 51-388 32-92-17-165-58-215-132-49 74-124 115-215 132-109 20-242 4-388-32-18-4-37-8-28-45 8-36 27-32 45-27zm356 210l402-9c19 0 38-1 38 37 1 38-18 38-37 38l-402 9c-19 0-37 1-38-37s18-38 37-38zm593-3082c151-125 293-227 423-297 133-72 254-111 359-106 19 1 37 1 36 39-1 37-20 37-39 36-92-4-200 32-322 97-125 67-263 166-410 289-14 12-29 24-53-5s-9-41 5-53zm-605 56c-141-130-298-240-445-314-139-71-268-108-363-100-19 2-37 4-40-34-4-37 15-39 34-40 110-10 252 31 404 107 152 77 315 191 461 325 14 13 28 25 2 53-25 27-39 15-53 2zm-213 1004c37-83 83-155 136-219 53-63 112-119 174-170 14-12 29-24 52 5 24 29 9 41-5 53-59 48-114 101-164 160-49 59-91 125-125 201-8 17-15 34-49 19s-27-32-19-49zm371-1734c49 66 88 139 114 223 26 82 40 175 39 279 5 80 6 165-7 249-13 86-42 170-97 246-43 60-101 97-165 113-53 13-109 10-164-7 29 100 51 208 6 308-8 18-33 27-51 18-43-22-86-43-128-62s-84-36-127-51l-1-1c-95-37-173-73-236-112-65-39-115-80-150-124l1 2c-44-49-72-106-88-170-14-55-20-114-22-174-72-39-138-78-194-116-64-43-118-87-161-131-13-14-26-27 1-53s40-12 53 1c39 40 89 80 150 121 60 40 128 81 204 121 124 13 247 51 370 109 106 50 211 115 317 192 13 7 19 16 27 20 8 6 16 13 25 19 51 22 104 28 152 16 47-11 90-39 122-84 48-66 72-139 84-214 12-77 11-157 6-234v-2c1-97-12-183-35-258-24-76-58-142-102-201-11-15-22-30 7-52s41-7 52 7zm-375 1047c-104-77-207-141-311-190-105-49-210-83-314-98 2 48 8 93 18 135 13 52 35 99 71 138l1 1c30 37 73 72 130 107 60 36 134 71 225 106l-1-1c45 16 89 34 133 54 31 14 61 28 93 44 19-83-10-179-37-267-2-8-5-15-9-29zm776-1003c-44 59-79 125-102 201-24 76-36 161-35 258v2c-5 77-6 158 6 234 12 75 37 148 84 214 32 45 75 72 122 84 48 12 101 6 152-16l25-19c6-4 13-12 27-20 105-77 211-143 317-192 123-58 246-95 370-109 75-40 144-80 204-121s111-81 149-121c13-13 26-27 53-1s14 39 0 53c-43 44-97 88-161 131-57 38-122 77-194 116-2 61-8 119-22 174-16 63-44 121-88 170l1-2c-35 44-85 85-150 124-63 38-141 75-237 112l-1 1c-43 15-85 32-127 51-43 19-85 40-128 62-18 9-43 0-51-18-45-100-23-208 6-308-55 18-111 20-164 7-64-15-122-53-165-113-55-76-84-160-97-246-13-85-12-169-7-249-1-104 13-196 39-279 26-84 65-158 114-223 11-15 22-30 52-7 30 22 19 37 7 52zm940 715c-105 15-209 49-314 98-104 49-207 113-311 190-4 13-6 21-8 29-27 88-56 184-37 267 31-15 62-30 93-44 44-20 87-38 133-54l-1 1c91-35 165-70 225-106 58-34 100-70 131-107l1-1c35-39 57-86 71-138 11-42 16-87 19-135z\"/>\n      <path fill-rule=\"evenodd\" d=\"M203459 50602a216.4 216.4 0 000 433 216.6 216.6 0 000-433zm0 69c-81 0-147 66-147 147s66 147 147 147 147-66 147-147-66-147-147-147zm0 60a87 87 0 10.1 174.1 87 87 0 00-.1-174.1zm-1697-124c119 0 217 97 217 216s-97 217-217 217a216.6 216.6 0 010-433zm0 69c81 0 147 66 147 147s-66 147-147 147-147-66-147-147 66-147 147-147zm0 60a87 87 0 11-.1 174.1 87 87 0 01.1-174.1z\"/>\n    </g>\n    <use width=\"100%\" height=\"100%\" transform=\"rotate(-2.2 -55532.8 156275.8)\" xlink:href=\"#a\"/>\n    <use width=\"100%\" height=\"100%\" transform=\"rotate(2.2 459865.8 156275.8)\" xlink:href=\"#a\"/>\n  </g>\n  <path fill=\"#171796\" d=\"M387.2 94.9l-19.3-22-25.2 14.5-4.3 51.1a219.7 219.7 0 0136.2 6L387.2 95z\"/>\n  <path d=\"M347.7 98c.8-.2 1.7-.2 2.6.3.3.1.6.3.8.6.4-.3.7-.6 1.2-.8a4 4 0 011.8-1c.9-.5 1.8-.8 2.7-.9h2.8c.8 0 1.6.2 2.3.6l2 1c.8.4 1.5.8 2.2 1a9.1 9.1 0 004.5.5c.4-.2.7.1.2.4-3.3 2-5.9.2-8.1-.6a16.2 16.2 0 012.1 1.7c.8.8 1.8 1.6 3.5 2.4a8.4 8.4 0 005 .7l.4.1-.1.5a4.8 4.8 0 01-2.6.7 10 10 0 01-5.2-1.3c-1.4-.7-2.3-1.6-3.3-2.4a7.5 7.5 0 00-3-1.4 6 6 0 00-2.9 0c.3.1.5.2.6.4.5.3 1 .4 2 .5.4 0 .2.3-.5.7a2 2 0 01-1.6.8c-1 .6-1.3.2-1.7-.2 0 .3 0 .5-.2.8a.6.6 0 010 .4l.2.7c0 .2 0 .3.2.4.2.2.3.4.3.7 0 .2.1.3.3.4l.6.6c.6.2.8.7 1 1.2.4.2.6.5.7.9.2 0 .4.2.6.4l2.6.1c.8.1 1.4.6 2 1.2h1.2a4 4 0 011.3-.3h2.3c.5.2.9.4 1.2.8.5.5 1.2.4 1.8.2a2.7 2.7 0 012.4 0 2.3 2.3 0 011-.2c.4-.3.7-.4 1-.4.6 0 1 0 .9.8 0 .2-.2.4-.3.4-.3.6-.7.7-1.3.7-.1.4-.3.7-.5.8.3.9 0 1.3-.7 1.2 0 .3-.3.4-.6.4a1.4 1.4 0 01-1 .5l.4.6c.4.7-.2 1-.8 1v1.2c.7.4.8.8.2 1.2.4.7.3 1.3-.5 1.6 0 .4 0 .8-.3 1-.2.2-.5.3-.3.6.3.5.2 1.1-.2 1.2l-.2.1-.2.2a9.6 9.6 0 00-1.5 1c-.1 0-.2.1-.2 0a9.6 9.6 0 01-1.8 2.4c0 .5-.4 1-1 1.1a.4.4 0 01-.3.4c.3.3.5.6.2 1a3 3 0 01-1.3.8c-1 .3-1.7.2-2-.2-.4-.3-.3-.6 0-.7-.7 0-.8-.2-.8-.7 0-.2.1-.2.3-.1.4 0 .7-.2 1-.3l.5-.6c0-.7.5-1 1.1-1.3.5-.2 1-.6 1.4-1.2l.9-1.5a1.2 1.2 0 01-.3-.7 1.5 1.5 0 01-.5-.6c-.5 0-.7-.2-.7-.5a1.1 1.1 0 01-.3 0c-.3.1-.5.3-.7.2a6.9 6.9 0 01-1.1 1c-.2.3-.4.5-.7.5-1 .1-1.5 1.2-2 1.7-.2.1-.3.4-.4.7 0 .6-.1 1-.4 1h-.4a1.2 1.2 0 00-.4 0c.3.3.3.6 0 .9-.1.3-.4.4-.8.4a3.6 3.6 0 01-1.6-.2c-.4-.2-.5-.5-.5-.7-.3-.2-.4-.3-.3-.5 0-.2.2-.3.4-.2l.6-.2a5.2 5.2 0 011.8-1.4 3 3 0 01.7-.7c0-.5.5-1 1-1.4l.1-.6v-.3c-.2-.3-.3-.7-.1-1a1.3 1.3 0 010-.6c-1.1.6-1.5.4-1.6-.1-.4.3-.8.5-1 0-.4.1-.8.3-1.2.1l-.8.2-.4.7c0 .5-.2 1-.5 1.5a9.3 9.3 0 01-.7 1.5 1 1 0 01-.1.5c0 .6-.2.9-.5 1a2.4 2.4 0 01-.4.8v.2c.1.3.1.7-.2 1l-1 .6h-1c-.4-.3-.4-.4-.3-.6a.6.6 0 01-.5 0l-.4-.3c-.1-.2-.1-.4.1-.5l.9-.6c0-.2.2-.3.4-.4.2-.4.4-.6.6-.7l.7-1.5c.1-.1.2-.3.1-.4l.1-.3s.2-.1 0-.2a1.4 1.4 0 01.2-1.2c.3-.4.6-1.4.3-2v-.8h-.3c-.2-.2-.4 0-.6.2l-.4.6c-.1.8-.5 1.5-1 1.6v1.2c0 .4 0 .7-.2.7s-.4.2-.5.5a1 1 0 00-.1.3c.3.3.2.7-.1 1-.6.6-1.4.5-2.2.3-.6-.3-.8-.5-.7-.8-.8 0-.7-.7 0-.9.8-.2 1.4-.7 1.9-1.4 0-.8.2-1.3.7-1.4 0-.5.2-1 .4-1.4.2-.4.3-.8.2-1.3-.4-.3-.4-.6 0-1 .1 0 .1 0 0-.2-.3 0-.3-.3-.3-.5s0-.2-.2-.2c-.6-.1-.5-.4-.2-.7.1 0 .2-.3 0-.4l-.1-.4c-.4-.3-.2-.6 0-.9l-.4-.8c-.7 0-1-.4-.6-.9a3.4 3.4 0 01.7-.6c.1-.3.3-.6.2-.8-.2-.6.5-1 1-1.4a.9.9 0 01-.1-.4c-.3-.3-.2-.6.1-.8a1 1 0 01-.1-.5c-.8.2-.8-.3-.4-1-.5-.3-.4-.8.5-1.5a1 1 0 010-.4 2 2 0 00-1 .3c-.3.3-.6.2-.9.1a1.5 1.5 0 00-.4-.4.6.6 0 01-.2-.6c-1 0-1.1-.7-.6-1 .3-.3.6-.6.7-.9.2-.6.7-1 1.3-1.5v-.5a1.6 1.6 0 00-.7-.3 1.2 1.2 0 00-.6-.7c-.1 0-.2-.2 0-.4-.6-.4-.5-.7-.3-1z\"/>\n  <g fill=\"#f7db17\">\n    <path d=\"M364.5 122a1.4 1.4 0 01-.2 0 8.4 8.4 0 01-.8.7c-.2-.3-.5 0-.2.1l-.2.2c0 .3-.2.4-.5.4h-.1a3 3 0 010-.3 3.5 3.5 0 010-.4 3.9 3.9 0 00-.1.4 2.8 2.8 0 000 .4c-.8.3-1.3 1.1-1.9 1.7l-.4.8c0 .2 0 .9-.3.9h-.2c0-.1-.2-.1-.4 0h-1c-.2.2.4.2.7.3.1.1.2.3.1.5-.2.7-1.8.5-2.3.2-.2-.1-.2-.3-.2-.5h.3c.2 0 .4 0 .5-.2 0 0 .1 0 0-.1 0-.1 0-.1 0 0a1.3 1.3 0 01-.5 0 2.6 2.6 0 01-.5 0h-.2c0-.1.2 0 .2 0l.7-.3a5.3 5.3 0 011.9-1.4l.8-.7c0-.7.4-1 .8-1.5l.3-.7v-.3c-.2-.4-.3-.7-.1-1a1.5 1.5 0 010-.8.3.3 0 000-.1 6.2 6.2 0 01.8-.6v.8a1.3 1.3 0 00-.2.3.5.5 0 000 .2v.1a.4.4 0 010-.3l.3-.2.7-.4.7-.6v1l-.6.7v.1h.1a2.3 2.3 0 01.5-.7 3.2 3.2 0 011-.6v1a1.5 1.5 0 00.5.9z\"/>\n    <path d=\"M349 113l.2-.2.4-.6a4 4 0 01.5-.6 4 4 0 00-.4.7 5.8 5.8 0 00-.4.5v.2c.1.3.1.5.3.7l.3-.4a1.6 1.6 0 01.4-.4 1.8 1.8 0 00.5-.6h.1l-.2.4a2 2 0 01-.3.3l-.4.3a1.3 1.3 0 00-.2.4v.3c-.2.3-.5.5 0 .7a.6.6 0 00.1.5l-.1.7c-.3.2 0 .2.1.2l.4-.4a4.3 4.3 0 01.3-.4l.4-.5.1-.5h.1a1.4 1.4 0 01-.1.6 2 2 0 01-.5.5 3.8 3.8 0 00-.2.4 2.6 2.6 0 00-.3.4c.2.1.2.4.2.7h.1l.2-.2.2-.4h.1l-.2.4-.2.3c.2.1.2.3 0 .5-.4.3-.3.4 0 .7v1.2l.1.3h-.1v-.3c-.4.7-.6 1.1-.7 1.8-.6.1-.5.8-.6 1.3a3.9 3.9 0 01-1.9 1.5c-.1 0-.5.1-.5.3 0 .1.2.3.4.2.4-.5.7-.2.2.2v.3c.5.4 1.6.5 2.2.2.3-.3.5-.5.2-.9 0-.5.2-1 .8-1.2v-.4l.1-1.3.2-.1c.2 0 .6-.7.7-1.3v-.4c.1-.2.2-.2.3 0 0-.2 0-.3.2-.4.2-.3.5-.6.8-.4a3 3 0 01-.1-.8 2.7 2.7 0 010-1l.2-.2.3-.7.3-.7h.1l-.3.7-.3.8v.1a2.5 2.5 0 00-.1 1l.2.9.2.4v.6c.4.6 0 1.7-.3 2.2a1 1 0 00-.1.8c.2.2 0 .4-.1.6v.1c0 .2 0 .4-.2.5l-.7 1.6c-.4.1-.5.3-.6.7-.3.1-.3.2-.4.4a2.7 2.7 0 01-.9.6c-.3.1 0 .2.2.4.2.1.4-.2.6-.4.2-.3.3-.2.2 0a2 2 0 00-.2.7l.7.3c.4 0 .9-.4 1.2-.6.3-.2.2-.5.1-.8a2 2 0 01-.5 0 3.4 3.4 0 01-.5-.3 2.8 2.8 0 001 .2v-.3a2.7 2.7 0 00.5-.8c.4-.2.4-.4.4-.9l.1-.5a10 10 0 00.7-1.6c.4-.4.5-.9.5-1.4 0-.2.1-.3.3-.3a3.8 3.8 0 00.3-.5l.1-.4a.8.8 0 01.2-.2 1 1 0 000-.5 1.1 1.1 0 00-.1-.4.5.5 0 01-.1-.2v-.2h.1c.1 0 0 0 0 0v.1a.5.5 0 000 .2c.2.2.2.3.2.5a1 1 0 010 .5.7.7 0 00-.2.2 1.7 1.7 0 000 .3l.6-.1.4-.5.2-.6c.1 0 0 0 0 0a2 2 0 01-.1.7l-.3.3c.4.2.7 0 1 0V119l.4-.7c.1 0 .1 0 0 0l-.2.8v1c.1.4.2.5.5.3l.4-.2v-.1a18.2 18.2 0 011.8-1.6c.1.1 0 .1 0 .1a6.5 6.5 0 00-.8.7l-.8.7v.3c0 .3.1.5.6.3l.6-.2a1.3 1.3 0 01.3-.2 8 8 0 01.5-.3l.5-.3a3 3 0 01.1-.6l.7-1.3a2.3 2.3 0 001.1-1.1h.1l-.4.7a2.5 2.5 0 01-.7.5l-.7 1.2a2.7 2.7 0 00-.1.5v.1a2.8 2.8 0 000 .8c.2 0 .4 0 .7-.3l.7-.7a1.7 1.7 0 01.2-.5 1 1 0 01.4-.4h.1v.1a.9.9 0 00-.4.3 1.7 1.7 0 00-.2.5v1.1l1-.5v1c0 .3.2.6.4.8a2.8 2.8 0 01.5-.6l.3-.3.2-.2.3-.2-.2.3-.2.2-.3.2v.5h.6c0 .5 0 .6.5.6a3.2 3.2 0 010-.5l.1-.5h.1a1.9 1.9 0 00-.1.5 3.1 3.1 0 000 .5c.2.3.3.4.7.6l.2-.5a1.4 1.4 0 000-.4h.1v.5l-.3.5v.5a3 3 0 01.2-.3l.3-.4c.1 0 .1 0 0 0 0 .2 0 .3-.2.4a4 4 0 00-.2.4l.2.2c-.6 1-1.3 2.5-2.5 3-.6.2-.9.5-1 1.2a1 1 0 00-.5.6l-1.2.3c0 .3 0 .4.3.4l.7-.3c.1 0 0 .5-.5.8v.1c.4.6 1.4.4 1.9.2.4 0 1-.5 1.2-.9.1-.2 0-.4-.2-.6-.8.1-.6-.6 0-.3.2 0 .3 0 .3-.3.6-.2.9-.5 1-1 .6-.7 1.2-1.4 1.6-2.1.1-.2.2-.4.1-.5a1 1 0 00.2-.5l.1-.4h.1v.5a4.5 4.5 0 01-.2.3c0 .1 0 .2.2.2l1.5-1c0-.3.2-.4.4-.4l.2-.1c.1-.4 0-.6-.2-.8-.1-.4.1-.5.4-.7.2-.2.2-.7.2-1v-.2a2.6 2.6 0 000-.3l.1.3v.1c.3-.1.6-.3.7-.6 0-.3-.1-.6-.3-.8a9.6 9.6 0 01-.6.2 10.2 10.2 0 00.7-.4 1.3 1.3 0 00.3-.2c.2-.3-.3-.5-.5-.6l-.7-.7v-.1l.7.6v-1.1l-.2-.4a1.1 1.1 0 01-.5-.4 1 1 0 01-.1-.5l.2.4.4.4h1c.3-.3-.2-.7-.3-.9l-.1-.5h.1a1 1 0 00-.2-.2.6.6 0 00-.1 0v-.2a.7.7 0 01.2.1l.2.2a.9.9 0 00.1 0c.3 0 .5-.2.7-.5a3.6 3.6 0 00-.3-.4 10 10 0 00-.5-.3v-.1h.1a4 4 0 01.8.8c.4 0 .4 0 .6-.3a1.5 1.5 0 00-.2-.4 2.5 2.5 0 00-.3-.4c0-.1 0 0 0 0 .2 0 .3.2.4.3l.2.5.4-.1c.3-.2 0-.8 0-1a2.8 2.8 0 00-.1 0l-.2-.2c0-.1 0 0 0 0h.2l.2.1.4-.6c0-.4 0-.2.5-.3.4 0 .6 0 .9-.6.1 0 .2 0 .2-.3s0-.4-.3-.4c-.5 0-.8 0-1 .3v.3c0 .1 0 0 0 0l-.2-.2c-.4 0-.7 0-1.1.2h-.2l.2.3.1.4a1 1 0 00-.2-.4 1.8 1.8 0 00-.3-.4 2.6 2.6 0 00-1-.2l.2.1.2.2v.1a7.7 7.7 0 01-.2-.2 6.5 6.5 0 01-.2-.2 2.7 2.7 0 00-.9.2l-.6.2.4.5.2.6a2.1 2.1 0 00-.3-.6 1.9 1.9 0 00-.4-.4 1.8 1.8 0 01-.5 0l.2.3-.3-.4a1.4 1.4 0 01-.5-.2 8.3 8.3 0 01.2 1.5 7.8 7.8 0 00-.2-.9 4.7 4.7 0 00-.1-.7 1.7 1.7 0 01-.2-.2 2.1 2.1 0 00-.6-.4 1 1 0 01-.2.7c-.1 0 0 0 0 0a.8.8 0 00.1-.8 3.1 3.1 0 00-1-.2 5.3 5.3 0 01.5.8l.3.5v.5a2 2 0 00-.1-.5.7.7 0 00-.3-.4 5.6 5.6 0 00-.3-.5 4.6 4.6 0 00-.3-.4h-.4.1a.6.6 0 010 .3.5.5 0 000-.2.7.7 0 00-.2-.1h-.8a5 5 0 011 2.3 4.8 4.8 0 00-.4-1.2 5.1 5.1 0 00-.7-1h-.6a1.7 1.7 0 01.4.4c0 .1 0 .1 0 0a1.6 1.6 0 00-.3-.1 2.4 2.4 0 00-.3-.2 5 5 0 00-.3 0l-.1.1a4.7 4.7 0 011 1.1c0 .1 0 0 0 0a3.8 3.8 0 00-.6-.6 4.7 4.7 0 00-.6-.4h-.6a5 5 0 01.5 1.7h-.1a3.5 3.5 0 00-.2-.8 6.2 6.2 0 00-.3-.9 8 8 0 01-.4 0 9.1 9.1 0 01.3 1.6v.1a9.3 9.3 0 00-.2-1 9.3 9.3 0 00-.3-.8 3.9 3.9 0 00-1.3-1 1.7 1.7 0 01.4 1.1v.1a1.6 1.6 0 00-.2-.7 1.7 1.7 0 00-.4-.6 2 2 0 00-.3 0 15.6 15.6 0 00-1 0c.2.1.4.4.4.6 0-.2-.3-.5-.6-.7h-.6l.3.3.2.5.2.6.4.4s.1 0 0 0c0 .1 0 .1 0 0a1.1 1.1 0 01-.5-.3 1.5 1.5 0 01-.2-.7 1.3 1.3 0 00-.2-.4 2.7 2.7 0 00-.3-.4h-.7l.2.8.1 1h-.1a7.1 7.1 0 000-1 4.5 4.5 0 00-.3-.8 1 1 0 00-.6-.5.6.6 0 010 .3h-.1a.5.5 0 000-.3c-.2-.5-.3-.7-.6-.8v.4l-.2.4h-.1l.1-.5v-.4c0-.6-.2-1-.8-1.2v.2l-.1.5h-.1v-.5a1.9 1.9 0 000-.3l-.5-.5a2.3 2.3 0 010 .7 3 3 0 01-.4.8h-.1a3 3 0 00.3-.8 2.2 2.2 0 00.1-.8 1 1 0 01-.2-.3v.2h-.1v-.2l.1-.1v-.1a.7.7 0 00-.3-.5 1.5 1.5 0 01-.2.5h-.1c-.1 0 0 0 0 0l.1-.3.1-.3a1 1 0 01-.1-.2.8.8 0 01-.1.2 1.2 1.2 0 01-.2.2c-.1-.1 0-.1 0-.1l.1-.2a.7.7 0 00.1-.2v-.2c0-.3 0-.4-.2-.7a.9.9 0 00-.3 0 2.8 2.8 0 00-.5.4v-.1a3.2 3.2 0 01.4-.3.9.9 0 01.4-.1.4.4 0 000-.2l-1 .3a1.6 1.6 0 01-.9-.2h.8c.3 0 .7 0 1.1-.2l.2-.6a1.7 1.7 0 01-.5 0l.6-.1v-.2c0-.2.3-.2.4 0 .2 0 .3.2.4.3.3.2.6 0 .9-.2h-.2v-.1h.3c.6 0 1 0 1.4-.5a7 7 0 01-1 0c-.2 0-.4 0-.6-.2l.7.1h1l.5-.3a5.4 5.4 0 01-2-.6 1.4 1.4 0 00-.6-.3c-.5 0-1 0-1.4.3l-.3-.3-.4-.2h-.6s-.1 0 0 0h1.2a4.5 4.5 0 011.7-.3 5.7 5.7 0 011.7-.2v-.2c.3-.3.4-.6.3-.9-.1-.2-.4-.5-.8-.7h-1.3a4 4 0 00-.8.1l.6.4.4 1v.1h-.2a2 2 0 00-.4-1c-.1-.2-.6-.3-.7-.4l-1.3.2-.7.4c.3-.1.6 0 .8 0 .3.2.5.4.6.8v.1h-.2a1 1 0 00-.5-.7c-.4-.2-1.2 0-1.6.3a4.2 4.2 0 00-.6.6h-.2v-.2l.7-.6.7-.4a2 2 0 011-.5l1.3-.2a1 1 0 00-.5-.5 1.4 1.4 0 00-.8 0c-.5.1-1 .4-1.5.7h.5l.1.2h-.5a1.4 1.4 0 00-.4 0l-1.5 1.2c-.5 0-.8 0-1 .2l-.1.6-.2.7c-.5.5-1 .9-1.3 1.5a1.4 1.4 0 01-.3.5.5.5 0 01.3.1v-.2l.2-.4h.1a1.2 1.2 0 00-.1.4v.5h-.2a.3.3 0 00-.1-.2.5.5 0 00-.3 0l-.3.2-.2.3c0 .3.2.3.5.3.6 0 .1.4.4.7l.5.4h.5c0-.4 0-.6.2-.6a.8.8 0 01.2-.4.8.8 0 000 .2.8.8 0 00-.1.2v.4a2.4 2.4 0 011-.2c.7-.8 1-.6.4 0l-.1.2a1.4 1.4 0 00-.2.6c-.2.1-1 .8-.7 1 .2 0 .4 0 .3.2-.1.2-.4.6-.3.9h.3a6.2 6.2 0 00.7-.6 3.8 3.8 0 00.5-.8h.1a9 9 0 01.3-.8c0-.2.1-.5.3-.7l.3.3a.4.4 0 00.2 0 .4.4 0 00.3 0l.2-.3h.1a1.2 1.2 0 01-.3.4.5.5 0 01-.3 0 .5.5 0 01-.2 0 1.1 1.1 0 01-.3-.3 12 12 0 00-.5 1.4v.1a5.6 5.6 0 01-1.2 1.4l.2.5 1-1 .8-1a6 6 0 01-.3.6v1.1h-.1v-.9l-.3.3a11.6 11.6 0 01-1 1c-.3.3-.6.3-.2.7l.3-.3.4-.3h.1v.1l-.4.3-.4.3a.6.6 0 00.1.3.5.5 0 01.1 0l.8-.6c.1 0 0 .1 0 .1l-.7.6a.7.7 0 01-.1 0c-.3.3-1.2.8-1 1.2l.6-.2.6-.5c.1 0 0 0 0 .1a2.5 2.5 0 01-.6.5v.2-.1a3.6 3.6 0 01-.7.1c.1.4 0 .7-.3 1 0 .1-1 .9-.6 1a1 1 0 00.3.2z\"/>\n    <path d=\"M349.4 100.1a2.2 2.2 0 00-.6-.3 1.4 1.4 0 00-.5-.5c-.2-.2-.2-.1-.1-.3l.2-.1a.9.9 0 01.3 0 .4.4 0 01.2.2h.1c.1 0 0 0 0 0a.5.5 0 00-.2-.2 1 1 0 00-.4-.1.7.7 0 00-.4 0l-.2-.5.4.1.2.1a.7.7 0 00-.2-.2 2 2 0 00-.2 0 2.9 2.9 0 012.1.2c.4.1.6.3.8.6l-.2.2c-.5 0-.8 0-1 .2-.2.1-.2.4-.2.6z\"/>\n  </g>\n  <path d=\"M365 121.8l-.4.2c0-.3.2-.4.3-.6v.2l.1.2zm2 4.2a2.3 2.3 0 01-.4.4 4 4 0 01-.5.4v-.1l.4-.4.4-.4zm1.3-1.6l-.2.3h-.1l.2-.3zm-.7 0a1.1 1.1 0 01-.2.3 1 1 0 01-.5.4v-.1a1 1 0 00.4-.3 1 1 0 00.1-.4h.1zm1.2-1.6a1 1 0 00-.1.2 1.1 1.1 0 00-.1.2h-.1a1.1 1.1 0 01.3-.5zm1 0v.5l-.3.5c-.1 0 0 0 0 0l.1-.5.2-.5zm-.4-6c.3.5.4 1 .4 1.5a7.3 7.3 0 01.1-.6 1.4 1.4 0 00.3-1.1c0-.1.1 0 .1 0v.6a1.7 1.7 0 01-.3.6l-.2 1h-.1v-.1c0-.6 0-1.2-.4-1.8v-.1zm-.8 1v.3h-.1v-.4h.1zm-.2 1.4a6.2 6.2 0 01.2 1.4 1 1 0 01.1-.1l.3-.3h.1a1 1 0 00-.3.3.7.7 0 00-.2.4 5 5 0 00-.1-.9 5.9 5.9 0 00-.2-.8zm1 .5a3.6 3.6 0 01.1 1.2v-.6a3.6 3.6 0 00-.1-.6zm1-.2v.6a1.5 1.5 0 010 .5 1.2 1.2 0 000 .6l.1.6a2.5 2.5 0 01-.3-.6 1.3 1.3 0 010-.6 1.4 1.4 0 00.2-.5 2.3 2.3 0 000-.6zm.5-1.5l-.1.3v.2h-.1v-.6h.1zm-.5-2.6v.2c.1 0 .1 0 0 0 0 .1 0 0 0 0v-.2s-.1 0 0 0c0-.1 0 0 0 0zm.2-2v.8a.8.8 0 00-.2.3 1.4 1.4 0 000 .6h-.1a1.4 1.4 0 010-.6.9.9 0 01.3-.4v-.7zm-2-.7c.4.2.6.4.8.7.2.2.3.5.3.9l-.6-.2v1.8c-.2.5-.5.8-1 1a3.8 3.8 0 000-1.8h.1a3.6 3.6 0 010 1.6 1.5 1.5 0 00.7-.8 3.7 3.7 0 00.1-1.9l.6.2c0-.3-.1-.5-.3-.8a2.5 2.5 0 00-.7-.6v-.1zm5.2-1v.2h-.1v-.2s0-.1 0 0h.1zm-1.2 0l.3.1a.8.8 0 01.1.2v.1a.8.8 0 00-.2-.2.6.6 0 00-.2-.2zm-1.8.5l.3.5v.6c-.1 0-.1 0 0 0l-.1-.6a1 1 0 00-.3-.5h.1zm-6 .5v.4l-.1.1v-.5zm1-.6l.2.4v.1h-.1v-.1l-.1-.3zm2.4 1.6v.1a1.1 1.1 0 010 .2.8.8 0 000-.2.6.6 0 00-.1 0v-.1zm.8-1.8v.2a.2.2 0 010 .2.1.1 0 000-.2c-.1-.1-.1-.1 0-.1zm-5.5.3a1 1 0 00.2.7c.2.1.2.3.3.4v.4h-.1v-.4a.9.9 0 00-.2-.3 1 1 0 01-.2-.4 1.1 1.1 0 01-.1-.4zm2.2 1.5l.2.7v.7c0 .3 0 .6.2.8l.6.7a2.9 2.9 0 01-.1-1l.3-1c.2 0 .2-.2.3-.3v-.4h.1v.4a1.5 1.5 0 01-.3.5 1.6 1.6 0 00-.3.9c0 .3 0 .6.2 1h-.1c-.4-.2-.6-.5-.8-.8a1.3 1.3 0 01-.2-.8v-.7a1.8 1.8 0 00-.2-.6c0-.1.1 0 .1 0zm-.9 1.4c0 .2 0 .5-.2.7a3.4 3.4 0 01-.4.6h.3a2.2 2.2 0 00.7-.6l.3-.3c.1 0 0 0 0 0a3.6 3.6 0 01-.2.4 2.5 2.5 0 01-.3.2 24.5 24.5 0 010 .4v-.2a1.5 1.5 0 00-.1-.1 2.2 2.2 0 01-.4.2l-.4.2v-.1l.4-.7.2-.7h.1zm-1 0v.1h-.1c-.1 0 0 0 0 0v-.2z\"/>\n  <path d=\"M363 113.7c.2.3.2.6.2 1a1.9 1.9 0 01-.4.8 1.9 1.9 0 00-.5.6 2.6 2.6 0 00-.2.6l.2-.3.5-.3a4.6 4.6 0 001.1-.9h.1c.1 0 0 0 0 0a4 4 0 01-1.2 1 1 1 0 00-.4.3 2.3 2.3 0 00-.4.5c0-.4 0-.7.2-1l.5-.6.4-.8c0-.3 0-.6-.2-.9h.1zm2.3 3.5l.1.4.1.1c.2.3.3.5.3.8l-.1 1h-.1a1.8 1.8 0 00-.4-1 3.4 3.4 0 00-.8-.6v-.1c.4.2.7.4.9.7l.3.6a3.4 3.4 0 000-.6 1.3 1.3 0 00-.1-.7l-.1-.2c-.2-.2-.3-.3-.2-.4zm1 0l.1.2c0 .1 0 0 0 0h-.1l-.2-.2h.1zm1 .3l-.2.7-.2.7.2-.7.2-.7zm.7 4v.1a.3.3 0 010-.2zm-.7-1.2v.3l-.2.4v-.4l.1-.4h.1zm-1 0h.1v.1h-.1v-.1zm-1.1-.6a7.3 7.3 0 01-.1.2v.2h-.1a5 5 0 010-.2 5 5 0 010-.2h.1c.1 0 0 0 0 0zm-1.7 1.8a.7.7 0 00-.1.2 1.3 1.3 0 000 .2s-.1.1-.2 0v-.2a.8.8 0 01.2-.3h.1zm-4.8 4.6a.7.7 0 010 .2 1.1 1.1 0 01-.2.1c-.1 0-.1 0 0 0a.8.8 0 00.1-.3h.1zm.8-.4a.3.3 0 01-.1.2.6.6 0 01-.2 0 .4.4 0 00.1-.1.3.3 0 000-.1h.2zm1-.6a.5.5 0 010 .1.5.5 0 01-.2.1.4.4 0 000-.2h.2zm1.5-3.8l-.1.4a1.4 1.4 0 000 .4h-.1a1.4 1.4 0 010-.4v-.5h.1zm1-10.3a.9.9 0 01-.1.3 1.4 1.4 0 01-.2.3h-.1l.2-.3a.8.8 0 000-.3l.1-.1zm-1-1a1.9 1.9 0 01.1 1 1.8 1.8 0 000-.5 1.5 1.5 0 00-.2-.4c0-.1 0 0 0 0zm-1.4 1.7a1.5 1.5 0 01-.4-.4.7.7 0 01-.1-.4l.2.4.3.4zm1.5 2.6v.2h-.1v-.2zm-2-2l.6 1 .1.8c.2 0 .3-.1.4-.3v-.9a1.9 1.9 0 00.3-.6 3.5 3.5 0 00.1-.5h.1l.4.8.3.9h-.1a2.9 2.9 0 00-.3-.9 3.9 3.9 0 00-.3-.6 2.9 2.9 0 010 .4 2 2 0 01-.3.5l-.1 1-.4.3v.4h-.1c0-.4 0-.8-.2-1.2a2 2 0 00-.5-1zm1.2 5v.3l-.1.4h-.1v-.8h.1c.1 0 .1 0 0 0zm-2.2.9v.3l-.1-.3c0-.1.1 0 .1 0zm1.9-2.5a2.3 2.3 0 01-.2.6l-.3.5a1.1 1.1 0 00-.3.6 1.8 1.8 0 000 .7c0 .1 0 0 0 0a1.9 1.9 0 01-.1-.7c0-.2.1-.5.3-.7a2.1 2.1 0 00.3-.5 2.1 2.1 0 00.2-.6c.1 0 0 0 0 0zm-.5-.8v.6a2.2 2.2 0 01-.5.6 1.8 1.8 0 00-.4.5l-.2.5h-.1l.2-.6.5-.5a2 2 0 00.3-.5 1 1 0 00.1-.6h.1zm-2.4 1.2c0 .4 0 .7-.2 1-.1.3-.3.6-.6.8h-.1v-.1c.3-.2.5-.5.6-.8.2-.2.2-.6.2-1zm-3 1.7v.2l.1.1v.1h-.1l-.1-.2v-.2s-.1 0 0 0zm-1.3 0a2.7 2.7 0 000 .7l.4.6.1.5v.4l.4-.5a1.4 1.4 0 00.2-.6 1.6 1.6 0 010 .6l-.5.6h-.1a3.3 3.3 0 000-.5 1.8 1.8 0 00-.2-.4 2 2 0 01-.3-.7 2.7 2.7 0 01-.1-.7zm.2 4.2a2.6 2.6 0 01.1-.8h.1a2.5 2.5 0 00-.1.8h-.1zm-.2 1.1v-.4s0-.1.1 0v.4zm-.8 2l.2-.3.2-.3h.1a4 4 0 01-.2.4l-.2.2c-.1 0-.1 0 0 0zm-1.1-6.6v.2h-.1v-.2zm-2 4.5a2.9 2.9 0 000-.1v-.2h.1v.3zm5-8l-.3 1c0 .3.1.6.3.7.3.2.4.4.5.7v-.4c.1-.1.1-.3 0-.4h.1a2.7 2.7 0 010 1h-.1a6 6 0 010-.2l-.5-.6c-.3-.2-.4-.4-.4-.8l.2-1h.1zm-.4-1.3a2.5 2.5 0 010 .8 4 4 0 01-.3.7 2.4 2.4 0 00-.2 1c0 .4.1.7.3 1v.1a2.5 2.5 0 01-.2-2.1 3.8 3.8 0 00.2-.7c0-.3.1-.5 0-.8h.1c.1 0 0 0 0 0zm-2.3 3.3a.8.8 0 000 .4l.1.5c0 .1 0 0 0 0a1.5 1.5 0 01-.3-.5.9.9 0 01.1-.5h.1zm-1-.4v.3a.9.9 0 010 .3.4.4 0 00-.1.3l.1.2v.1a.8.8 0 01-.2-.3.5.5 0 010-.4.8.8 0 00.1-.2v-.3h.1zm5.8-8.6a2.3 2.3 0 00.3 1.5 2.6 2.6 0 01-.4-.7 2.3 2.3 0 010-.8h.1zm-.7.7a4 4 0 01.5 1.7h-.1a3.8 3.8 0 00-.5-1.6v-.1zm-3.6.1c-.4.5-.5 1-.6 1.3l.2.9.2.8a2.6 2.6 0 01-.2.8c-.1 0 0 0 0 0v-.8a2.3 2.3 0 000-.8 1.7 1.7 0 01-.3-1c0-.3.2-.7.6-1.2.1 0 0 0 0 0zm3.3-1.4v.5l-.4.4a.8.8 0 00-.3.4v.7c0 .1 0 0 0 0a1.9 1.9 0 010-.7 1 1 0 01.3-.5 1 1 0 00.3-.4.6.6 0 000-.4h.1zm-3.5.3v.7c0 .2-.2.4-.4.6a1.2 1.2 0 00-.4.6 2.9 2.9 0 00-.1.7h-.1a3 3 0 01.1-.8c0-.2.2-.4.4-.6l.4-.6a1 1 0 000-.6zm2 .1a.8.8 0 000 .2.5.5 0 00.1.3.6.6 0 01-.2-.2.8.8 0 010-.3h.1zm0-.5a.8.8 0 00-.5.4l-.2.7.2.5v.7a2.4 2.4 0 000-.7l-.3-.4a2 2 0 00-.5 1.2c0 .5.1 1 .5 1.5h-.1a2.7 2.7 0 01-.5-1.5c0-.5.2-.9.6-1.3 0-.3 0-.6.2-.8a1 1 0 01.5-.4zm-.7-.8v.1c0 .3 0 .6-.2.7a.8.8 0 00-.2.3 1.6 1.6 0 00-.1.4h-.1a1.7 1.7 0 010-.4 1 1 0 01.3-.4c.2-.1.2-.4.2-.6a2.7 2.7 0 000-.1h.1zm5.7 6l.1.5v.4a1.4 1.4 0 000-.4 1.9 1.9 0 00-.2-.4h.1zm0 2v.6l-.2.6-.3.6.2-.6a2.1 2.1 0 00.2-.6 1.6 1.6 0 000-.7h.1zm-1.2-1.8a2.5 2.5 0 01.7 2.5h-.1a2.4 2.4 0 00-.6-2.4v-.1c0-.1 0 0 0 0zm0 2a5.3 5.3 0 01-1 1.4 2.5 2.5 0 00-.5 1 1.4 1.4 0 00-.1-.6 1.9 1.9 0 00-.2-.4 1.4 1.4 0 01-.3-.9l.3-.8.3-.6a2.4 2.4 0 000-.6h.1c.1 0 0 0 0 0a2.6 2.6 0 01-.3 1.3 1 1 0 00-.3.7c0 .3 0 .6.2.8a2 2 0 01.3.8 2.6 2.6 0 01.5-.8 5 5 0 00.5-.6l.3-.7h.1zm-3.2-1a2.8 2.8 0 00.4 1.4v.1h-.1a2.3 2.3 0 01-.3-.7 3 3 0 010-.7zm-1.7 1v.3h-.1v-.3zm.6-1.6l-.1.5a1.4 1.4 0 01-.3.5c-.1 0 0 0 0 0l.2-.5a1.4 1.4 0 000-.5h.1zm-1.6 3.1a3.3 3.3 0 01-.3-1.7c0-.5.3-.8.6-1l.4-.7c.1-.2.2-.5.1-1s.1 0 .1 0v1l-.6.7a1.9 1.9 0 00-.5 1c0 .5 0 1 .3 1.7h-.1zm-1-1.1a.7.7 0 000 .3l.1.4a1 1 0 01-.2-.4.8.8 0 010-.4h.1zm4.6-3.2c.1.2.3.5.3.8 0 .3 0 .6-.2.9h-.1c-.1 0 0 0 0 0l.2-.9a1.5 1.5 0 00-.3-.8zm1.4-1.1a2.4 2.4 0 010 1.7 1.8 1.8 0 00-.2-.8 1.5 1.5 0 00-.5-.5c0-.1 0-.1.1 0a1.6 1.6 0 01.6 1v-.6a2.3 2.3 0 00-.1-.8zm.8-1.2l.4.8v1a2 2 0 000 .5 1 1 0 00.2.4 1 1 0 01-.2-.4 2.3 2.3 0 010-.5 3.5 3.5 0 00-.1-1 1.5 1.5 0 00-.4-.7c0-.1 0 0 .1 0zm-2.2-.2a1 1 0 00-.3.5v.7a2 2 0 010-.7c0-.2 0-.4.2-.5.1 0 .1 0 0 0zm-4.4 3a2 2 0 01-.3 1 2.5 2.5 0 01-.8.7c-.1 0 0 0 0 0l.7-.7c.2-.3.3-.6.3-1l.1-.1zm0-1.6v.5a2.2 2.2 0 01-.3.5l.1-.5v-.5h.1zm2.9-.2v1h-.1v-1zm.7-1.3c-.2.3-.3.5-.3.8l.2.7.3 1.2c0 .4-.2.7-.4 1.1l.3-1.1a1.9 1.9 0 00-.3-1.2l-.2-.7c0-.3 0-.6.3-.8.1 0 0 0 0 0zm-4.6-8.1a2 2 0 011-.5c.4 0 .8 0 1.2.3h.8-.8c-.4.5-.8.7-1.1.7a1 1 0 01-.9-.2c0-.1 0-.1 0 0a1 1 0 00.9 0c.2 0 .6-.1 1-.5a1.9 1.9 0 00-1-.1 2 2 0 00-1 .4c-.1 0 0 0 0-.1z\"/>\n  <path d=\"M351.6 101a.3.3 0 01.3.3.3.3 0 01-.3.2.3.3 0 01-.2-.2.3.3 0 01.2-.3zm1.8 1.6a2.2 2.2 0 00.8-.7c.1 0 0 0 0 .1a2.3 2.3 0 01-.2.3l-.5.4c-.1-.1 0-.1 0-.1zm3.7-1.6a.5.5 0 01.3 0 .8.8 0 01.3.2.7.7 0 00-.3 0 .5.5 0 00-.2 0l-.1-.1zm-2 .1a.8.8 0 01.3-.4l.7-.1v.1a1 1 0 00-.7 0 .7.7 0 00-.3.5c-.1 0-.1 0 0 0zm.2.4a.4.4 0 010-.3.6.6 0 01.3-.1h.1a.5.5 0 00-.3.2.3.3 0 000 .2h-.1zm-3.6 1.1l-.1.3a.8.8 0 000 .3l-.1.1a1 1 0 010-.4c0-.1 0-.2.2-.3zm1 .5v.2-.2zm-.6-1.1a1 1 0 00.3 0h.3a1.4 1.4 0 01-.3.1 1 1 0 01-.3 0s-.1 0 0-.1zm.6-2a.3.3 0 00-.2.1.4.4 0 00-.1.2h-.1a.5.5 0 01.2-.3.4.4 0 01.2 0h.1zm-1 .2a.8.8 0 00-.2 0 .3.3 0 000 .2h-.1c-.1 0 0 0 0 0a.4.4 0 010-.2.9.9 0 01.3-.1zm-.7 0a.8.8 0 00-.1.1.7.7 0 00-.1.2h-.1a.7.7 0 01.1-.2.9.9 0 01.2-.2v.1zm-.8.7a1.7 1.7 0 00-.4.4v-.1a2 2 0 01.4-.4zm0 .9v.1l-.2.2c-.1 0-.1 0 0 0v-.2l.2-.2c.1 0 .1 0 0 0zm-.7.2v.3l-.1.1c-.1 0 0 0 0 0v-.4zm1 1.4v.6h-.1v-.6h.1zm-.6-.4v.3h-.1v-.3h.1zm-.6-4.5a.7.7 0 01.5.4v.1h-.1a.7.7 0 00-.2-.3.7.7 0 00-.2-.1v-.1zm5.2 6.7a1.6 1.6 0 010 1.4h-.1a1.6 1.6 0 000-1.3v-.1zm-1.7 2c0-.3.2-.5.3-.7l.4-.6c.2-.2.3-.4.3-.7a1.8 1.8 0 000-.7h.1a2 2 0 01-.3 1.5 6.3 6.3 0 00-.4.5l-.3.7h-.1zm-2.2-.6a.7.7 0 01.2-.3.9.9 0 01.3-.1.8.8 0 00-.2.2.6.6 0 00-.2.2zm-.4-.2l.3-.3.3-.2v.1a1 1 0 00-.3.2 2 2 0 00-.2.3c-.1 0-.1 0 0 0zm2.3-2.2h.2a.8.8 0 00.3 0v.1a.8.8 0 01-.6 0c0-.1 0-.1 0 0zm-1.2-.1l.1-.1c.1 0 .1 0 0 0v.1c-.1 0 0 0 0 0zm24.2 7a1.1 1.1 0 01.2.3h-.1a.8.8 0 000-.1.8.8 0 00-.2-.2c0-.1 0 0 0 0zm-26.8 12.5l.3.3a1 1 0 00.5 0v.1a1 1 0 01-.5 0 1.7 1.7 0 01-.4-.3c0-.1 0-.1 0 0z\"/>\n  <g fill=\"red\">\n    <path d=\"M368.9 99.6a8.2 8.2 0 001.7 0c-.6.3-1.2.6-2 .7a.8.8 0 00.3-.4.4.4 0 000-.3zm-1.4-.1h1.2v.4s0 .2-.2.3c0 0-.1 0 0 .1a5.6 5.6 0 01-1.3 0 1 1 0 00.3-.5.6.6 0 000-.4zm-10.5-3c.7-.2 1.3-.2 2-.2a1 1 0 01.5.4c.1.2.2.5.1.8l.1.1h.1l-.1-1a1 1 0 00-.3-.2h.2a5 5 0 012.1.6c.2.2.3.3.2.5l-.3.5v.2h.2l.3-.7a.7.7 0 000-.3l1.7.8a.5.5 0 010 .5 1 1 0 01-.5.3v.1l.1.1c.3 0 .5-.2.6-.4a.6.6 0 000-.4l1.2.6v.3c0 .2-.1.3-.3.4 0 0-.1 0 0 .1 0 .1 0 0 0 0 .3 0 .5-.2.6-.4a.5.5 0 000-.3l.4.1a8.1 8.1 0 001.3.4.5.5 0 01.1.4.7.7 0 01-.2.3v.2c-1.4-.1-2.7-.9-4.1-1.4l-.5-.2-1.6-.6-.1-.1a8.5 8.5 0 00-1.5-.4 6.1 6.1 0 00-1.6 0h-.1l-.1-.8a1.3 1.3 0 00-.5-.4z\"/>\n    <path d=\"M354.6 97a8.7 8.7 0 012-.5c.4.1.6.3.7.5v.6a4.2 4.2 0 00-1.7.2 1.2 1.2 0 00-.7-.6 1.2 1.2 0 00-.3-.1zm7.4 3.9a9.4 9.4 0 00-.5-.4 7 7 0 00-3-.8c.3-.4.4-.8.3-1.1a1.7 1.7 0 00-.7-.8h1a8 8 0 012 .6c0 .3.1.6 0 .8 0 .3-.2.5-.5.7 0 0-.1 0 0 .1 0 .1 0 .1 0 0 .4-.1.6-.4.7-.7v-.8l1 .6 1 .8c0 .4 0 .6-.3.8h-.9v.2z\"/>\n    <path d=\"M364 102.4l-1.8-1.4c.4 0 .7 0 1-.2.1-.1.3-.4.3-.8l1.1 1 .6.5v.4a.5.5 0 010 .2.6.6 0 01-.4.2h-.7z\"/>\n    <path d=\"M366.2 103.8a11.8 11.8 0 01-2-1.3h.7a.8.8 0 00.4-.2l.1-.4a1 1 0 000-.2 10.5 10.5 0 002.1 1.4c0 .3 0 .4-.3.5a3 3 0 01-1 .1z\"/>\n    <path d=\"M368.4 104.7a11.9 11.9 0 01-2-.8c.4 0 .7 0 1-.2.2 0 .3-.2.3-.5a10.8 10.8 0 001.3.6v.4l-.5.4s-.1 0 0 0z\"/>\n    <path d=\"M373.2 104.2s.4-.1.2 0c-1.4 1-3.1 1-4.8.5.3-.1.5-.2.6-.4a.6.6 0 000-.5l1.7.4a.4.4 0 01-.1.3l-.5.3s-.1 0 0 .1c0 .1 0 0 0 0 .3 0 .5-.2.6-.3a.6.6 0 00.2-.4 9 9 0 002 0zm-9.7 24l-.2.4-1.2.3c0 .3 0 .4.3.4l.7-.3c.1 0 0 .5-.5.8v.1c.4.6 1.4.4 1.9.3a3 3 0 001.3-1l-.3-.6c-.4.1-.6 0-.5-.2a3.9 3.9 0 00-1.5-.2zm-15.1-4.8c-.3.3-.7.5-1 .6-.2 0-.6.1-.6.3 0 .1.2.3.4.2.4-.5.7-.2.2.2v.3c.5.4 1.6.5 2.2.2.3-.2.6-.5.2-.9a1.7 1.7 0 010-.2h-.6l-.4-.3-.4-.4zm10 3.5h-.1c-.2.2.3.2.6.3.2.1.2.3.2.5-.3.7-1.9.5-2.4.2-.2-.1-.2-.3-.2-.5h.3c.2 0 .4 0 .6-.2v-.2h-.2a1.3 1.3 0 01-.4.2 2.6 2.6 0 01-.5 0l-.2-.2h.2l.7-.2.1-.1c.5 0 1 0 1.3.2zm-7.2-.4l-.2.3a2.7 2.7 0 01-.9.6c-.2.1 0 .2.2.4.2.1.5-.2.6-.4.2-.3.3-.2.2 0l-.2.7.7.3c.4 0 1-.4 1.2-.6.3-.2.2-.5.1-.8a2 2 0 01-.5 0 3.4 3.4 0 01-.5-.3l-.7-.2zm2.8-26.4h.3l.6.1a4.5 4.5 0 011.7-.3 5.7 5.7 0 011.7-.2v-.2c.3-.3.4-.6.3-.9-.1-.2-.4-.5-.8-.7h-1.3a4 4 0 00-.8.1l.6.4.4 1c-.2.1-.2 0-.2 0 0-.4-.2-.6-.3-.9l-.8-.4a9 9 0 00-1.3.2c-.3 0-.5.2-.7.3l.8.1c.3.1.5.4.6.8-.1.1-.1 0-.1 0a1 1 0 00-.5-.6c-.4-.2-1.3 0-1.7.2a4.2 4.2 0 00-.6.6l2 .4zm-2.3-.4v-.1l.7-.6.7-.4a2 2 0 011-.5l1.3-.2a1 1 0 00-.5-.5l-.8-.1-1.5.8h.5l.1.2h-.4a1.4 1.4 0 00-.4 0h-.1l-1.3 1c.3.1.6.2.7.4z\"/>\n  </g>\n  <path fill=\"#0093dd\" d=\"M409 156.5l20.8-47-15.3-24.7-27.3 10-12.7 49.8a219.4 219.4 0 0134.5 11.9z\"/>\n  <path fill=\"#fff\" d=\"M382.6 113a251.7 251.7 0 0139.6 13.7l-8 18.2a232 232 0 00-36.5-12.7z\"/>\n  <path fill=\"red\" d=\"M415.4 142l5.4-12.2a248.6 248.6 0 00-39-13.5l-3.2 12.4a235.9 235.9 0 0137 12.8l-.1.4z\"/>\n  <path d=\"M385.6 125.8c.3-.3.7-.2 1.1-.1.3-.2.7-.2 1-.2l.6-.2c.2 0 .2-.2 0-.3a.6.6 0 010-.3c-.7-.4-1-1-1.2-1.5-.3 0-.5-.2-.5-.3h-.5c-.8 0-1-.3-1.3-.5a1 1 0 01-.6-.4l-.3-.3c-.2-.3-.1-.7.2-.7h.7a2 2 0 01.9-.1c.3 0 .5-.3.9-.6v-.4s0-.2.2-.1a1 1 0 01.8.5c.5 0 1 .3 1.2.7.7 0 1.1.3 1.2.5 0 .2-.2.4-.5.6v.2l.4.4 1 .7c1-.1 2.6.6 4.8 2a18.6 18.6 0 014.1 1.2h.9c2.4-.4 4.7 0 6.8 1.5.8.1 1.5.4 2.2.7.5.2 1 .3 1.6.3a8 8 0 012.6.7c1 .2 1.9.6 2.4 1.2.4.5.3 1-.2 1.2-.3.6-.9.6-1.8.3-.6.1-1.3-.4-2-.9-.8-.2-1.6-.8-2.4-1.3l-1.3-.6h-.8v.2c.2.2.4.4.4.8v1c0 .4.3.6.7.9l1 .4c.2 0 .3.1.3.3l.4 1.7.4.3c.6.5.2 1-.3 1a3.1 3.1 0 01-1.3.8c-.4.2-.6 0-.7-.2a.5.5 0 01-.4-.2c-.5-.4-.1-1 1-.7l.2-.2a1.5 1.5 0 010-.9l-.3-.2a2.8 2.8 0 01-1-.6c-.6-.5-1.5-1-2.4-1.4-.7 0-1.2-.4-1.8-.7h-.8c-.2 0-.4 0-.5.2-.2.3-.5.2-.8.2h-1.6c-.4 0-.7 0-1 .3-.2.2-.4.2-.7 0a1 1 0 01-.3-.2c-.3 0-.5 0-.5-.2-.5-.1-.6-.2-.6-.4-.6-.1-.3-.6 0-.6l1.4.1c.4.1 1 0 1.2-.2l.5-.5a4 4 0 01-1.8-.5c-1.1-.7-2-.9-2.8-.3-.2.2-.3.2-.6.1a1 1 0 00-.5 0c-.5.1-.9 0-1.3-.1a4 4 0 01-1.8 0c-.6.3-1 .4-1.2.2a8.6 8.6 0 01-.6-.4c-.4-.1-.5-.2-.5-.3-.4 0-.5-.2-.5-.4-.2-.2 0-.3 0-.4.4-.2.7-.2 1 0 .3 0 .5.2.6.3h.6c.1-.2.5-.2 1-.2l.7-.2v-.2c-.4 0-.6-.4-.9-.7a3 3 0 01-1.5-.5c-.4 0-.7-.1-1-.3h-.7a2.5 2.5 0 01-1.4 0h-.8a1 1 0 01-1 .2 1.5 1.5 0 00-.8-.5c-.3-.1-.4-.2-.4-.4-.4-.2-.3-.4 0-.5.3-.1.5-.2 1 0l.5.2z\"/>\n  <path fill=\"#fff\" d=\"M401.2 130.5s0-.2-.3 0c-.8 0-1.6 0-2.2-.4-.7-.4-1.3-.8-2-.8l.7-.4h1.5c.7 0 1.4.2 2 .4.4.2.8.5 1 .8a3.4 3.4 0 01.8.7 2.5 2.5 0 01-.7 0 2.9 2.9 0 01-.8-.3z\"/>\n  <path d=\"M403 94.7v.2l.9 4.9-3.7 3.2-.2.1.2.1 4.7 1.6 1 4.9v.2l.2-.1 3.7-3.3 4.6 1.6h.3v-.1l-1-4.9 3.7-3.2.2-.2h-.3l-4.6-1.6-1-4.9V93l-.2.1-3.7 3.3-4.7-1.6z\"/>\n  <path fill=\"#f7db17\" d=\"M400.6 103l3.5-3 4.4 1.4zm8.5-1.7l3.4-3 4.4 1.5zm7.8-1.3l-3.4 3-4.4-1.5zm-8.4 1.6l-3.5 3-4.3-1.5zm-5-6.4l4.3 1.4.8 4.6zm5.5 6.4l4.4 1.5.9 4.5zm5.1 6.1l-4.3-1.5-.9-4.5zm-5.6-6.4l-4.3-1.5-.9-4.5zm3-7.7l1 4.6-3.5 3zm-2.7 8.1l.8 4.6-3.4 3zm-2.8 7.5l-.9-4.5 3.5-3zm2.8-8l-.9-4.6 3.5-3z\"/>\n</svg>";

var ar$1 = "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?>\r\n<svg\r\n   xmlns:dc=\"http://purl.org/dc/elements/1.1/\"\r\n   xmlns:cc=\"http://creativecommons.org/ns#\"\r\n   xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\"\r\n   xmlns:svg=\"http://www.w3.org/2000/svg\"\r\n   xmlns=\"http://www.w3.org/2000/svg\"\r\n   id=\"flag-icon-css-ar\"\r\n   viewBox=\"0 0 640 480\"\r\n   version=\"1.1\">\r\n  <metadata\r\n     id=\"metadata1678\">\r\n    <rdf:RDF>\r\n      <cc:Work\r\n         rdf:about=\"\">\r\n        <dc:format>image/svg+xml</dc:format>\r\n        <dc:type\r\n           rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\" />\r\n        <dc:title></dc:title>\r\n      </cc:Work>\r\n    </rdf:RDF>\r\n  </metadata>\r\n  <defs\r\n     id=\"defs1676\" />\r\n  <path\r\n     id=\"21399192\"\r\n     d=\"M 640,479.9928 V 0 L 0,0.00719971 V 480 h 640 z\"\r\n     class=\"fil0 str0\"\r\n     fill=\"#006233\"\r\n     style=\"stroke-width:0.169532\" />\r\n  <g\r\n     id=\"g13004\"\r\n     transform=\"matrix(0.25707542,0,0,0.25727772,319.29932,-19.227473)\">\r\n    <g\r\n       id=\"g9244\"\r\n       fill-rule=\"evenodd\"\r\n       transform=\"matrix(1.7598,0,0,1.6,-2175.2,-3398.1)\"\r\n       stroke=\"#ffffff\"\r\n       fill=\"#ffffff\">\r\n      <path\r\n         id=\"path3159\"\r\n         d=\"m 1071.9,2779.7 c -25.9,38.9 -7.2,64.2 19.5,66 17.6,1.3 54.2,-24.9 54.1,-55.7 l -10,-5.6 c 5.6,15.8 -0.2,20.8 -12.1,31.6 -23.5,21.3 -71.5,22.8 -51.5,-36.3 z\"\r\n         stroke-width=\"0.4008\" />\r\n      <path\r\n         id=\"path3115\"\r\n         d=\"m 1277.2,2881.7 c 145.8,4.1 192.2,-137 102.2,-257.8 l -8.9,13.3 c 5.8,56.3 14.2,111.8 15,169.5 -17.6,20.7 -43.2,13 -48.3,-10 0.3,-31.2 -9.9,-57.6 -22.8,-82.8 l -7.2,13.3 c 8.4,20.7 17.5,44 19.4,69.5 -41.6,49.9 -87.6,60 -70.5,-5.6 -32.9,57.5 16.9,98 73.3,9.5 12.1,60.4 58.9,22.9 61.7,9.9 5.1,-39.6 2.5,-103.4 -7.8,-153.8 40.6,70.3 42,121 20.4,154.9 -24,37.7 -76.2,55.3 -126.5,70.1 z\"\r\n         stroke-width=\"1px\" />\r\n      <path\r\n         id=\"path3117\"\r\n         d=\"m 1359.9,2722.2 c -31.2,2.3 -47.2,-4.1 -30.3,-27.2 16.7,-22.6 32.3,-4.6 36.5,25.6 3.9,28.3 -54.8,64.4 -75.1,64.4 -30.7,0 -44.9,-39.5 -16.6,-75 -36.4,103.6 78.6,43.5 85.5,12.2 z m -21.6,-24 c -3.8,-0.2 -6.6,6.5 -4.7,7.8 5.5,3.8 14.2,1.5 15.1,-0.4 1.9,-4.2 -5.1,-7.2 -10.4,-7.4 z\"\r\n         stroke-width=\"1px\" />\r\n      <path\r\n         id=\"path3140\"\r\n         d=\"m 1190.5,2771.1 c -30,59 -0.1,83.4 38.4,76.6 22.4,-4.1 50.8,-20 67.2,-41.7 0.3,-47.8 -0.4,-95.2 -4.6,-141.5 15,-17.9 -1.3,-17.8 -7,-37 -2.6,11.2 -8.9,23.3 -2.8,32 4.3,46.7 6.7,94 6.6,142.2 -30.2,24.3 -52.9,33.3 -69.1,33.1 -33.5,-0.3 -40.7,-28.5 -28.7,-63.7 z\"\r\n         stroke-width=\"1px\" />\r\n      <path\r\n         id=\"path3150\"\r\n         d=\"m 1251.8,2786.7 c -0.5,-44.5 -1.2,-95 -5.2,-126.1 15.6,-17.3 -0.8,-17.7 -5.9,-37.1 -3,11 -9.6,23 -3.8,31.9 2.6,47.6 5.1,95.2 5.6,142.8 3.6,-2.3 7.7,-3.2 9.3,-11.5 z\"\r\n         stroke-width=\"1px\" />\r\n      <path\r\n         id=\"path3152\"\r\n         d=\"m 1135.4,2784.6 c -3.8,-4.8 -6.5,-10.2 -9.6,-14.9 -0.5,-6.7 4,-12.9 4.6,-16.3 5.1,7.9 8.1,13.9 12.2,17.8 m 5.4,3.1 c 7.5,3 16.7,3 25.2,3.2 32.8,0.6 67.3,-4.8 63.6,39.6 -3.2,39.4 -35.9,62.2 -65.2,61.9 -41.7,-0.4 -77.3,-46.4 -13,-131.1 6.2,-1 14.3,0.7 21,1.3 11.5,0.9 23.3,-0.2 36.8,-11 -1.6,-27.9 -1.6,-54.3 -5,-79.5 -5.8,-8.9 0.8,-20.8 3.8,-31.9 5.1,19.4 21.4,19.8 5.9,37.2 3.7,28 4.1,56.5 4.1,73.5 -7.8,11.9 -13.9,24.5 -36.7,29.3 -23.3,-3.4 -33.8,-36 -58.1,-25.2 6.7,-29.4 68.4,-36.1 74.6,-12.9 -4.1,24.2 -61.7,14.5 -77,92.7 -4.7,24.1 20.7,46.3 46.8,44.5 25.5,-1.7 52.7,-19.4 55.4,-49.2 2.1,-24.9 -33,-22 -47.7,-21.7 -21.4,0.5 -34.9,-2.8 -43,-7.5 m 21.9,-53.9 c 3.8,-3.6 17.1,-6.1 21.9,-0.3 -3.6,2.4 -7.1,5 -10,8.1 -5,-2.6 -8.3,-5.2 -11.9,-7.8 z\"\r\n         stroke-width=\"0.4008\" />\r\n      <path\r\n         id=\"path3161\"\r\n         d=\"m 1194,2650.9 c 3.6,8 5.1,13.3 5.3,21 -2.2,10.4 -11.1,20.1 -20.3,20.4 -5.7,0.2 -12.1,-1.4 -16.6,-10.3 -0.5,-1.1 -2.9,-3.7 -5.2,-2.5 -10.1,16.6 -17.6,23.6 -26.7,23.5 -18.2,-0.3 -12.8,-16.5 -29.6,-21.5 -7,-0.2 -18.5,6.9 -24.4,20.8 -22.4,63.5 -42.8,-0.2 -34.1,-29.8 1.3,28.3 8.1,45.1 15.1,44.6 5.1,-0.5 9.6,-12.3 16.1,-24.7 5,-9.5 17,-26.6 29.7,-26.6 11.6,0.3 4.3,21.6 27.5,21.3 11.2,-0.2 21.5,-8.8 31.9,-26 2.3,-0.4 2.9,3.7 3.4,5.1 1.6,5.9 11.8,22.1 25.6,7.3 -0.7,-3.2 -0.4,-8.5 -3.9,-9.6 z\"\r\n         stroke-width=\"1px\" />\r\n      <path\r\n         id=\"path3163\"\r\n         d=\"m 1266.9,2598.3 c -12.3,6.1 -21.3,0.5 -26.4,-4.9 8.9,-1.8 15.8,-5 17.8,-12 -4,-9 -13.5,-12.9 -26.9,-13 -17.9,0.5 -27.1,7.7 -28.2,17.6 8.3,0.3 15.8,-2 19,6 -14.7,7.2 -32,9.8 -50.8,9.7 -30.8,1.6 -35.3,-12.3 -43.4,-24.5 -0.6,-0.8 -3.3,-2.1 -4.7,-1.9 -9.5,0 -16.5,33.2 -27.2,33.1 -10.7,-1.4 -8.3,-21.4 -11.4,-32.8 -2.6,17.9 3.3,84.5 36.4,12.2 1,-2.4 2.4,-1.7 3.3,0.3 8.9,20.2 27,27.2 46.5,28.2 16.3,0.9 37.1,-6.2 59.4,-18.8 5.9,6.5 10.6,13.9 23,15.3 14.5,0.7 30,-9.8 33.5,-22.8 1.8,-6.7 2.1,-19.9 -5,-20.1 -9.9,-0.3 -17.1,23.7 -14.8,45.3 0.2,-0.3 1.3,-5.4 1.3,-5.4 m -43.8,-28.8 c 6.5,-3 12.8,-4.4 17.8,2.2 -3.9,1.4 -6.3,2.3 -8.4,4 -2.8,-2.2 -6.6,-3.3 -9.4,-6.2 z m 47.8,14.9 c 1.6,-7.1 2.5,-12.8 8.3,-16.5 1.2,7.5 1.4,11.7 -8.3,16.5 z\"\r\n         stroke-width=\"0.4008\" />\r\n      <path\r\n         id=\"path3169\"\r\n         d=\"m 1311.3,2606.9 c -1.9,-6.1 -3.8,-11.4 -4.4,-18 -1.4,-13.4 10.1,-21 20.5,-19.9 10.7,1.1 17.8,5.1 28,8.6 8,2.7 18.8,4.8 29.1,7.7 5.8,2.6 0,9.4 -1.5,10.3 -25.8,10.1 -44.1,26.1 -60.5,26.8 -9.8,0.5 -18.5,-5.9 -26.4,-19 -0.5,-25.4 -1.4,-55.2 -3.9,-73.9 3.8,-3.8 4.6,-6.6 6.4,-9.7 2,24.7 2.8,50.7 3.3,76.9 2.1,4.5 4.7,8.3 9.4,10.2 z m 16.5,2 c -13.8,3.9 -12.1,-7.8 -13.4,-15 -1.5,-8.4 -0.5,-17.9 10.2,-15.5 13.9,3.7 26.6,8.6 38.9,13.8 z\"\r\n         stroke-width=\"0.4008\" />\r\n      <path\r\n         id=\"path3173\"\r\n         d=\"m 1314.3,2621.3 1.9,9.3 h 1.5 l -0.6,-8.7\"\r\n         stroke-width=\"0.4008\" />\r\n      <path\r\n         id=\"path5196\"\r\n         stroke-linejoin=\"round\"\r\n         d=\"m 1094.2,2718.5 7,-7.2 8.1,6.9 -7.5,6.7 z\"\r\n         stroke-linecap=\"round\"\r\n         stroke-width=\"4.008\" />\r\n      <path\r\n         id=\"path6168\"\r\n         stroke-linejoin=\"round\"\r\n         d=\"m 1112,2716.1 7.1,-7.2 8.1,6.9 -7.5,6.7 z\"\r\n         stroke-linecap=\"round\"\r\n         stroke-width=\"4.008\" />\r\n      <path\r\n         id=\"path6170\"\r\n         stroke-linejoin=\"round\"\r\n         d=\"m 1062.5,2641.5 7.1,-7.2 8.1,6.9 -7.5,6.7 z\"\r\n         stroke-linecap=\"round\"\r\n         stroke-width=\"4.008\" />\r\n      <path\r\n         id=\"path6172\"\r\n         stroke-linejoin=\"round\"\r\n         d=\"m 1065.7,2662.7 7.1,-7.2 8,6.9 -7.5,6.7 z\"\r\n         stroke-linecap=\"round\"\r\n         stroke-width=\"4.008\" />\r\n      <path\r\n         id=\"path6174\"\r\n         stroke-linejoin=\"round\"\r\n         d=\"m 1194.2,2698.2 6.5,-5.3 6,6.5 -6.8,4.8 z\"\r\n         stroke-linecap=\"round\"\r\n         stroke-width=\"4.008\" />\r\n      <path\r\n         id=\"path6176\"\r\n         stroke-linejoin=\"round\"\r\n         d=\"m 1108.4,2562.5 4.6,-4.7 5.3,4.5 -4.9,4.4 z\"\r\n         stroke-linecap=\"round\"\r\n         stroke-width=\"4.008\" />\r\n      <path\r\n         id=\"path6178\"\r\n         stroke-linejoin=\"round\"\r\n         d=\"m 1120.1,2561 4.6,-4.8 5.3,4.6 -4.9,4.3 z\"\r\n         stroke-linecap=\"round\"\r\n         stroke-width=\"4.008\" />\r\n      <path\r\n         id=\"path6180\"\r\n         stroke-linejoin=\"round\"\r\n         d=\"m 1365.7,2614.7 -4.4,3.7 -4.2,-4.3 4.6,-3.4 z\"\r\n         stroke-linecap=\"round\"\r\n         stroke-width=\"4.008\" />\r\n      <path\r\n         id=\"path9240\"\r\n         d=\"m 1158.7,2747.4 -0.5,7.9 12.6,1.2 10.1,-7.6 z\"\r\n         stroke-width=\"0.4008\" />\r\n      <path\r\n         id=\"path9242\"\r\n         d=\"m 1265.2,2599.8 3.7,-0.8 -0.4,10.3 -2.3,0.9 z\"\r\n         stroke-width=\"1px\" />\r\n    </g>\r\n    <path\r\n       id=\"path2722\"\r\n       d=\"m 2.7256,1425 c 249.82,0 453.08,-184.8 453.08,-411.9 0,-124.96 -61.32,-236.46 -157.84,-311.83 57.91,61.95 93.11,143.51 93.11,232.3 0,197.23 -173.74,357.23 -388.35,357.23 -214.62,0 -388.36,-160 -388.36,-357.23 0,-88.79 35.2,-170.35 93.11,-232.3 -96.52,75.37 -157.84,186.87 -157.84,311.83 0,227.1 203.27,411.9 453.09,411.9 z\"\r\n       fill=\"#ffffff\"\r\n       class=\"fil2\" />\r\n    <g\r\n       id=\"g2908\"\r\n       transform=\"matrix(1.1355,0,0,1.0324,2.7256,-21.429)\"\r\n       stroke=\"#000000\"\r\n       stroke-width=\"8.012\"\r\n       fill=\"#ffffff\">\r\n   <path\r\n   id=\"path2910\"\r\n   d=\"m -54,1623 c -88,44 -198,32 -291,-28 -4,-2 -6,1 -2,12 10,29 18,52 -12,95 -13,19 2,22 24,20 112,-11 222,-36 275,-57 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2912\"\r\n   d=\"m -56,1675 c -35,14 -95,31 -162,43 -27,4 -26,21 22,27 49,5 112,-30 150,-61 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2914\"\r\n   d=\"m 0,1579 c 12,0 34,-5 56,-8 41,-7 11,56 -56,56 v 21 c 68,0 139,-74 124,-107 -21,-48 -79,-7 -124,-7 -45,0 -103,-41 -124,7 -15,33 56,107 124,107 v -21 c -67,0 -97,-63 -56,-56 22,3 44,8 56,8 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2916\"\r\n   d=\"m 54,1623 c 88,44 198,32 291,-28 4,-2 6,1 2,12 -10,29 -18,52 12,95 13,19 -2,22 -24,20 -112,-11 -222,-36 -275,-57 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2918\"\r\n   d=\"m 56,1675 c 35,14 94,31 162,43 27,4 26,21 -22,27 -49,5 -112,-30 -150,-61 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2920\"\r\n   d=\"m 3,1665 c 2,17 5,54 28,38 31,-21 38,-37 38,-67 0,-19 -23,-47 -69,-47 -46,0 -69,28 -69,47 0,30 7,46 38,67 23,16 25,-21 28,-38 1,-6 6,-4 6,0 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n  </g>\r\n    <g\r\n       id=\"g2724\"\r\n       transform=\"matrix(1.1355,0,0,1.0324,2.7256,-21.429)\"\r\n       stroke=\"#000000\"\r\n       stroke-width=\"8.012\"\r\n       fill=\"#ffffff\">\r\n   <path\r\n   id=\"path2726\"\r\n   d=\"m -29,384 c -13,-74 -122,-79 -139,-91 -20,-13 -17,0 -10,20 20,52 88,73 119,79 25,4 33,6 30,-8 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2728\"\r\n   d=\"m 4,386 c 11,-76 -97,-112 -110,-129 -15,-18 -17,-7 -10,14 13,45 60,98 88,112 23,12 30,17 32,3 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2730\"\r\n   d=\"M 93,430 C 103,339 15,325 -8,296 c -15,-18 -16,-8 -11,13 10,46 54,100 81,117 21,13 30,18 31,4 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2732\"\r\n   d=\"m 66,410 c -91,-59 -155,-26 -181,-29 -25,-3 -33,13 10,37 53,29 127,25 156,14 30,-12 21,-18 15,-22 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2734\"\r\n   d=\"M 203,450 C 175,352 110,368 91,356 72,344 70,347 74,369 c 8,39 75,82 108,95 12,4 27,10 21,-14 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2736\"\r\n   d=\"M 190,467 C 112,404 51,451 27,444 c -18,-5 -10,7 -3,12 50,35 112,54 160,32 19,-8 20,-10 6,-21 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2738\"\r\n   d=\"m 359,531 c 1,-62 -127,-88 -154,-126 -16,-23 -30,-11 -22,26 12,48 100,101 148,111 29,6 28,-4 28,-11 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2740\"\r\n   d=\"m 355,542 c -81,-73 -149,-49 -174,-56 -25,-6 -35,9 4,39 48,36 122,43 153,36 31,-7 23,-14 17,-19 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2742\"\r\n   d=\"M 500,649 C 477,543 404,521 386,501 c -17,-20 -35,-14 -20,34 18,57 77,107 108,119 30,13 28,3 26,-5 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2744\"\r\n   d=\"M 499,663 C 440,568 363,571 339,558 c -23,-14 -39,-2 -8,39 36,50 110,78 144,80 34,2 28,-7 24,-14 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2746\"\r\n   d=\"m 575,776 c 34,-108 -44,-148 -52,-166 -9,-18 -18,-18 -23,1 -22,77 49,152 60,167 11,14 13,7 15,-2 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2748\"\r\n   d=\"M 559,806 C 532,685 461,692 445,675 c -17,-17 -19,-5 -16,17 8,59 79,99 111,119 10,6 22,13 19,-5 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2750\"\r\n   d=\"m 627,948 c 49,-114 -9,-191 -27,-208 -18,-16 -29,-23 -23,0 8,35 -20,125 23,191 14,22 16,43 27,17 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2752\"\r\n   d=\"m 601,971 c 11,-70 -29,-134 -72,-159 -25,-15 -26,-11 -26,10 2,65 63,119 81,149 17,28 16,7 17,0 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2754\"\r\n   d=\"m 590,1153 c -36,-132 39,-208 62,-223 22,-16 36,-22 26,3 -15,37 1,140 -56,205 -18,22 -25,45 -32,15 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2756\"\r\n   d=\"m 598,1124 c 30,-115 -35,-180 -55,-193 -19,-13 -31,-18 -22,3 12,32 -1,122 49,178 16,19 22,38 28,12 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2758\"\r\n   d=\"m 561,1070 c -54,58 -55,143 -31,193 15,29 17,27 31,6 38,-61 15,-149 17,-188 1,-37 -11,-17 -17,-11 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2760\"\r\n   d=\"m 650,1162 c 0,80 -49,145 -101,165 -30,11 -30,8 -26,-16 14,-90 83,-123 108,-152 24,-28 19,-5 19,3 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2762\"\r\n   d=\"m 464,1400 c 88,-80 41,-136 45,-188 2,-28 -9,-21 -19,-11 -56,55 -59,153 -47,191 5,17 13,15 21,8 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2764\"\r\n   d=\"m 582,1348 c -29,88 -106,142 -171,145 -38,2 -37,-1 -24,-27 49,-94 136,-105 175,-129 36,-22 23,2 20,11 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2766\"\r\n   d=\"m 343,1513 c 114,-57 91,-152 112,-176 15,-17 -3,-15 -12,-9 -67,39 -121,101 -122,167 0,25 2,28 22,18 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2768\"\r\n   d=\"m 187,1619 c 144,23 211,-86 253,-96 22,-5 6,-14 -5,-15 -96,-11 -218,34 -255,84 -15,20 -15,24 7,27 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2770\"\r\n   d=\"m 333,1448 c -29,95 -137,173 -218,179 -38,3 -38,-1 -24,-26 65,-118 178,-138 218,-168 34,-26 27,6 24,15 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2772\"\r\n   d=\"m 29,384 c 13,-74 122,-79 139,-91 20,-13 17,0 10,20 -20,52 -88,73 -119,79 -25,4 -33,6 -30,-8 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2774\"\r\n   d=\"m -4,386 c -11,-76 97,-112 110,-129 15,-18 17,-7 10,14 -13,45 -60,98 -88,112 -23,12 -30,17 -32,3 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2776\"\r\n   d=\"m -93,430 c -10,-91 78,-105 101,-134 15,-18 16,-8 11,13 -10,46 -54,100 -81,117 -21,13 -30,18 -31,4 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2778\"\r\n   d=\"m -66,410 c 91,-59 155,-26 181,-29 25,-3 33,13 -10,37 -53,29 -127,25 -156,14 -30,-12 -21,-18 -15,-22 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2780\"\r\n   d=\"m -203,450 c 28,-98 93,-82 112,-94 19,-12 21,-9 17,13 -8,39 -75,82 -108,95 -12,4 -27,10 -21,-14 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2782\"\r\n   d=\"m -190,467 c 78,-63 139,-16 163,-23 18,-5 10,7 3,12 -50,35 -112,54 -160,32 -19,-8 -20,-10 -6,-21 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2784\"\r\n   d=\"m -359,531 c -1,-62 127,-88 154,-126 16,-23 30,-11 22,26 -12,48 -100,101 -148,111 -29,6 -28,-4 -28,-11 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2786\"\r\n   d=\"m -355,542 c 81,-73 149,-49 174,-56 25,-6 35,9 -4,39 -48,36 -122,43 -153,36 -31,-7 -23,-14 -17,-19 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2788\"\r\n   d=\"m -500,649 c 23,-106 96,-128 114,-148 17,-20 35,-14 20,34 -18,57 -77,107 -108,119 -30,13 -28,3 -26,-5 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2790\"\r\n   d=\"m -499,663 c 59,-95 136,-92 160,-105 23,-14 39,-2 8,39 -36,50 -110,78 -144,80 -34,2 -28,-7 -24,-14 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2792\"\r\n   d=\"m -575,776 c -34,-108 44,-148 52,-166 9,-18 18,-18 23,1 22,77 -49,152 -60,167 -11,14 -13,7 -15,-2 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2794\"\r\n   d=\"m -559,806 c 27,-121 98,-114 114,-131 17,-17 19,-5 16,17 -8,59 -79,99 -111,119 -10,6 -22,13 -19,-5 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2796\"\r\n   d=\"m -627,948 c -49,-114 9,-191 27,-208 18,-16 29,-23 23,0 -8,35 20,125 -23,191 -14,22 -16,43 -27,17 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2798\"\r\n   d=\"m -601,971 c -11,-70 29,-134 72,-159 25,-15 26,-11 26,10 -2,65 -63,119 -81,149 -17,28 -16,7 -17,0 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2800\"\r\n   d=\"m -590,1153 c 36,-132 -39,-208 -62,-223 -22,-16 -36,-22 -26,3 15,37 -1,140 56,205 18,22 24,45 32,15 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2802\"\r\n   d=\"m -598,1124 c -30,-115 35,-180 55,-193 19,-13 31,-18 22,3 -12,32 1,122 -49,178 -16,19 -22,38 -28,12 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2804\"\r\n   d=\"m -561,1070 c 54,58 55,143 31,193 -15,29 -17,27 -31,6 -38,-61 -15,-149 -17,-188 -1,-37 11,-17 17,-11 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2806\"\r\n   d=\"m -650,1162 c 0,80 49,145 101,165 30,11 30,8 26,-16 -14,-90 -83,-123 -108,-152 -24,-28 -19,-5 -19,3 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2808\"\r\n   d=\"m -464,1400 c -88,-80 -41,-136 -45,-188 -2,-28 9,-21 19,-11 56,55 59,153 47,191 -5,17 -13,15 -21,8 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2810\"\r\n   d=\"m -582,1348 c 29,88 106,142 171,145 38,2 37,-1 24,-27 -49,-94 -136,-105 -175,-129 -36,-22 -23,2 -20,11 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2812\"\r\n   d=\"m -343,1513 c -114,-57 -91,-152 -112,-176 -15,-17 3,-15 12,-9 67,39 121,101 122,167 0,25 -2,28 -22,18 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2814\"\r\n   d=\"m -187,1619 c -144,23 -211,-86 -253,-96 -22,-5 -6,-14 5,-15 96,-11 218,34 255,84 15,20 15,24 -7,27 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n   <path\r\n   id=\"path2816\"\r\n   d=\"m -333,1448 c 29,95 137,173 218,179 38,3 38,-1 24,-26 -65,-118 -178,-138 -218,-168 -34,-26 -27,6 -24,15 z\"\r\n   class=\"fil2 str2\" />\r\n\r\n  </g>\r\n    <g\r\n       id=\"g2818\"\r\n       fill=\"#006233\"\r\n       transform=\"matrix(1.1355,0,0,1.0324,2.7256,-21.429)\">\r\n   <path\r\n   id=\"path2820\"\r\n   d=\"m 169,476 c -19,-14 -89,-6 -102,-15 25,21 81,6 102,15 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2822\"\r\n   d=\"m 338,512 c -15,-27 -104,-45 -117,-69 23,46 92,40 117,69 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2824\"\r\n   d=\"m 325,543 c -33,-32 -110,-19 -133,-38 54,49 84,11 133,38 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2826\"\r\n   d=\"m 132,401 c 21,11 47,22 60,48 -15,-20 -42,-28 -64,-45 1,0 3,-2 4,-3 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2828\"\r\n   d=\"m 460,607 c -13,-30 -59,-63 -63,-74 13,39 51,48 63,74 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2830\"\r\n   d=\"m 472,660 c -40,-63 -103,-56 -128,-80 19,23 91,38 128,80 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2832\"\r\n   d=\"m 565,757 c 3,-67 -47,-92 -49,-130 -1,45 51,106 49,130 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2834\"\r\n   d=\"m 540,793 c -10,-58 -78,-62 -90,-96 0,32 80,65 90,96 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2836\"\r\n   d=\"m 596,760 c 36,44 11,111 26,160 -18,-36 -9,-126 -26,-160 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2838\"\r\n   d=\"m 537,948 c 54,58 32,123 54,151 -27,-39 -23,-115 -54,-151 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2840\"\r\n   d=\"m 649,956 c -46,51 -18,128 -42,164 27,-31 23,-126 42,-164 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2842\"\r\n   d=\"m 591,956 c -6,-59 -61,-90 -66,-122 -6,32 53,82 66,122 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2844\"\r\n   d=\"m 563,1097 c 9,41 -24,129 -14,156 -22,-47 19,-136 14,-156 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2846\"\r\n   d=\"m 634,1191 c -22,73 -66,68 -80,112 10,-42 68,-80 80,-112 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2848\"\r\n   d=\"m 491,1225 c -29,49 -5,105 -29,140 34,-35 16,-100 29,-140 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2850\"\r\n   d=\"m 561,1359 c -35,65 -107,59 -136,106 29,-59 118,-69 136,-106 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2852\"\r\n   d=\"m 434,1351 c -62,43 -43,88 -90,136 59,-48 54,-101 90,-136 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2854\"\r\n   d=\"m 405,1525 c -60,-2 -146,76 -198,70 52,11 148,-59 198,-70 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2856\"\r\n   d=\"m 308,1455 c -4,61 -160,100 -177,141 19,-54 156,-94 177,-141 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2858\"\r\n   d=\"m -45,330 c -20,-17 -44,-31 -51,-48 5,22 25,38 45,53 2,-1 4,-4 6,-5 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2860\"\r\n   d=\"m -79,348 c -31,-15 -67,-14 -83,-35 10,21 44,29 73,40 3,-2 7,-4 10,-5 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2862\"\r\n   d=\"m -169,476 c 19,-14 89,-6 102,-15 -25,21 -81,6 -102,15 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2864\"\r\n   d=\"m -338,512 c 15,-27 104,-45 117,-69 -23,46 -92,40 -117,69 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2866\"\r\n   d=\"m -325,543 c 33,-32 110,-19 133,-38 -54,49 -84,11 -133,38 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2868\"\r\n   d=\"m -192,449 c 19,-40 73,-45 87,-69 -21,36 -67,42 -87,69 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2870\"\r\n   d=\"M -38,414 C 17,388 71,410 97,398 65,415 -11,407 -38,414 Z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2872\"\r\n   d=\"m -460,607 c 13,-30 59,-63 63,-74 -13,39 -51,48 -63,74 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2874\"\r\n   d=\"m -472,660 c 40,-63 103,-56 128,-80 -19,23 -91,38 -128,80 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2876\"\r\n   d=\"m -565,757 c -3,-67 47,-92 49,-130 1,45 -51,106 -49,130 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2878\"\r\n   d=\"m -540,793 c 10,-58 78,-62 90,-96 0,32 -80,65 -90,96 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2880\"\r\n   d=\"m -596,760 c -36,44 -11,111 -26,160 18,-36 9,-126 26,-160 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2882\"\r\n   d=\"m -537,948 c -54,58 -32,123 -54,151 27,-39 23,-115 54,-151 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2884\"\r\n   d=\"m -649,956 c 46,51 18,128 42,164 -27,-31 -23,-126 -42,-164 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2886\"\r\n   d=\"m -591,956 c 6,-59 61,-90 66,-122 6,32 -53,82 -66,122 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2888\"\r\n   d=\"m -563,1097 c -9,41 24,129 14,156 22,-47 -19,-136 -14,-156 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2890\"\r\n   d=\"m -634,1191 c 22,73 66,68 80,112 -10,-42 -68,-80 -80,-112 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2892\"\r\n   d=\"m -491,1225 c 29,49 5,105 29,140 -34,-35 -16,-100 -29,-140 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2894\"\r\n   d=\"m -561,1359 c 35,65 107,59 136,106 -29,-59 -118,-69 -136,-106 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2896\"\r\n   d=\"m -434,1351 c 62,43 43,88 90,136 -59,-48 -54,-101 -90,-136 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2898\"\r\n   d=\"m -405,1525 c 60,-2 146,76 198,70 -52,11 -148,-59 -198,-70 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2900\"\r\n   d=\"m -308,1455 c 4,61 160,100 177,141 -19,-54 -156,-94 -177,-141 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2902\"\r\n   d=\"m -81,416 c 12,-54 72,-64 80,-96 -3,34 -74,72 -80,96 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2904\"\r\n   d=\"m 96,282 c -9,41 -74,64 -83,95 3,-42 70,-66 83,-95 z\"\r\n   class=\"fil0\" />\r\n\r\n   <path\r\n   id=\"path2906\"\r\n   d=\"m 45,379 c 31,-50 95,-37 117,-66 -16,34 -95,35 -117,66 z\"\r\n   class=\"fil0\" />\r\n\r\n  </g>\r\n    <path\r\n       id=\"path12826\"\r\n       stroke-linejoin=\"round\"\r\n       d=\"m 475.64,1011.9 c 0,263.22 -213.38,476.6 -476.6,476.6 -263.22,0 -476.6,-213.38 -476.6,-476.6 0,-263.22 213.38,-476.6 476.6,-476.6 263.22,0 476.6,213.38 476.6,476.6 z\"\r\n       transform=\"matrix(1.1203,0,0,1.0186,1.5554,-22.824)\"\r\n       stroke=\"#f7c608\"\r\n       stroke-linecap=\"round\"\r\n       stroke-width=\"8.1208\"\r\n       fill=\"none\" />\r\n    <g\r\n       id=\"g12874\"\r\n       transform=\"matrix(1.089,0.29066,-0.31969,0.99014,322.08,9.1715)\">\r\n      <path\r\n         id=\"path12861\"\r\n         fill=\"#f7c608\"\r\n         d=\"m 44.747,1486.1 v 6 c 0,4 -3.002,7 -7.004,8 -10.005,0 -23.011,1 -35.017,1 l -3e-4,-38 c 13.006,0 26.013,-1 35.017,-2 4.002,0 7.004,3 7.004,7 v 5 m -84.042,1 v -6 c 0,-4 3.001,-7 7.003,-7 10.005,1 22.011,2 35.018,2 l -3e-4,38 c -12.006,0 -24.012,0 -35.018,-1 -4.002,-1 -7.003,-8 -7.003,-12\" />\r\n      <path\r\n         id=\"path12865\"\r\n         fill=\"#006233\"\r\n         d=\"m 37.554,1484.9 v 4.3 c 0,2.9 -2.497,5 -5.825,5.7 -8.321,0 -19.139,0.7 -29.124,0.7 l -4e-4,-27.2 c 10.817,0 21.635,-0.7 29.124,-1.4 3.328,0 5.825,2.1 5.825,5 v 3.6 m -69.898,0.7 v -4.3 c 0,-2.9 2.496,-5 5.825,-5 8.321,0.7 18.306,1.4 29.124,1.4 l -4e-4,27.2 c -9.9854,0 -19.971,0 -29.124,-0.7 -3.329,-0.7 -5.825,-5.7 -5.825,-8.6\" />\r\n    </g>\r\n    <g\r\n       id=\"g12878\"\r\n       transform=\"matrix(0.95488,0.55779,-0.6135,0.86818,618.66,131.41)\">\r\n      <path\r\n         id=\"path12880\"\r\n         fill=\"#f7c608\"\r\n         d=\"m 44.747,1486.1 v 6 c 0,4 -3.002,7 -7.004,8 -10.005,0 -23.011,1 -35.017,1 l -3e-4,-38 c 13.006,0 26.013,-1 35.017,-2 4.002,0 7.004,3 7.004,7 v 5 m -84.042,1 v -6 c 0,-4 3.001,-7 7.003,-7 10.005,1 22.011,2 35.018,2 l -3e-4,38 c -12.006,0 -24.012,0 -35.018,-1 -4.002,-1 -7.003,-8 -7.003,-12\" />\r\n      <path\r\n         id=\"path12882\"\r\n         fill=\"#006233\"\r\n         d=\"m 37.554,1484.9 v 4.3 c 0,2.9 -2.497,5 -5.825,5.7 -8.321,0 -19.139,0.7 -29.124,0.7 l -4e-4,-27.2 c 10.817,0 21.635,-0.7 29.124,-1.4 3.328,0 5.825,2.1 5.825,5 v 3.6 m -69.898,0.7 v -4.3 c 0,-2.9 2.496,-5 5.825,-5 8.321,0.7 18.306,1.4 29.124,1.4 l -4e-4,27.2 c -9.9854,0 -19.971,0 -29.124,-0.7 -3.329,-0.7 -5.825,-5.7 -5.825,-8.6\" />\r\n    </g>\r\n    <g\r\n       id=\"g12884\"\r\n       transform=\"matrix(0.74342,0.77974,-0.85762,0.67591,865.37,324.65)\">\r\n      <path\r\n         id=\"path12886\"\r\n         fill=\"#f7c608\"\r\n         d=\"m 44.747,1486.1 v 6 c 0,4 -3.002,7 -7.004,8 -10.005,0 -23.011,1 -35.017,1 l -3e-4,-38 c 13.006,0 26.013,-1 35.017,-2 4.002,0 7.004,3 7.004,7 v 5 m -84.042,1 v -6 c 0,-4 3.001,-7 7.003,-7 10.005,1 22.011,2 35.018,2 l -3e-4,38 c -12.006,0 -24.012,0 -35.018,-1 -4.002,-1 -7.003,-8 -7.003,-12\" />\r\n      <path\r\n         id=\"path12888\"\r\n         fill=\"#006233\"\r\n         d=\"m 37.554,1484.9 v 4.3 c 0,2.9 -2.497,5 -5.825,5.7 -8.321,0 -19.139,0.7 -29.124,0.7 l -4e-4,-27.2 c 10.817,0 21.635,-0.7 29.124,-1.4 3.328,0 5.825,2.1 5.825,5 v 3.6 m -69.898,0.7 v -4.3 c 0,-2.9 2.496,-5 5.825,-5 8.321,0.7 18.306,1.4 29.124,1.4 l -4e-4,27.2 c -9.9854,0 -19.971,0 -29.124,-0.7 -3.329,-0.7 -5.825,-5.7 -5.825,-8.6\" />\r\n    </g>\r\n    <g\r\n       id=\"g12890\"\r\n       transform=\"matrix(0.47175,0.93856,-1.0323,0.42891,1042.2,573.25)\">\r\n      <path\r\n         id=\"path12892\"\r\n         fill=\"#f7c608\"\r\n         d=\"m 44.747,1486.1 v 6 c 0,4 -3.002,7 -7.004,8 -10.005,0 -23.011,1 -35.017,1 l -3e-4,-38 c 13.006,0 26.013,-1 35.017,-2 4.002,0 7.004,3 7.004,7 v 5 m -84.042,1 v -6 c 0,-4 3.001,-7 7.003,-7 10.005,1 22.011,2 35.018,2 l -3e-4,38 c -12.006,0 -24.012,0 -35.018,-1 -4.002,-1 -7.003,-8 -7.003,-12\" />\r\n      <path\r\n         id=\"path12894\"\r\n         fill=\"#006233\"\r\n         d=\"m 37.554,1484.9 v 4.3 c 0,2.9 -2.497,5 -5.825,5.7 -8.321,0 -19.139,0.7 -29.124,0.7 l -4e-4,-27.2 c 10.817,0 21.635,-0.7 29.124,-1.4 3.328,0 5.825,2.1 5.825,5 v 3.6 m -69.898,0.7 v -4.3 c 0,-2.9 2.496,-5 5.825,-5 8.321,0.7 18.306,1.4 29.124,1.4 l -4e-4,27.2 c -9.9854,0 -19.971,0 -29.124,-0.7 -3.329,-0.7 -5.825,-5.7 -5.825,-8.6\" />\r\n    </g>\r\n    <g\r\n       id=\"g12896\"\r\n       transform=\"matrix(0.16188,1.0214,-1.1234,0.14718,1134.9,857.07)\">\r\n      <path\r\n         id=\"path12898\"\r\n         fill=\"#f7c608\"\r\n         d=\"m 44.747,1486.1 v 6 c 0,4 -3.002,7 -7.004,8 -10.005,0 -23.011,1 -35.017,1 l -3e-4,-38 c 13.006,0 26.013,-1 35.017,-2 4.002,0 7.004,3 7.004,7 v 5 m -84.042,1 v -6 c 0,-4 3.001,-7 7.003,-7 10.005,1 22.011,2 35.018,2 l -3e-4,38 c -12.006,0 -24.012,0 -35.018,-1 -4.002,-1 -7.003,-8 -7.003,-12\" />\r\n      <path\r\n         id=\"path12900\"\r\n         fill=\"#006233\"\r\n         d=\"m 37.554,1484.9 v 4.3 c 0,2.9 -2.497,5 -5.825,5.7 -8.321,0 -19.139,0.7 -29.124,0.7 l -4e-4,-27.2 c 10.817,0 21.635,-0.7 29.124,-1.4 3.328,0 5.825,2.1 5.825,5 v 3.6 m -69.898,0.7 v -4.3 c 0,-2.9 2.496,-5 5.825,-5 8.321,0.7 18.306,1.4 29.124,1.4 l -4e-4,27.2 c -9.9854,0 -19.971,0 -29.124,-0.7 -3.329,-0.7 -5.825,-5.7 -5.825,-8.6\" />\r\n    </g>\r\n    <g\r\n       id=\"g12902\"\r\n       transform=\"matrix(-0.1611,1.0215,-1.1235,-0.14647,1135.9,1153.1)\">\r\n      <path\r\n         id=\"path12904\"\r\n         fill=\"#f7c608\"\r\n         d=\"m 44.747,1486.1 v 6 c 0,4 -3.002,7 -7.004,8 -10.005,0 -23.011,1 -35.017,1 l -3e-4,-38 c 13.006,0 26.013,-1 35.017,-2 4.002,0 7.004,3 7.004,7 v 5 m -84.042,1 v -6 c 0,-4 3.001,-7 7.003,-7 10.005,1 22.011,2 35.018,2 l -3e-4,38 c -12.006,0 -24.012,0 -35.018,-1 -4.002,-1 -7.003,-8 -7.003,-12\" />\r\n      <path\r\n         id=\"path12906\"\r\n         fill=\"#006233\"\r\n         d=\"m 37.554,1484.9 v 4.3 c 0,2.9 -2.497,5 -5.825,5.7 -8.321,0 -19.139,0.7 -29.124,0.7 l -4e-4,-27.2 c 10.817,0 21.635,-0.7 29.124,-1.4 3.328,0 5.825,2.1 5.825,5 v 3.6 m -69.898,0.7 v -4.3 c 0,-2.9 2.496,-5 5.825,-5 8.321,0.7 18.306,1.4 29.124,1.4 l -4e-4,27.2 c -9.9854,0 -19.971,0 -29.124,-0.7 -3.329,-0.7 -5.825,-5.7 -5.825,-8.6\" />\r\n    </g>\r\n    <g\r\n       id=\"g12908\"\r\n       transform=\"matrix(-0.47103,0.93886,-1.0326,-0.42826,1045.1,1437.5)\">\r\n      <path\r\n         id=\"path12910\"\r\n         fill=\"#f7c608\"\r\n         d=\"m 44.747,1486.1 v 6 c 0,4 -3.002,7 -7.004,8 -10.005,0 -23.011,1 -35.017,1 l -3e-4,-38 c 13.006,0 26.013,-1 35.017,-2 4.002,0 7.004,3 7.004,7 v 5 m -84.042,1 v -6 c 0,-4 3.001,-7 7.003,-7 10.005,1 22.011,2 35.018,2 l -3e-4,38 c -12.006,0 -24.012,0 -35.018,-1 -4.002,-1 -7.003,-8 -7.003,-12\" />\r\n      <path\r\n         id=\"path12912\"\r\n         fill=\"#006233\"\r\n         d=\"m 37.554,1484.9 v 4.3 c 0,2.9 -2.497,5 -5.825,5.7 -8.321,0 -19.139,0.7 -29.124,0.7 l -4e-4,-27.2 c 10.817,0 21.635,-0.7 29.124,-1.4 3.328,0 5.825,2.1 5.825,5 v 3.6 m -69.898,0.7 v -4.3 c 0,-2.9 2.496,-5 5.825,-5 8.321,0.7 18.306,1.4 29.124,1.4 l -4e-4,27.2 c -9.9854,0 -19.971,0 -29.124,-0.7 -3.329,-0.7 -5.825,-5.7 -5.825,-8.6\" />\r\n    </g>\r\n    <g\r\n       id=\"g12914\"\r\n       transform=\"matrix(-0.74282,0.78021,-0.85814,-0.67537,869.95,1687)\">\r\n      <path\r\n         id=\"path12916\"\r\n         fill=\"#f7c608\"\r\n         d=\"m 44.747,1486.1 v 6 c 0,4 -3.002,7 -7.004,8 -10.005,0 -23.011,1 -35.017,1 l -3e-4,-38 c 13.006,0 26.013,-1 35.017,-2 4.002,0 7.004,3 7.004,7 v 5 m -84.042,1 v -6 c 0,-4 3.001,-7 7.003,-7 10.005,1 22.011,2 35.018,2 l -3e-4,38 c -12.006,0 -24.012,0 -35.018,-1 -4.002,-1 -7.003,-8 -7.003,-12\" />\r\n      <path\r\n         id=\"path12918\"\r\n         fill=\"#006233\"\r\n         d=\"m 37.554,1484.9 v 4.3 c 0,2.9 -2.497,5 -5.825,5.7 -8.321,0 -19.139,0.7 -29.124,0.7 l -4e-4,-27.2 c 10.817,0 21.635,-0.7 29.124,-1.4 3.328,0 5.825,2.1 5.825,5 v 3.6 m -69.898,0.7 v -4.3 c 0,-2.9 2.496,-5 5.825,-5 8.321,0.7 18.306,1.4 29.124,1.4 l -4e-4,27.2 c -9.9854,0 -19.971,0 -29.124,-0.7 -3.329,-0.7 -5.825,-5.7 -5.825,-8.6\" />\r\n    </g>\r\n    <g\r\n       id=\"g12920\"\r\n       transform=\"matrix(-0.95446,0.55839,-0.61416,-0.86779,624.54,1881.6)\">\r\n      <path\r\n         id=\"path12922\"\r\n         fill=\"#f7c608\"\r\n         d=\"m 44.747,1486.1 v 6 c 0,4 -3.002,7 -7.004,8 -10.005,0 -23.011,1 -35.017,1 l -3e-4,-38 c 13.006,0 26.013,-1 35.017,-2 4.002,0 7.004,3 7.004,7 v 5 m -84.042,1 v -6 c 0,-4 3.001,-7 7.003,-7 10.005,1 22.011,2 35.018,2 l -3e-4,38 c -12.006,0 -24.012,0 -35.018,-1 -4.002,-1 -7.003,-8 -7.003,-12\" />\r\n      <path\r\n         id=\"path12924\"\r\n         fill=\"#006233\"\r\n         d=\"m 37.554,1484.9 v 4.3 c 0,2.9 -2.497,5 -5.825,5.7 -8.321,0 -19.139,0.7 -29.124,0.7 l -4e-4,-27.2 c 10.817,0 21.635,-0.7 29.124,-1.4 3.328,0 5.825,2.1 5.825,5 v 3.6 m -69.898,0.7 v -4.3 c 0,-2.9 2.496,-5 5.825,-5 8.321,0.7 18.306,1.4 29.124,1.4 l -4e-4,27.2 c -9.9854,0 -19.971,0 -29.124,-0.7 -3.329,-0.7 -5.825,-5.7 -5.825,-8.6\" />\r\n    </g>\r\n    <g\r\n       id=\"g12926\"\r\n       transform=\"matrix(-1.0888,0.29135,-0.32045,-0.98993,328.78,2005.5)\">\r\n      <path\r\n         id=\"path12928\"\r\n         fill=\"#f7c608\"\r\n         d=\"m 44.747,1486.1 v 6 c 0,4 -3.002,7 -7.004,8 -10.005,0 -23.011,1 -35.017,1 l -3e-4,-38 c 13.006,0 26.013,-1 35.017,-2 4.002,0 7.004,3 7.004,7 v 5 m -84.042,1 v -6 c 0,-4 3.001,-7 7.003,-7 10.005,1 22.011,2 35.018,2 l -3e-4,38 c -12.006,0 -24.012,0 -35.018,-1 -4.002,-1 -7.003,-8 -7.003,-12\" />\r\n      <path\r\n         id=\"path12930\"\r\n         fill=\"#006233\"\r\n         d=\"m 37.554,1484.9 v 4.3 c 0,2.9 -2.497,5 -5.825,5.7 -8.321,0 -19.139,0.7 -29.124,0.7 l -4e-4,-27.2 c 10.817,0 21.635,-0.7 29.124,-1.4 3.328,0 5.825,2.1 5.825,5 v 3.6 m -69.898,0.7 v -4.3 c 0,-2.9 2.496,-5 5.825,-5 8.321,0.7 18.306,1.4 29.124,1.4 l -4e-4,27.2 c -9.9854,0 -19.971,0 -29.124,-0.7 -3.329,-0.7 -5.825,-5.7 -5.825,-8.6\" />\r\n    </g>\r\n    <g\r\n       id=\"g12932\"\r\n       transform=\"matrix(-1.135,7.2019e-4,-7.9212e-4,-1.0319,6.6183,2048.7)\">\r\n      <path\r\n         id=\"path12934\"\r\n         fill=\"#f7c608\"\r\n         d=\"m 44.747,1486.1 v 6 c 0,4 -3.002,7 -7.004,8 -10.005,0 -23.011,1 -35.017,1 l -3e-4,-38 c 13.006,0 26.013,-1 35.017,-2 4.002,0 7.004,3 7.004,7 v 5 m -84.042,1 v -6 c 0,-4 3.001,-7 7.003,-7 10.005,1 22.011,2 35.018,2 l -3e-4,38 c -12.006,0 -24.012,0 -35.018,-1 -4.002,-1 -7.003,-8 -7.003,-12\" />\r\n      <path\r\n         id=\"path12936\"\r\n         fill=\"#006233\"\r\n         d=\"m 37.554,1484.9 v 4.3 c 0,2.9 -2.497,5 -5.825,5.7 -8.321,0 -19.139,0.7 -29.124,0.7 l -4e-4,-27.2 c 10.817,0 21.635,-0.7 29.124,-1.4 3.328,0 5.825,2.1 5.825,5 v 3.6 m -69.898,0.7 v -4.3 c 0,-2.9 2.496,-5 5.825,-5 8.321,0.7 18.306,1.4 29.124,1.4 l -4e-4,27.2 c -9.9854,0 -19.971,0 -29.124,-0.7 -3.329,-0.7 -5.825,-5.7 -5.825,-8.6\" />\r\n    </g>\r\n    <g\r\n       id=\"g12938\"\r\n       transform=\"matrix(-1.0918,-0.28208,0.31025,-0.99262,-313.06,2009.9)\">\r\n      <path\r\n         id=\"path12940\"\r\n         fill=\"#f7c608\"\r\n         d=\"m 44.747,1486.1 v 6 c 0,4 -3.002,7 -7.004,8 -10.005,0 -23.011,1 -35.017,1 l -3e-4,-38 c 13.006,0 26.013,-1 35.017,-2 4.002,0 7.004,3 7.004,7 v 5 m -84.042,1 v -6 c 0,-4 3.001,-7 7.003,-7 10.005,1 22.011,2 35.018,2 l -3e-4,38 c -12.006,0 -24.012,0 -35.018,-1 -4.002,-1 -7.003,-8 -7.003,-12\" />\r\n      <path\r\n         id=\"path12942\"\r\n         fill=\"#006233\"\r\n         d=\"m 37.554,1484.9 v 4.3 c 0,2.9 -2.497,5 -5.825,5.7 -8.321,0 -19.139,0.7 -29.124,0.7 l -4e-4,-27.2 c 10.817,0 21.635,-0.7 29.124,-1.4 3.328,0 5.825,2.1 5.825,5 v 3.6 m -69.898,0.7 v -4.3 c 0,-2.9 2.496,-5 5.825,-5 8.321,0.7 18.306,1.4 29.124,1.4 l -4e-4,27.2 c -9.9854,0 -19.971,0 -29.124,-0.7 -3.329,-0.7 -5.825,-5.7 -5.825,-8.6\" />\r\n    </g>\r\n    <g\r\n       id=\"g12944\"\r\n       transform=\"matrix(-0.96016,-0.55025,0.60521,-0.87297,-610.8,1890)\">\r\n      <path\r\n         id=\"path12946\"\r\n         fill=\"#f7c608\"\r\n         d=\"m 44.747,1486.1 v 6 c 0,4 -3.002,7 -7.004,8 -10.005,0 -23.011,1 -35.017,1 l -3e-4,-38 c 13.006,0 26.013,-1 35.017,-2 4.002,0 7.004,3 7.004,7 v 5 m -84.042,1 v -6 c 0,-4 3.001,-7 7.003,-7 10.005,1 22.011,2 35.018,2 l -3e-4,38 c -12.006,0 -24.012,0 -35.018,-1 -4.002,-1 -7.003,-8 -7.003,-12\" />\r\n      <path\r\n         id=\"path12948\"\r\n         fill=\"#006233\"\r\n         d=\"m 37.554,1484.9 v 4.3 c 0,2.9 -2.497,5 -5.825,5.7 -8.321,0 -19.139,0.7 -29.124,0.7 l -4e-4,-27.2 c 10.817,0 21.635,-0.7 29.124,-1.4 3.328,0 5.825,2.1 5.825,5 v 3.6 m -69.898,0.7 v -4.3 c 0,-2.9 2.496,-5 5.825,-5 8.321,0.7 18.306,1.4 29.124,1.4 l -4e-4,27.2 c -9.9854,0 -19.971,0 -29.124,-0.7 -3.329,-0.7 -5.825,-5.7 -5.825,-8.6\" />\r\n    </g>\r\n    <g\r\n       id=\"g12950\"\r\n       transform=\"matrix(-0.75081,-0.77386,0.85115,-0.68264,-859.34,1698.7)\">\r\n      <path\r\n         id=\"path12952\"\r\n         fill=\"#f7c608\"\r\n         d=\"m 44.747,1486.1 v 6 c 0,4 -3.002,7 -7.004,8 -10.005,0 -23.011,1 -35.017,1 l -3e-4,-38 c 13.006,0 26.013,-1 35.017,-2 4.002,0 7.004,3 7.004,7 v 5 m -84.042,1 v -6 c 0,-4 3.001,-7 7.003,-7 10.005,1 22.011,2 35.018,2 l -3e-4,38 c -12.006,0 -24.012,0 -35.018,-1 -4.002,-1 -7.003,-8 -7.003,-12\" />\r\n      <path\r\n         id=\"path12954\"\r\n         fill=\"#006233\"\r\n         d=\"m 37.554,1484.9 v 4.3 c 0,2.9 -2.497,5 -5.825,5.7 -8.321,0 -19.139,0.7 -29.124,0.7 l -4e-4,-27.2 c 10.817,0 21.635,-0.7 29.124,-1.4 3.328,0 5.825,2.1 5.825,5 v 3.6 m -69.898,0.7 v -4.3 c 0,-2.9 2.496,-5 5.825,-5 8.321,0.7 18.306,1.4 29.124,1.4 l -4e-4,27.2 c -9.9854,0 -19.971,0 -29.124,-0.7 -3.329,-0.7 -5.825,-5.7 -5.825,-8.6\" />\r\n    </g>\r\n    <g\r\n       id=\"g12956\"\r\n       transform=\"matrix(-0.48067,-0.93481,1.0282,-0.43702,-1038.6,1451.5)\">\r\n      <path\r\n         id=\"path12958\"\r\n         fill=\"#f7c608\"\r\n         d=\"m 44.747,1486.1 v 6 c 0,4 -3.002,7 -7.004,8 -10.005,0 -23.011,1 -35.017,1 l -3e-4,-38 c 13.006,0 26.013,-1 35.017,-2 4.002,0 7.004,3 7.004,7 v 5 m -84.042,1 v -6 c 0,-4 3.001,-7 7.003,-7 10.005,1 22.011,2 35.018,2 l -3e-4,38 c -12.006,0 -24.012,0 -35.018,-1 -4.002,-1 -7.003,-8 -7.003,-12\" />\r\n      <path\r\n         id=\"path12960\"\r\n         fill=\"#006233\"\r\n         d=\"m 37.554,1484.9 v 4.3 c 0,2.9 -2.497,5 -5.825,5.7 -8.321,0 -19.139,0.7 -29.124,0.7 l -4e-4,-27.2 c 10.817,0 21.635,-0.7 29.124,-1.4 3.328,0 5.825,2.1 5.825,5 v 3.6 m -69.898,0.7 v -4.3 c 0,-2.9 2.496,-5 5.825,-5 8.321,0.7 18.306,1.4 29.124,1.4 l -4e-4,27.2 c -9.9854,0 -19.971,0 -29.124,-0.7 -3.329,-0.7 -5.825,-5.7 -5.825,-8.6\" />\r\n    </g>\r\n    <g\r\n       id=\"g12962\"\r\n       transform=\"matrix(-0.1716,-1.0201,1.1219,-0.15602,-1133.9,1168.4)\">\r\n      <path\r\n         id=\"path12964\"\r\n         fill=\"#f7c608\"\r\n         d=\"m 44.747,1486.1 v 6 c 0,4 -3.002,7 -7.004,8 -10.005,0 -23.011,1 -35.017,1 l -3e-4,-38 c 13.006,0 26.013,-1 35.017,-2 4.002,0 7.004,3 7.004,7 v 5 m -84.042,1 v -6 c 0,-4 3.001,-7 7.003,-7 10.005,1 22.011,2 35.018,2 l -3e-4,38 c -12.006,0 -24.012,0 -35.018,-1 -4.002,-1 -7.003,-8 -7.003,-12\" />\r\n      <path\r\n         id=\"path12966\"\r\n         fill=\"#006233\"\r\n         d=\"m 37.554,1484.9 v 4.3 c 0,2.9 -2.497,5 -5.825,5.7 -8.321,0 -19.139,0.7 -29.124,0.7 l -4e-4,-27.2 c 10.817,0 21.635,-0.7 29.124,-1.4 3.328,0 5.825,2.1 5.825,5 v 3.6 m -69.898,0.7 v -4.3 c 0,-2.9 2.496,-5 5.825,-5 8.321,0.7 18.306,1.4 29.124,1.4 l -4e-4,27.2 c -9.9854,0 -19.971,0 -29.124,-0.7 -3.329,-0.7 -5.825,-5.7 -5.825,-8.6\" />\r\n    </g>\r\n    <g\r\n       id=\"g12968\"\r\n       transform=\"matrix(0.15136,-1.0227,1.1248,0.13762,-1137.7,872.37)\">\r\n      <path\r\n         id=\"path12970\"\r\n         fill=\"#f7c608\"\r\n         d=\"m 44.747,1486.1 v 6 c 0,4 -3.002,7 -7.004,8 -10.005,0 -23.011,1 -35.017,1 l -3e-4,-38 c 13.006,0 26.013,-1 35.017,-2 4.002,0 7.004,3 7.004,7 v 5 m -84.042,1 v -6 c 0,-4 3.001,-7 7.003,-7 10.005,1 22.011,2 35.018,2 l -3e-4,38 c -12.006,0 -24.012,0 -35.018,-1 -4.002,-1 -7.003,-8 -7.003,-12\" />\r\n      <path\r\n         id=\"path12972\"\r\n         fill=\"#006233\"\r\n         d=\"m 37.554,1484.9 v 4.3 c 0,2.9 -2.497,5 -5.825,5.7 -8.321,0 -19.139,0.7 -29.124,0.7 l -4e-4,-27.2 c 10.817,0 21.635,-0.7 29.124,-1.4 3.328,0 5.825,2.1 5.825,5 v 3.6 m -69.898,0.7 v -4.3 c 0,-2.9 2.496,-5 5.825,-5 8.321,0.7 18.306,1.4 29.124,1.4 l -4e-4,27.2 c -9.9854,0 -19.971,0 -29.124,-0.7 -3.329,-0.7 -5.825,-5.7 -5.825,-8.6\" />\r\n    </g>\r\n    <g\r\n       id=\"g12974\"\r\n       transform=\"matrix(0.46207,-0.94253,1.0367,0.42011,-1049.7,587.33)\">\r\n      <path\r\n         id=\"path12976\"\r\n         fill=\"#f7c608\"\r\n         d=\"m 44.747,1486.1 v 6 c 0,4 -3.002,7 -7.004,8 -10.005,0 -23.011,1 -35.017,1 l -3e-4,-38 c 13.006,0 26.013,-1 35.017,-2 4.002,0 7.004,3 7.004,7 v 5 m -84.042,1 v -6 c 0,-4 3.001,-7 7.003,-7 10.005,1 22.011,2 35.018,2 l -3e-4,38 c -12.006,0 -24.012,0 -35.018,-1 -4.002,-1 -7.003,-8 -7.003,-12\" />\r\n      <path\r\n         id=\"path12978\"\r\n         fill=\"#006233\"\r\n         d=\"m 37.554,1484.9 v 4.3 c 0,2.9 -2.497,5 -5.825,5.7 -8.321,0 -19.139,0.7 -29.124,0.7 l -4e-4,-27.2 c 10.817,0 21.635,-0.7 29.124,-1.4 3.328,0 5.825,2.1 5.825,5 v 3.6 m -69.898,0.7 v -4.3 c 0,-2.9 2.496,-5 5.825,-5 8.321,0.7 18.306,1.4 29.124,1.4 l -4e-4,27.2 c -9.9854,0 -19.971,0 -29.124,-0.7 -3.329,-0.7 -5.825,-5.7 -5.825,-8.6\" />\r\n    </g>\r\n    <g\r\n       id=\"g12980\"\r\n       transform=\"matrix(0.73536,-0.78603,0.86454,0.66859,-876.89,336.39)\">\r\n      <path\r\n         id=\"path12982\"\r\n         fill=\"#f7c608\"\r\n         d=\"m 44.747,1486.1 v 6 c 0,4 -3.002,7 -7.004,8 -10.005,0 -23.011,1 -35.017,1 l -3e-4,-38 c 13.006,0 26.013,-1 35.017,-2 4.002,0 7.004,3 7.004,7 v 5 m -84.042,1 v -6 c 0,-4 3.001,-7 7.003,-7 10.005,1 22.011,2 35.018,2 l -3e-4,38 c -12.006,0 -24.012,0 -35.018,-1 -4.002,-1 -7.003,-8 -7.003,-12\" />\r\n      <path\r\n         id=\"path12984\"\r\n         fill=\"#006233\"\r\n         d=\"m 37.554,1484.9 v 4.3 c 0,2.9 -2.497,5 -5.825,5.7 -8.321,0 -19.139,0.7 -29.124,0.7 l -4e-4,-27.2 c 10.817,0 21.635,-0.7 29.124,-1.4 3.328,0 5.825,2.1 5.825,5 v 3.6 m -69.898,0.7 v -4.3 c 0,-2.9 2.496,-5 5.825,-5 8.321,0.7 18.306,1.4 29.124,1.4 l -4e-4,27.2 c -9.9854,0 -19.971,0 -29.124,-0.7 -3.329,-0.7 -5.825,-5.7 -5.825,-8.6\" />\r\n    </g>\r\n    <g\r\n       id=\"g12986\"\r\n       transform=\"matrix(0.9491,-0.56588,0.6224,0.86292,-633.34,139.86)\">\r\n      <path\r\n         id=\"path12988\"\r\n         fill=\"#f7c608\"\r\n         d=\"m 44.747,1486.1 v 6 c 0,4 -3.002,7 -7.004,8 -10.005,0 -23.011,1 -35.017,1 l -3e-4,-38 c 13.006,0 26.013,-1 35.017,-2 4.002,0 7.004,3 7.004,7 v 5 m -84.042,1 v -6 c 0,-4 3.001,-7 7.003,-7 10.005,1 22.011,2 35.018,2 l -3e-4,38 c -12.006,0 -24.012,0 -35.018,-1 -4.002,-1 -7.003,-8 -7.003,-12\" />\r\n      <path\r\n         id=\"path12990\"\r\n         fill=\"#006233\"\r\n         d=\"m 37.554,1484.9 v 4.3 c 0,2.9 -2.497,5 -5.825,5.7 -8.321,0 -19.139,0.7 -29.124,0.7 l -4e-4,-27.2 c 10.817,0 21.635,-0.7 29.124,-1.4 3.328,0 5.825,2.1 5.825,5 v 3.6 m -69.898,0.7 v -4.3 c 0,-2.9 2.496,-5 5.825,-5 8.321,0.7 18.306,1.4 29.124,1.4 l -4e-4,27.2 c -9.9854,0 -19.971,0 -29.124,-0.7 -3.329,-0.7 -5.825,-5.7 -5.825,-8.6\" />\r\n    </g>\r\n    <g\r\n       id=\"g12992\"\r\n       transform=\"matrix(1.086,-0.29991,0.32987,0.98737,-338.77,13.655)\">\r\n      <path\r\n         id=\"path12994\"\r\n         fill=\"#f7c608\"\r\n         d=\"m 44.747,1486.1 v 6 c 0,4 -3.002,7 -7.004,8 -10.005,0 -23.011,1 -35.017,1 l -3e-4,-38 c 13.006,0 26.013,-1 35.017,-2 4.002,0 7.004,3 7.004,7 v 5 m -84.042,1 v -6 c 0,-4 3.001,-7 7.003,-7 10.005,1 22.011,2 35.018,2 l -3e-4,38 c -12.006,0 -24.012,0 -35.018,-1 -4.002,-1 -7.003,-8 -7.003,-12\" />\r\n      <path\r\n         id=\"path12996\"\r\n         fill=\"#006233\"\r\n         d=\"m 37.554,1484.9 v 4.3 c 0,2.9 -2.497,5 -5.825,5.7 -8.321,0 -19.139,0.7 -29.124,0.7 l -4e-4,-27.2 c 10.817,0 21.635,-0.7 29.124,-1.4 3.328,0 5.825,2.1 5.825,5 v 3.6 m -69.898,0.7 v -4.3 c 0,-2.9 2.496,-5 5.825,-5 8.321,0.7 18.306,1.4 29.124,1.4 l -4e-4,27.2 c -9.9854,0 -19.971,0 -29.124,-0.7 -3.329,-0.7 -5.825,-5.7 -5.825,-8.6\" />\r\n    </g>\r\n    <g\r\n       id=\"g12998\"\r\n       transform=\"matrix(1.1349,-0.0096543,0.010618,1.0319,-17.033,-32.001)\">\r\n      <path\r\n         id=\"path13000\"\r\n         fill=\"#f7c608\"\r\n         d=\"m 44.747,1486.1 v 6 c 0,4 -3.002,7 -7.004,8 -10.005,0 -23.011,1 -35.017,1 l -3e-4,-38 c 13.006,0 26.013,-1 35.017,-2 4.002,0 7.004,3 7.004,7 v 5 m -84.042,1 v -6 c 0,-4 3.001,-7 7.003,-7 10.005,1 22.011,2 35.018,2 l -3e-4,38 c -12.006,0 -24.012,0 -35.018,-1 -4.002,-1 -7.003,-8 -7.003,-12\" />\r\n      <path\r\n         id=\"path13002\"\r\n         fill=\"#006233\"\r\n         d=\"m 37.554,1484.9 v 4.3 c 0,2.9 -2.497,5 -5.825,5.7 -8.321,0 -19.139,0.7 -29.124,0.7 l -4e-4,-27.2 c 10.817,0 21.635,-0.7 29.124,-1.4 3.328,0 5.825,2.1 5.825,5 v 3.6 m -69.898,0.7 v -4.3 c 0,-2.9 2.496,-5 5.825,-5 8.321,0.7 18.306,1.4 29.124,1.4 l -4e-4,27.2 c -9.9854,0 -19.971,0 -29.124,-0.7 -3.329,-0.7 -5.825,-5.7 -5.825,-8.6\" />\r\n    </g>\r\n  </g>\r\n</svg>";

var ko$1 = "<svg xmlns=\"http://www.w3.org/2000/svg\" id=\"flag-icon-css-kr\" viewBox=\"0 0 640 480\">\n  <defs>\n    <clipPath id=\"kr-a\">\n      <path fill-opacity=\".7\" d=\"M-95.8-.4h682.7v512H-95.8z\"/>\n    </clipPath>\n  </defs>\n  <g fill-rule=\"evenodd\" clip-path=\"url(#kr-a)\" transform=\"translate(89.8 .4) scale(.9375)\">\n    <path fill=\"#fff\" d=\"M610.6 511.6h-730.2V-.4h730.2z\"/>\n    <path fill=\"#fff\" d=\"M251.9 256a112.5 112.5 0 11-225 0 112.5 112.5 0 01225 0z\"/>\n    <path fill=\"#c70000\" d=\"M393 262.6c0 81-65 146.8-145.3 146.8s-145.2-65.8-145.2-146.8 65-146.9 145.3-146.9S393 181.6 393 262.6z\"/>\n    <path d=\"M-49.4 126.4l83.6-96.7 19.9 17.1-83.7 96.8zm27.4 23.7l83.6-96.7 19.9 17-83.7 96.9z\"/>\n    <path d=\"M-49.4 126.4l83.6-96.7 19.9 17.1-83.7 96.8z\"/>\n    <path d=\"M-49.4 126.4l83.6-96.7 19.9 17.1-83.7 96.8zm55.4 48l83.6-96.9 19.9 17.2-83.7 96.8z\"/>\n    <path d=\"M-49.4 126.4l83.6-96.7 19.9 17.1-83.7 96.8z\"/>\n    <path d=\"M-49.4 126.4l83.6-96.7 19.9 17.1-83.7 96.8zm508.8-96.8l83 97.4-20 17-83-97.4zm-55.7 47.5l83 97.4-20 17-83-97.4z\"/>\n    <path fill=\"#fff\" d=\"M417.6 133.2L496 65.4l14.7 17-84 75.4-9.3-24.6z\"/>\n    <path d=\"M514.2 372l-80.4 95.8-19.7-16.4 80.4-95.8zM431.8 53.1l83 97.4-19.9 17L412 70zm109.7 341.6L461 490.5l-19.8-16.4 80.5-95.8zm-55.1-45.8L406 444.7l-19.7-16.4 80.4-95.8z\"/>\n    <path fill=\"#3d5897\" d=\"M104.6 236.7c4.6 37 11.3 78.2 68.2 82.4 21.3 1.3 62.8-5 77-63.2 18.8-55.8 75-71.8 113.3-41.6C385 228.5 391 251 392.4 268c-1.7 54-32.9 101-72.8 122-46 27.3-109.6 27.9-165.3-13.5-25.1-23.5-60.2-67-49.7-139.8z\"/>\n    <path fill=\"#fff\" d=\"M436 370.6l78.6 67.6-14.6 17-87.1-71.8 23-12.8z\"/>\n    <path d=\"M-1.9 357.2l83 97.3-20 17-83-97.3z\"/>\n    <path fill=\"#fff\" d=\"M-16.2 437.3l78.6-67.9 14.7 17-84 75.5-9.3-24.7z\"/>\n    <path d=\"M25.7 333.7l83 97.3-20 17-83-97.3zM-30 381.2l83 97.3-20 17-83-97.3z\"/>\n  </g>\n</svg>";

var ph$1 = "<svg xmlns=\"http://www.w3.org/2000/svg\" id=\"flag-icon-css-ph\" viewBox=\"0 0 640 480\">\n  <path fill=\"#0038a8\" d=\"M0 0h640v240H0z\"/>\n  <path fill=\"#ce1126\" d=\"M0 240h640v240H0z\"/>\n  <path fill=\"#fff\" d=\"M415.7 240L0 480V0\"/>\n  <g fill=\"#fcd116\">\n    <path stroke-width=\"1pt\" d=\"M26.7 42.4L41 55l16.6-9.2-7.4 17.5 14 13-19-1.6-8.1 17.2-4.3-18.5L14 71l16.3-10zm323.8 172.3l.4 19 18 6.3-18 6.2-.4 19-11.5-15.1-18.2 5.5 10.8-15.6-10.8-15.6 18.2 5.5zM37.2 388.1l8 17.2 19-1.6-13.9 13 7.4 17.5-16.6-9.1-14.4 12.4 3.6-18.7L14 409l18.9-2.4z\"/>\n    <path stroke-width=\"5.3\" d=\"M151.4 139.1l-6.2 6.2 3.1 47-3 .3-5.7-42.9-5.1 5 7.6 38.4a47.5 47.5 0 00-17.2 7.1l-21.7-32.4H96l26.4 34.3a48 48 0 00-2.4 2l-31.1-35.5h-8.8v8.8l35.4 31-2 2.5-34.3-26.3v7.1l32.5 21.7c-3.4 5.2-5.9 11-7.1 17.2L66.3 223l-5.1 5 42.9 5.7c-.2 1-.3 2.1-.3 3.1l-47-3-6.2 6.2 6.2 6.2 47-3.1.3 3.1-42.9 5.7 5 5 38.4-7.6a47.5 47.5 0 007.1 17.2l-32.5 21.7v7.2l34.3-26.3a48 48 0 002 2.4l-35.4 31v8.8H89l31-35.4 2.5 2L96 312.2h7.2l21.7-32.5c5.1 3.4 11 5.9 17.2 7.1l-7.6 38.4 5 5 5.7-42.9c1 .2 2 .3 3.1.3l-3 47 6.1 6.2 6.3-6.2-3.1-47 3-.3 5.7 43 5.1-5.1-7.6-38.4a47.5 47.5 0 0017.2-7.1l21.7 32.5h7.2l-26.4-34.3a48 48 0 002.4-2l31.1 35.4h8.8v-8.8l-35.4-31 2-2.4 34.3 26.3v-7.2l-32.5-21.7c3.4-5.1 5.9-11 7.1-17.2l38.3 7.6 5.1-5-42.9-5.7c.2-1 .3-2 .3-3.1l47 3 6.2-6.1-6.2-6.2-47 3-.3-3 42.9-5.7-5-5-38.4 7.5a47.5 47.5 0 00-7.1-17.2l32.5-21.7v-7.1l-34.3 26.3a48 48 0 00-2-2.4l35.4-31v-8.9H214l-31 35.5a48 48 0 00-2.5-2l26.4-34.3h-7.2L178 200.2c-5.1-3.4-11-5.9-17.2-7.1l7.6-38.3-5-5-5.7 42.8-3.1-.3 3-47z\"/>\n  </g>\n</svg>";

var tw = "<svg xmlns=\"http://www.w3.org/2000/svg\" id=\"flag-icon-css-tw\" viewBox=\"0 0 640 480\">\n  <defs>\n    <clipPath id=\"tw-a\">\n      <path fill-opacity=\".7\" d=\"M0 0h682.7v512H0z\"/>\n    </clipPath>\n  </defs>\n  <g fill-rule=\"evenodd\" stroke-width=\"1pt\" clip-path=\"url(#tw-a)\" transform=\"scale(.9375)\">\n    <path fill=\"#fe0000\" d=\"M0 0h768v512H0z\"/>\n    <path fill=\"#000095\" d=\"M0 0h385.7v256H0z\"/>\n    <path fill=\"#fff\" d=\"M282.1 178.6l-47.3-9.8 10 47.3-36-32.1-15 46-15.2-45.9-36 32.4 9.8-47.4-47.2 10.1 32-36.1-46-15 46-15.2-32.4-35.8 47.3 9.7-10-47.3 36 32.1 15-46 15.2 45.9 35.9-32.4-9.7 47.4 47.2-10.1-32 36.1 45.9 15-45.9 15.2z\"/>\n    <path fill=\"#000095\" d=\"M238.5 175l-15 7.9-14.5 8.6-17-.6-16.9.2-14.3-9L146 174l-8-15-8.6-14.5.6-16.8-.2-17 9-14.2 8.3-14.8 14.9-7.9 14.6-8.6 16.9.6 17-.2 14.3 9 14.7 8.2 8 14.9 8.6 14.5-.6 16.9.2 16.9-9 14.3z\"/>\n    <path fill=\"#fff\" d=\"M244.6 128.3a51.9 51.9 0 11-103.7 0 51.9 51.9 0 01103.7 0z\"/>\n  </g>\n</svg>";

var pl$1 = "<svg xmlns=\"http://www.w3.org/2000/svg\" id=\"flag-icon-css-pl\" viewBox=\"0 0 640 480\">\n  <g fill-rule=\"evenodd\">\n    <path fill=\"#fff\" d=\"M640 480H0V0h640z\"/>\n    <path fill=\"#dc143c\" d=\"M640 480H0V240h640z\"/>\n  </g>\n</svg>";

const flags$1 = {
	it: it$1,
	en: gb,
	es: es$1,
	de: de$1,
	fr: fr$1,
	id: id$1,
	pt: pt$1,
	pt_br: br,
	ru: ru$1,
	tr: tr$1,
	vn: vn$1,
	hr: hr$1,
	ar: ar$1,
	ko: ko$1,
	ph: ph$1,
	zh_tw: tw,
	pl: pl$1
};

//

var script$p = {
	data() {
		return {
			flags: flags$1,
			currentLocale: this.$i18n.locale,
			locales: this.$i18n.availableLocales,
			settings: {
				tags: {}
			},
			lastSettings: {},
			spotifyFeatures: {},
			lastCredentials: {},
			defaultSettings: {},
			lastUser: '',
			spotifyUser: '',
			slimDownloads: false,
			previewVolume: window.vol,
			accountNum: 0,
			accounts: []
		}
	},
	computed: {
		...mapGetters({
			arl: 'getARL',
			user: 'getUser',
			isLoggedIn: 'isLoggedIn',
			clientMode: 'getClientMode'
		}),
		needToWait() {
			return Object.keys(this.getSettings).length === 0
		},
		changeSlimDownloads: {
			get() {
				return this.slimDownloads
			},
			set(wantSlimDownloads) {
				this.slimDownloads = wantSlimDownloads;
				document.getElementById('download_list').classList.toggle('slim', wantSlimDownloads);
				localStorage.setItem('slimDownloads', wantSlimDownloads);
			}
		},
		pictureHref() {
			// Default image: https://e-cdns-images.dzcdn.net/images/user/125x125-000000-80-0-0.jpg
			return `https://e-cdns-images.dzcdn.net/images/user/${this.user.picture}/125x125-000000-80-0-0.jpg`
		}
	},
	async mounted() {
		const { settingsData, defaultSettingsData, spotifyCredentials } = await getSettingsData();

		this.defaultSettings = defaultSettingsData;
		this.initSettings(settingsData, spotifyCredentials);

		let storedAccountNum = localStorage.getItem('accountNum');

		if (storedAccountNum) {
			this.accountNum = storedAccountNum;
		}

		let spotifyUser = localStorage.getItem('spotifyUser');

		if (spotifyUser) {
			this.lastUser = spotifyUser;
			this.spotifyUser = spotifyUser;
			socket.emit('update_userSpotifyPlaylists', spotifyUser);
		}

		this.changeSlimDownloads = 'true' === localStorage.getItem('slimDownloads');

		let volume = parseInt(localStorage.getItem('previewVolume'));

		if (isNaN(volume)) {
			volume = 80;
			localStorage.setItem('previewVolume', volume);
		}

		window.vol.preview_max_volume = volume;

		socket.on('updateSettings', this.updateSettings);
		socket.on('accountChanged', this.accountChanged);
		socket.on('familyAccounts', this.initAccounts);
		socket.on('downloadFolderSelected', this.downloadFolderSelected);
		socket.on('applogin_arl', this.loggedInViaDeezer);

		this.$on('hook:destroyed', () => {
			socket.off('updateSettings');
			socket.off('accountChanged');
			socket.off('familyAccounts');
			socket.off('downloadFolderSelected');
			socket.off('applogin_arl');
		});
	},
	methods: {
		...mapActions({
			dispatchARL: 'setARL'
		}),
		revertSettings() {
			this.settings = JSON.parse(JSON.stringify(this.lastSettings));
		},
		revertCredentials() {
			this.spotifyCredentials = JSON.parse(JSON.stringify(this.lastCredentials));
			this.spotifyUser = (' ' + this.lastUser).slice(1);
		},
		copyARLtoClipboard() {
			let copyText = this.$refs.loginInput;

			copyText.setAttribute('type', 'text');
			copyText.select();
			copyText.setSelectionRange(0, 99999);
			document.execCommand('copy');
			copyText.setAttribute('type', 'password');

			toast(this.$t('settings.toasts.ARLcopied'), 'assignment');
		},
		changeLocale(newLocale) {
			this.$i18n.locale = newLocale;
			this.currentLocale = newLocale;
			localStorage.setItem('locale', newLocale);
		},
		updateMaxVolume() {
			localStorage.setItem('previewVolume', this.previewVolume.preview_max_volume);
		},
		saveSettings() {
			this.lastSettings = JSON.parse(JSON.stringify(this.settings));
			this.lastCredentials = JSON.parse(JSON.stringify(this.spotifyFeatures));

			let changed = false;

			if (this.lastUser != this.spotifyUser) {
				// force cloning without linking
				this.lastUser = (' ' + this.spotifyUser).slice(1);
				localStorage.setItem('spotifyUser', this.lastUser);
				changed = true;
			}

			socket.emit('saveSettings', this.lastSettings, this.lastCredentials, changed ? this.lastUser : false);
		},
		selectDownloadFolder() {
			socket.emit('selectDownloadFolder');
		},
		downloadFolderSelected(folder) {
			this.$set(this.settings, 'downloadLocation', folder);
		},
		loadSettings(data) {
			this.lastSettings = JSON.parse(JSON.stringify(data));
			this.settings = JSON.parse(JSON.stringify(data));
		},
		loadCredentials(credentials) {
			this.lastCredentials = JSON.parse(JSON.stringify(credentials));
			this.spotifyFeatures = JSON.parse(JSON.stringify(credentials));
		},
		loggedInViaDeezer(arl) {
			this.dispatchARL({ arl });
			socket.emit('login', arl, true, this.accountNum);
			// this.login()
		},
		login() {
			let newArl = this.$refs.loginInput.value.trim();

			if (newArl && newArl !== this.arl) {
				socket.emit('login', newArl, true, this.accountNum);
			}
		},
		appLogin(e) {
			socket.emit('applogin');
		},
		changeAccount() {
			socket.emit('changeAccount', this.accountNum);
		},
		accountChanged(user, accountNum) {
			this.$refs.username.innerText = user.name;
			this.$refs.userpicture.src = `https://e-cdns-images.dzcdn.net/images/user/${user.picture}/125x125-000000-80-0-0.jpg`;
			this.accountNum = accountNum;

			localStorage.setItem('accountNum', this.accountNum);
		},
		initAccounts(accounts) {
			this.accounts = accounts;
		},
		logout() {
			socket.emit('logout');
		},
		initSettings(settings, credentials) {
			// this.loadDefaultSettings()
			this.loadSettings(settings);
			this.loadCredentials(credentials);

			toast(this.$t('settings.toasts.init'), 'settings');
		},
		updateSettings(newSettings, newCredentials) {
			this.loadSettings(newSettings);
			this.loadCredentials(newCredentials);

			toast(this.$t('settings.toasts.update'), 'settings');
		},
		resetSettings() {
			this.settings = JSON.parse(JSON.stringify(this.defaultSettings));
		}
	}
};

/* script */
const __vue_script__$p = script$p;

/* template */
var __vue_render__$q = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c(
    "div",
    { ref: "root", staticClass: "fixed_footer", attrs: { id: "settings_tab" } },
    [
      _c("h1", { staticClass: "mb-8 text-5xl" }, [
        _vm._v(_vm._s(_vm.$t("settings.title")))
      ]),
      _vm._v(" "),
      _vm.isLoggedIn
        ? _c(
            "div",
            { ref: "loggedInInfo", attrs: { id: "logged_in_info" } },
            [
              _c("img", {
                ref: "userpicture",
                staticClass: "circle",
                attrs: {
                  id: "settings_picture",
                  src: _vm.pictureHref,
                  alt: "Profile Picture"
                }
              }),
              _vm._v(" "),
              _c(
                "i18n",
                { attrs: { path: "settings.login.loggedIn", tag: "p" } },
                [
                  _c(
                    "strong",
                    {
                      ref: "username",
                      attrs: { place: "username", id: "settings_username" }
                    },
                    [_vm._v(_vm._s(_vm.user.name || "not logged"))]
                  )
                ]
              ),
              _vm._v(" "),
              _c(
                "button",
                {
                  staticClass: "btn btn-primary",
                  attrs: { id: "settings_btn_logout" },
                  on: { click: _vm.logout }
                },
                [
                  _vm._v(
                    "\n\t\t\t" +
                      _vm._s(_vm.$t("settings.login.logout")) +
                      "\n\t\t"
                  )
                ]
              ),
              _vm._v(" "),
              _vm.accounts.length
                ? _c(
                    "select",
                    {
                      directives: [
                        {
                          name: "model",
                          rawName: "v-model",
                          value: _vm.accountNum,
                          expression: "accountNum"
                        }
                      ],
                      attrs: { id: "family_account" },
                      on: {
                        change: [
                          function($event) {
                            var $$selectedVal = Array.prototype.filter
                              .call($event.target.options, function(o) {
                                return o.selected
                              })
                              .map(function(o) {
                                var val = "_value" in o ? o._value : o.value;
                                return val
                              });
                            _vm.accountNum = $event.target.multiple
                              ? $$selectedVal
                              : $$selectedVal[0];
                          },
                          _vm.changeAccount
                        ]
                      }
                    },
                    _vm._l(_vm.accounts, function(account, i) {
                      return _c(
                        "option",
                        { key: account, domProps: { value: i.toString() } },
                        [_vm._v(_vm._s(account.BLOG_NAME))]
                      )
                    }),
                    0
                  )
                : _vm._e()
            ],
            1
          )
        : _vm._e(),
      _vm._v(" "),
      _c("div", { staticClass: "settings-group" }, [
        _c(
          "h3",
          {
            staticClass:
              "settings-group__header settings-group__header--with-icon"
          },
          [
            _c("i", { staticClass: "material-icons" }, [_vm._v("person")]),
            _vm._v(_vm._s(_vm.$t("settings.login.title")) + "\n\t\t")
          ]
        ),
        _vm._v(" "),
        _c("div", { staticClass: "inline-flex" }, [
          _c("input", {
            ref: "loginInput",
            attrs: {
              autocomplete: "off",
              type: "password",
              id: "login_input_arl",
              placeholder: "ARL"
            },
            domProps: { value: _vm.arl }
          }),
          _vm._v(" "),
          _c(
            "button",
            {
              staticClass: "ml-2 btn btn-primary btn-only-icon",
              attrs: { id: "settings_btn_copyArl" },
              on: { click: _vm.copyARLtoClipboard }
            },
            [_c("i", { staticClass: "material-icons" }, [_vm._v("assignment")])]
          )
        ]),
        _vm._v(" "),
        _c(
          "a",
          {
            attrs: {
              href:
                "https://codeberg.org/RemixDev/deemix/wiki/Getting-your-own-ARL",
              target: "_blank"
            }
          },
          [
            _vm._v(
              "\n\t\t\t" +
                _vm._s(_vm.$t("settings.login.arl.question")) +
                "\n\t\t"
            )
          ]
        ),
        _vm._v(" "),
        _vm.clientMode
          ? _c(
              "a",
              {
                attrs: { id: "settings_btn_applogin", href: "#" },
                on: { click: _vm.appLogin }
              },
              [
                _vm._v(
                  "\n\t\t\t" + _vm._s(_vm.$t("settings.login.login")) + "\n\t\t"
                )
              ]
            )
          : _vm._e(),
        _vm._v(" "),
        _c(
          "button",
          {
            staticClass: "btn btn-primary",
            staticStyle: { width: "100%" },
            attrs: { id: "settings_btn_updateArl" },
            on: { click: _vm.login }
          },
          [
            _vm._v(
              "\n\t\t\t" +
                _vm._s(_vm.$t("settings.login.arl.update")) +
                "\n\t\t"
            )
          ]
        )
      ]),
      _vm._v(" "),
      _c("div", { staticClass: "settings-group" }, [
        _c(
          "h3",
          {
            staticClass:
              "settings-group__header settings-group__header--with-icon"
          },
          [
            _c("i", { staticClass: "material-icons" }, [_vm._v("language")]),
            _vm._v(_vm._s(_vm.$t("settings.languages")) + "\n\t\t")
          ]
        ),
        _vm._v(" "),
        _c(
          "div",
          _vm._l(_vm.locales, function(locale) {
            return _c("span", {
              key: locale,
              staticClass: "locale-flag",
              class: { "locale-flag--current": _vm.currentLocale === locale },
              attrs: { title: locale },
              domProps: { innerHTML: _vm._s(_vm.flags[locale]) },
              on: {
                click: function($event) {
                  return _vm.changeLocale(locale)
                }
              }
            })
          }),
          0
        )
      ]),
      _vm._v(" "),
      _c("div", { staticClass: "settings-group" }, [
        _c(
          "h3",
          {
            staticClass:
              "settings-group__header settings-group__header--with-icon"
          },
          [
            _c("i", { staticClass: "material-icons" }, [_vm._v("web")]),
            _vm._v(_vm._s(_vm.$t("settings.appearance.title")) + "\n\t\t")
          ]
        ),
        _vm._v(" "),
        _c("label", { staticClass: "with_checkbox" }, [
          _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model",
                value: _vm.changeSlimDownloads,
                expression: "changeSlimDownloads"
              }
            ],
            attrs: { type: "checkbox" },
            domProps: {
              checked: Array.isArray(_vm.changeSlimDownloads)
                ? _vm._i(_vm.changeSlimDownloads, null) > -1
                : _vm.changeSlimDownloads
            },
            on: {
              change: function($event) {
                var $$a = _vm.changeSlimDownloads,
                  $$el = $event.target,
                  $$c = $$el.checked ? true : false;
                if (Array.isArray($$a)) {
                  var $$v = null,
                    $$i = _vm._i($$a, $$v);
                  if ($$el.checked) {
                    $$i < 0 && (_vm.changeSlimDownloads = $$a.concat([$$v]));
                  } else {
                    $$i > -1 &&
                      (_vm.changeSlimDownloads = $$a
                        .slice(0, $$i)
                        .concat($$a.slice($$i + 1)));
                  }
                } else {
                  _vm.changeSlimDownloads = $$c;
                }
              }
            }
          }),
          _vm._v(" "),
          _c("span", { staticClass: "checkbox_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.appearance.slimDownloadTab")))
          ])
        ])
      ]),
      _vm._v(" "),
      _c("div", { staticClass: "settings-group" }, [
        _c(
          "h3",
          {
            staticClass:
              "settings-group__header settings-group__header--with-icon"
          },
          [
            _c("i", { staticClass: "material-icons" }, [_vm._v("folder")]),
            _vm._v(_vm._s(_vm.$t("settings.downloadPath.title")) + "\n\t\t")
          ]
        ),
        _vm._v(" "),
        _c("div", { staticClass: "inline-flex" }, [
          _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model",
                value: _vm.settings.downloadLocation,
                expression: "settings.downloadLocation"
              }
            ],
            attrs: { autocomplete: "off", type: "text" },
            domProps: { value: _vm.settings.downloadLocation },
            on: {
              input: function($event) {
                if ($event.target.composing) {
                  return
                }
                _vm.$set(_vm.settings, "downloadLocation", $event.target.value);
              }
            }
          }),
          _vm._v(" "),
          _vm.clientMode
            ? _c(
                "button",
                {
                  staticClass: "ml-2 btn btn-primary btn-only-icon",
                  attrs: { id: "select_downloads_folder" },
                  on: { click: _vm.selectDownloadFolder }
                },
                [_c("i", { staticClass: "material-icons" }, [_vm._v("folder")])]
              )
            : _vm._e()
        ])
      ]),
      _vm._v(" "),
      _c("div", { staticClass: "settings-group" }, [
        _c(
          "h3",
          {
            staticClass:
              "settings-group__header settings-group__header--with-icon"
          },
          [
            _c("i", { staticClass: "material-icons" }, [
              _vm._v("font_download")
            ]),
            _vm._v(_vm._s(_vm.$t("settings.templates.title")) + "\n\t\t")
          ]
        ),
        _vm._v(" "),
        _c("p", [
          _vm._v(_vm._s(_vm.$t("settings.templates.tracknameTemplate")))
        ]),
        _vm._v(" "),
        _c("input", {
          directives: [
            {
              name: "model",
              rawName: "v-model",
              value: _vm.settings.tracknameTemplate,
              expression: "settings.tracknameTemplate"
            }
          ],
          attrs: { type: "text" },
          domProps: { value: _vm.settings.tracknameTemplate },
          on: {
            input: function($event) {
              if ($event.target.composing) {
                return
              }
              _vm.$set(_vm.settings, "tracknameTemplate", $event.target.value);
            }
          }
        }),
        _vm._v(" "),
        _c("p", [
          _vm._v(_vm._s(_vm.$t("settings.templates.albumTracknameTemplate")))
        ]),
        _vm._v(" "),
        _c("input", {
          directives: [
            {
              name: "model",
              rawName: "v-model",
              value: _vm.settings.albumTracknameTemplate,
              expression: "settings.albumTracknameTemplate"
            }
          ],
          attrs: { type: "text" },
          domProps: { value: _vm.settings.albumTracknameTemplate },
          on: {
            input: function($event) {
              if ($event.target.composing) {
                return
              }
              _vm.$set(
                _vm.settings,
                "albumTracknameTemplate",
                $event.target.value
              );
            }
          }
        }),
        _vm._v(" "),
        _c("p", [
          _vm._v(_vm._s(_vm.$t("settings.templates.playlistTracknameTemplate")))
        ]),
        _vm._v(" "),
        _c("input", {
          directives: [
            {
              name: "model",
              rawName: "v-model",
              value: _vm.settings.playlistTracknameTemplate,
              expression: "settings.playlistTracknameTemplate"
            }
          ],
          attrs: { type: "text" },
          domProps: { value: _vm.settings.playlistTracknameTemplate },
          on: {
            input: function($event) {
              if ($event.target.composing) {
                return
              }
              _vm.$set(
                _vm.settings,
                "playlistTracknameTemplate",
                $event.target.value
              );
            }
          }
        })
      ]),
      _vm._v(" "),
      _c("div", { staticClass: "settings-group" }, [
        _c(
          "h3",
          {
            staticClass:
              "settings-group__header settings-group__header--with-icon"
          },
          [
            _c("i", { staticClass: "material-icons" }, [
              _vm._v("create_new_folder")
            ]),
            _vm._v(_vm._s(_vm.$t("settings.folders.title")) + "\n\t\t")
          ]
        ),
        _vm._v(" "),
        _c("div", { staticClass: "settings-container" }, [
          _c("div", { staticClass: "settings-container__third" }, [
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.createPlaylistFolder,
                    expression: "settings.createPlaylistFolder"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.createPlaylistFolder)
                    ? _vm._i(_vm.settings.createPlaylistFolder, null) > -1
                    : _vm.settings.createPlaylistFolder
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.createPlaylistFolder,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(
                            _vm.settings,
                            "createPlaylistFolder",
                            $$a.concat([$$v])
                          );
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings,
                            "createPlaylistFolder",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings, "createPlaylistFolder", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.folders.createPlaylistFolder")))
              ])
            ]),
            _vm._v(" "),
            _vm.settings.createPlaylistFolder
              ? _c("div", { staticClass: "input_group" }, [
                  _c("p", { staticClass: "input_group_text" }, [
                    _vm._v(
                      _vm._s(_vm.$t("settings.folders.playlistNameTemplate"))
                    )
                  ]),
                  _vm._v(" "),
                  _c("input", {
                    directives: [
                      {
                        name: "model",
                        rawName: "v-model",
                        value: _vm.settings.playlistNameTemplate,
                        expression: "settings.playlistNameTemplate"
                      }
                    ],
                    attrs: { type: "text" },
                    domProps: { value: _vm.settings.playlistNameTemplate },
                    on: {
                      input: function($event) {
                        if ($event.target.composing) {
                          return
                        }
                        _vm.$set(
                          _vm.settings,
                          "playlistNameTemplate",
                          $event.target.value
                        );
                      }
                    }
                  })
                ])
              : _vm._e()
          ]),
          _vm._v(" "),
          _c("div", { staticClass: "settings-container__third" }, [
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.createArtistFolder,
                    expression: "settings.createArtistFolder"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.createArtistFolder)
                    ? _vm._i(_vm.settings.createArtistFolder, null) > -1
                    : _vm.settings.createArtistFolder
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.createArtistFolder,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(
                            _vm.settings,
                            "createArtistFolder",
                            $$a.concat([$$v])
                          );
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings,
                            "createArtistFolder",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings, "createArtistFolder", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.folders.createArtistFolder")))
              ])
            ]),
            _vm._v(" "),
            _vm.settings.createArtistFolder
              ? _c("div", { staticClass: "input_group" }, [
                  _c("p", { staticClass: "input_group_text" }, [
                    _vm._v(
                      _vm._s(_vm.$t("settings.folders.artistNameTemplate"))
                    )
                  ]),
                  _vm._v(" "),
                  _c("input", {
                    directives: [
                      {
                        name: "model",
                        rawName: "v-model",
                        value: _vm.settings.artistNameTemplate,
                        expression: "settings.artistNameTemplate"
                      }
                    ],
                    attrs: { type: "text" },
                    domProps: { value: _vm.settings.artistNameTemplate },
                    on: {
                      input: function($event) {
                        if ($event.target.composing) {
                          return
                        }
                        _vm.$set(
                          _vm.settings,
                          "artistNameTemplate",
                          $event.target.value
                        );
                      }
                    }
                  })
                ])
              : _vm._e()
          ]),
          _vm._v(" "),
          _c("div", { staticClass: "settings-container__third" }, [
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.createAlbumFolder,
                    expression: "settings.createAlbumFolder"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.createAlbumFolder)
                    ? _vm._i(_vm.settings.createAlbumFolder, null) > -1
                    : _vm.settings.createAlbumFolder
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.createAlbumFolder,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(
                            _vm.settings,
                            "createAlbumFolder",
                            $$a.concat([$$v])
                          );
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings,
                            "createAlbumFolder",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings, "createAlbumFolder", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.folders.createAlbumFolder")))
              ])
            ]),
            _vm._v(" "),
            _vm.settings.createAlbumFolder
              ? _c("div", { staticClass: "input_group" }, [
                  _c("p", { staticClass: "input_group_text" }, [
                    _vm._v(_vm._s(_vm.$t("settings.folders.albumNameTemplate")))
                  ]),
                  _vm._v(" "),
                  _c("input", {
                    directives: [
                      {
                        name: "model",
                        rawName: "v-model",
                        value: _vm.settings.albumNameTemplate,
                        expression: "settings.albumNameTemplate"
                      }
                    ],
                    attrs: { type: "text" },
                    domProps: { value: _vm.settings.albumNameTemplate },
                    on: {
                      input: function($event) {
                        if ($event.target.composing) {
                          return
                        }
                        _vm.$set(
                          _vm.settings,
                          "albumNameTemplate",
                          $event.target.value
                        );
                      }
                    }
                  })
                ])
              : _vm._e()
          ])
        ]),
        _vm._v(" "),
        _c("label", { staticClass: "with_checkbox" }, [
          _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model",
                value: _vm.settings.createCDFolder,
                expression: "settings.createCDFolder"
              }
            ],
            attrs: { type: "checkbox" },
            domProps: {
              checked: Array.isArray(_vm.settings.createCDFolder)
                ? _vm._i(_vm.settings.createCDFolder, null) > -1
                : _vm.settings.createCDFolder
            },
            on: {
              change: function($event) {
                var $$a = _vm.settings.createCDFolder,
                  $$el = $event.target,
                  $$c = $$el.checked ? true : false;
                if (Array.isArray($$a)) {
                  var $$v = null,
                    $$i = _vm._i($$a, $$v);
                  if ($$el.checked) {
                    $$i < 0 &&
                      _vm.$set(
                        _vm.settings,
                        "createCDFolder",
                        $$a.concat([$$v])
                      );
                  } else {
                    $$i > -1 &&
                      _vm.$set(
                        _vm.settings,
                        "createCDFolder",
                        $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                      );
                  }
                } else {
                  _vm.$set(_vm.settings, "createCDFolder", $$c);
                }
              }
            }
          }),
          _vm._v(" "),
          _c("span", { staticClass: "checkbox_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.folders.createCDFolder")))
          ])
        ]),
        _vm._v(" "),
        _c("label", { staticClass: "with_checkbox" }, [
          _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model",
                value: _vm.settings.createStructurePlaylist,
                expression: "settings.createStructurePlaylist"
              }
            ],
            attrs: { type: "checkbox" },
            domProps: {
              checked: Array.isArray(_vm.settings.createStructurePlaylist)
                ? _vm._i(_vm.settings.createStructurePlaylist, null) > -1
                : _vm.settings.createStructurePlaylist
            },
            on: {
              change: function($event) {
                var $$a = _vm.settings.createStructurePlaylist,
                  $$el = $event.target,
                  $$c = $$el.checked ? true : false;
                if (Array.isArray($$a)) {
                  var $$v = null,
                    $$i = _vm._i($$a, $$v);
                  if ($$el.checked) {
                    $$i < 0 &&
                      _vm.$set(
                        _vm.settings,
                        "createStructurePlaylist",
                        $$a.concat([$$v])
                      );
                  } else {
                    $$i > -1 &&
                      _vm.$set(
                        _vm.settings,
                        "createStructurePlaylist",
                        $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                      );
                  }
                } else {
                  _vm.$set(_vm.settings, "createStructurePlaylist", $$c);
                }
              }
            }
          }),
          _vm._v(" "),
          _c("span", { staticClass: "checkbox_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.folders.createStructurePlaylist")))
          ])
        ]),
        _vm._v(" "),
        _c("label", { staticClass: "with_checkbox" }, [
          _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model",
                value: _vm.settings.createSingleFolder,
                expression: "settings.createSingleFolder"
              }
            ],
            attrs: { type: "checkbox" },
            domProps: {
              checked: Array.isArray(_vm.settings.createSingleFolder)
                ? _vm._i(_vm.settings.createSingleFolder, null) > -1
                : _vm.settings.createSingleFolder
            },
            on: {
              change: function($event) {
                var $$a = _vm.settings.createSingleFolder,
                  $$el = $event.target,
                  $$c = $$el.checked ? true : false;
                if (Array.isArray($$a)) {
                  var $$v = null,
                    $$i = _vm._i($$a, $$v);
                  if ($$el.checked) {
                    $$i < 0 &&
                      _vm.$set(
                        _vm.settings,
                        "createSingleFolder",
                        $$a.concat([$$v])
                      );
                  } else {
                    $$i > -1 &&
                      _vm.$set(
                        _vm.settings,
                        "createSingleFolder",
                        $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                      );
                  }
                } else {
                  _vm.$set(_vm.settings, "createSingleFolder", $$c);
                }
              }
            }
          }),
          _vm._v(" "),
          _c("span", { staticClass: "checkbox_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.folders.createSingleFolder")))
          ])
        ])
      ]),
      _vm._v(" "),
      _c("div", { staticClass: "settings-group" }, [
        _c(
          "h3",
          {
            staticClass:
              "settings-group__header settings-group__header--with-icon"
          },
          [
            _c("i", { staticClass: "material-icons" }, [_vm._v("title")]),
            _vm._v(_vm._s(_vm.$t("settings.trackTitles.title")) + "\n\t\t")
          ]
        ),
        _vm._v(" "),
        _c("div", { staticClass: "settings-container" }, [
          _c(
            "div",
            {
              staticClass:
                "settings-container__third settings-container__third--only-checkbox"
            },
            [
              _c("label", { staticClass: "with_checkbox" }, [
                _c("input", {
                  directives: [
                    {
                      name: "model",
                      rawName: "v-model",
                      value: _vm.settings.padTracks,
                      expression: "settings.padTracks"
                    }
                  ],
                  attrs: { type: "checkbox" },
                  domProps: {
                    checked: Array.isArray(_vm.settings.padTracks)
                      ? _vm._i(_vm.settings.padTracks, null) > -1
                      : _vm.settings.padTracks
                  },
                  on: {
                    change: function($event) {
                      var $$a = _vm.settings.padTracks,
                        $$el = $event.target,
                        $$c = $$el.checked ? true : false;
                      if (Array.isArray($$a)) {
                        var $$v = null,
                          $$i = _vm._i($$a, $$v);
                        if ($$el.checked) {
                          $$i < 0 &&
                            _vm.$set(
                              _vm.settings,
                              "padTracks",
                              $$a.concat([$$v])
                            );
                        } else {
                          $$i > -1 &&
                            _vm.$set(
                              _vm.settings,
                              "padTracks",
                              $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                            );
                        }
                      } else {
                        _vm.$set(_vm.settings, "padTracks", $$c);
                      }
                    }
                  }
                }),
                _vm._v(" "),
                _c("span", { staticClass: "checkbox_text" }, [
                  _vm._v(_vm._s(_vm.$t("settings.trackTitles.padTracks")))
                ])
              ])
            ]
          ),
          _vm._v(" "),
          _c("div", { staticClass: "settings-container__third" }, [
            _c("div", { staticClass: "input_group" }, [
              _c("p", { staticClass: "input_group_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.trackTitles.paddingSize")))
              ]),
              _vm._v(" "),
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.paddingSize,
                    expression: "settings.paddingSize"
                  }
                ],
                attrs: { max: "10", type: "number" },
                domProps: { value: _vm.settings.paddingSize },
                on: {
                  input: function($event) {
                    if ($event.target.composing) {
                      return
                    }
                    _vm.$set(_vm.settings, "paddingSize", $event.target.value);
                  }
                }
              })
            ])
          ]),
          _vm._v(" "),
          _c("div", { staticClass: "settings-container__third" }, [
            _c("div", { staticClass: "input_group" }, [
              _c("p", { staticClass: "input_group_text" }, [
                _vm._v(
                  _vm._s(
                    _vm.$t("settings.trackTitles.illegalCharacterReplacer")
                  )
                )
              ]),
              _vm._v(" "),
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.illegalCharacterReplacer,
                    expression: "settings.illegalCharacterReplacer"
                  }
                ],
                attrs: { type: "text" },
                domProps: { value: _vm.settings.illegalCharacterReplacer },
                on: {
                  input: function($event) {
                    if ($event.target.composing) {
                      return
                    }
                    _vm.$set(
                      _vm.settings,
                      "illegalCharacterReplacer",
                      $event.target.value
                    );
                  }
                }
              })
            ])
          ])
        ])
      ]),
      _vm._v(" "),
      _c("div", { staticClass: "settings-group" }, [
        _c(
          "h3",
          {
            staticClass:
              "settings-group__header settings-group__header--with-icon"
          },
          [
            _c("i", { staticClass: "material-icons" }, [_vm._v("get_app")]),
            _vm._v(_vm._s(_vm.$t("settings.downloads.title")) + "\n\t\t")
          ]
        ),
        _vm._v(" "),
        _c("div", { staticClass: "input_group" }, [
          _c("p", { staticClass: "input_group_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.downloads.queueConcurrency")))
          ]),
          _vm._v(" "),
          _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model.number",
                value: _vm.settings.queueConcurrency,
                expression: "settings.queueConcurrency",
                modifiers: { number: true }
              }
            ],
            attrs: { type: "number", min: "1" },
            domProps: { value: _vm.settings.queueConcurrency },
            on: {
              input: function($event) {
                if ($event.target.composing) {
                  return
                }
                _vm.$set(
                  _vm.settings,
                  "queueConcurrency",
                  _vm._n($event.target.value)
                );
              },
              blur: function($event) {
                return _vm.$forceUpdate()
              }
            }
          })
        ]),
        _vm._v(" "),
        _c("div", { staticClass: "input_group" }, [
          _c("p", { staticClass: "input_group_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.downloads.maxBitrate.title")))
          ]),
          _vm._v(" "),
          _c(
            "select",
            {
              directives: [
                {
                  name: "model",
                  rawName: "v-model",
                  value: _vm.settings.maxBitrate,
                  expression: "settings.maxBitrate"
                }
              ],
              on: {
                change: function($event) {
                  var $$selectedVal = Array.prototype.filter
                    .call($event.target.options, function(o) {
                      return o.selected
                    })
                    .map(function(o) {
                      var val = "_value" in o ? o._value : o.value;
                      return val
                    });
                  _vm.$set(
                    _vm.settings,
                    "maxBitrate",
                    $event.target.multiple ? $$selectedVal : $$selectedVal[0]
                  );
                }
              }
            },
            [
              _c("option", { attrs: { value: "9" } }, [
                _vm._v(_vm._s(_vm.$t("settings.downloads.maxBitrate.9")))
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "3" } }, [
                _vm._v(_vm._s(_vm.$t("settings.downloads.maxBitrate.3")))
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "1" } }, [
                _vm._v(_vm._s(_vm.$t("settings.downloads.maxBitrate.1")))
              ])
            ]
          )
        ]),
        _vm._v(" "),
        _c("div", { staticClass: "input_group" }, [
          _c("p", { staticClass: "input_group_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.downloads.overwriteFile.title")))
          ]),
          _vm._v(" "),
          _c(
            "select",
            {
              directives: [
                {
                  name: "model",
                  rawName: "v-model",
                  value: _vm.settings.overwriteFile,
                  expression: "settings.overwriteFile"
                }
              ],
              on: {
                change: function($event) {
                  var $$selectedVal = Array.prototype.filter
                    .call($event.target.options, function(o) {
                      return o.selected
                    })
                    .map(function(o) {
                      var val = "_value" in o ? o._value : o.value;
                      return val
                    });
                  _vm.$set(
                    _vm.settings,
                    "overwriteFile",
                    $event.target.multiple ? $$selectedVal : $$selectedVal[0]
                  );
                }
              }
            },
            [
              _c("option", { attrs: { value: "y" } }, [
                _vm._v(_vm._s(_vm.$t("settings.downloads.overwriteFile.y")))
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "n" } }, [
                _vm._v(_vm._s(_vm.$t("settings.downloads.overwriteFile.n")))
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "e" } }, [
                _vm._v(_vm._s(_vm.$t("settings.downloads.overwriteFile.e")))
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "b" } }, [
                _vm._v(_vm._s(_vm.$t("settings.downloads.overwriteFile.b")))
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "t" } }, [
                _vm._v(_vm._s(_vm.$t("settings.downloads.overwriteFile.t")))
              ])
            ]
          )
        ]),
        _vm._v(" "),
        _c("div", { staticClass: "settings-container" }, [
          _c(
            "div",
            {
              staticClass:
                "settings-container__third settings-container__third--only-checkbox"
            },
            [
              _c("label", { staticClass: "with_checkbox" }, [
                _c("input", {
                  directives: [
                    {
                      name: "model",
                      rawName: "v-model",
                      value: _vm.settings.fallbackBitrate,
                      expression: "settings.fallbackBitrate"
                    }
                  ],
                  attrs: { type: "checkbox" },
                  domProps: {
                    checked: Array.isArray(_vm.settings.fallbackBitrate)
                      ? _vm._i(_vm.settings.fallbackBitrate, null) > -1
                      : _vm.settings.fallbackBitrate
                  },
                  on: {
                    change: function($event) {
                      var $$a = _vm.settings.fallbackBitrate,
                        $$el = $event.target,
                        $$c = $$el.checked ? true : false;
                      if (Array.isArray($$a)) {
                        var $$v = null,
                          $$i = _vm._i($$a, $$v);
                        if ($$el.checked) {
                          $$i < 0 &&
                            _vm.$set(
                              _vm.settings,
                              "fallbackBitrate",
                              $$a.concat([$$v])
                            );
                        } else {
                          $$i > -1 &&
                            _vm.$set(
                              _vm.settings,
                              "fallbackBitrate",
                              $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                            );
                        }
                      } else {
                        _vm.$set(_vm.settings, "fallbackBitrate", $$c);
                      }
                    }
                  }
                }),
                _vm._v(" "),
                _c("span", { staticClass: "checkbox_text" }, [
                  _vm._v(_vm._s(_vm.$t("settings.downloads.fallbackBitrate")))
                ])
              ]),
              _vm._v(" "),
              _c("label", { staticClass: "with_checkbox" }, [
                _c("input", {
                  directives: [
                    {
                      name: "model",
                      rawName: "v-model",
                      value: _vm.settings.fallbackSearch,
                      expression: "settings.fallbackSearch"
                    }
                  ],
                  attrs: { type: "checkbox" },
                  domProps: {
                    checked: Array.isArray(_vm.settings.fallbackSearch)
                      ? _vm._i(_vm.settings.fallbackSearch, null) > -1
                      : _vm.settings.fallbackSearch
                  },
                  on: {
                    change: function($event) {
                      var $$a = _vm.settings.fallbackSearch,
                        $$el = $event.target,
                        $$c = $$el.checked ? true : false;
                      if (Array.isArray($$a)) {
                        var $$v = null,
                          $$i = _vm._i($$a, $$v);
                        if ($$el.checked) {
                          $$i < 0 &&
                            _vm.$set(
                              _vm.settings,
                              "fallbackSearch",
                              $$a.concat([$$v])
                            );
                        } else {
                          $$i > -1 &&
                            _vm.$set(
                              _vm.settings,
                              "fallbackSearch",
                              $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                            );
                        }
                      } else {
                        _vm.$set(_vm.settings, "fallbackSearch", $$c);
                      }
                    }
                  }
                }),
                _vm._v(" "),
                _c("span", { staticClass: "checkbox_text" }, [
                  _vm._v(_vm._s(_vm.$t("settings.downloads.fallbackSearch")))
                ])
              ])
            ]
          ),
          _vm._v(" "),
          _c(
            "div",
            {
              staticClass:
                "settings-container__third settings-container__third--only-checkbox"
            },
            [
              _c("label", { staticClass: "with_checkbox" }, [
                _c("input", {
                  directives: [
                    {
                      name: "model",
                      rawName: "v-model",
                      value: _vm.settings.logErrors,
                      expression: "settings.logErrors"
                    }
                  ],
                  attrs: { type: "checkbox" },
                  domProps: {
                    checked: Array.isArray(_vm.settings.logErrors)
                      ? _vm._i(_vm.settings.logErrors, null) > -1
                      : _vm.settings.logErrors
                  },
                  on: {
                    change: function($event) {
                      var $$a = _vm.settings.logErrors,
                        $$el = $event.target,
                        $$c = $$el.checked ? true : false;
                      if (Array.isArray($$a)) {
                        var $$v = null,
                          $$i = _vm._i($$a, $$v);
                        if ($$el.checked) {
                          $$i < 0 &&
                            _vm.$set(
                              _vm.settings,
                              "logErrors",
                              $$a.concat([$$v])
                            );
                        } else {
                          $$i > -1 &&
                            _vm.$set(
                              _vm.settings,
                              "logErrors",
                              $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                            );
                        }
                      } else {
                        _vm.$set(_vm.settings, "logErrors", $$c);
                      }
                    }
                  }
                }),
                _vm._v(" "),
                _c("span", { staticClass: "checkbox_text" }, [
                  _vm._v(_vm._s(_vm.$t("settings.downloads.logErrors")))
                ])
              ]),
              _vm._v(" "),
              _c("label", { staticClass: "with_checkbox" }, [
                _c("input", {
                  directives: [
                    {
                      name: "model",
                      rawName: "v-model",
                      value: _vm.settings.logSearched,
                      expression: "settings.logSearched"
                    }
                  ],
                  attrs: { type: "checkbox" },
                  domProps: {
                    checked: Array.isArray(_vm.settings.logSearched)
                      ? _vm._i(_vm.settings.logSearched, null) > -1
                      : _vm.settings.logSearched
                  },
                  on: {
                    change: function($event) {
                      var $$a = _vm.settings.logSearched,
                        $$el = $event.target,
                        $$c = $$el.checked ? true : false;
                      if (Array.isArray($$a)) {
                        var $$v = null,
                          $$i = _vm._i($$a, $$v);
                        if ($$el.checked) {
                          $$i < 0 &&
                            _vm.$set(
                              _vm.settings,
                              "logSearched",
                              $$a.concat([$$v])
                            );
                        } else {
                          $$i > -1 &&
                            _vm.$set(
                              _vm.settings,
                              "logSearched",
                              $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                            );
                        }
                      } else {
                        _vm.$set(_vm.settings, "logSearched", $$c);
                      }
                    }
                  }
                }),
                _vm._v(" "),
                _c("span", { staticClass: "checkbox_text" }, [
                  _vm._v(_vm._s(_vm.$t("settings.downloads.logSearched")))
                ])
              ])
            ]
          ),
          _vm._v(" "),
          _c(
            "div",
            {
              staticClass:
                "settings-container__third settings-container__third--only-checkbox"
            },
            [
              _c("label", { staticClass: "with_checkbox" }, [
                _c("input", {
                  directives: [
                    {
                      name: "model",
                      rawName: "v-model",
                      value: _vm.settings.syncedLyrics,
                      expression: "settings.syncedLyrics"
                    }
                  ],
                  attrs: { type: "checkbox" },
                  domProps: {
                    checked: Array.isArray(_vm.settings.syncedLyrics)
                      ? _vm._i(_vm.settings.syncedLyrics, null) > -1
                      : _vm.settings.syncedLyrics
                  },
                  on: {
                    change: function($event) {
                      var $$a = _vm.settings.syncedLyrics,
                        $$el = $event.target,
                        $$c = $$el.checked ? true : false;
                      if (Array.isArray($$a)) {
                        var $$v = null,
                          $$i = _vm._i($$a, $$v);
                        if ($$el.checked) {
                          $$i < 0 &&
                            _vm.$set(
                              _vm.settings,
                              "syncedLyrics",
                              $$a.concat([$$v])
                            );
                        } else {
                          $$i > -1 &&
                            _vm.$set(
                              _vm.settings,
                              "syncedLyrics",
                              $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                            );
                        }
                      } else {
                        _vm.$set(_vm.settings, "syncedLyrics", $$c);
                      }
                    }
                  }
                }),
                _vm._v(" "),
                _c("span", { staticClass: "checkbox_text" }, [
                  _vm._v(_vm._s(_vm.$t("settings.downloads.syncedLyrics")))
                ])
              ]),
              _vm._v(" "),
              _c("label", { staticClass: "with_checkbox" }, [
                _c("input", {
                  directives: [
                    {
                      name: "model",
                      rawName: "v-model",
                      value: _vm.settings.createM3U8File,
                      expression: "settings.createM3U8File"
                    }
                  ],
                  attrs: { type: "checkbox" },
                  domProps: {
                    checked: Array.isArray(_vm.settings.createM3U8File)
                      ? _vm._i(_vm.settings.createM3U8File, null) > -1
                      : _vm.settings.createM3U8File
                  },
                  on: {
                    change: function($event) {
                      var $$a = _vm.settings.createM3U8File,
                        $$el = $event.target,
                        $$c = $$el.checked ? true : false;
                      if (Array.isArray($$a)) {
                        var $$v = null,
                          $$i = _vm._i($$a, $$v);
                        if ($$el.checked) {
                          $$i < 0 &&
                            _vm.$set(
                              _vm.settings,
                              "createM3U8File",
                              $$a.concat([$$v])
                            );
                        } else {
                          $$i > -1 &&
                            _vm.$set(
                              _vm.settings,
                              "createM3U8File",
                              $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                            );
                        }
                      } else {
                        _vm.$set(_vm.settings, "createM3U8File", $$c);
                      }
                    }
                  }
                }),
                _vm._v(" "),
                _c("span", { staticClass: "checkbox_text" }, [
                  _vm._v(_vm._s(_vm.$t("settings.downloads.createM3U8File")))
                ])
              ])
            ]
          )
        ]),
        _vm._v(" "),
        _vm.settings.createM3U8File
          ? _c("div", { staticClass: "input_group" }, [
              _c("p", { staticClass: "input_group_text" }, [
                _vm._v(
                  _vm._s(_vm.$t("settings.downloads.playlistFilenameTemplate"))
                )
              ]),
              _vm._v(" "),
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.playlistFilenameTemplate,
                    expression: "settings.playlistFilenameTemplate"
                  }
                ],
                attrs: { type: "text" },
                domProps: { value: _vm.settings.playlistFilenameTemplate },
                on: {
                  input: function($event) {
                    if ($event.target.composing) {
                      return
                    }
                    _vm.$set(
                      _vm.settings,
                      "playlistFilenameTemplate",
                      $event.target.value
                    );
                  }
                }
              })
            ])
          : _vm._e(),
        _vm._v(" "),
        _c("label", { staticClass: "with_checkbox" }, [
          _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model",
                value: _vm.settings.saveDownloadQueue,
                expression: "settings.saveDownloadQueue"
              }
            ],
            attrs: { type: "checkbox" },
            domProps: {
              checked: Array.isArray(_vm.settings.saveDownloadQueue)
                ? _vm._i(_vm.settings.saveDownloadQueue, null) > -1
                : _vm.settings.saveDownloadQueue
            },
            on: {
              change: function($event) {
                var $$a = _vm.settings.saveDownloadQueue,
                  $$el = $event.target,
                  $$c = $$el.checked ? true : false;
                if (Array.isArray($$a)) {
                  var $$v = null,
                    $$i = _vm._i($$a, $$v);
                  if ($$el.checked) {
                    $$i < 0 &&
                      _vm.$set(
                        _vm.settings,
                        "saveDownloadQueue",
                        $$a.concat([$$v])
                      );
                  } else {
                    $$i > -1 &&
                      _vm.$set(
                        _vm.settings,
                        "saveDownloadQueue",
                        $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                      );
                  }
                } else {
                  _vm.$set(_vm.settings, "saveDownloadQueue", $$c);
                }
              }
            }
          }),
          _vm._v(" "),
          _c("span", { staticClass: "checkbox_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.downloads.saveDownloadQueue")))
          ])
        ])
      ]),
      _vm._v(" "),
      _c("div", { staticClass: "settings-group" }, [
        _c(
          "h3",
          {
            staticClass:
              "settings-group__header settings-group__header--with-icon"
          },
          [
            _c("i", { staticClass: "material-icons" }, [_vm._v("album")]),
            _vm._v(_vm._s(_vm.$t("settings.covers.title")) + "\n\t\t")
          ]
        ),
        _vm._v(" "),
        _c("label", { staticClass: "with_checkbox" }, [
          _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model",
                value: _vm.settings.saveArtwork,
                expression: "settings.saveArtwork"
              }
            ],
            attrs: { type: "checkbox" },
            domProps: {
              checked: Array.isArray(_vm.settings.saveArtwork)
                ? _vm._i(_vm.settings.saveArtwork, null) > -1
                : _vm.settings.saveArtwork
            },
            on: {
              change: function($event) {
                var $$a = _vm.settings.saveArtwork,
                  $$el = $event.target,
                  $$c = $$el.checked ? true : false;
                if (Array.isArray($$a)) {
                  var $$v = null,
                    $$i = _vm._i($$a, $$v);
                  if ($$el.checked) {
                    $$i < 0 &&
                      _vm.$set(_vm.settings, "saveArtwork", $$a.concat([$$v]));
                  } else {
                    $$i > -1 &&
                      _vm.$set(
                        _vm.settings,
                        "saveArtwork",
                        $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                      );
                  }
                } else {
                  _vm.$set(_vm.settings, "saveArtwork", $$c);
                }
              }
            }
          }),
          _vm._v(" "),
          _c("span", { staticClass: "checkbox_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.covers.saveArtwork")))
          ])
        ]),
        _vm._v(" "),
        _vm.settings.saveArtwork
          ? _c("div", { staticClass: "input_group" }, [
              _c("p", { staticClass: "input_group_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.covers.coverImageTemplate")))
              ]),
              _vm._v(" "),
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.coverImageTemplate,
                    expression: "settings.coverImageTemplate"
                  }
                ],
                attrs: { type: "text" },
                domProps: { value: _vm.settings.coverImageTemplate },
                on: {
                  input: function($event) {
                    if ($event.target.composing) {
                      return
                    }
                    _vm.$set(
                      _vm.settings,
                      "coverImageTemplate",
                      $event.target.value
                    );
                  }
                }
              })
            ])
          : _vm._e(),
        _vm._v(" "),
        _c("label", { staticClass: "with_checkbox" }, [
          _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model",
                value: _vm.settings.saveArtworkArtist,
                expression: "settings.saveArtworkArtist"
              }
            ],
            attrs: { type: "checkbox" },
            domProps: {
              checked: Array.isArray(_vm.settings.saveArtworkArtist)
                ? _vm._i(_vm.settings.saveArtworkArtist, null) > -1
                : _vm.settings.saveArtworkArtist
            },
            on: {
              change: function($event) {
                var $$a = _vm.settings.saveArtworkArtist,
                  $$el = $event.target,
                  $$c = $$el.checked ? true : false;
                if (Array.isArray($$a)) {
                  var $$v = null,
                    $$i = _vm._i($$a, $$v);
                  if ($$el.checked) {
                    $$i < 0 &&
                      _vm.$set(
                        _vm.settings,
                        "saveArtworkArtist",
                        $$a.concat([$$v])
                      );
                  } else {
                    $$i > -1 &&
                      _vm.$set(
                        _vm.settings,
                        "saveArtworkArtist",
                        $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                      );
                  }
                } else {
                  _vm.$set(_vm.settings, "saveArtworkArtist", $$c);
                }
              }
            }
          }),
          _vm._v(" "),
          _c("span", { staticClass: "checkbox_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.covers.saveArtworkArtist")))
          ])
        ]),
        _vm._v(" "),
        _vm.settings.saveArtworkArtist
          ? _c("div", { staticClass: "input_group" }, [
              _c("p", { staticClass: "input_group_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.covers.artistImageTemplate")))
              ]),
              _vm._v(" "),
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.artistImageTemplate,
                    expression: "settings.artistImageTemplate"
                  }
                ],
                attrs: { type: "text" },
                domProps: { value: _vm.settings.artistImageTemplate },
                on: {
                  input: function($event) {
                    if ($event.target.composing) {
                      return
                    }
                    _vm.$set(
                      _vm.settings,
                      "artistImageTemplate",
                      $event.target.value
                    );
                  }
                }
              })
            ])
          : _vm._e(),
        _vm._v(" "),
        _c("div", { staticClass: "input_group" }, [
          _c("p", { staticClass: "input_group_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.covers.localArtworkSize")))
          ]),
          _vm._v(" "),
          _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model.number",
                value: _vm.settings.localArtworkSize,
                expression: "settings.localArtworkSize",
                modifiers: { number: true }
              }
            ],
            attrs: { type: "number", min: "100", max: "10000", step: "100" },
            domProps: { value: _vm.settings.localArtworkSize },
            on: {
              input: function($event) {
                if ($event.target.composing) {
                  return
                }
                _vm.$set(
                  _vm.settings,
                  "localArtworkSize",
                  _vm._n($event.target.value)
                );
              },
              blur: function($event) {
                return _vm.$forceUpdate()
              }
            }
          }),
          _vm._v(" "),
          _vm.settings.localArtworkSize > 1200
            ? _c(
                "p",
                {
                  staticClass: "input_group_text",
                  staticStyle: { opacity: "0.75", color: "#ffcc22" }
                },
                [
                  _vm._v(
                    "\n\t\t\t\t⚠️ " +
                      _vm._s(_vm.$t("settings.covers.imageSizeWarning")) +
                      "\n\t\t\t"
                  )
                ]
              )
            : _vm._e()
        ]),
        _vm._v(" "),
        _c("div", { staticClass: "input_group" }, [
          _c("p", { staticClass: "input_group_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.covers.embeddedArtworkSize")))
          ]),
          _vm._v(" "),
          _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model.number",
                value: _vm.settings.embeddedArtworkSize,
                expression: "settings.embeddedArtworkSize",
                modifiers: { number: true }
              }
            ],
            attrs: { type: "number", min: "100", max: "10000", step: "100" },
            domProps: { value: _vm.settings.embeddedArtworkSize },
            on: {
              input: function($event) {
                if ($event.target.composing) {
                  return
                }
                _vm.$set(
                  _vm.settings,
                  "embeddedArtworkSize",
                  _vm._n($event.target.value)
                );
              },
              blur: function($event) {
                return _vm.$forceUpdate()
              }
            }
          }),
          _vm._v(" "),
          _vm.settings.embeddedArtworkSize > 1200
            ? _c(
                "p",
                {
                  staticClass: "input_group_text",
                  staticStyle: { opacity: "0.75", color: "#ffcc22" }
                },
                [
                  _vm._v(
                    "\n\t\t\t\t⚠️ " +
                      _vm._s(_vm.$t("settings.covers.imageSizeWarning")) +
                      "\n\t\t\t"
                  )
                ]
              )
            : _vm._e()
        ]),
        _vm._v(" "),
        _c("div", { staticClass: "input_group" }, [
          _c("p", { staticClass: "input_group_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.covers.localArtworkFormat.title")))
          ]),
          _vm._v(" "),
          _c(
            "select",
            {
              directives: [
                {
                  name: "model",
                  rawName: "v-model",
                  value: _vm.settings.localArtworkFormat,
                  expression: "settings.localArtworkFormat"
                }
              ],
              on: {
                change: function($event) {
                  var $$selectedVal = Array.prototype.filter
                    .call($event.target.options, function(o) {
                      return o.selected
                    })
                    .map(function(o) {
                      var val = "_value" in o ? o._value : o.value;
                      return val
                    });
                  _vm.$set(
                    _vm.settings,
                    "localArtworkFormat",
                    $event.target.multiple ? $$selectedVal : $$selectedVal[0]
                  );
                }
              }
            },
            [
              _c("option", { attrs: { value: "jpg" } }, [
                _vm._v(_vm._s(_vm.$t("settings.covers.localArtworkFormat.jpg")))
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "png" } }, [
                _vm._v(_vm._s(_vm.$t("settings.covers.localArtworkFormat.png")))
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "jpg,png" } }, [
                _vm._v(
                  _vm._s(_vm.$t("settings.covers.localArtworkFormat.both"))
                )
              ])
            ]
          )
        ]),
        _vm._v(" "),
        _c("label", { staticClass: "with_checkbox" }, [
          _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model",
                value: _vm.settings.embeddedArtworkPNG,
                expression: "settings.embeddedArtworkPNG"
              }
            ],
            attrs: { type: "checkbox" },
            domProps: {
              checked: Array.isArray(_vm.settings.embeddedArtworkPNG)
                ? _vm._i(_vm.settings.embeddedArtworkPNG, null) > -1
                : _vm.settings.embeddedArtworkPNG
            },
            on: {
              change: function($event) {
                var $$a = _vm.settings.embeddedArtworkPNG,
                  $$el = $event.target,
                  $$c = $$el.checked ? true : false;
                if (Array.isArray($$a)) {
                  var $$v = null,
                    $$i = _vm._i($$a, $$v);
                  if ($$el.checked) {
                    $$i < 0 &&
                      _vm.$set(
                        _vm.settings,
                        "embeddedArtworkPNG",
                        $$a.concat([$$v])
                      );
                  } else {
                    $$i > -1 &&
                      _vm.$set(
                        _vm.settings,
                        "embeddedArtworkPNG",
                        $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                      );
                  }
                } else {
                  _vm.$set(_vm.settings, "embeddedArtworkPNG", $$c);
                }
              }
            }
          }),
          _vm._v(" "),
          _c("span", { staticClass: "checkbox_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.covers.embeddedArtworkPNG")))
          ])
        ]),
        _vm._v(" "),
        _vm.settings.embeddedArtworkPNG
          ? _c("p", { staticStyle: { opacity: "0.75", color: "#ffcc22" } }, [
              _vm._v(
                "\n\t\t\t⚠️ " +
                  _vm._s(_vm.$t("settings.covers.embeddedPNGWarning")) +
                  "\n\t\t"
              )
            ])
          : _vm._e(),
        _vm._v(" "),
        _c("label", { staticClass: "with_checkbox" }, [
          _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model",
                value: _vm.settings.tags.coverDescriptionUTF8,
                expression: "settings.tags.coverDescriptionUTF8"
              }
            ],
            attrs: { type: "checkbox" },
            domProps: {
              checked: Array.isArray(_vm.settings.tags.coverDescriptionUTF8)
                ? _vm._i(_vm.settings.tags.coverDescriptionUTF8, null) > -1
                : _vm.settings.tags.coverDescriptionUTF8
            },
            on: {
              change: function($event) {
                var $$a = _vm.settings.tags.coverDescriptionUTF8,
                  $$el = $event.target,
                  $$c = $$el.checked ? true : false;
                if (Array.isArray($$a)) {
                  var $$v = null,
                    $$i = _vm._i($$a, $$v);
                  if ($$el.checked) {
                    $$i < 0 &&
                      _vm.$set(
                        _vm.settings.tags,
                        "coverDescriptionUTF8",
                        $$a.concat([$$v])
                      );
                  } else {
                    $$i > -1 &&
                      _vm.$set(
                        _vm.settings.tags,
                        "coverDescriptionUTF8",
                        $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                      );
                  }
                } else {
                  _vm.$set(_vm.settings.tags, "coverDescriptionUTF8", $$c);
                }
              }
            }
          }),
          _vm._v(" "),
          _c("span", { staticClass: "checkbox_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.covers.coverDescriptionUTF8")))
          ])
        ]),
        _vm._v(" "),
        _c("div", { staticClass: "input_group" }, [
          _c("p", { staticClass: "input_group_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.covers.jpegImageQuality")))
          ]),
          _vm._v(" "),
          _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model.number",
                value: _vm.settings.jpegImageQuality,
                expression: "settings.jpegImageQuality",
                modifiers: { number: true }
              }
            ],
            attrs: { type: "number", min: "1", max: "100" },
            domProps: { value: _vm.settings.jpegImageQuality },
            on: {
              input: function($event) {
                if ($event.target.composing) {
                  return
                }
                _vm.$set(
                  _vm.settings,
                  "jpegImageQuality",
                  _vm._n($event.target.value)
                );
              },
              blur: function($event) {
                return _vm.$forceUpdate()
              }
            }
          })
        ])
      ]),
      _vm._v(" "),
      _c("div", { staticClass: "settings-group" }, [
        _c(
          "h3",
          {
            staticClass:
              "settings-group__header settings-group__header--with-icon"
          },
          [
            _c(
              "i",
              {
                staticClass: "material-icons",
                staticStyle: { width: "1em", height: "1em" }
              },
              [_vm._v("bookmarks")]
            ),
            _vm._v(_vm._s(_vm.$t("settings.tags.head")) + "\n\t\t")
          ]
        ),
        _vm._v(" "),
        _c("div", { staticClass: "settings-container" }, [
          _c("div", { staticClass: "settings-container__half" }, [
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.tags.title,
                    expression: "settings.tags.title"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.tags.title)
                    ? _vm._i(_vm.settings.tags.title, null) > -1
                    : _vm.settings.tags.title
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.tags.title,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "title",
                            $$a.concat([$$v])
                          );
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "title",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings.tags, "title", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.tags.title")))
              ])
            ]),
            _vm._v(" "),
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.tags.artist,
                    expression: "settings.tags.artist"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.tags.artist)
                    ? _vm._i(_vm.settings.tags.artist, null) > -1
                    : _vm.settings.tags.artist
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.tags.artist,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "artist",
                            $$a.concat([$$v])
                          );
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "artist",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings.tags, "artist", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.tags.artist")))
              ])
            ]),
            _vm._v(" "),
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.tags.album,
                    expression: "settings.tags.album"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.tags.album)
                    ? _vm._i(_vm.settings.tags.album, null) > -1
                    : _vm.settings.tags.album
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.tags.album,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "album",
                            $$a.concat([$$v])
                          );
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "album",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings.tags, "album", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.tags.album")))
              ])
            ]),
            _vm._v(" "),
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.tags.cover,
                    expression: "settings.tags.cover"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.tags.cover)
                    ? _vm._i(_vm.settings.tags.cover, null) > -1
                    : _vm.settings.tags.cover
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.tags.cover,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "cover",
                            $$a.concat([$$v])
                          );
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "cover",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings.tags, "cover", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.tags.cover")))
              ])
            ]),
            _vm._v(" "),
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.tags.trackNumber,
                    expression: "settings.tags.trackNumber"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.tags.trackNumber)
                    ? _vm._i(_vm.settings.tags.trackNumber, null) > -1
                    : _vm.settings.tags.trackNumber
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.tags.trackNumber,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "trackNumber",
                            $$a.concat([$$v])
                          );
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "trackNumber",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings.tags, "trackNumber", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.tags.trackNumber")))
              ])
            ]),
            _vm._v(" "),
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.tags.trackTotal,
                    expression: "settings.tags.trackTotal"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.tags.trackTotal)
                    ? _vm._i(_vm.settings.tags.trackTotal, null) > -1
                    : _vm.settings.tags.trackTotal
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.tags.trackTotal,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "trackTotal",
                            $$a.concat([$$v])
                          );
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "trackTotal",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings.tags, "trackTotal", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.tags.trackTotal")))
              ])
            ]),
            _vm._v(" "),
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.tags.discNumber,
                    expression: "settings.tags.discNumber"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.tags.discNumber)
                    ? _vm._i(_vm.settings.tags.discNumber, null) > -1
                    : _vm.settings.tags.discNumber
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.tags.discNumber,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "discNumber",
                            $$a.concat([$$v])
                          );
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "discNumber",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings.tags, "discNumber", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.tags.discNumber")))
              ])
            ]),
            _vm._v(" "),
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.tags.discTotal,
                    expression: "settings.tags.discTotal"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.tags.discTotal)
                    ? _vm._i(_vm.settings.tags.discTotal, null) > -1
                    : _vm.settings.tags.discTotal
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.tags.discTotal,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "discTotal",
                            $$a.concat([$$v])
                          );
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "discTotal",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings.tags, "discTotal", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.tags.discTotal")))
              ])
            ]),
            _vm._v(" "),
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.tags.albumArtist,
                    expression: "settings.tags.albumArtist"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.tags.albumArtist)
                    ? _vm._i(_vm.settings.tags.albumArtist, null) > -1
                    : _vm.settings.tags.albumArtist
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.tags.albumArtist,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "albumArtist",
                            $$a.concat([$$v])
                          );
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "albumArtist",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings.tags, "albumArtist", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.tags.albumArtist")))
              ])
            ]),
            _vm._v(" "),
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.tags.genre,
                    expression: "settings.tags.genre"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.tags.genre)
                    ? _vm._i(_vm.settings.tags.genre, null) > -1
                    : _vm.settings.tags.genre
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.tags.genre,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "genre",
                            $$a.concat([$$v])
                          );
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "genre",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings.tags, "genre", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.tags.genre")))
              ])
            ]),
            _vm._v(" "),
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.tags.year,
                    expression: "settings.tags.year"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.tags.year)
                    ? _vm._i(_vm.settings.tags.year, null) > -1
                    : _vm.settings.tags.year
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.tags.year,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(_vm.settings.tags, "year", $$a.concat([$$v]));
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "year",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings.tags, "year", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.tags.year")))
              ])
            ]),
            _vm._v(" "),
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.tags.date,
                    expression: "settings.tags.date"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.tags.date)
                    ? _vm._i(_vm.settings.tags.date, null) > -1
                    : _vm.settings.tags.date
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.tags.date,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(_vm.settings.tags, "date", $$a.concat([$$v]));
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "date",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings.tags, "date", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.tags.date")))
              ])
            ])
          ]),
          _vm._v(" "),
          _c("div", { staticClass: "settings-container__half" }, [
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.tags.explicit,
                    expression: "settings.tags.explicit"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.tags.explicit)
                    ? _vm._i(_vm.settings.tags.explicit, null) > -1
                    : _vm.settings.tags.explicit
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.tags.explicit,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "explicit",
                            $$a.concat([$$v])
                          );
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "explicit",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings.tags, "explicit", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.tags.explicit")))
              ])
            ]),
            _vm._v(" "),
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.tags.isrc,
                    expression: "settings.tags.isrc"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.tags.isrc)
                    ? _vm._i(_vm.settings.tags.isrc, null) > -1
                    : _vm.settings.tags.isrc
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.tags.isrc,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(_vm.settings.tags, "isrc", $$a.concat([$$v]));
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "isrc",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings.tags, "isrc", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.tags.isrc")))
              ])
            ]),
            _vm._v(" "),
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.tags.length,
                    expression: "settings.tags.length"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.tags.length)
                    ? _vm._i(_vm.settings.tags.length, null) > -1
                    : _vm.settings.tags.length
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.tags.length,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "length",
                            $$a.concat([$$v])
                          );
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "length",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings.tags, "length", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.tags.length")))
              ])
            ]),
            _vm._v(" "),
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.tags.barcode,
                    expression: "settings.tags.barcode"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.tags.barcode)
                    ? _vm._i(_vm.settings.tags.barcode, null) > -1
                    : _vm.settings.tags.barcode
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.tags.barcode,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "barcode",
                            $$a.concat([$$v])
                          );
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "barcode",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings.tags, "barcode", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.tags.barcode")))
              ])
            ]),
            _vm._v(" "),
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.tags.bpm,
                    expression: "settings.tags.bpm"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.tags.bpm)
                    ? _vm._i(_vm.settings.tags.bpm, null) > -1
                    : _vm.settings.tags.bpm
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.tags.bpm,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(_vm.settings.tags, "bpm", $$a.concat([$$v]));
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "bpm",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings.tags, "bpm", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.tags.bpm")))
              ])
            ]),
            _vm._v(" "),
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.tags.replayGain,
                    expression: "settings.tags.replayGain"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.tags.replayGain)
                    ? _vm._i(_vm.settings.tags.replayGain, null) > -1
                    : _vm.settings.tags.replayGain
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.tags.replayGain,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "replayGain",
                            $$a.concat([$$v])
                          );
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "replayGain",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings.tags, "replayGain", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.tags.replayGain")))
              ])
            ]),
            _vm._v(" "),
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.tags.label,
                    expression: "settings.tags.label"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.tags.label)
                    ? _vm._i(_vm.settings.tags.label, null) > -1
                    : _vm.settings.tags.label
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.tags.label,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "label",
                            $$a.concat([$$v])
                          );
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "label",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings.tags, "label", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.tags.label")))
              ])
            ]),
            _vm._v(" "),
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.tags.lyrics,
                    expression: "settings.tags.lyrics"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.tags.lyrics)
                    ? _vm._i(_vm.settings.tags.lyrics, null) > -1
                    : _vm.settings.tags.lyrics
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.tags.lyrics,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "lyrics",
                            $$a.concat([$$v])
                          );
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "lyrics",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings.tags, "lyrics", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.tags.lyrics")))
              ])
            ]),
            _vm._v(" "),
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.tags.syncedLyrics,
                    expression: "settings.tags.syncedLyrics"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.tags.syncedLyrics)
                    ? _vm._i(_vm.settings.tags.syncedLyrics, null) > -1
                    : _vm.settings.tags.syncedLyrics
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.tags.syncedLyrics,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "syncedLyrics",
                            $$a.concat([$$v])
                          );
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "syncedLyrics",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings.tags, "syncedLyrics", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.tags.syncedLyrics")))
              ])
            ]),
            _vm._v(" "),
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.tags.copyright,
                    expression: "settings.tags.copyright"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.tags.copyright)
                    ? _vm._i(_vm.settings.tags.copyright, null) > -1
                    : _vm.settings.tags.copyright
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.tags.copyright,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "copyright",
                            $$a.concat([$$v])
                          );
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "copyright",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings.tags, "copyright", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.tags.copyright")))
              ])
            ]),
            _vm._v(" "),
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.tags.composer,
                    expression: "settings.tags.composer"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.tags.composer)
                    ? _vm._i(_vm.settings.tags.composer, null) > -1
                    : _vm.settings.tags.composer
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.tags.composer,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "composer",
                            $$a.concat([$$v])
                          );
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "composer",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings.tags, "composer", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.tags.composer")))
              ])
            ]),
            _vm._v(" "),
            _c("label", { staticClass: "with_checkbox" }, [
              _c("input", {
                directives: [
                  {
                    name: "model",
                    rawName: "v-model",
                    value: _vm.settings.tags.involvedPeople,
                    expression: "settings.tags.involvedPeople"
                  }
                ],
                attrs: { type: "checkbox" },
                domProps: {
                  checked: Array.isArray(_vm.settings.tags.involvedPeople)
                    ? _vm._i(_vm.settings.tags.involvedPeople, null) > -1
                    : _vm.settings.tags.involvedPeople
                },
                on: {
                  change: function($event) {
                    var $$a = _vm.settings.tags.involvedPeople,
                      $$el = $event.target,
                      $$c = $$el.checked ? true : false;
                    if (Array.isArray($$a)) {
                      var $$v = null,
                        $$i = _vm._i($$a, $$v);
                      if ($$el.checked) {
                        $$i < 0 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "involvedPeople",
                            $$a.concat([$$v])
                          );
                      } else {
                        $$i > -1 &&
                          _vm.$set(
                            _vm.settings.tags,
                            "involvedPeople",
                            $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                          );
                      }
                    } else {
                      _vm.$set(_vm.settings.tags, "involvedPeople", $$c);
                    }
                  }
                }
              }),
              _vm._v(" "),
              _c("span", { staticClass: "checkbox_text" }, [
                _vm._v(_vm._s(_vm.$t("settings.tags.involvedPeople")))
              ])
            ])
          ])
        ])
      ]),
      _vm._v(" "),
      _c("div", { staticClass: "settings-group" }, [
        _c(
          "h3",
          {
            staticClass:
              "settings-group__header settings-group__header--with-icon"
          },
          [
            _c("i", { staticClass: "material-icons" }, [_vm._v("list")]),
            _vm._v(_vm._s(_vm.$t("settings.other.title")) + "\n\t\t")
          ]
        ),
        _vm._v(" "),
        _c("label", { staticClass: "with_checkbox" }, [
          _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model",
                value: _vm.settings.tags.savePlaylistAsCompilation,
                expression: "settings.tags.savePlaylistAsCompilation"
              }
            ],
            attrs: { type: "checkbox" },
            domProps: {
              checked: Array.isArray(
                _vm.settings.tags.savePlaylistAsCompilation
              )
                ? _vm._i(_vm.settings.tags.savePlaylistAsCompilation, null) > -1
                : _vm.settings.tags.savePlaylistAsCompilation
            },
            on: {
              change: function($event) {
                var $$a = _vm.settings.tags.savePlaylistAsCompilation,
                  $$el = $event.target,
                  $$c = $$el.checked ? true : false;
                if (Array.isArray($$a)) {
                  var $$v = null,
                    $$i = _vm._i($$a, $$v);
                  if ($$el.checked) {
                    $$i < 0 &&
                      _vm.$set(
                        _vm.settings.tags,
                        "savePlaylistAsCompilation",
                        $$a.concat([$$v])
                      );
                  } else {
                    $$i > -1 &&
                      _vm.$set(
                        _vm.settings.tags,
                        "savePlaylistAsCompilation",
                        $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                      );
                  }
                } else {
                  _vm.$set(_vm.settings.tags, "savePlaylistAsCompilation", $$c);
                }
              }
            }
          }),
          _vm._v(" "),
          _c("span", { staticClass: "checkbox_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.other.savePlaylistAsCompilation")))
          ])
        ]),
        _vm._v(" "),
        _c("label", { staticClass: "with_checkbox" }, [
          _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model",
                value: _vm.settings.tags.useNullSeparator,
                expression: "settings.tags.useNullSeparator"
              }
            ],
            attrs: { type: "checkbox" },
            domProps: {
              checked: Array.isArray(_vm.settings.tags.useNullSeparator)
                ? _vm._i(_vm.settings.tags.useNullSeparator, null) > -1
                : _vm.settings.tags.useNullSeparator
            },
            on: {
              change: function($event) {
                var $$a = _vm.settings.tags.useNullSeparator,
                  $$el = $event.target,
                  $$c = $$el.checked ? true : false;
                if (Array.isArray($$a)) {
                  var $$v = null,
                    $$i = _vm._i($$a, $$v);
                  if ($$el.checked) {
                    $$i < 0 &&
                      _vm.$set(
                        _vm.settings.tags,
                        "useNullSeparator",
                        $$a.concat([$$v])
                      );
                  } else {
                    $$i > -1 &&
                      _vm.$set(
                        _vm.settings.tags,
                        "useNullSeparator",
                        $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                      );
                  }
                } else {
                  _vm.$set(_vm.settings.tags, "useNullSeparator", $$c);
                }
              }
            }
          }),
          _vm._v(" "),
          _c("span", { staticClass: "checkbox_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.other.useNullSeparator")))
          ])
        ]),
        _vm._v(" "),
        _c("label", { staticClass: "with_checkbox" }, [
          _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model",
                value: _vm.settings.tags.saveID3v1,
                expression: "settings.tags.saveID3v1"
              }
            ],
            attrs: { type: "checkbox" },
            domProps: {
              checked: Array.isArray(_vm.settings.tags.saveID3v1)
                ? _vm._i(_vm.settings.tags.saveID3v1, null) > -1
                : _vm.settings.tags.saveID3v1
            },
            on: {
              change: function($event) {
                var $$a = _vm.settings.tags.saveID3v1,
                  $$el = $event.target,
                  $$c = $$el.checked ? true : false;
                if (Array.isArray($$a)) {
                  var $$v = null,
                    $$i = _vm._i($$a, $$v);
                  if ($$el.checked) {
                    $$i < 0 &&
                      _vm.$set(
                        _vm.settings.tags,
                        "saveID3v1",
                        $$a.concat([$$v])
                      );
                  } else {
                    $$i > -1 &&
                      _vm.$set(
                        _vm.settings.tags,
                        "saveID3v1",
                        $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                      );
                  }
                } else {
                  _vm.$set(_vm.settings.tags, "saveID3v1", $$c);
                }
              }
            }
          }),
          _vm._v(" "),
          _c("span", { staticClass: "checkbox_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.other.saveID3v1")))
          ])
        ]),
        _vm._v(" "),
        _c("div", { staticClass: "input_group" }, [
          _c("p", { staticClass: "input_group_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.other.multiArtistSeparator.title")))
          ]),
          _vm._v(" "),
          _c(
            "select",
            {
              directives: [
                {
                  name: "model",
                  rawName: "v-model",
                  value: _vm.settings.tags.multiArtistSeparator,
                  expression: "settings.tags.multiArtistSeparator"
                }
              ],
              on: {
                change: function($event) {
                  var $$selectedVal = Array.prototype.filter
                    .call($event.target.options, function(o) {
                      return o.selected
                    })
                    .map(function(o) {
                      var val = "_value" in o ? o._value : o.value;
                      return val
                    });
                  _vm.$set(
                    _vm.settings.tags,
                    "multiArtistSeparator",
                    $event.target.multiple ? $$selectedVal : $$selectedVal[0]
                  );
                }
              }
            },
            [
              _c("option", { attrs: { value: "nothing" } }, [
                _vm._v(
                  _vm._s(_vm.$t("settings.other.multiArtistSeparator.nothing"))
                )
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "default" } }, [
                _vm._v(
                  _vm._s(_vm.$t("settings.other.multiArtistSeparator.default"))
                )
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "andFeat" } }, [
                _vm._v(
                  _vm._s(_vm.$t("settings.other.multiArtistSeparator.andFeat"))
                )
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: " & " } }, [
                _vm._v(
                  _vm._s(
                    _vm.$t("settings.other.multiArtistSeparator.using", {
                      separator: " & "
                    })
                  )
                )
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "," } }, [
                _vm._v(
                  _vm._s(
                    _vm.$t("settings.other.multiArtistSeparator.using", {
                      separator: ","
                    })
                  )
                )
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: ", " } }, [
                _vm._v(
                  _vm._s(
                    _vm.$t("settings.other.multiArtistSeparator.using", {
                      separator: ", "
                    })
                  )
                )
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "/" } }, [
                _vm._v(
                  _vm._s(
                    _vm.$t("settings.other.multiArtistSeparator.using", {
                      separator: "/"
                    })
                  )
                )
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: " / " } }, [
                _vm._v(
                  _vm._s(
                    _vm.$t("settings.other.multiArtistSeparator.using", {
                      separator: " / "
                    })
                  )
                )
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: ";" } }, [
                _vm._v(
                  _vm._s(
                    _vm.$t("settings.other.multiArtistSeparator.using", {
                      separator: ";"
                    })
                  )
                )
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "; " } }, [
                _vm._v(
                  _vm._s(
                    _vm.$t("settings.other.multiArtistSeparator.using", {
                      separator: "; "
                    })
                  )
                )
              ])
            ]
          )
        ]),
        _vm._v(" "),
        _c("label", { staticClass: "with_checkbox" }, [
          _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model",
                value: _vm.settings.tags.singleAlbumArtist,
                expression: "settings.tags.singleAlbumArtist"
              }
            ],
            attrs: { type: "checkbox" },
            domProps: {
              checked: Array.isArray(_vm.settings.tags.singleAlbumArtist)
                ? _vm._i(_vm.settings.tags.singleAlbumArtist, null) > -1
                : _vm.settings.tags.singleAlbumArtist
            },
            on: {
              change: function($event) {
                var $$a = _vm.settings.tags.singleAlbumArtist,
                  $$el = $event.target,
                  $$c = $$el.checked ? true : false;
                if (Array.isArray($$a)) {
                  var $$v = null,
                    $$i = _vm._i($$a, $$v);
                  if ($$el.checked) {
                    $$i < 0 &&
                      _vm.$set(
                        _vm.settings.tags,
                        "singleAlbumArtist",
                        $$a.concat([$$v])
                      );
                  } else {
                    $$i > -1 &&
                      _vm.$set(
                        _vm.settings.tags,
                        "singleAlbumArtist",
                        $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                      );
                  }
                } else {
                  _vm.$set(_vm.settings.tags, "singleAlbumArtist", $$c);
                }
              }
            }
          }),
          _vm._v(" "),
          _c("span", { staticClass: "checkbox_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.other.singleAlbumArtist")))
          ])
        ]),
        _vm._v(" "),
        _c("label", { staticClass: "with_checkbox" }, [
          _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model",
                value: _vm.settings.albumVariousArtists,
                expression: "settings.albumVariousArtists"
              }
            ],
            attrs: { type: "checkbox" },
            domProps: {
              checked: Array.isArray(_vm.settings.albumVariousArtists)
                ? _vm._i(_vm.settings.albumVariousArtists, null) > -1
                : _vm.settings.albumVariousArtists
            },
            on: {
              change: function($event) {
                var $$a = _vm.settings.albumVariousArtists,
                  $$el = $event.target,
                  $$c = $$el.checked ? true : false;
                if (Array.isArray($$a)) {
                  var $$v = null,
                    $$i = _vm._i($$a, $$v);
                  if ($$el.checked) {
                    $$i < 0 &&
                      _vm.$set(
                        _vm.settings,
                        "albumVariousArtists",
                        $$a.concat([$$v])
                      );
                  } else {
                    $$i > -1 &&
                      _vm.$set(
                        _vm.settings,
                        "albumVariousArtists",
                        $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                      );
                  }
                } else {
                  _vm.$set(_vm.settings, "albumVariousArtists", $$c);
                }
              }
            }
          }),
          _vm._v(" "),
          _c("span", { staticClass: "checkbox_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.other.albumVariousArtists")))
          ])
        ]),
        _vm._v(" "),
        _c("label", { staticClass: "with_checkbox" }, [
          _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model",
                value: _vm.settings.removeAlbumVersion,
                expression: "settings.removeAlbumVersion"
              }
            ],
            attrs: { type: "checkbox" },
            domProps: {
              checked: Array.isArray(_vm.settings.removeAlbumVersion)
                ? _vm._i(_vm.settings.removeAlbumVersion, null) > -1
                : _vm.settings.removeAlbumVersion
            },
            on: {
              change: function($event) {
                var $$a = _vm.settings.removeAlbumVersion,
                  $$el = $event.target,
                  $$c = $$el.checked ? true : false;
                if (Array.isArray($$a)) {
                  var $$v = null,
                    $$i = _vm._i($$a, $$v);
                  if ($$el.checked) {
                    $$i < 0 &&
                      _vm.$set(
                        _vm.settings,
                        "removeAlbumVersion",
                        $$a.concat([$$v])
                      );
                  } else {
                    $$i > -1 &&
                      _vm.$set(
                        _vm.settings,
                        "removeAlbumVersion",
                        $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                      );
                  }
                } else {
                  _vm.$set(_vm.settings, "removeAlbumVersion", $$c);
                }
              }
            }
          }),
          _vm._v(" "),
          _c("span", { staticClass: "checkbox_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.other.removeAlbumVersion")))
          ])
        ]),
        _vm._v(" "),
        _c("label", { staticClass: "with_checkbox" }, [
          _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model",
                value: _vm.settings.removeDuplicateArtists,
                expression: "settings.removeDuplicateArtists"
              }
            ],
            attrs: { type: "checkbox" },
            domProps: {
              checked: Array.isArray(_vm.settings.removeDuplicateArtists)
                ? _vm._i(_vm.settings.removeDuplicateArtists, null) > -1
                : _vm.settings.removeDuplicateArtists
            },
            on: {
              change: function($event) {
                var $$a = _vm.settings.removeDuplicateArtists,
                  $$el = $event.target,
                  $$c = $$el.checked ? true : false;
                if (Array.isArray($$a)) {
                  var $$v = null,
                    $$i = _vm._i($$a, $$v);
                  if ($$el.checked) {
                    $$i < 0 &&
                      _vm.$set(
                        _vm.settings,
                        "removeDuplicateArtists",
                        $$a.concat([$$v])
                      );
                  } else {
                    $$i > -1 &&
                      _vm.$set(
                        _vm.settings,
                        "removeDuplicateArtists",
                        $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                      );
                  }
                } else {
                  _vm.$set(_vm.settings, "removeDuplicateArtists", $$c);
                }
              }
            }
          }),
          _vm._v(" "),
          _c("span", { staticClass: "checkbox_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.other.removeDuplicateArtists")))
          ])
        ]),
        _vm._v(" "),
        _c("div", { staticClass: "input_group" }, [
          _c("p", { staticClass: "input_group_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.other.dateFormat.title")))
          ]),
          _vm._v(" "),
          _c(
            "select",
            {
              directives: [
                {
                  name: "model",
                  rawName: "v-model",
                  value: _vm.settings.dateFormat,
                  expression: "settings.dateFormat"
                }
              ],
              on: {
                change: function($event) {
                  var $$selectedVal = Array.prototype.filter
                    .call($event.target.options, function(o) {
                      return o.selected
                    })
                    .map(function(o) {
                      var val = "_value" in o ? o._value : o.value;
                      return val
                    });
                  _vm.$set(
                    _vm.settings,
                    "dateFormat",
                    $event.target.multiple ? $$selectedVal : $$selectedVal[0]
                  );
                }
              }
            },
            [
              _c("option", { attrs: { value: "Y-M-D" } }, [
                _vm._v(
                  "\n\t\t\t\t\t" +
                    _vm._s(
                      _vm.$t("settings.other.dateFormat.year") +
                        "-" +
                        _vm.$t("settings.other.dateFormat.month") +
                        "-" +
                        _vm.$t("settings.other.dateFormat.day")
                    ) +
                    "\n\t\t\t\t"
                )
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "Y-D-M" } }, [
                _vm._v(
                  "\n\t\t\t\t\t" +
                    _vm._s(
                      _vm.$t("settings.other.dateFormat.year") +
                        "-" +
                        _vm.$t("settings.other.dateFormat.day") +
                        "-" +
                        _vm.$t("settings.other.dateFormat.month")
                    ) +
                    "\n\t\t\t\t"
                )
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "D-M-Y" } }, [
                _vm._v(
                  "\n\t\t\t\t\t" +
                    _vm._s(
                      _vm.$t("settings.other.dateFormat.day") +
                        "-" +
                        _vm.$t("settings.other.dateFormat.month") +
                        "-" +
                        _vm.$t("settings.other.dateFormat.year")
                    ) +
                    "\n\t\t\t\t"
                )
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "M-D-Y" } }, [
                _vm._v(
                  "\n\t\t\t\t\t" +
                    _vm._s(
                      _vm.$t("settings.other.dateFormat.month") +
                        "-" +
                        _vm.$t("settings.other.dateFormat.day") +
                        "-" +
                        _vm.$t("settings.other.dateFormat.year")
                    ) +
                    "\n\t\t\t\t"
                )
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "Y" } }, [
                _vm._v(_vm._s(_vm.$t("settings.other.dateFormat.year")))
              ])
            ]
          )
        ]),
        _vm._v(" "),
        _c("div", { staticClass: "input_group" }, [
          _c("p", { staticClass: "input_group_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.other.featuredToTitle.title")))
          ]),
          _vm._v(" "),
          _c(
            "select",
            {
              directives: [
                {
                  name: "model",
                  rawName: "v-model",
                  value: _vm.settings.featuredToTitle,
                  expression: "settings.featuredToTitle"
                }
              ],
              on: {
                change: function($event) {
                  var $$selectedVal = Array.prototype.filter
                    .call($event.target.options, function(o) {
                      return o.selected
                    })
                    .map(function(o) {
                      var val = "_value" in o ? o._value : o.value;
                      return val
                    });
                  _vm.$set(
                    _vm.settings,
                    "featuredToTitle",
                    $event.target.multiple ? $$selectedVal : $$selectedVal[0]
                  );
                }
              }
            },
            [
              _c("option", { attrs: { value: "0" } }, [
                _vm._v(_vm._s(_vm.$t("settings.other.featuredToTitle.0")))
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "1" } }, [
                _vm._v(_vm._s(_vm.$t("settings.other.featuredToTitle.1")))
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "3" } }, [
                _vm._v(_vm._s(_vm.$t("settings.other.featuredToTitle.3")))
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "2" } }, [
                _vm._v(_vm._s(_vm.$t("settings.other.featuredToTitle.2")))
              ])
            ]
          )
        ]),
        _vm._v(" "),
        _c("div", { staticClass: "input_group" }, [
          _c("p", { staticClass: "input_group_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.other.titleCasing")))
          ]),
          _vm._v(" "),
          _c(
            "select",
            {
              directives: [
                {
                  name: "model",
                  rawName: "v-model",
                  value: _vm.settings.titleCasing,
                  expression: "settings.titleCasing"
                }
              ],
              on: {
                change: function($event) {
                  var $$selectedVal = Array.prototype.filter
                    .call($event.target.options, function(o) {
                      return o.selected
                    })
                    .map(function(o) {
                      var val = "_value" in o ? o._value : o.value;
                      return val
                    });
                  _vm.$set(
                    _vm.settings,
                    "titleCasing",
                    $event.target.multiple ? $$selectedVal : $$selectedVal[0]
                  );
                }
              }
            },
            [
              _c("option", { attrs: { value: "nothing" } }, [
                _vm._v(_vm._s(_vm.$t("settings.other.casing.nothing")))
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "lower" } }, [
                _vm._v(_vm._s(_vm.$t("settings.other.casing.lower")))
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "upper" } }, [
                _vm._v(_vm._s(_vm.$t("settings.other.casing.upper")))
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "start" } }, [
                _vm._v(_vm._s(_vm.$t("settings.other.casing.start")))
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "sentence" } }, [
                _vm._v(_vm._s(_vm.$t("settings.other.casing.sentence")))
              ])
            ]
          )
        ]),
        _vm._v(" "),
        _c("div", { staticClass: "input_group" }, [
          _c("p", { staticClass: "input_group_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.other.artistCasing")))
          ]),
          _vm._v(" "),
          _c(
            "select",
            {
              directives: [
                {
                  name: "model",
                  rawName: "v-model",
                  value: _vm.settings.artistCasing,
                  expression: "settings.artistCasing"
                }
              ],
              on: {
                change: function($event) {
                  var $$selectedVal = Array.prototype.filter
                    .call($event.target.options, function(o) {
                      return o.selected
                    })
                    .map(function(o) {
                      var val = "_value" in o ? o._value : o.value;
                      return val
                    });
                  _vm.$set(
                    _vm.settings,
                    "artistCasing",
                    $event.target.multiple ? $$selectedVal : $$selectedVal[0]
                  );
                }
              }
            },
            [
              _c("option", { attrs: { value: "nothing" } }, [
                _vm._v(_vm._s(_vm.$t("settings.other.casing.nothing")))
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "lower" } }, [
                _vm._v(_vm._s(_vm.$t("settings.other.casing.lower")))
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "upper" } }, [
                _vm._v(_vm._s(_vm.$t("settings.other.casing.upper")))
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "start" } }, [
                _vm._v(_vm._s(_vm.$t("settings.other.casing.start")))
              ]),
              _vm._v(" "),
              _c("option", { attrs: { value: "sentence" } }, [
                _vm._v(_vm._s(_vm.$t("settings.other.casing.sentence")))
              ])
            ]
          )
        ]),
        _vm._v(" "),
        _c("div", { staticClass: "input_group" }, [
          _c("p", { staticClass: "input_group_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.other.previewVolume")))
          ]),
          _vm._v(" "),
          _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model.number",
                value: _vm.previewVolume.preview_max_volume,
                expression: "previewVolume.preview_max_volume",
                modifiers: { number: true }
              }
            ],
            staticClass: "slider",
            attrs: { type: "range", min: "0", max: "100", step: "1" },
            domProps: { value: _vm.previewVolume.preview_max_volume },
            on: {
              change: _vm.updateMaxVolume,
              __r: function($event) {
                _vm.$set(
                  _vm.previewVolume,
                  "preview_max_volume",
                  _vm._n($event.target.value)
                );
              },
              blur: function($event) {
                return _vm.$forceUpdate()
              }
            }
          }),
          _vm._v(" "),
          _c("span", [
            _vm._v(_vm._s(_vm.previewVolume.preview_max_volume) + "%")
          ])
        ]),
        _vm._v(" "),
        _c("div", { staticClass: "input_group" }, [
          _c("p", { staticClass: "input_group_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.other.executeCommand.title")))
          ]),
          _vm._v(" "),
          _c("p", { staticClass: "secondary-text" }, [
            _vm._v(_vm._s(_vm.$t("settings.other.executeCommand.description")))
          ]),
          _vm._v(" "),
          _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model",
                value: _vm.settings.executeCommand,
                expression: "settings.executeCommand"
              }
            ],
            attrs: { type: "text" },
            domProps: { value: _vm.settings.executeCommand },
            on: {
              input: function($event) {
                if ($event.target.composing) {
                  return
                }
                _vm.$set(_vm.settings, "executeCommand", $event.target.value);
              }
            }
          })
        ])
      ]),
      _vm._v(" "),
      _c("div", { staticClass: "settings-group" }, [
        _c(
          "h3",
          {
            staticClass:
              "settings-group__header settings-group__header--with-icon"
          },
          [
            _c(
              "svg",
              {
                attrs: {
                  id: "spotify_icon",
                  "enable-background": "new 0 0 24 24",
                  viewBox: "0 0 24 24",
                  xmlns: "http://www.w3.org/2000/svg"
                }
              },
              [
                _c("path", {
                  attrs: {
                    d:
                      "m12 24c6.624 0 12-5.376 12-12s-5.376-12-12-12-12 5.376-12 12 5.376 12 12 12zm4.872-6.344v.001c-.807 0-3.356-2.828-10.52-1.36-.189.049-.436.126-.576.126-.915 0-1.09-1.369-.106-1.578 3.963-.875 8.013-.798 11.467 1.268.824.526.474 1.543-.265 1.543zm1.303-3.173c-.113-.03-.08.069-.597-.203-3.025-1.79-7.533-2.512-11.545-1.423-.232.063-.358.126-.576.126-1.071 0-1.355-1.611-.188-1.94 4.716-1.325 9.775-.552 13.297 1.543.392.232.547.533.547.953-.005.522-.411.944-.938.944zm-13.627-7.485c4.523-1.324 11.368-.906 15.624 1.578 1.091.629.662 2.22-.498 2.22l-.001-.001c-.252 0-.407-.063-.625-.189-3.443-2.056-9.604-2.549-13.59-1.436-.175.048-.393.125-.625.125-.639 0-1.127-.499-1.127-1.142 0-.657.407-1.029.842-1.155z"
                  }
                })
              ]
            ),
            _vm._v(
              "\n\t\t\t" + _vm._s(_vm.$t("settings.spotify.title")) + "\n\t\t"
            )
          ]
        ),
        _vm._v(" "),
        _c(
          "a",
          {
            attrs: {
              href:
                "https://codeberg.org/RemixDev/deemix/wiki/Enabling-Spotify-Features",
              target: "_blank"
            }
          },
          [
            _vm._v(
              "\n\t\t\t" +
                _vm._s(_vm.$t("settings.spotify.question")) +
                "\n\t\t"
            )
          ]
        ),
        _vm._v(" "),
        _c("div", { staticClass: "input_group" }, [
          _c("p", { staticClass: "input_group_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.spotify.clientID")))
          ]),
          _vm._v(" "),
          _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model",
                value: _vm.spotifyFeatures.clientId,
                expression: "spotifyFeatures.clientId"
              }
            ],
            attrs: { type: "text" },
            domProps: { value: _vm.spotifyFeatures.clientId },
            on: {
              input: function($event) {
                if ($event.target.composing) {
                  return
                }
                _vm.$set(_vm.spotifyFeatures, "clientId", $event.target.value);
              }
            }
          })
        ]),
        _vm._v(" "),
        _c("div", { staticClass: "input_group" }, [
          _c("p", { staticClass: "input_group_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.spotify.clientSecret")))
          ]),
          _vm._v(" "),
          _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model",
                value: _vm.spotifyFeatures.clientSecret,
                expression: "spotifyFeatures.clientSecret"
              }
            ],
            attrs: { type: "password" },
            domProps: { value: _vm.spotifyFeatures.clientSecret },
            on: {
              input: function($event) {
                if ($event.target.composing) {
                  return
                }
                _vm.$set(
                  _vm.spotifyFeatures,
                  "clientSecret",
                  $event.target.value
                );
              }
            }
          })
        ]),
        _vm._v(" "),
        _c("div", { staticClass: "input_group" }, [
          _c("p", { staticClass: "input_group_text" }, [
            _vm._v(_vm._s(_vm.$t("settings.spotify.username")))
          ]),
          _vm._v(" "),
          _c("input", {
            directives: [
              {
                name: "model",
                rawName: "v-model",
                value: _vm.spotifyUser,
                expression: "spotifyUser"
              }
            ],
            attrs: { type: "text" },
            domProps: { value: _vm.spotifyUser },
            on: {
              input: function($event) {
                if ($event.target.composing) {
                  return
                }
                _vm.spotifyUser = $event.target.value;
              }
            }
          })
        ])
      ]),
      _vm._v(" "),
      _c("footer", [
        _c(
          "button",
          {
            staticClass: "mr-2 btn btn-primary",
            on: { click: _vm.resetSettings }
          },
          [_vm._v(_vm._s(_vm.$t("settings.reset")))]
        ),
        _vm._v(" "),
        _c(
          "button",
          { staticClass: "btn btn-primary", on: { click: _vm.saveSettings } },
          [_vm._v(_vm._s(_vm.$t("settings.save")))]
        )
      ])
    ]
  )
};
var __vue_staticRenderFns__$q = [];
__vue_render__$q._withStripped = true;

  /* style */
  const __vue_inject_styles__$q = function (inject) {
    if (!inject) return
    inject("data-v-1a543a48_0", { source: "#logged_in_info {\n  height: 250px;\n  display: flex;\n  flex-direction: column;\n  justify-content: space-evenly;\n  align-items: center;\n}\n.locale-flag {\n  width: 60px;\n  display: inline-flex;\n  justify-content: center;\n  align-items: center;\n  cursor: pointer;\n}\n.locale-flag:not(:last-child) {\n    margin-right: 10px;\n}\n.locale-flag.locale-flag--current svg {\n    filter: brightness(1);\n}\n.locale-flag svg {\n    width: 40px !important;\n    height: 40px !important;\n    filter: brightness(0.5);\n}\n\n/*# sourceMappingURL=Settings.vue.map */", map: {"version":3,"sources":["C:\\Users\\Roberto\\Dev\\repos\\deemix-pyweb\\webui\\src\\components\\pages\\Settings.vue","Settings.vue"],"names":[],"mappings":"AAmnBA;EACA,aAAA;EACA,aAAA;EACA,sBAAA;EACA,6BAAA;EACA,mBAAA;AAAA;AAGA;EACA,WAAA;EACA,oBAAA;EACA,uBAAA;EACA,mBAAA;EACA,eAAA;AAAA;AALA;IAQA,kBAAA;AAAA;AARA;IAaA,qBAAA;AAAA;AAbA;IAkBA,sBAAA;IACA,uBAAA;IACA,uBAAA;AAAA;;ACznBA,uCAAuC","file":"Settings.vue","sourcesContent":["<template>\r\n\t<div id=\"settings_tab\" class=\"fixed_footer\" ref=\"root\">\r\n\t\t<h1 class=\"mb-8 text-5xl\">{{ $t('settings.title') }}</h1>\r\n\r\n\t\t<div id=\"logged_in_info\" v-if=\"isLoggedIn\" ref=\"loggedInInfo\">\r\n\t\t\t<img id=\"settings_picture\" :src=\"pictureHref\" alt=\"Profile Picture\" ref=\"userpicture\" class=\"circle\" />\r\n\r\n\t\t\t<i18n path=\"settings.login.loggedIn\" tag=\"p\">\r\n\t\t\t\t<strong place=\"username\" id=\"settings_username\" ref=\"username\">{{ user.name || 'not logged' }}</strong>\r\n\t\t\t</i18n>\r\n\r\n\t\t\t<button class=\"btn btn-primary\" id=\"settings_btn_logout\" @click=\"logout\">\r\n\t\t\t\t{{ $t('settings.login.logout') }}\r\n\t\t\t</button>\r\n\r\n\t\t\t<select v-if=\"accounts.length\" id=\"family_account\" v-model=\"accountNum\" @change=\"changeAccount\">\r\n\t\t\t\t<option v-for=\"(account, i) in accounts\" :key=\"account\" :value=\"i.toString()\">{{ account.BLOG_NAME }}</option>\r\n\t\t\t</select>\r\n\t\t</div>\r\n\r\n\t\t<div class=\"settings-group\">\r\n\t\t\t<h3 class=\"settings-group__header settings-group__header--with-icon\">\r\n\t\t\t\t<i class=\"material-icons\">person</i>{{ $t('settings.login.title') }}\r\n\t\t\t</h3>\r\n\t\t\t<div class=\"inline-flex\">\r\n\t\t\t\t<input\r\n\t\t\t\t\tautocomplete=\"off\"\r\n\t\t\t\t\ttype=\"password\"\r\n\t\t\t\t\t:value=\"arl\"\r\n\t\t\t\t\tid=\"login_input_arl\"\r\n\t\t\t\t\tref=\"loginInput\"\r\n\t\t\t\t\tplaceholder=\"ARL\"\r\n\t\t\t\t/>\r\n\t\t\t\t<button id=\"settings_btn_copyArl\" class=\"ml-2 btn btn-primary btn-only-icon\" @click=\"copyARLtoClipboard\">\r\n\t\t\t\t\t<i class=\"material-icons\">assignment</i>\r\n\t\t\t\t</button>\r\n\t\t\t</div>\r\n\t\t\t<a href=\"https://codeberg.org/RemixDev/deemix/wiki/Getting-your-own-ARL\" target=\"_blank\">\r\n\t\t\t\t{{ $t('settings.login.arl.question') }}\r\n\t\t\t</a>\r\n\t\t\t<a id=\"settings_btn_applogin\" v-if=\"clientMode\" href=\"#\" @click=\"appLogin\">\r\n\t\t\t\t{{ $t('settings.login.login') }}\r\n\t\t\t</a>\r\n\t\t\t<button class=\"btn btn-primary\" id=\"settings_btn_updateArl\" @click=\"login\" style=\"width: 100%\">\r\n\t\t\t\t{{ $t('settings.login.arl.update') }}\r\n\t\t\t</button>\r\n\t\t</div>\r\n\r\n\t\t<div class=\"settings-group\">\r\n\t\t\t<h3 class=\"settings-group__header settings-group__header--with-icon\">\r\n\t\t\t\t<i class=\"material-icons\">language</i>{{ $t('settings.languages') }}\r\n\t\t\t</h3>\r\n\t\t\t<div>\r\n\t\t\t\t<span\r\n\t\t\t\t\tv-for=\"locale in locales\"\r\n\t\t\t\t\t:key=\"locale\"\r\n\t\t\t\t\tclass=\"locale-flag\"\r\n\t\t\t\t\t:class=\"{ 'locale-flag--current': currentLocale === locale }\"\r\n\t\t\t\t\t@click=\"changeLocale(locale)\"\r\n\t\t\t\t\tv-html=\"flags[locale]\"\r\n\t\t\t\t\t:title=\"locale\"\r\n\t\t\t\t>\r\n\t\t\t\t</span>\r\n\t\t\t</div>\r\n\t\t</div>\r\n\r\n\t\t<div class=\"settings-group\">\r\n\t\t\t<h3 class=\"settings-group__header settings-group__header--with-icon\">\r\n\t\t\t\t<i class=\"material-icons\">web</i>{{ $t('settings.appearance.title') }}\r\n\t\t\t</h3>\r\n\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t<input type=\"checkbox\" v-model=\"changeSlimDownloads\" />\r\n\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.appearance.slimDownloadTab') }}</span>\r\n\t\t\t</label>\r\n\t\t</div>\r\n\r\n\t\t<div class=\"settings-group\">\r\n\t\t\t<h3 class=\"settings-group__header settings-group__header--with-icon\">\r\n\t\t\t\t<i class=\"material-icons\">folder</i>{{ $t('settings.downloadPath.title') }}\r\n\t\t\t</h3>\r\n\t\t\t<div class=\"inline-flex\">\r\n\t\t\t\t<input autocomplete=\"off\" type=\"text\" v-model=\"settings.downloadLocation\" />\r\n\t\t\t\t<button\r\n\t\t\t\t\tid=\"select_downloads_folder\"\r\n\t\t\t\t\tv-if=\"clientMode\"\r\n\t\t\t\t\tclass=\"ml-2 btn btn-primary btn-only-icon\"\r\n\t\t\t\t\t@click=\"selectDownloadFolder\"\r\n\t\t\t\t>\r\n\t\t\t\t\t<i class=\"material-icons\">folder</i>\r\n\t\t\t\t</button>\r\n\t\t\t</div>\r\n\t\t</div>\r\n\r\n\t\t<div class=\"settings-group\">\r\n\t\t\t<h3 class=\"settings-group__header settings-group__header--with-icon\">\r\n\t\t\t\t<i class=\"material-icons\">font_download</i>{{ $t('settings.templates.title') }}\r\n\t\t\t</h3>\r\n\r\n\t\t\t<p>{{ $t('settings.templates.tracknameTemplate') }}</p>\r\n\t\t\t<input type=\"text\" v-model=\"settings.tracknameTemplate\" />\r\n\r\n\t\t\t<p>{{ $t('settings.templates.albumTracknameTemplate') }}</p>\r\n\t\t\t<input type=\"text\" v-model=\"settings.albumTracknameTemplate\" />\r\n\r\n\t\t\t<p>{{ $t('settings.templates.playlistTracknameTemplate') }}</p>\r\n\t\t\t<input type=\"text\" v-model=\"settings.playlistTracknameTemplate\" />\r\n\t\t</div>\r\n\r\n\t\t<div class=\"settings-group\">\r\n\t\t\t<h3 class=\"settings-group__header settings-group__header--with-icon\">\r\n\t\t\t\t<i class=\"material-icons\">create_new_folder</i>{{ $t('settings.folders.title') }}\r\n\t\t\t</h3>\r\n\t\t\t<div class=\"settings-container\">\r\n\t\t\t\t<div class=\"settings-container__third\">\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.createPlaylistFolder\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.folders.createPlaylistFolder') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t\t<div class=\"input_group\" v-if=\"settings.createPlaylistFolder\">\r\n\t\t\t\t\t\t<p class=\"input_group_text\">{{ $t('settings.folders.playlistNameTemplate') }}</p>\r\n\t\t\t\t\t\t<input type=\"text\" v-model=\"settings.playlistNameTemplate\" />\r\n\t\t\t\t\t</div>\r\n\t\t\t\t</div>\r\n\t\t\t\t<div class=\"settings-container__third\">\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.createArtistFolder\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.folders.createArtistFolder') }}</span>\r\n\t\t\t\t\t</label>\r\n\r\n\t\t\t\t\t<div class=\"input_group\" v-if=\"settings.createArtistFolder\">\r\n\t\t\t\t\t\t<p class=\"input_group_text\">{{ $t('settings.folders.artistNameTemplate') }}</p>\r\n\t\t\t\t\t\t<input type=\"text\" v-model=\"settings.artistNameTemplate\" />\r\n\t\t\t\t\t</div>\r\n\t\t\t\t</div>\r\n\t\t\t\t<div class=\"settings-container__third\">\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.createAlbumFolder\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.folders.createAlbumFolder') }}</span>\r\n\t\t\t\t\t</label>\r\n\r\n\t\t\t\t\t<div class=\"input_group\" v-if=\"settings.createAlbumFolder\">\r\n\t\t\t\t\t\t<p class=\"input_group_text\">{{ $t('settings.folders.albumNameTemplate') }}</p>\r\n\t\t\t\t\t\t<input type=\"text\" v-model=\"settings.albumNameTemplate\" />\r\n\t\t\t\t\t</div>\r\n\t\t\t\t</div>\r\n\t\t\t</div>\r\n\r\n\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t<input type=\"checkbox\" v-model=\"settings.createCDFolder\" />\r\n\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.folders.createCDFolder') }}</span>\r\n\t\t\t</label>\r\n\r\n\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t<input type=\"checkbox\" v-model=\"settings.createStructurePlaylist\" />\r\n\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.folders.createStructurePlaylist') }}</span>\r\n\t\t\t</label>\r\n\r\n\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t<input type=\"checkbox\" v-model=\"settings.createSingleFolder\" />\r\n\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.folders.createSingleFolder') }}</span>\r\n\t\t\t</label>\r\n\t\t</div>\r\n\r\n\t\t<div class=\"settings-group\">\r\n\t\t\t<h3 class=\"settings-group__header settings-group__header--with-icon\">\r\n\t\t\t\t<i class=\"material-icons\">title</i>{{ $t('settings.trackTitles.title') }}\r\n\t\t\t</h3>\r\n\r\n\t\t\t<div class=\"settings-container\">\r\n\t\t\t\t<div class=\"settings-container__third settings-container__third--only-checkbox\">\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.padTracks\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.trackTitles.padTracks') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t</div>\r\n\t\t\t\t<div class=\"settings-container__third\">\r\n\t\t\t\t\t<div class=\"input_group\">\r\n\t\t\t\t\t\t<p class=\"input_group_text\">{{ $t('settings.trackTitles.paddingSize') }}</p>\r\n\t\t\t\t\t\t<input max=\"10\" type=\"number\" v-model=\"settings.paddingSize\" />\r\n\t\t\t\t\t</div>\r\n\t\t\t\t</div>\r\n\t\t\t\t<div class=\"settings-container__third\">\r\n\t\t\t\t\t<div class=\"input_group\">\r\n\t\t\t\t\t\t<p class=\"input_group_text\">{{ $t('settings.trackTitles.illegalCharacterReplacer') }}</p>\r\n\t\t\t\t\t\t<input type=\"text\" v-model=\"settings.illegalCharacterReplacer\" />\r\n\t\t\t\t\t</div>\r\n\t\t\t\t</div>\r\n\t\t\t</div>\r\n\t\t</div>\r\n\r\n\t\t<div class=\"settings-group\">\r\n\t\t\t<h3 class=\"settings-group__header settings-group__header--with-icon\">\r\n\t\t\t\t<i class=\"material-icons\">get_app</i>{{ $t('settings.downloads.title') }}\r\n\t\t\t</h3>\r\n\r\n\t\t\t<div class=\"input_group\">\r\n\t\t\t\t<p class=\"input_group_text\">{{ $t('settings.downloads.queueConcurrency') }}</p>\r\n\t\t\t\t<input type=\"number\" min=\"1\" v-model.number=\"settings.queueConcurrency\" />\r\n\t\t\t</div>\r\n\r\n\t\t\t<div class=\"input_group\">\r\n\t\t\t\t<p class=\"input_group_text\">{{ $t('settings.downloads.maxBitrate.title') }}</p>\r\n\t\t\t\t<select v-model=\"settings.maxBitrate\">\r\n\t\t\t\t\t<option value=\"9\">{{ $t('settings.downloads.maxBitrate.9') }}</option>\r\n\t\t\t\t\t<option value=\"3\">{{ $t('settings.downloads.maxBitrate.3') }}</option>\r\n\t\t\t\t\t<option value=\"1\">{{ $t('settings.downloads.maxBitrate.1') }}</option>\r\n\t\t\t\t</select>\r\n\t\t\t</div>\r\n\r\n\t\t\t<div class=\"input_group\">\r\n\t\t\t\t<p class=\"input_group_text\">{{ $t('settings.downloads.overwriteFile.title') }}</p>\r\n\t\t\t\t<select v-model=\"settings.overwriteFile\">\r\n\t\t\t\t\t<option value=\"y\">{{ $t('settings.downloads.overwriteFile.y') }}</option>\r\n\t\t\t\t\t<option value=\"n\">{{ $t('settings.downloads.overwriteFile.n') }}</option>\r\n\t\t\t\t\t<option value=\"e\">{{ $t('settings.downloads.overwriteFile.e') }}</option>\r\n\t\t\t\t\t<option value=\"b\">{{ $t('settings.downloads.overwriteFile.b') }}</option>\r\n\t\t\t\t\t<option value=\"t\">{{ $t('settings.downloads.overwriteFile.t') }}</option>\r\n\t\t\t\t</select>\r\n\t\t\t</div>\r\n\r\n\t\t\t<div class=\"settings-container\">\r\n\t\t\t\t<div class=\"settings-container__third settings-container__third--only-checkbox\">\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.fallbackBitrate\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.downloads.fallbackBitrate') }}</span>\r\n\t\t\t\t\t</label>\r\n\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.fallbackSearch\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.downloads.fallbackSearch') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t</div>\r\n\t\t\t\t<div class=\"settings-container__third settings-container__third--only-checkbox\">\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.logErrors\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.downloads.logErrors') }}</span>\r\n\t\t\t\t\t</label>\r\n\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.logSearched\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.downloads.logSearched') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t</div>\r\n\t\t\t\t<div class=\"settings-container__third settings-container__third--only-checkbox\">\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.syncedLyrics\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.downloads.syncedLyrics') }}</span>\r\n\t\t\t\t\t</label>\r\n\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.createM3U8File\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.downloads.createM3U8File') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t</div>\r\n\t\t\t</div>\r\n\r\n\t\t\t<div class=\"input_group\" v-if=\"settings.createM3U8File\">\r\n\t\t\t\t<p class=\"input_group_text\">{{ $t('settings.downloads.playlistFilenameTemplate') }}</p>\r\n\t\t\t\t<input type=\"text\" v-model=\"settings.playlistFilenameTemplate\" />\r\n\t\t\t</div>\r\n\r\n\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t<input type=\"checkbox\" v-model=\"settings.saveDownloadQueue\" />\r\n\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.downloads.saveDownloadQueue') }}</span>\r\n\t\t\t</label>\r\n\t\t</div>\r\n\r\n\t\t<div class=\"settings-group\">\r\n\t\t\t<h3 class=\"settings-group__header settings-group__header--with-icon\">\r\n\t\t\t\t<i class=\"material-icons\">album</i>{{ $t('settings.covers.title') }}\r\n\t\t\t</h3>\r\n\r\n\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t<input type=\"checkbox\" v-model=\"settings.saveArtwork\" />\r\n\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.covers.saveArtwork') }}</span>\r\n\t\t\t</label>\r\n\r\n\t\t\t<div class=\"input_group\" v-if=\"settings.saveArtwork\">\r\n\t\t\t\t<p class=\"input_group_text\">{{ $t('settings.covers.coverImageTemplate') }}</p>\r\n\t\t\t\t<input type=\"text\" v-model=\"settings.coverImageTemplate\" />\r\n\t\t\t</div>\r\n\r\n\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t<input type=\"checkbox\" v-model=\"settings.saveArtworkArtist\" />\r\n\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.covers.saveArtworkArtist') }}</span>\r\n\t\t\t</label>\r\n\r\n\t\t\t<div class=\"input_group\" v-if=\"settings.saveArtworkArtist\">\r\n\t\t\t\t<p class=\"input_group_text\">{{ $t('settings.covers.artistImageTemplate') }}</p>\r\n\t\t\t\t<input type=\"text\" v-model=\"settings.artistImageTemplate\" />\r\n\t\t\t</div>\r\n\r\n\t\t\t<div class=\"input_group\">\r\n\t\t\t\t<p class=\"input_group_text\">{{ $t('settings.covers.localArtworkSize') }}</p>\r\n\t\t\t\t<input type=\"number\" min=\"100\" max=\"10000\" step=\"100\" v-model.number=\"settings.localArtworkSize\" />\r\n\t\t\t\t<p v-if=\"settings.localArtworkSize > 1200\" class=\"input_group_text\" style=\"opacity: 0.75; color: #ffcc22\">\r\n\t\t\t\t\t⚠️ {{ $t('settings.covers.imageSizeWarning') }}\r\n\t\t\t\t</p>\r\n\t\t\t</div>\r\n\r\n\t\t\t<div class=\"input_group\">\r\n\t\t\t\t<p class=\"input_group_text\">{{ $t('settings.covers.embeddedArtworkSize') }}</p>\r\n\t\t\t\t<input type=\"number\" min=\"100\" max=\"10000\" step=\"100\" v-model.number=\"settings.embeddedArtworkSize\" />\r\n\t\t\t\t<p v-if=\"settings.embeddedArtworkSize > 1200\" class=\"input_group_text\" style=\"opacity: 0.75; color: #ffcc22\">\r\n\t\t\t\t\t⚠️ {{ $t('settings.covers.imageSizeWarning') }}\r\n\t\t\t\t</p>\r\n\t\t\t</div>\r\n\r\n\t\t\t<div class=\"input_group\">\r\n\t\t\t\t<p class=\"input_group_text\">{{ $t('settings.covers.localArtworkFormat.title') }}</p>\r\n\t\t\t\t<select v-model=\"settings.localArtworkFormat\">\r\n\t\t\t\t\t<option value=\"jpg\">{{ $t('settings.covers.localArtworkFormat.jpg') }}</option>\r\n\t\t\t\t\t<option value=\"png\">{{ $t('settings.covers.localArtworkFormat.png') }}</option>\r\n\t\t\t\t\t<option value=\"jpg,png\">{{ $t('settings.covers.localArtworkFormat.both') }}</option>\r\n\t\t\t\t</select>\r\n\t\t\t</div>\r\n\r\n\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t<input type=\"checkbox\" v-model=\"settings.embeddedArtworkPNG\" />\r\n\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.covers.embeddedArtworkPNG') }}</span>\r\n\t\t\t</label>\r\n\t\t\t<p v-if=\"settings.embeddedArtworkPNG\" style=\"opacity: 0.75; color: #ffcc22\">\r\n\t\t\t\t⚠️ {{ $t('settings.covers.embeddedPNGWarning') }}\r\n\t\t\t</p>\r\n\r\n\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.coverDescriptionUTF8\" />\r\n\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.covers.coverDescriptionUTF8') }}</span>\r\n\t\t\t</label>\r\n\r\n\t\t\t<div class=\"input_group\">\r\n\t\t\t\t<p class=\"input_group_text\">{{ $t('settings.covers.jpegImageQuality') }}</p>\r\n\t\t\t\t<input type=\"number\" min=\"1\" max=\"100\" v-model.number=\"settings.jpegImageQuality\" />\r\n\t\t\t</div>\r\n\t\t</div>\r\n\r\n\t\t<div class=\"settings-group\">\r\n\t\t\t<h3 class=\"settings-group__header settings-group__header--with-icon\">\r\n\t\t\t\t<i class=\"material-icons\" style=\"width: 1em; height: 1em\">bookmarks</i>{{ $t('settings.tags.head') }}\r\n\t\t\t</h3>\r\n\r\n\t\t\t<div class=\"settings-container\">\r\n\t\t\t\t<div class=\"settings-container__half\">\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.title\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.tags.title') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.artist\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.tags.artist') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.album\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.tags.album') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.cover\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.tags.cover') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.trackNumber\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.tags.trackNumber') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.trackTotal\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.tags.trackTotal') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.discNumber\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.tags.discNumber') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.discTotal\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.tags.discTotal') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.albumArtist\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.tags.albumArtist') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.genre\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.tags.genre') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.year\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.tags.year') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.date\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.tags.date') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t</div>\r\n\r\n\t\t\t\t<div class=\"settings-container__half\">\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.explicit\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.tags.explicit') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.isrc\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.tags.isrc') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.length\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.tags.length') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.barcode\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.tags.barcode') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.bpm\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.tags.bpm') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.replayGain\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.tags.replayGain') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.label\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.tags.label') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.lyrics\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.tags.lyrics') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.syncedLyrics\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.tags.syncedLyrics') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.copyright\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.tags.copyright') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.composer\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.tags.composer') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.involvedPeople\" />\r\n\t\t\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.tags.involvedPeople') }}</span>\r\n\t\t\t\t\t</label>\r\n\t\t\t\t</div>\r\n\t\t\t</div>\r\n\t\t</div>\r\n\r\n\t\t<div class=\"settings-group\">\r\n\t\t\t<h3 class=\"settings-group__header settings-group__header--with-icon\">\r\n\t\t\t\t<i class=\"material-icons\">list</i>{{ $t('settings.other.title') }}\r\n\t\t\t</h3>\r\n\r\n\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.savePlaylistAsCompilation\" />\r\n\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.other.savePlaylistAsCompilation') }}</span>\r\n\t\t\t</label>\r\n\r\n\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.useNullSeparator\" />\r\n\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.other.useNullSeparator') }}</span>\r\n\t\t\t</label>\r\n\r\n\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.saveID3v1\" />\r\n\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.other.saveID3v1') }}</span>\r\n\t\t\t</label>\r\n\r\n\t\t\t<div class=\"input_group\">\r\n\t\t\t\t<p class=\"input_group_text\">{{ $t('settings.other.multiArtistSeparator.title') }}</p>\r\n\t\t\t\t<select v-model=\"settings.tags.multiArtistSeparator\">\r\n\t\t\t\t\t<option value=\"nothing\">{{ $t('settings.other.multiArtistSeparator.nothing') }}</option>\r\n\t\t\t\t\t<option value=\"default\">{{ $t('settings.other.multiArtistSeparator.default') }}</option>\r\n\t\t\t\t\t<option value=\"andFeat\">{{ $t('settings.other.multiArtistSeparator.andFeat') }}</option>\r\n\t\t\t\t\t<option value=\" & \">{{ $t('settings.other.multiArtistSeparator.using', { separator: ' & ' }) }}</option>\r\n\t\t\t\t\t<option value=\",\">{{ $t('settings.other.multiArtistSeparator.using', { separator: ',' }) }}</option>\r\n\t\t\t\t\t<option value=\", \">{{ $t('settings.other.multiArtistSeparator.using', { separator: ', ' }) }}</option>\r\n\t\t\t\t\t<option value=\"/\">{{ $t('settings.other.multiArtistSeparator.using', { separator: '/' }) }}</option>\r\n\t\t\t\t\t<option value=\" / \">{{ $t('settings.other.multiArtistSeparator.using', { separator: ' / ' }) }}</option>\r\n\t\t\t\t\t<option value=\";\">{{ $t('settings.other.multiArtistSeparator.using', { separator: ';' }) }}</option>\r\n\t\t\t\t\t<option value=\"; \">{{ $t('settings.other.multiArtistSeparator.using', { separator: '; ' }) }}</option>\r\n\t\t\t\t</select>\r\n\t\t\t</div>\r\n\r\n\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t<input type=\"checkbox\" v-model=\"settings.tags.singleAlbumArtist\" />\r\n\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.other.singleAlbumArtist') }}</span>\r\n\t\t\t</label>\r\n\r\n\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t<input type=\"checkbox\" v-model=\"settings.albumVariousArtists\" />\r\n\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.other.albumVariousArtists') }}</span>\r\n\t\t\t</label>\r\n\r\n\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t<input type=\"checkbox\" v-model=\"settings.removeAlbumVersion\" />\r\n\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.other.removeAlbumVersion') }}</span>\r\n\t\t\t</label>\r\n\r\n\t\t\t<label class=\"with_checkbox\">\r\n\t\t\t\t<input type=\"checkbox\" v-model=\"settings.removeDuplicateArtists\" />\r\n\t\t\t\t<span class=\"checkbox_text\">{{ $t('settings.other.removeDuplicateArtists') }}</span>\r\n\t\t\t</label>\r\n\r\n\t\t\t<div class=\"input_group\">\r\n\t\t\t\t<p class=\"input_group_text\">{{ $t('settings.other.dateFormat.title') }}</p>\r\n\t\t\t\t<select v-model=\"settings.dateFormat\">\r\n\t\t\t\t\t<option value=\"Y-M-D\">\r\n\t\t\t\t\t\t{{\r\n\t\t\t\t\t\t\t`${$t('settings.other.dateFormat.year')}-${$t('settings.other.dateFormat.month')}-${$t(\r\n\t\t\t\t\t\t\t\t'settings.other.dateFormat.day'\r\n\t\t\t\t\t\t\t)}`\r\n\t\t\t\t\t\t}}\r\n\t\t\t\t\t</option>\r\n\t\t\t\t\t<option value=\"Y-D-M\">\r\n\t\t\t\t\t\t{{\r\n\t\t\t\t\t\t\t`${$t('settings.other.dateFormat.year')}-${$t('settings.other.dateFormat.day')}-${$t(\r\n\t\t\t\t\t\t\t\t'settings.other.dateFormat.month'\r\n\t\t\t\t\t\t\t)}`\r\n\t\t\t\t\t\t}}\r\n\t\t\t\t\t</option>\r\n\t\t\t\t\t<option value=\"D-M-Y\">\r\n\t\t\t\t\t\t{{\r\n\t\t\t\t\t\t\t`${$t('settings.other.dateFormat.day')}-${$t('settings.other.dateFormat.month')}-${$t(\r\n\t\t\t\t\t\t\t\t'settings.other.dateFormat.year'\r\n\t\t\t\t\t\t\t)}`\r\n\t\t\t\t\t\t}}\r\n\t\t\t\t\t</option>\r\n\t\t\t\t\t<option value=\"M-D-Y\">\r\n\t\t\t\t\t\t{{\r\n\t\t\t\t\t\t\t`${$t('settings.other.dateFormat.month')}-${$t('settings.other.dateFormat.day')}-${$t(\r\n\t\t\t\t\t\t\t\t'settings.other.dateFormat.year'\r\n\t\t\t\t\t\t\t)}`\r\n\t\t\t\t\t\t}}\r\n\t\t\t\t\t</option>\r\n\t\t\t\t\t<option value=\"Y\">{{ $t('settings.other.dateFormat.year') }}</option>\r\n\t\t\t\t</select>\r\n\t\t\t</div>\r\n\r\n\t\t\t<div class=\"input_group\">\r\n\t\t\t\t<p class=\"input_group_text\">{{ $t('settings.other.featuredToTitle.title') }}</p>\r\n\t\t\t\t<select v-model=\"settings.featuredToTitle\">\r\n\t\t\t\t\t<option value=\"0\">{{ $t('settings.other.featuredToTitle.0') }}</option>\r\n\t\t\t\t\t<option value=\"1\">{{ $t('settings.other.featuredToTitle.1') }}</option>\r\n\t\t\t\t\t<option value=\"3\">{{ $t('settings.other.featuredToTitle.3') }}</option>\r\n\t\t\t\t\t<option value=\"2\">{{ $t('settings.other.featuredToTitle.2') }}</option>\r\n\t\t\t\t</select>\r\n\t\t\t</div>\r\n\r\n\t\t\t<div class=\"input_group\">\r\n\t\t\t\t<p class=\"input_group_text\">{{ $t('settings.other.titleCasing') }}</p>\r\n\t\t\t\t<select v-model=\"settings.titleCasing\">\r\n\t\t\t\t\t<option value=\"nothing\">{{ $t('settings.other.casing.nothing') }}</option>\r\n\t\t\t\t\t<option value=\"lower\">{{ $t('settings.other.casing.lower') }}</option>\r\n\t\t\t\t\t<option value=\"upper\">{{ $t('settings.other.casing.upper') }}</option>\r\n\t\t\t\t\t<option value=\"start\">{{ $t('settings.other.casing.start') }}</option>\r\n\t\t\t\t\t<option value=\"sentence\">{{ $t('settings.other.casing.sentence') }}</option>\r\n\t\t\t\t</select>\r\n\t\t\t</div>\r\n\r\n\t\t\t<div class=\"input_group\">\r\n\t\t\t\t<p class=\"input_group_text\">{{ $t('settings.other.artistCasing') }}</p>\r\n\t\t\t\t<select v-model=\"settings.artistCasing\">\r\n\t\t\t\t\t<option value=\"nothing\">{{ $t('settings.other.casing.nothing') }}</option>\r\n\t\t\t\t\t<option value=\"lower\">{{ $t('settings.other.casing.lower') }}</option>\r\n\t\t\t\t\t<option value=\"upper\">{{ $t('settings.other.casing.upper') }}</option>\r\n\t\t\t\t\t<option value=\"start\">{{ $t('settings.other.casing.start') }}</option>\r\n\t\t\t\t\t<option value=\"sentence\">{{ $t('settings.other.casing.sentence') }}</option>\r\n\t\t\t\t</select>\r\n\t\t\t</div>\r\n\r\n\t\t\t<div class=\"input_group\">\r\n\t\t\t\t<p class=\"input_group_text\">{{ $t('settings.other.previewVolume') }}</p>\r\n\t\t\t\t<input\r\n\t\t\t\t\ttype=\"range\"\r\n\t\t\t\t\t@change=\"updateMaxVolume\"\r\n\t\t\t\t\tmin=\"0\"\r\n\t\t\t\t\tmax=\"100\"\r\n\t\t\t\t\tstep=\"1\"\r\n\t\t\t\t\tclass=\"slider\"\r\n\t\t\t\t\tv-model.number=\"previewVolume.preview_max_volume\"\r\n\t\t\t\t/>\r\n\t\t\t\t<span>{{ previewVolume.preview_max_volume }}%</span>\r\n\t\t\t</div>\r\n\r\n\t\t\t<div class=\"input_group\">\r\n\t\t\t\t<p class=\"input_group_text\">{{ $t('settings.other.executeCommand.title') }}</p>\r\n\t\t\t\t<p class=\"secondary-text\">{{ $t('settings.other.executeCommand.description') }}</p>\r\n\t\t\t\t<input type=\"text\" v-model=\"settings.executeCommand\" />\r\n\t\t\t</div>\r\n\t\t</div>\r\n\r\n\t\t<div class=\"settings-group\">\r\n\t\t\t<h3 class=\"settings-group__header settings-group__header--with-icon\">\r\n\t\t\t\t<svg id=\"spotify_icon\" enable-background=\"new 0 0 24 24\" viewBox=\"0 0 24 24\" xmlns=\"http://www.w3.org/2000/svg\">\r\n\t\t\t\t\t<path\r\n\t\t\t\t\t\td=\"m12 24c6.624 0 12-5.376 12-12s-5.376-12-12-12-12 5.376-12 12 5.376 12 12 12zm4.872-6.344v.001c-.807 0-3.356-2.828-10.52-1.36-.189.049-.436.126-.576.126-.915 0-1.09-1.369-.106-1.578 3.963-.875 8.013-.798 11.467 1.268.824.526.474 1.543-.265 1.543zm1.303-3.173c-.113-.03-.08.069-.597-.203-3.025-1.79-7.533-2.512-11.545-1.423-.232.063-.358.126-.576.126-1.071 0-1.355-1.611-.188-1.94 4.716-1.325 9.775-.552 13.297 1.543.392.232.547.533.547.953-.005.522-.411.944-.938.944zm-13.627-7.485c4.523-1.324 11.368-.906 15.624 1.578 1.091.629.662 2.22-.498 2.22l-.001-.001c-.252 0-.407-.063-.625-.189-3.443-2.056-9.604-2.549-13.59-1.436-.175.048-.393.125-.625.125-.639 0-1.127-.499-1.127-1.142 0-.657.407-1.029.842-1.155z\"\r\n\t\t\t\t\t/>\r\n\t\t\t\t</svg>\r\n\t\t\t\t{{ $t('settings.spotify.title') }}\r\n\t\t\t</h3>\r\n\t\t\t<a href=\"https://codeberg.org/RemixDev/deemix/wiki/Enabling-Spotify-Features\" target=\"_blank\">\r\n\t\t\t\t{{ $t('settings.spotify.question') }}\r\n\t\t\t</a>\r\n\r\n\t\t\t<div class=\"input_group\">\r\n\t\t\t\t<p class=\"input_group_text\">{{ $t('settings.spotify.clientID') }}</p>\r\n\t\t\t\t<input type=\"text\" v-model=\"spotifyFeatures.clientId\" />\r\n\t\t\t</div>\r\n\r\n\t\t\t<div class=\"input_group\">\r\n\t\t\t\t<p class=\"input_group_text\">{{ $t('settings.spotify.clientSecret') }}</p>\r\n\t\t\t\t<input type=\"password\" v-model=\"spotifyFeatures.clientSecret\" />\r\n\t\t\t</div>\r\n\r\n\t\t\t<div class=\"input_group\">\r\n\t\t\t\t<p class=\"input_group_text\">{{ $t('settings.spotify.username') }}</p>\r\n\t\t\t\t<input type=\"text\" v-model=\"spotifyUser\" />\r\n\t\t\t</div>\r\n\t\t</div>\r\n\r\n\t\t<footer>\r\n\t\t\t<button class=\"mr-2 btn btn-primary\" @click=\"resetSettings\">{{ $t('settings.reset') }}</button>\r\n\t\t\t<button class=\"btn btn-primary\" @click=\"saveSettings\">{{ $t('settings.save') }}</button>\r\n\t\t</footer>\r\n\t</div>\r\n</template>\r\n\r\n<style lang=\"scss\">\r\n#logged_in_info {\r\n\theight: 250px;\r\n\tdisplay: flex;\r\n\tflex-direction: column;\r\n\tjustify-content: space-evenly;\r\n\talign-items: center;\r\n}\r\n\r\n.locale-flag {\r\n\twidth: 60px;\r\n\tdisplay: inline-flex;\r\n\tjustify-content: center;\r\n\talign-items: center;\r\n\tcursor: pointer;\r\n\r\n\t&:not(:last-child) {\r\n\t\tmargin-right: 10px;\r\n\t}\r\n\r\n\t&.locale-flag--current {\r\n\t\tsvg {\r\n\t\t\tfilter: brightness(1);\r\n\t\t}\r\n\t}\r\n\r\n\tsvg {\r\n\t\twidth: 40px !important;\r\n\t\theight: 40px !important;\r\n\t\tfilter: brightness(0.5);\r\n\t}\r\n}\r\n</style>\r\n\r\n<script>\r\nimport { mapActions, mapGetters } from 'vuex'\r\n\r\nimport { getSettingsData } from '@/data/settings'\r\n\r\nimport { toast } from '@/utils/toasts'\r\nimport { socket } from '@/utils/socket'\r\nimport { flags } from '@/utils/flags'\r\n\r\nexport default {\r\n\tdata() {\r\n\t\treturn {\r\n\t\t\tflags,\r\n\t\t\tcurrentLocale: this.$i18n.locale,\r\n\t\t\tlocales: this.$i18n.availableLocales,\r\n\t\t\tsettings: {\r\n\t\t\t\ttags: {}\r\n\t\t\t},\r\n\t\t\tlastSettings: {},\r\n\t\t\tspotifyFeatures: {},\r\n\t\t\tlastCredentials: {},\r\n\t\t\tdefaultSettings: {},\r\n\t\t\tlastUser: '',\r\n\t\t\tspotifyUser: '',\r\n\t\t\tslimDownloads: false,\r\n\t\t\tpreviewVolume: window.vol,\r\n\t\t\taccountNum: 0,\r\n\t\t\taccounts: []\r\n\t\t}\r\n\t},\r\n\tcomputed: {\r\n\t\t...mapGetters({\r\n\t\t\tarl: 'getARL',\r\n\t\t\tuser: 'getUser',\r\n\t\t\tisLoggedIn: 'isLoggedIn',\r\n\t\t\tclientMode: 'getClientMode'\r\n\t\t}),\r\n\t\tneedToWait() {\r\n\t\t\treturn Object.keys(this.getSettings).length === 0\r\n\t\t},\r\n\t\tchangeSlimDownloads: {\r\n\t\t\tget() {\r\n\t\t\t\treturn this.slimDownloads\r\n\t\t\t},\r\n\t\t\tset(wantSlimDownloads) {\r\n\t\t\t\tthis.slimDownloads = wantSlimDownloads\r\n\t\t\t\tdocument.getElementById('download_list').classList.toggle('slim', wantSlimDownloads)\r\n\t\t\t\tlocalStorage.setItem('slimDownloads', wantSlimDownloads)\r\n\t\t\t}\r\n\t\t},\r\n\t\tpictureHref() {\r\n\t\t\t// Default image: https://e-cdns-images.dzcdn.net/images/user/125x125-000000-80-0-0.jpg\r\n\t\t\treturn `https://e-cdns-images.dzcdn.net/images/user/${this.user.picture}/125x125-000000-80-0-0.jpg`\r\n\t\t}\r\n\t},\r\n\tasync mounted() {\r\n\t\tconst { settingsData, defaultSettingsData, spotifyCredentials } = await getSettingsData()\r\n\r\n\t\tthis.defaultSettings = defaultSettingsData\r\n\t\tthis.initSettings(settingsData, spotifyCredentials)\r\n\r\n\t\tlet storedAccountNum = localStorage.getItem('accountNum')\r\n\r\n\t\tif (storedAccountNum) {\r\n\t\t\tthis.accountNum = storedAccountNum\r\n\t\t}\r\n\r\n\t\tlet spotifyUser = localStorage.getItem('spotifyUser')\r\n\r\n\t\tif (spotifyUser) {\r\n\t\t\tthis.lastUser = spotifyUser\r\n\t\t\tthis.spotifyUser = spotifyUser\r\n\t\t\tsocket.emit('update_userSpotifyPlaylists', spotifyUser)\r\n\t\t}\r\n\r\n\t\tthis.changeSlimDownloads = 'true' === localStorage.getItem('slimDownloads')\r\n\r\n\t\tlet volume = parseInt(localStorage.getItem('previewVolume'))\r\n\r\n\t\tif (isNaN(volume)) {\r\n\t\t\tvolume = 80\r\n\t\t\tlocalStorage.setItem('previewVolume', volume)\r\n\t\t}\r\n\r\n\t\twindow.vol.preview_max_volume = volume\r\n\r\n\t\tsocket.on('updateSettings', this.updateSettings)\r\n\t\tsocket.on('accountChanged', this.accountChanged)\r\n\t\tsocket.on('familyAccounts', this.initAccounts)\r\n\t\tsocket.on('downloadFolderSelected', this.downloadFolderSelected)\r\n\t\tsocket.on('applogin_arl', this.loggedInViaDeezer)\r\n\r\n\t\tthis.$on('hook:destroyed', () => {\r\n\t\t\tsocket.off('updateSettings')\r\n\t\t\tsocket.off('accountChanged')\r\n\t\t\tsocket.off('familyAccounts')\r\n\t\t\tsocket.off('downloadFolderSelected')\r\n\t\t\tsocket.off('applogin_arl')\r\n\t\t})\r\n\t},\r\n\tmethods: {\r\n\t\t...mapActions({\r\n\t\t\tdispatchARL: 'setARL'\r\n\t\t}),\r\n\t\trevertSettings() {\r\n\t\t\tthis.settings = JSON.parse(JSON.stringify(this.lastSettings))\r\n\t\t},\r\n\t\trevertCredentials() {\r\n\t\t\tthis.spotifyCredentials = JSON.parse(JSON.stringify(this.lastCredentials))\r\n\t\t\tthis.spotifyUser = (' ' + this.lastUser).slice(1)\r\n\t\t},\r\n\t\tcopyARLtoClipboard() {\r\n\t\t\tlet copyText = this.$refs.loginInput\r\n\r\n\t\t\tcopyText.setAttribute('type', 'text')\r\n\t\t\tcopyText.select()\r\n\t\t\tcopyText.setSelectionRange(0, 99999)\r\n\t\t\tdocument.execCommand('copy')\r\n\t\t\tcopyText.setAttribute('type', 'password')\r\n\r\n\t\t\ttoast(this.$t('settings.toasts.ARLcopied'), 'assignment')\r\n\t\t},\r\n\t\tchangeLocale(newLocale) {\r\n\t\t\tthis.$i18n.locale = newLocale\r\n\t\t\tthis.currentLocale = newLocale\r\n\t\t\tlocalStorage.setItem('locale', newLocale)\r\n\t\t},\r\n\t\tupdateMaxVolume() {\r\n\t\t\tlocalStorage.setItem('previewVolume', this.previewVolume.preview_max_volume)\r\n\t\t},\r\n\t\tsaveSettings() {\r\n\t\t\tthis.lastSettings = JSON.parse(JSON.stringify(this.settings))\r\n\t\t\tthis.lastCredentials = JSON.parse(JSON.stringify(this.spotifyFeatures))\r\n\r\n\t\t\tlet changed = false\r\n\r\n\t\t\tif (this.lastUser != this.spotifyUser) {\r\n\t\t\t\t// force cloning without linking\r\n\t\t\t\tthis.lastUser = (' ' + this.spotifyUser).slice(1)\r\n\t\t\t\tlocalStorage.setItem('spotifyUser', this.lastUser)\r\n\t\t\t\tchanged = true\r\n\t\t\t}\r\n\r\n\t\t\tsocket.emit('saveSettings', this.lastSettings, this.lastCredentials, changed ? this.lastUser : false)\r\n\t\t},\r\n\t\tselectDownloadFolder() {\r\n\t\t\tsocket.emit('selectDownloadFolder')\r\n\t\t},\r\n\t\tdownloadFolderSelected(folder) {\r\n\t\t\tthis.$set(this.settings, 'downloadLocation', folder)\r\n\t\t},\r\n\t\tloadSettings(data) {\r\n\t\t\tthis.lastSettings = JSON.parse(JSON.stringify(data))\r\n\t\t\tthis.settings = JSON.parse(JSON.stringify(data))\r\n\t\t},\r\n\t\tloadCredentials(credentials) {\r\n\t\t\tthis.lastCredentials = JSON.parse(JSON.stringify(credentials))\r\n\t\t\tthis.spotifyFeatures = JSON.parse(JSON.stringify(credentials))\r\n\t\t},\r\n\t\tloggedInViaDeezer(arl) {\r\n\t\t\tthis.dispatchARL({ arl })\r\n\t\t\tsocket.emit('login', arl, true, this.accountNum)\r\n\t\t\t// this.login()\r\n\t\t},\r\n\t\tlogin() {\r\n\t\t\tlet newArl = this.$refs.loginInput.value.trim()\r\n\r\n\t\t\tif (newArl && newArl !== this.arl) {\r\n\t\t\t\tsocket.emit('login', newArl, true, this.accountNum)\r\n\t\t\t}\r\n\t\t},\r\n\t\tappLogin(e) {\r\n\t\t\tsocket.emit('applogin')\r\n\t\t},\r\n\t\tchangeAccount() {\r\n\t\t\tsocket.emit('changeAccount', this.accountNum)\r\n\t\t},\r\n\t\taccountChanged(user, accountNum) {\r\n\t\t\tthis.$refs.username.innerText = user.name\r\n\t\t\tthis.$refs.userpicture.src = `https://e-cdns-images.dzcdn.net/images/user/${user.picture}/125x125-000000-80-0-0.jpg`\r\n\t\t\tthis.accountNum = accountNum\r\n\r\n\t\t\tlocalStorage.setItem('accountNum', this.accountNum)\r\n\t\t},\r\n\t\tinitAccounts(accounts) {\r\n\t\t\tthis.accounts = accounts\r\n\t\t},\r\n\t\tlogout() {\r\n\t\t\tsocket.emit('logout')\r\n\t\t},\r\n\t\tinitSettings(settings, credentials) {\r\n\t\t\t// this.loadDefaultSettings()\r\n\t\t\tthis.loadSettings(settings)\r\n\t\t\tthis.loadCredentials(credentials)\r\n\r\n\t\t\ttoast(this.$t('settings.toasts.init'), 'settings')\r\n\t\t},\r\n\t\tupdateSettings(newSettings, newCredentials) {\r\n\t\t\tthis.loadSettings(newSettings)\r\n\t\t\tthis.loadCredentials(newCredentials)\r\n\r\n\t\t\ttoast(this.$t('settings.toasts.update'), 'settings')\r\n\t\t},\r\n\t\tresetSettings() {\r\n\t\t\tthis.settings = JSON.parse(JSON.stringify(this.defaultSettings))\r\n\t\t}\r\n\t}\r\n}\r\n</script>\r\n","#logged_in_info {\n  height: 250px;\n  display: flex;\n  flex-direction: column;\n  justify-content: space-evenly;\n  align-items: center; }\n\n.locale-flag {\n  width: 60px;\n  display: inline-flex;\n  justify-content: center;\n  align-items: center;\n  cursor: pointer; }\n  .locale-flag:not(:last-child) {\n    margin-right: 10px; }\n  .locale-flag.locale-flag--current svg {\n    filter: brightness(1); }\n  .locale-flag svg {\n    width: 40px !important;\n    height: 40px !important;\n    filter: brightness(0.5); }\n\n/*# sourceMappingURL=Settings.vue.map */"]}, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$q = undefined;
  /* module identifier */
  const __vue_module_identifier__$q = undefined;
  /* functional template */
  const __vue_is_functional_template__$q = false;
  /* style inject SSR */
  

  
  var Settings = normalizeComponent_1(
    { render: __vue_render__$q, staticRenderFns: __vue_staticRenderFns__$q },
    __vue_inject_styles__$q,
    __vue_script__$p,
    __vue_scope_id__$q,
    __vue_is_functional_template__$q,
    __vue_module_identifier__$q,
    browser,
    undefined
  );

//

var script$q = {
	data() {
		return {
			title: '',
			metadata: '',
			release_date: '',
			label: '',
			explicit: false,
			image: '',
			type: 'empty',
			link: '',
			body: []
		}
	},
	mounted() {
		EventBus.$on('tracklistTab:selectRow', this.selectRow);

		socket.on('show_album', this.showAlbum);
		socket.on('show_playlist', this.showPlaylist);
		socket.on('show_spotifyplaylist', this.showSpotifyPlaylist);
	},
	methods: {
		playPausePreview(e) {
			EventBus.$emit('trackPreview:playPausePreview', e);
		},
		reset() {
			this.title = 'Loading...';
			this.image = '';
			this.metadata = '';
			this.label = '';
			this.release_date = '';
			this.explicit = false;
			this.type = 'empty';
			this.body = [];
		},
		addToQueue(e) {
			Downloads.sendAddToQueue(e.currentTarget.dataset.link);
		},
		toggleAll(e) {
			this.body.forEach(item => {
				if (item.type == 'track') {
					item.selected = e.currentTarget.checked;
				}
			});
		},
		selectedLinks() {
			var selected = [];
			if (this.body) {
				this.body.forEach(item => {
					if (item.type == 'track' && item.selected)
						selected.push(this.type == 'spotifyPlaylist' ? item.uri : item.link);
				});
			}
			return selected.join(';')
		},
		convertDuration: Utils.convertDuration,
		showAlbum(data) {
			this.reset();

			const {
				id: albumID,
				title: albumTitle,
				explicit_lyrics,
				label: albumLabel,
				artist: { name: artistName },
				tracks: albumTracks,
				tracks: { length: numberOfTracks },
				release_date,
				cover_xl
			} = data;

			this.type = 'album';
			this.link = `https://www.deezer.com/album/${albumID}`;
			this.title = albumTitle;
			this.explicit = explicit_lyrics;
			this.label = albumLabel;
			this.metadata = `${artistName} • ${this.$tc('globals.listTabs.trackN', numberOfTracks)}`;
			this.release_date = release_date.substring(0, 10);
			this.image = cover_xl;

			if (isEmpty(albumTracks)) {
				this.body = null;
			} else {
				this.body = albumTracks;
			}
		},
		showPlaylist(data) {
			this.reset();

			const {
				id: playlistID,
				title: playlistTitle,
				picture_xl: playlistCover,
				creation_date,
				creator: { name: creatorName },
				tracks: playlistTracks,
				tracks: { length: numberOfTracks }
			} = data;

			this.type = 'playlist';
			this.link = `https://www.deezer.com/playlist/${playlistID}`;
			this.title = playlistTitle;
			this.image = playlistCover;
			this.release_date = creation_date.substring(0, 10);
			this.metadata = `${this.$t('globals.by', { artist: creatorName })} • ${this.$tc(
				'globals.listTabs.trackN',
				numberOfTracks
			)}`;

			if (isEmpty(playlistTracks)) {
				this.body = null;
			} else {
				this.body = playlistTracks;
			}
		},
		showSpotifyPlaylist(data) {
			this.reset();

			const {
				uri: playlistURI,
				name: playlistName,
				images,
				images: { length: numberOfImages },
				owner: { display_name: ownerName },
				tracks: playlistTracks,
				tracks: { length: numberOfTracks }
			} = data;

			this.type = 'spotifyPlaylist';
			this.link = playlistURI;
			this.title = playlistName;
			this.image = numberOfImages
				? images[0].url
				: 'https://e-cdns-images.dzcdn.net/images/cover/d41d8cd98f00b204e9800998ecf8427e/1000x1000-000000-80-0-0.jpg';
			this.release_date = '';
			this.metadata = `${this.$t('globals.by', { artist: ownerName })} • ${this.$tc(
				'globals.listTabs.trackN',
				numberOfTracks
			)}`;

			if (isEmpty(playlistTracks)) {
				this.body = null;
			} else {
				this.body = playlistTracks;
			}
		},
		selectRow(index, track) {
			track.selected = !track.selected;
		}
	}
};

/* script */
const __vue_script__$q = script$q;

/* template */
var __vue_render__$r = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c(
    "div",
    { ref: "root", staticClass: "relative fixed_footer image_header" },
    [
      _c(
        "header",
        {
          style: {
            "background-image":
              "linear-gradient(to bottom, transparent 0%, var(--main-background) 100%), url('" +
              _vm.image +
              "')"
          }
        },
        [
          _c("h1", { staticClass: "inline-flex m-0 text-5xl" }, [
            _vm._v("\n\t\t\t" + _vm._s(_vm.title) + " "),
            _vm.explicit
              ? _c(
                  "i",
                  {
                    staticClass:
                      "material-icons explicit_icon explicit_icon--right"
                  },
                  [_vm._v("explicit")]
                )
              : _vm._e()
          ]),
          _vm._v(" "),
          _c("h2", { staticClass: "m-0 mb-3 text-lg" }, [
            _vm.metadata ? _c("p", [_vm._v(_vm._s(_vm.metadata))]) : _vm._e(),
            _vm._v(" "),
            _vm.release_date
              ? _c("p", [_vm._v(_vm._s(_vm.release_date))])
              : _vm._e()
          ])
        ]
      ),
      _vm._v(" "),
      _c("table", { staticClass: "table table--tracklist" }, [
        _c("thead", [
          _c("tr", [
            _vm._m(0),
            _vm._v(" "),
            _c("th", [_vm._v("#")]),
            _vm._v(" "),
            _c("th", [_vm._v(_vm._s(_vm.$tc("globals.listTabs.title", 1)))]),
            _vm._v(" "),
            _c("th", [_vm._v(_vm._s(_vm.$tc("globals.listTabs.artist", 1)))]),
            _vm._v(" "),
            _vm.type === "playlist"
              ? _c("th", [_vm._v(_vm._s(_vm.$tc("globals.listTabs.album", 1)))])
              : _vm._e(),
            _vm._v(" "),
            _vm._m(1),
            _vm._v(" "),
            _c(
              "th",
              { staticClass: "table__icon table__cell--center clickable" },
              [
                _c("input", {
                  staticClass: "selectAll",
                  attrs: { type: "checkbox" },
                  on: { click: _vm.toggleAll }
                })
              ]
            )
          ])
        ]),
        _vm._v(" "),
        _c(
          "tbody",
          [
            _vm.type !== "spotifyPlaylist"
              ? [
                  _vm._l(_vm.body, function(track, index) {
                    return [
                      track.type == "track"
                        ? _c(
                            "tr",
                            {
                              on: {
                                click: function($event) {
                                  return _vm.selectRow(index, track)
                                }
                              }
                            },
                            [
                              _c(
                                "td",
                                {
                                  staticClass:
                                    "table__cell--x-small table__cell--center"
                                },
                                [
                                  _c(
                                    "div",
                                    {
                                      staticClass:
                                        "table__cell-content table__cell-content--vertical-center"
                                    },
                                    [
                                      _c(
                                        "i",
                                        _vm._g(
                                          {
                                            staticClass: "material-icons",
                                            class: {
                                              preview_playlist_controls:
                                                track.preview,
                                              "cursor-pointer": track.preview,
                                              disabled: !track.preview
                                            },
                                            attrs: {
                                              "data-preview": track.preview,
                                              title: _vm.$t("globals.play_hint")
                                            }
                                          },
                                          {
                                            click: track.preview
                                              ? _vm.playPausePreview
                                              : false
                                          }
                                        ),
                                        [
                                          _vm._v(
                                            "\n\t\t\t\t\t\t\t\t\tplay_arrow\n\t\t\t\t\t\t\t\t"
                                          )
                                        ]
                                      )
                                    ]
                                  )
                                ]
                              ),
                              _vm._v(" "),
                              _c(
                                "td",
                                {
                                  staticClass:
                                    "table__cell--small table__cell--center track_position"
                                },
                                [
                                  _vm._v(
                                    "\n\t\t\t\t\t\t\t" +
                                      _vm._s(
                                        _vm.type === "album"
                                          ? track.track_position
                                          : _vm.body.indexOf(track) + 1
                                      ) +
                                      "\n\t\t\t\t\t\t"
                                  )
                                ]
                              ),
                              _vm._v(" "),
                              _c(
                                "td",
                                {
                                  staticClass:
                                    "table__cell--large table__cell--with-icon"
                                },
                                [
                                  _c(
                                    "div",
                                    {
                                      staticClass:
                                        "table__cell-content table__cell-content--vertical-center"
                                    },
                                    [
                                      track.explicit_lyrics
                                        ? _c(
                                            "i",
                                            {
                                              staticClass:
                                                "material-icons explicit_icon"
                                            },
                                            [_vm._v(" explicit ")]
                                          )
                                        : _vm._e(),
                                      _vm._v(
                                        "\n\t\t\t\t\t\t\t\t" +
                                          _vm._s(
                                            track.title +
                                              (track.title_version &&
                                              track.title.indexOf(
                                                track.title_version
                                              ) == -1
                                                ? " " + track.title_version
                                                : "")
                                          ) +
                                          "\n\t\t\t\t\t\t\t"
                                      )
                                    ]
                                  )
                                ]
                              ),
                              _vm._v(" "),
                              _c(
                                "router-link",
                                {
                                  staticClass:
                                    "table__cell--medium table__cell--center clickable",
                                  attrs: {
                                    tag: "td",
                                    to: {
                                      name: "Artist",
                                      params: { id: track.artist.id }
                                    }
                                  }
                                },
                                [
                                  _vm._v(
                                    "\n\t\t\t\t\t\t\t" +
                                      _vm._s(track.artist.name) +
                                      "\n\t\t\t\t\t\t"
                                  )
                                ]
                              ),
                              _vm._v(" "),
                              _vm.type === "playlist"
                                ? _c(
                                    "router-link",
                                    {
                                      staticClass:
                                        "table__cell--medium table__cell--center clickable",
                                      attrs: {
                                        tag: "td",
                                        to: {
                                          name: "Album",
                                          params: { id: track.album.id }
                                        }
                                      }
                                    },
                                    [
                                      _vm._v(
                                        "\n\t\t\t\t\t\t\t" +
                                          _vm._s(track.album.title) +
                                          "\n\t\t\t\t\t\t"
                                      )
                                    ]
                                  )
                                : _vm._e(),
                              _vm._v(" "),
                              _c(
                                "td",
                                {
                                  staticClass: "table__cell--center",
                                  class: {
                                    "table__cell--small": _vm.type === "album",
                                    "table__cell--x-small":
                                      _vm.type === "playlist"
                                  }
                                },
                                [
                                  _vm._v(
                                    "\n\t\t\t\t\t\t\t" +
                                      _vm._s(
                                        _vm.convertDuration(track.duration)
                                      ) +
                                      "\n\t\t\t\t\t\t"
                                  )
                                ]
                              ),
                              _vm._v(" "),
                              _c(
                                "td",
                                {
                                  staticClass: "table__icon table__cell--center"
                                },
                                [
                                  _c("input", {
                                    directives: [
                                      {
                                        name: "model",
                                        rawName: "v-model",
                                        value: track.selected,
                                        expression: "track.selected"
                                      }
                                    ],
                                    staticClass: "clickable",
                                    attrs: { type: "checkbox" },
                                    domProps: {
                                      checked: Array.isArray(track.selected)
                                        ? _vm._i(track.selected, null) > -1
                                        : track.selected
                                    },
                                    on: {
                                      change: function($event) {
                                        var $$a = track.selected,
                                          $$el = $event.target,
                                          $$c = $$el.checked ? true : false;
                                        if (Array.isArray($$a)) {
                                          var $$v = null,
                                            $$i = _vm._i($$a, $$v);
                                          if ($$el.checked) {
                                            $$i < 0 &&
                                              _vm.$set(
                                                track,
                                                "selected",
                                                $$a.concat([$$v])
                                              );
                                          } else {
                                            $$i > -1 &&
                                              _vm.$set(
                                                track,
                                                "selected",
                                                $$a
                                                  .slice(0, $$i)
                                                  .concat($$a.slice($$i + 1))
                                              );
                                          }
                                        } else {
                                          _vm.$set(track, "selected", $$c);
                                        }
                                      }
                                    }
                                  })
                                ]
                              )
                            ],
                            1
                          )
                        : track.type == "disc_separator"
                        ? _c(
                            "tr",
                            {
                              staticClass: "table__row-no-highlight",
                              staticStyle: { opacity: "0.54" }
                            },
                            [
                              _vm._m(2, true),
                              _vm._v(" "),
                              _c("td", { staticClass: "table__cell--center" }, [
                                _vm._v(
                                  "\n\t\t\t\t\t\t\t" +
                                    _vm._s(track.number) +
                                    "\n\t\t\t\t\t\t"
                                )
                              ]),
                              _vm._v(" "),
                              _c("td", { attrs: { colspan: "4" } })
                            ]
                          )
                        : _vm._e()
                    ]
                  })
                ]
              : _vm._l(_vm.body, function(track, i) {
                  return _c("tr", [
                    _c("td", [
                      track.preview_url
                        ? _c(
                            "i",
                            {
                              staticClass: "material-icons",
                              class: {
                                preview_playlist_controls: track.preview_url,
                                "cursor-pointer": track.preview_url
                              },
                              attrs: {
                                "data-preview": track.preview_url,
                                title: _vm.$t("globals.play_hint")
                              },
                              on: { click: _vm.playPausePreview }
                            },
                            [_vm._v("\n\t\t\t\t\t\t\tplay_arrow\n\t\t\t\t\t\t")]
                          )
                        : _c("i", { staticClass: "material-icons disabled" }, [
                            _vm._v("play_arrow")
                          ])
                    ]),
                    _vm._v(" "),
                    _c("td", [_vm._v(_vm._s(i + 1))]),
                    _vm._v(" "),
                    _c("td", { staticClass: "inline-flex" }, [
                      track.explicit
                        ? _c(
                            "i",
                            { staticClass: "material-icons explicit_icon" },
                            [_vm._v("explicit")]
                          )
                        : _vm._e(),
                      _vm._v(
                        "\n\t\t\t\t\t\t" + _vm._s(track.name) + "\n\t\t\t\t\t"
                      )
                    ]),
                    _vm._v(" "),
                    _c("td", [_vm._v(_vm._s(track.artists[0].name))]),
                    _vm._v(" "),
                    _c("td", [_vm._v(_vm._s(track.album.name))]),
                    _vm._v(" "),
                    _c("td", [
                      _vm._v(
                        _vm._s(
                          _vm.convertDuration(
                            Math.floor(track.duration_ms / 1000)
                          )
                        )
                      )
                    ]),
                    _vm._v(" "),
                    _c("td", [
                      _c("input", {
                        directives: [
                          {
                            name: "model",
                            rawName: "v-model",
                            value: track.selected,
                            expression: "track.selected"
                          }
                        ],
                        staticClass: "clickable",
                        attrs: { type: "checkbox" },
                        domProps: {
                          checked: Array.isArray(track.selected)
                            ? _vm._i(track.selected, null) > -1
                            : track.selected
                        },
                        on: {
                          change: function($event) {
                            var $$a = track.selected,
                              $$el = $event.target,
                              $$c = $$el.checked ? true : false;
                            if (Array.isArray($$a)) {
                              var $$v = null,
                                $$i = _vm._i($$a, $$v);
                              if ($$el.checked) {
                                $$i < 0 &&
                                  _vm.$set(track, "selected", $$a.concat([$$v]));
                              } else {
                                $$i > -1 &&
                                  _vm.$set(
                                    track,
                                    "selected",
                                    $$a.slice(0, $$i).concat($$a.slice($$i + 1))
                                  );
                              }
                            } else {
                              _vm.$set(track, "selected", $$c);
                            }
                          }
                        }
                      })
                    ])
                  ])
                })
          ],
          2
        )
      ]),
      _vm._v(" "),
      _vm.label
        ? _c(
            "span",
            {
              staticStyle: {
                opacity: "0.4",
                "margin-top": "8px",
                display: "inline-block",
                "font-size": "13px"
              }
            },
            [_vm._v(_vm._s(_vm.label))]
          )
        : _vm._e(),
      _vm._v(" "),
      _c("footer", [
        _c(
          "button",
          {
            staticClass: "mr-2 btn btn-primary",
            attrs: { "data-link": _vm.link },
            on: {
              click: function($event) {
                $event.stopPropagation();
                return _vm.addToQueue($event)
              }
            }
          },
          [
            _vm._v(
              "\n\t\t\t" +
                _vm._s(
                  "" +
                    _vm.$t("globals.download", {
                      thing: _vm.$tc("globals.listTabs." + _vm.type, 1)
                    })
                ) +
                "\n\t\t"
            )
          ]
        ),
        _vm._v(" "),
        _c(
          "button",
          {
            staticClass: "flex items-center btn btn-primary",
            attrs: { "data-link": _vm.selectedLinks() },
            on: {
              click: function($event) {
                $event.stopPropagation();
                return _vm.addToQueue($event)
              }
            }
          },
          [
            _vm._v("\n\t\t\t" + _vm._s(_vm.$t("tracklist.downloadSelection"))),
            _c("i", { staticClass: "ml-2 material-icons" }, [
              _vm._v("file_download")
            ])
          ]
        )
      ])
    ]
  )
};
var __vue_staticRenderFns__$r = [
  function() {
    var _vm = this;
    var _h = _vm.$createElement;
    var _c = _vm._self._c || _h;
    return _c("th", [
      _c("i", { staticClass: "material-icons" }, [_vm._v("music_note")])
    ])
  },
  function() {
    var _vm = this;
    var _h = _vm.$createElement;
    var _c = _vm._self._c || _h;
    return _c("th", [
      _c("i", { staticClass: "material-icons" }, [_vm._v("timer")])
    ])
  },
  function() {
    var _vm = this;
    var _h = _vm.$createElement;
    var _c = _vm._self._c || _h;
    return _c("td", [
      _c(
        "div",
        {
          staticClass:
            "table__cell-content table__cell-content--vertical-center",
          staticStyle: { opacity: "0.54" }
        },
        [_c("i", { staticClass: "material-icons" }, [_vm._v("album")])]
      )
    ])
  }
];
__vue_render__$r._withStripped = true;

  /* style */
  const __vue_inject_styles__$r = undefined;
  /* scoped */
  const __vue_scope_id__$r = undefined;
  /* module identifier */
  const __vue_module_identifier__$r = undefined;
  /* functional template */
  const __vue_is_functional_template__$r = false;
  /* style inject */
  
  /* style inject SSR */
  

  
  var Tracklist = normalizeComponent_1(
    { render: __vue_render__$r, staticRenderFns: __vue_staticRenderFns__$r },
    __vue_inject_styles__$r,
    __vue_script__$q,
    __vue_scope_id__$r,
    __vue_is_functional_template__$r,
    __vue_module_identifier__$r,
    undefined,
    undefined
  );

Vue.use(VueRouter);

const routes = [
	{
		path: '/',
		name: 'Home',
		component: Home,
		meta: {
			notKeepAlive: true
		}
	},
	{
		path: '/tracklist/:type/:id',
		name: 'Tracklist',
		component: Tracklist
	},
	{
		path: '/artist/:id',
		name: 'Artist',
		component: Artist
	},
	{
		path: '/album/:id',
		name: 'Album',
		component: Tracklist
	},
	{
		path: '/playlist/:id',
		name: 'Playlist',
		component: Tracklist
	},
	{
		path: '/spotify-playlist/:id',
		name: 'Spotify Playlist',
		component: Tracklist
	},
	{
		path: '/charts',
		name: 'Charts',
		component: Charts,
		meta: {
			notKeepAlive: true
		}
	},
	{
		path: '/favorites',
		name: 'Favorites',
		component: Favorites,
		meta: {
			notKeepAlive: true
		}
	},
	{
		path: '/errors',
		name: 'Errors',
		component: Errors
	},
	{
		path: '/link-analyzer',
		name: 'Link Analyzer',
		component: LinkAnalyzer
	},
	{
		path: '/about',
		name: 'About',
		component: About
	},
	{
		path: '/settings',
		name: 'Settings',
		component: Settings
	},
	{
		path: '/search',
		name: 'Search',
		component: Search
	},
	// 404 client side
	{
		path: '*',
		component: Home
	}
];

const router = new VueRouter({
	mode: 'history',
	// linkActiveClass: 'open',
	routes,
	scrollBehavior(to, from, savedPosition) {
		return { x: 0, y: 0 }
	}
});

router.beforeEach((to, from, next) => {
	let getTracklistParams = null;

	switch (to.name) {
		case 'Artist':
			getTracklistParams = {
				type: 'artist',
				id: to.params.id
			};
			break
		case 'Tracklist':
			getTracklistParams = {
				type: to.params.type,
				id: to.params.id
			};
			break
		case 'Album':
			getTracklistParams = {
				type: 'album',
				id: to.params.id
			};
			break
		case 'Playlist':
			getTracklistParams = {
				type: 'playlist',
				id: to.params.id
			};
			break
		case 'Spotify Playlist':
			getTracklistParams = {
				type: 'spotifyplaylist',
				id: to.params.id
			};
			break
	}

	if (getTracklistParams) {
		socket.emit('getTracklist', getTracklistParams);
	}

	next();
});

// Object is needed for vue change detection
window.vol = {
	preview_max_volume: 100
};

/* ===== App initialization ===== */
function startApp() {
	new Vue({
		store,
		router,
		i18n,
		render: h => h(App)
	}).$mount('#app');
}

function initClient() {
	store.dispatch('setClientMode', true);
	setClientModeKeyBindings();
}

document.addEventListener('DOMContentLoaded', startApp);
window.addEventListener('pywebviewready', initClient);

/* ===== Global shortcuts ===== */

document.addEventListener('paste', pasteEvent => {
	if (pasteEvent.target.localName === 'input') return

	let pastedText = pasteEvent.clipboardData.getData('Text');

	if (isValidURL(pastedText)) {
		if (router.currentRoute.name === 'Link Analyzer') {
			socket.emit('analyzeLink', pastedText);
		} else {
			sendAddToQueue(pastedText);
		}
	} else {
		let searchbar = document.querySelector('#searchbar');
		searchbar.select();
		searchbar.setSelectionRange(0, 99999);
	}
});

/**
 * Sets up key bindings that already work in the browser (server mode)
 */
function setClientModeKeyBindings() {
	document.addEventListener('keyup', keyEvent => {
		// ALT + left
		if (keyEvent.altKey && keyEvent.key === 'ArrowLeft') {
			router.back();
		}

		// ALT + right
		if (keyEvent.altKey && keyEvent.key === 'ArrowRight') {
			router.forward();
		}
	});
}

/* ===== Socketio listeners ===== */

// Debug messages for socketio
socket.on('message', function(msg) {
	console.log(msg);
});

socket.on('logging_in', function() {
	toast(i18n.t('toasts.loggingIn'), 'loading', false, 'login-toast');
});

socket.on('init_autologin', function() {
	let arl = localStorage.getItem('arl');
	let accountNum = localStorage.getItem('accountNum');

	if (arl) {
		arl = arl.trim();

		if (accountNum != 0) {
			socket.emit('login', arl, true, accountNum);
		} else {
			socket.emit('login', arl);
		}
	}
});

socket.on('logged_in', function(data) {
	const { status, user } = data;

	switch (status) {
		case 1:
		case 3:
			// Login ok
			toast(i18n.t('toasts.loggedIn'), 'done', true, 'login-toast');

			store.dispatch('login', data);
			break
		case 2:
			// Already logged in
			toast(i18n.t('toasts.alreadyLogged'), 'done', true, 'login-toast');

			store.dispatch('setUser', user);
			break
		case 0:
			// Login failed
			toast(i18n.t('toasts.loginFailed'), 'close', true, 'login-toast');

			store.dispatch('removeARL');
			break
		case -1:
			toast(i18n.t('toasts.deezerNotAvailable'), 'close', true, 'login-toast');
			return
		// TODO
		// $('#open_login_prompt').show()
		// document.getElementById('logged_in_info').classList.add('hide')
		// $('#settings_username').text('Not Logged')
		// $('#settings_picture').attr('src', `https://e-cdns-images.dzcdn.net/images/user/125x125-000000-80-0-0.jpg`)
		// document.getElementById('home_not_logged_in').classList.remove('hide')
	}
});

socket.on('logged_out', function() {
	toast(i18n.t('toasts.loggedOut'), 'done', true, 'login-toast');

	store.dispatch('logout');
});

socket.on('restoringQueue', function() {
	toast(i18n.t('toasts.restoringQueue'), 'loading', false, 'restoring_queue');
});

socket.on('cancellingCurrentItem', function(uuid) {
	toast(i18n.t('toasts.cancellingCurrentItem'), 'loading', false, 'cancelling_' + uuid);
});

socket.on('currentItemCancelled', function(uuid) {
	toast(i18n.t('toasts.currentItemCancelled'), 'done', true, 'cancelling_' + uuid);
});

socket.on('startAddingArtist', function(data) {
	toast(i18n.t('toasts.startAddingArtist', { artist: data.name }), 'loading', false, 'artist_' + data.id);
});

socket.on('finishAddingArtist', function(data) {
	toast(i18n.t('toasts.finishAddingArtist', { artist: data.name }), 'done', true, 'artist_' + data.id);
});

socket.on('startConvertingSpotifyPlaylist', function(id) {
	toast(i18n.t('toasts.startConvertingSpotifyPlaylist'), 'loading', false, 'spotifyplaylist_' + id);
});

socket.on('finishConvertingSpotifyPlaylist', function(id) {
	toast(i18n.t('toasts.finishConvertingSpotifyPlaylist'), 'done', true, 'spotifyplaylist_' + id);
});

socket.on('errorMessage', function(error) {
	toast(error, 'error');
});

socket.on('queueError', function(queueItem) {
	if (queueItem.errid) {
		toast(queueItem.link+ " - " +i18n.t(`errors.ids.${queueItem.errid}`), 'error');
	} else {
		toast(queueItem.link+ " - " +queueItem.error, 'error');
	}
});

socket.on('alreadyInQueue', function(data) {
	toast(i18n.t('toasts.alreadyInQueue', { item: data.title }), 'playlist_add_check');
});

socket.on('loginNeededToDownload', function(data) {
	toast(i18n.t('toasts.loginNeededToDownload'), 'report');
});

socket.on('startGeneratingItems', function(data) {
	toast(i18n.t('toasts.startGeneratingItems', { n: data.total }), 'loading', false, 'batch_' + data.uuid);
});

socket.on('finishGeneratingItems', function(data) {
	toast(i18n.t('toasts.finishGeneratingItems', { n: data.total }), 'done', true, 'batch_' + data.uuid);
});
//# sourceMappingURL=bundle.js.map
